/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [],
        "extra_compile_args": [
            "-DSYSLOG_NAMES=1"
        ],
        "libraries": [
            "systemd"
        ],
        "name": "cysystemd.reader",
        "sources": [
            "cysystemd/reader.pyx"
        ]
    },
    "module_name": "cysystemd.reader"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__cysystemd__reader
#define __PYX_HAVE_API__cysystemd__reader
/* Early includes */
#include <stdint.h>
#include <string.h>
#include <stdio.h>

    #if __PYX_LIMITED_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE PyObject *
    __Pyx_CAPI_PyList_GetItemRef(PyObject *list, Py_ssize_t index)
    {
        PyObject *item = PyList_GetItem(list, index);
        Py_XINCREF(item);
        return item;
    }
    #else
    #define __Pyx_CAPI_PyList_GetItemRef PyList_GetItemRef
    #endif

    #if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int
    __Pyx_CAPI_PyList_Extend(PyObject *list, PyObject *iterable)
    {
        return PyList_SetSlice(list, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, iterable);
    }

    static CYTHON_INLINE int
    __Pyx_CAPI_PyList_Clear(PyObject *list)
    {
        return PyList_SetSlice(list, 0, PY_SSIZE_T_MAX, NULL);
    }
    #else
    #define __Pyx_CAPI_PyList_Extend PyList_Extend
    #define __Pyx_CAPI_PyList_Clear PyList_Clear
    #endif
    

    #if PY_MAJOR_VERSION >= 3
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj)
    #else
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj, NULL)
    #endif
    
#include <stddef.h>

    #if PY_MAJOR_VERSION <= 2
    #define PyDict_GetItemWithError _PyDict_GetItemWithError
    #endif

    #if __PYX_LIMITED_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int
    __Pyx_CAPI_PyDict_GetItemStringRef(PyObject *mp, const char *key, PyObject **result)
    {
        int res;
        PyObject *key_obj = PyUnicode_FromString(key);
        if (key_obj == NULL) {
            *result = NULL;
            return -1;
        }
        res = __Pyx_PyDict_GetItemRef(mp, key_obj, result);
        Py_DECREF(key_obj);
        return res;
    }
    #else
    #define __Pyx_CAPI_PyDict_GetItemStringRef PyDict_GetItemStringRef
    #endif
    #if PY_VERSION_HEX < 0x030d0000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030F0000)
    static CYTHON_INLINE int
    __Pyx_CAPI_PyDict_SetDefaultRef(PyObject *d, PyObject *key, PyObject *default_value,
                        PyObject **result)
    {
        PyObject *value;
        if (__Pyx_PyDict_GetItemRef(d, key, &value) < 0) {
            // get error
            if (result) {
                *result = NULL;
            }
            return -1;
        }
        if (value != NULL) {
            // present
            if (result) {
                *result = value;
            }
            else {
                Py_DECREF(value);
            }
            return 1;
        }

        // missing: set the item
        if (PyDict_SetItem(d, key, default_value) < 0) {
            // set error
            if (result) {
                *result = NULL;
            }
            return -1;
        }
        if (result) {
            Py_INCREF(default_value);
            *result = default_value;
        }
        return 0;
    }
    #else
    #define __Pyx_CAPI_PyDict_SetDefaultRef PyDict_SetDefaultRef
    #endif
    

    #if PY_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int __Pyx_PyWeakref_GetRef(PyObject *ref, PyObject **pobj)
    {
        PyObject *obj = PyWeakref_GetObject(ref);
        if (obj == NULL) {
            // SystemError if ref is NULL
            *pobj = NULL;
            return -1;
        }
        if (obj == Py_None) {
            *pobj = NULL;
            return 0;
        }
        Py_INCREF(obj);
        *pobj = obj;
        return 1;
    }
    #else
    #define __Pyx_PyWeakref_GetRef PyWeakref_GetRef
    #endif
    
#include "pythread.h"

    #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM < 0x07030600) && !defined(PyContextVar_Get)
    #define PyContextVar_Get(var, d, v)         ((d) ?             ((void)(var), Py_INCREF(d), (v)[0] = (d), 0) :             ((v)[0] = NULL, 0)         )
    #endif
    
#include <systemd/sd-id128.h>
#include "sys/uio.h"
#include <systemd/sd-journal.h>
#include <sys/syslog.h>
#include <poll.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "cysystemd/reader.pyx",
  "cfunc.to_py",
  "cpython/contextvars.pxd",
  "cpython/type.pxd",
  "cpython/bool.pxd",
  "cpython/complex.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_9cysystemd_6reader_Rule;
struct __pyx_obj_9cysystemd_6reader_JournalEntry;
struct __pyx_obj_9cysystemd_6reader_JournalReader;
struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__;
struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock;
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path;
struct __pyx_opt_args_7cpython_11contextvars_get_value;
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default;

/* "cpython/contextvars.pxd":116
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
*/

#line 116 "cpython/contextvars.pxd"
struct __pyx_opt_args_7cpython_11contextvars_get_value {

#line 116 "cpython/contextvars.pxd"
  int __pyx_n;

#line 116 "cpython/contextvars.pxd"
  PyObject *default_value;

#line 116 "cpython/contextvars.pxd"
};

/* "cpython/contextvars.pxd":134
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
*/

#line 134 "cpython/contextvars.pxd"
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default {

#line 134 "cpython/contextvars.pxd"
  int __pyx_n;

#line 134 "cpython/contextvars.pxd"
  PyObject *default_value;

#line 134 "cpython/contextvars.pxd"
};

#line 134 "cpython/contextvars.pxd"
struct __pyx_opt_args_9cysystemd_6reader_13JournalReader_wait;

/* "cysystemd/reader.pyx":34
 * 
 * 
 * cdef enum MATCHER_OPERATION:             # <<<<<<<<<<<<<<
 *     MATCHER_OPERATION_CONJUNCTION,
 *     MATCHER_OPERATION_DISJUNCTION,
*/

#line 34 "cysystemd/reader.pyx"
enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION {

#line 34 "cysystemd/reader.pyx"
  __pyx_e_9cysystemd_6reader_MATCHER_OPERATION_CONJUNCTION,

#line 34 "cysystemd/reader.pyx"
  __pyx_e_9cysystemd_6reader_MATCHER_OPERATION_DISJUNCTION

#line 34 "cysystemd/reader.pyx"
};

/* "cysystemd/reader.pyx":160
 * 
 * 
 * cdef enum READER_STATE:             # <<<<<<<<<<<<<<
 *     READER_CLOSED,
 *     READER_OPENED,
*/

#line 160 "cysystemd/reader.pyx"
enum __pyx_t_9cysystemd_6reader_READER_STATE {

#line 160 "cysystemd/reader.pyx"
  __pyx_e_9cysystemd_6reader_READER_CLOSED,

#line 160 "cysystemd/reader.pyx"
  __pyx_e_9cysystemd_6reader_READER_OPENED,

#line 160 "cysystemd/reader.pyx"
  __pyx_e_9cysystemd_6reader_READER_LOCKED,

#line 160 "cysystemd/reader.pyx"
  __pyx_e_9cysystemd_6reader_READER_NULL

#line 160 "cysystemd/reader.pyx"
};

/* "cysystemd/reader.pyx":445
 *         return True
 * 
 *     cpdef wait(self, uint32_t timeout = WAIT_MAX_TIME):             # <<<<<<<<<<<<<<
 *         cdef uint64_t timeout_usec = timeout * 1000000
 *         cdef int result
*/

#line 445 "cysystemd/reader.pyx"
struct __pyx_opt_args_9cysystemd_6reader_13JournalReader_wait {

#line 445 "cysystemd/reader.pyx"
  int __pyx_n;

#line 445 "cysystemd/reader.pyx"
  uint32_t timeout;

#line 445 "cysystemd/reader.pyx"
};

/* "cysystemd/reader.pyx":54
 * 
 * 
 * cdef class Rule:             # <<<<<<<<<<<<<<
 *     cdef object _expression
 *     cdef object _child
*/

#line 54 "cysystemd/reader.pyx"
struct __pyx_obj_9cysystemd_6reader_Rule {

#line 54 "cysystemd/reader.pyx"
  PyObject_HEAD

#line 54 "cysystemd/reader.pyx"
  PyObject *_expression;

#line 54 "cysystemd/reader.pyx"
  PyObject *_child;

#line 54 "cysystemd/reader.pyx"
  PyObject *_root;

#line 54 "cysystemd/reader.pyx"
  PyObject *_operand;

#line 54 "cysystemd/reader.pyx"
};

#line 54 "cysystemd/reader.pyx"


/* "cysystemd/reader.pyx":211
 * 
 * 
 * cdef class JournalEntry:             # <<<<<<<<<<<<<<
 *     cdef sd_id128_t __boot_id
 *     cdef object __boot_uuid
*/

#line 211 "cysystemd/reader.pyx"
struct __pyx_obj_9cysystemd_6reader_JournalEntry {

#line 211 "cysystemd/reader.pyx"
  PyObject_HEAD

#line 211 "cysystemd/reader.pyx"
  struct __pyx_vtabstruct_9cysystemd_6reader_JournalEntry *__pyx_vtab;

#line 211 "cysystemd/reader.pyx"
  sd_id128_t _JournalEntry__boot_id;

#line 211 "cysystemd/reader.pyx"
  PyObject *_JournalEntry__boot_uuid;

#line 211 "cysystemd/reader.pyx"
  char *cursor;

#line 211 "cysystemd/reader.pyx"
  uint64_t monotonic_usec;

#line 211 "cysystemd/reader.pyx"
  uint64_t realtime_usec;

#line 211 "cysystemd/reader.pyx"
  PyObject *_JournalEntry__data;

#line 211 "cysystemd/reader.pyx"
  PyObject *_data;

#line 211 "cysystemd/reader.pyx"
  PyObject *_JournalEntry__date;

#line 211 "cysystemd/reader.pyx"
};

#line 211 "cysystemd/reader.pyx"


/* "cysystemd/reader.pyx":304
 * 
 * 
 * cdef class JournalReader:             # <<<<<<<<<<<<<<
 *     cdef sd_journal* context
 *     cdef char state
*/

#line 304 "cysystemd/reader.pyx"
struct __pyx_obj_9cysystemd_6reader_JournalReader {

#line 304 "cysystemd/reader.pyx"
  PyObject_HEAD

#line 304 "cysystemd/reader.pyx"
  struct __pyx_vtabstruct_9cysystemd_6reader_JournalReader *__pyx_vtab;

#line 304 "cysystemd/reader.pyx"
  sd_journal *context;

#line 304 "cysystemd/reader.pyx"
  char state;

#line 304 "cysystemd/reader.pyx"
  PyObject *flags;

#line 304 "cysystemd/reader.pyx"
};

#line 304 "cysystemd/reader.pyx"


/* "cysystemd/reader.pyx":121
 *         return 'Rule(%r)' % ' '.join(ret[:-1])
 * 
 *     def __iter__(self) -> Iterator[Tuple[MatchOperation, bytes]]:             # <<<<<<<<<<<<<<
 *         rule = self.root
 * 
*/

#line 121 "cysystemd/reader.pyx"
struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ {

#line 121 "cysystemd/reader.pyx"
  PyObject_HEAD

#line 121 "cysystemd/reader.pyx"
  PyObject *__pyx_v_rule;

#line 121 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self;

#line 121 "cysystemd/reader.pyx"
};

#line 121 "cysystemd/reader.pyx"


/* "cysystemd/reader.pyx":376
 *         return self.state == READER_OPENED
 * 
 *     @contextmanager             # <<<<<<<<<<<<<<
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:
*/

#line 376 "cysystemd/reader.pyx"
struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock {

#line 376 "cysystemd/reader.pyx"
  PyObject_HEAD

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_v_opening;

#line 376 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self;

#line 376 "cysystemd/reader.pyx"
};

#line 376 "cysystemd/reader.pyx"


/* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(str (*f)(object) ):
 *     def wrap(object path):
*/

#line 65 "cfunc.to_py"
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path {

#line 65 "cfunc.to_py"
  PyObject_HEAD

#line 65 "cfunc.to_py"
  PyObject *(*__pyx_v_f)(PyObject *);

#line 65 "cfunc.to_py"
};

#line 65 "cfunc.to_py"


#line 65 "cfunc.to_py"


/* "cysystemd/reader.pyx":211
 * 
 * 
 * cdef class JournalEntry:             # <<<<<<<<<<<<<<
 *     cdef sd_id128_t __boot_id
 *     cdef object __boot_uuid
*/

#line 211 "cysystemd/reader.pyx"


#line 211 "cysystemd/reader.pyx"
struct __pyx_vtabstruct_9cysystemd_6reader_JournalEntry {

#line 211 "cysystemd/reader.pyx"
  double (*get_realtime_sec)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch);

#line 211 "cysystemd/reader.pyx"
  double (*get_monotonic_sec)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch);

#line 211 "cysystemd/reader.pyx"
  uint64_t (*get_realtime_usec)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch);

#line 211 "cysystemd/reader.pyx"
  uint64_t (*get_monotonic_usec)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch);

#line 211 "cysystemd/reader.pyx"
};

#line 211 "cysystemd/reader.pyx"
static struct __pyx_vtabstruct_9cysystemd_6reader_JournalEntry *__pyx_vtabptr_9cysystemd_6reader_JournalEntry;

#line 211 "cysystemd/reader.pyx"


/* "cysystemd/reader.pyx":304
 * 
 * 
 * cdef class JournalReader:             # <<<<<<<<<<<<<<
 *     cdef sd_journal* context
 *     cdef char state
*/

#line 304 "cysystemd/reader.pyx"


#line 304 "cysystemd/reader.pyx"
struct __pyx_vtabstruct_9cysystemd_6reader_JournalReader {

#line 304 "cysystemd/reader.pyx"
  PyObject *(*wait)(struct __pyx_obj_9cysystemd_6reader_JournalReader *, int __pyx_skip_dispatch, struct __pyx_opt_args_9cysystemd_6reader_13JournalReader_wait *__pyx_optional_args);

#line 304 "cysystemd/reader.pyx"
};

#line 304 "cysystemd/reader.pyx"
static struct __pyx_vtabstruct_9cysystemd_6reader_JournalReader *__pyx_vtabptr_9cysystemd_6reader_JournalReader;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* PyOverflowError_Check.proto */
#define __Pyx_PyExc_OverflowError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_OverflowError)

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* PyIndexError_Check.proto */
#define __Pyx_PyExc_IndexError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_IndexError)

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* GetException.proto (used by pep479) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* RejectKeywords.export */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* pyint_simplify.proto */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* PySystemError_Check.proto */
#define __Pyx_PyExc_SystemError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_SystemError)

/* PyDeprecationWarning_Check.proto */
#define __Pyx_PyExc_DeprecationWarning_Check(obj)  __Pyx_TypeCheck(obj, PyExc_DeprecationWarning)

/* PyObjectVectorCallKwBuilder.proto */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared)
    #endif
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_OwnStrongReference)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_SharedReference)
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right))

/* PyObject_Unicode.proto */
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* PyOSError_Check.proto */
#define __Pyx_PyExc_OSError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_OSError)

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyObjectCall2Args.proto (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod1) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod1.proto (used by append) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyRuntimeError_Check.proto */
#define __Pyx_PyExc_RuntimeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_RuntimeError)

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* decode_c_string_utf16.proto (used by decode_c_bytes) */
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 0;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16LE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = -1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16BE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}

/* decode_c_bytes.proto (used by decode_bytes) */
static CYTHON_INLINE PyObject* __Pyx_decode_c_bytes(
         const char* cstring, Py_ssize_t length, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* decode_bytes.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_bytes(
         PyObject* string, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    as_c_string = PyBytes_AS_STRING(string);
    size = PyBytes_GET_SIZE(string);
#else
    if (PyBytes_AsStringAndSize(string, &as_c_string, &size) < 0) {
        return NULL;
    }
#endif
    return __Pyx_decode_c_bytes(
        as_c_string, size,
        start, stop, encoding, errors, decode_func);
}

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CheckTypeForFreelists.proto */
#if CYTHON_USE_FREELISTS
#if CYTHON_USE_TYPE_SPECS
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t) == (expected_tp)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  Py_TPFLAGS_IS_ABSTRACT
#else
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t)->tp_basicsize == (expected_size)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)
#endif
#define __PYX_CHECK_TYPE_FOR_FREELISTS(t, expected_tp, expected_size)\
    (__PYX_CHECK_FINAL_TYPE_FOR_FREELISTS((t), (expected_tp), (expected_size)) &\
     (int) (!__Pyx_PyType_HasFeature((t), __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS)))
#endif

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallMethod0.proto (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* DelItemOnTypeDict.proto (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k);
#define __Pyx_DelItemOnTypeDict(tp, k) __Pyx__DelItemOnTypeDict((PyTypeObject*)tp, k)

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* ClassMethod.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include "descrobject.h"
#endif
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CheckUnpickleChecksum.proto */
static CYTHON_INLINE int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From___pyx_anon_enum(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_enum____pyx_t_9cysystemd_6reader_MATCHER_OPERATION(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE uint8_t __Pyx_PyLong_As_uint8_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE uint64_t __Pyx_PyLong_As_uint64_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE uint32_t __Pyx_PyLong_As_uint32_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint32_t(uint32_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint8_t(uint8_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint64_t(uint64_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyLong_As_size_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* UpdateUnpickledDict.proto */
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* IterNextPlain.proto (used by CoroutineBase) */
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator);
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void);
#endif

/* ReturnWithStopIteration.proto (used by CoroutineBase) */
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext);

/* CoroutineBase.proto (used by Generator) */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *gi_weakreflist;
#endif
    PyObject *classobj;
    PyObject *yieldfrom;
    __Pyx_pyiter_sendfunc yieldfrom_am_send;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
#if CYTHON_USE_SYS_MONITORING && (CYTHON_PROFILE || CYTHON_TRACE)
    PyMonitoringState __pyx_pymonitoring_state[__Pyx_MonitoringEventTypes_CyGen_count];
    uint64_t __pyx_pymonitoring_version;
#endif
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static __Pyx_PySendResult __Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static __Pyx_PySendResult __Pyx_Coroutine_Close(PyObject *self, PyObject **retval);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen);
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen);
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen);
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure);
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send);
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_mstate_global->__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);
static CYTHON_INLINE PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self); /* proto*/
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self); /* proto*/
#endif
static double __pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static double __pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static uint64_t __pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static uint64_t __pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9cysystemd_6reader_13JournalReader_wait(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_9cysystemd_6reader_13JournalReader_wait *__pyx_optional_args); /* proto*/

/* Module declarations from "cpython.mem" */

/* Module declarations from "libc.stdint" */

/* Module declarations from "cpython.version" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "cpython.exc" */

/* Module declarations from "cpython.module" */

/* Module declarations from "cpython.tuple" */

/* Module declarations from "cpython.list" */

/* Module declarations from "cpython.sequence" */

/* Module declarations from "cpython.mapping" */

/* Module declarations from "cpython.iterator" */

/* Module declarations from "cpython.number" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.bool" */

/* Module declarations from "cpython.long" */

/* Module declarations from "cpython.float" */

/* Module declarations from "cython" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.complex" */

/* Module declarations from "libc.stddef" */

/* Module declarations from "cpython.unicode" */

/* Module declarations from "cpython.pyport" */

/* Module declarations from "cpython.dict" */

/* Module declarations from "cpython.instance" */

/* Module declarations from "cpython.function" */

/* Module declarations from "cpython.method" */

/* Module declarations from "cpython.weakref" */

/* Module declarations from "cpython.getargs" */

/* Module declarations from "cpython.pythread" */

/* Module declarations from "cpython.pystate" */

/* Module declarations from "cpython.set" */

/* Module declarations from "cpython.buffer" */

/* Module declarations from "cpython.bytes" */

/* Module declarations from "cpython.pycapsule" */

/* Module declarations from "cpython.contextvars" */

/* Module declarations from "cpython" */

/* Module declarations from "cysystemd.sd_id128" */

/* Module declarations from "cysystemd.sd_journal" */

/* Module declarations from "cysystemd.reader" */
static PyObject *__pyx_f_9cysystemd_6reader__check_dir_path(PyObject *); /*proto*/
static PyObject *__pyx_f_9cysystemd_6reader__check_file_path(PyObject *); /*proto*/
static PyObject *__pyx_f_9cysystemd_6reader___pyx_unpickle_Rule__set_state(struct __pyx_obj_9cysystemd_6reader_Rule *, PyObject *); /*proto*/
static PyObject *__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(PyObject *(*)(PyObject *)); /*proto*/
static int __Pyx_carray_from_py_uint8_t(PyObject *, uint8_t *, Py_ssize_t); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "cysystemd.reader"
extern int __pyx_module_is_main_cysystemd__reader;
int __pyx_module_is_main_cysystemd__reader = 0;

/* Implementation of "cysystemd.reader" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_map;
static PyObject *__pyx_builtin_enumerate;
/* #### Code section: string_decls ### */
static const char __pyx_k_child__expression__operand__roo[] = "_child, _expression, _operand, _root";
static const char __pyx_k_not_enough_values_found_during_a[] = "not enough values found during array assignment, expected %zd, got %zd";
static const char __pyx_k_too_many_values_found_during_arr[] = "too many values found during array assignment, expected %zd";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_wrap(PyObject *__pyx_self, PyObject *__pyx_v_path); /* proto */
static int __pyx_pf_9cysystemd_6reader_4Rule___init__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_10expression___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_5child___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self); /* proto */
static int __pyx_pf_9cysystemd_6reader_4Rule_5child_2__set__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_child); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_4root___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self); /* proto */
static int __pyx_pf_9cysystemd_6reader_4Rule_4root_2__set__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_root); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_7operand___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self); /* proto */
static int __pyx_pf_9cysystemd_6reader_4Rule_7operand_2__set__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, uint8_t __pyx_v_op); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_2__and__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_4__or__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_6__repr__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_8__iter__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_11__reduce_cython__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_13__setstate_cython__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_check_error_code(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_code); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_15JournalOpenMode__missing_(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9cysystemd_6reader_12JournalEntry___cinit__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_reader); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_6cursor___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_2get_realtime_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_4get_monotonic_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_6get_realtime_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_8get_monotonic_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_7boot_id___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_4date___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_4data___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static void __pyx_pf_9cysystemd_6reader_12JournalEntry_10__dealloc__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_12__repr__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_14__getitem__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9cysystemd_6reader_13JournalReader___init__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_2open(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_flags); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_4open_directory(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6open_files(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_file_names); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_14data_threshold___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static int __pyx_pf_9cysystemd_6reader_13JournalReader_14data_threshold_2__set__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_size); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6closed___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6locked___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_4idle___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_8_lock(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_opening); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_11seek_head(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_13seek_tail(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_15seek_monotonic_usec(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_boot_id, uint64_t __pyx_v_usec); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_17seek_realtime_usec(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_usec); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_19seek_cursor(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_cursor); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_21wait(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint32_t __pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_23__iter__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pf_9cysystemd_6reader_13JournalReader_25next(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_27skip_next(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip); /* proto */
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pf_9cysystemd_6reader_13JournalReader_29previous(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_31skip_previous(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_33add_filter(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_rule); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_35clear_filter(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_37__repr__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static void __pyx_pf_9cysystemd_6reader_13JournalReader_39__dealloc__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_2fd___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6events___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_7timeout___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_41process_events(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_43get_catalog(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_45get_catalog_for_message_id(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_message_id); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_47__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_49__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9cysystemd_6reader_2__pyx_unpickle_Rule(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_9cysystemd_6reader_Rule(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9cysystemd_6reader_JournalEntry(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9cysystemd_6reader_JournalReader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct____iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct_1__lock(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyTypeObject *__pyx_ptype_7cpython_4bool_bool;
  PyTypeObject *__pyx_ptype_7cpython_7complex_complex;
  PyObject *__pyx_type_9cysystemd_6reader_Rule;
  PyObject *__pyx_type_9cysystemd_6reader_JournalEntry;
  PyObject *__pyx_type_9cysystemd_6reader_JournalReader;
  PyObject *__pyx_type_9cysystemd_6reader___pyx_scope_struct____iter__;
  PyObject *__pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock;
  PyObject *__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path;
  PyTypeObject *__pyx_ptype_9cysystemd_6reader_Rule;
  PyTypeObject *__pyx_ptype_9cysystemd_6reader_JournalEntry;
  PyTypeObject *__pyx_ptype_9cysystemd_6reader_JournalReader;
  PyTypeObject *__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__;
  PyTypeObject *__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock;
  PyTypeObject *__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type__upper;
  PyObject *__pyx_k__4;
  uint32_t __pyx_k__5;
  PyObject *__pyx_tuple[3];
  PyObject *__pyx_codeobj_tab[34];
  PyObject *__pyx_string_tab[280];
  PyObject *__pyx_number_tab[7];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;


#if CYTHON_USE_FREELISTS
struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *__pyx_freelist_9cysystemd_6reader___pyx_scope_struct____iter__[8];
int __pyx_freecount_9cysystemd_6reader___pyx_scope_struct____iter__;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *__pyx_freelist_9cysystemd_6reader___pyx_scope_struct_1__lock[8];
int __pyx_freecount_9cysystemd_6reader___pyx_scope_struct_1__lock;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *__pyx_freelist___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path[8];
int __pyx_freecount___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path;
#endif
/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* IterNextPlain.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
PyObject *__Pyx_GetBuiltinNext_LimitedAPI_cache;
#endif

/* Generator.module_state_decls */
PyTypeObject *__pyx_GeneratorType;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Can_t_lock_closed_reader __pyx_string_tab[1]
#define __pyx_kp_u_Can_t_reopen_opened_reader __pyx_string_tab[2]
#define __pyx_kp_u_Directory_not_found __pyx_string_tab[3]
#define __pyx_kp_u_Expression_must_not_contains_0_c __pyx_string_tab[4]
#define __pyx_kp_u_File_not_found __pyx_string_tab[5]
#define __pyx_kp_u_Invalid_operation __pyx_string_tab[6]
#define __pyx_kp_u_It_s_not_a_directory __pyx_string_tab[7]
#define __pyx_kp_u_It_s_not_a_regular_file __pyx_string_tab[8]
#define __pyx_kp_u_JournalEntry_r __pyx_string_tab[9]
#define __pyx_kp_u_JournalOpenMode_2 __pyx_string_tab[10]
#define __pyx_kp_u_Link_recursive_reslolution_error __pyx_string_tab[11]
#define __pyx_kp_u_None __pyx_string_tab[12]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[13]
#define __pyx_kp_u_Reader __pyx_string_tab[14]
#define __pyx_kp_u_Reader_locked __pyx_string_tab[15]
#define __pyx_kp_u_Rule_r __pyx_string_tab[16]
#define __pyx_kp_u_The_JournalOpenMode_SYSTEM_ONLY __pyx_string_tab[17]
#define __pyx_kp_u_Union_str_Path __pyx_string_tab[18]
#define __pyx_kp_u__2 __pyx_string_tab[19]
#define __pyx_kp_u__3 __pyx_string_tab[20]
#define __pyx_kp_u__6 __pyx_string_tab[21]
#define __pyx_kp_u__7 __pyx_string_tab[22]
#define __pyx_kp_u__8 __pyx_string_tab[23]
#define __pyx_kp_u__9 __pyx_string_tab[24]
#define __pyx_kp_u_add_note __pyx_string_tab[25]
#define __pyx_kp_u_cfunc_to_py __pyx_string_tab[26]
#define __pyx_kp_u_cysystemd_reader_pyx __pyx_string_tab[27]
#define __pyx_kp_u_disable __pyx_string_tab[28]
#define __pyx_kp_u_enable __pyx_string_tab[29]
#define __pyx_kp_u_gc __pyx_string_tab[30]
#define __pyx_kp_u_got_message_with_enormous_length __pyx_string_tab[31]
#define __pyx_kp_u_got_unexpected_r_from_sd_journal __pyx_string_tab[32]
#define __pyx_kp_u_is_not_a_valid_open_mode __pyx_string_tab[33]
#define __pyx_kp_u_isenabled __pyx_string_tab[34]
#define __pyx_kp_u_no_default___reduce___due_to_non __pyx_string_tab[35]
#define __pyx_kp_u_r __pyx_string_tab[36]
#define __pyx_kp_u_self_context_cannot_be_converted __pyx_string_tab[37]
#define __pyx_kp_u_tree_fragment __pyx_string_tab[38]
#define __pyx_n_u_AND __pyx_string_tab[39]
#define __pyx_n_u_APPEND __pyx_string_tab[40]
#define __pyx_n_u_CURRENT_USER __pyx_string_tab[41]
#define __pyx_n_u_IN __pyx_string_tab[42]
#define __pyx_n_u_INVALIDATE __pyx_string_tab[43]
#define __pyx_n_u_IntEnum __pyx_string_tab[44]
#define __pyx_n_u_IntFlag __pyx_string_tab[45]
#define __pyx_n_u_Iterator __pyx_string_tab[46]
#define __pyx_n_u_JournalEntry __pyx_string_tab[47]
#define __pyx_n_u_JournalEntry___reduce_cython __pyx_string_tab[48]
#define __pyx_n_u_JournalEntry___setstate_cython __pyx_string_tab[49]
#define __pyx_n_u_JournalEntry_get_monotonic_sec __pyx_string_tab[50]
#define __pyx_n_u_JournalEntry_get_monotonic_usec __pyx_string_tab[51]
#define __pyx_n_u_JournalEntry_get_realtime_sec __pyx_string_tab[52]
#define __pyx_n_u_JournalEntry_get_realtime_usec __pyx_string_tab[53]
#define __pyx_n_u_JournalEvent __pyx_string_tab[54]
#define __pyx_n_u_JournalOpenMode __pyx_string_tab[55]
#define __pyx_n_u_JournalOpenMode__missing __pyx_string_tab[56]
#define __pyx_n_u_JournalReader __pyx_string_tab[57]
#define __pyx_n_u_JournalReader___reduce_cython __pyx_string_tab[58]
#define __pyx_n_u_JournalReader___setstate_cython __pyx_string_tab[59]
#define __pyx_n_u_JournalReader__lock __pyx_string_tab[60]
#define __pyx_n_u_JournalReader_add_filter __pyx_string_tab[61]
#define __pyx_n_u_JournalReader_clear_filter __pyx_string_tab[62]
#define __pyx_n_u_JournalReader_get_catalog __pyx_string_tab[63]
#define __pyx_n_u_JournalReader_get_catalog_for_me __pyx_string_tab[64]
#define __pyx_n_u_JournalReader_next __pyx_string_tab[65]
#define __pyx_n_u_JournalReader_open __pyx_string_tab[66]
#define __pyx_n_u_JournalReader_open_directory __pyx_string_tab[67]
#define __pyx_n_u_JournalReader_open_files __pyx_string_tab[68]
#define __pyx_n_u_JournalReader_previous __pyx_string_tab[69]
#define __pyx_n_u_JournalReader_process_events __pyx_string_tab[70]
#define __pyx_n_u_JournalReader_seek_cursor __pyx_string_tab[71]
#define __pyx_n_u_JournalReader_seek_head __pyx_string_tab[72]
#define __pyx_n_u_JournalReader_seek_monotonic_use __pyx_string_tab[73]
#define __pyx_n_u_JournalReader_seek_realtime_usec __pyx_string_tab[74]
#define __pyx_n_u_JournalReader_seek_tail __pyx_string_tab[75]
#define __pyx_n_u_JournalReader_skip_next __pyx_string_tab[76]
#define __pyx_n_u_JournalReader_skip_previous __pyx_string_tab[77]
#define __pyx_n_u_JournalReader_wait __pyx_string_tab[78]
#define __pyx_n_u_LOCAL_ONLY __pyx_string_tab[79]
#define __pyx_n_u_MatchOperation __pyx_string_tab[80]
#define __pyx_n_u_NOP __pyx_string_tab[81]
#define __pyx_n_u_None __pyx_string_tab[82]
#define __pyx_n_u_OR __pyx_string_tab[83]
#define __pyx_n_u_OUT __pyx_string_tab[84]
#define __pyx_n_u_Path __pyx_string_tab[85]
#define __pyx_n_u_Poll __pyx_string_tab[86]
#define __pyx_n_u_Pyx_CFunc_9cysystemd_6reader_s __pyx_string_tab[87]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[88]
#define __pyx_n_u_RUNTIME_ONLY __pyx_string_tab[89]
#define __pyx_n_u_Rule __pyx_string_tab[90]
#define __pyx_n_u_Rule___iter __pyx_string_tab[91]
#define __pyx_n_u_Rule___reduce_cython __pyx_string_tab[92]
#define __pyx_n_u_Rule___setstate_cython __pyx_string_tab[93]
#define __pyx_n_u_SYSTEM __pyx_string_tab[94]
#define __pyx_n_u_Tuple __pyx_string_tab[95]
#define __pyx_n_u_UUID __pyx_string_tab[96]
#define __pyx_n_u_Union __pyx_string_tab[97]
#define __pyx_n_u_WAIT_MAX_TIME __pyx_string_tab[98]
#define __pyx_n_u_abspath __pyx_string_tab[99]
#define __pyx_n_u_add_filter __pyx_string_tab[100]
#define __pyx_n_u_append __pyx_string_tab[101]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[102]
#define __pyx_n_u_bcatalog __pyx_string_tab[103]
#define __pyx_n_u_bool __pyx_string_tab[104]
#define __pyx_n_u_boot_id __pyx_string_tab[105]
#define __pyx_n_u_bytes __pyx_string_tab[106]
#define __pyx_n_u_catalog __pyx_string_tab[107]
#define __pyx_n_u_cboot_id __pyx_string_tab[108]
#define __pyx_n_u_ccursor __pyx_string_tab[109]
#define __pyx_n_u_cfunc_to_py __pyx_string_tab[110]
#define __pyx_n_u_check_error_code __pyx_string_tab[111]
#define __pyx_n_u_child __pyx_string_tab[112]
#define __pyx_n_u_clear_filter __pyx_string_tab[113]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[114]
#define __pyx_n_u_close __pyx_string_tab[115]
#define __pyx_n_u_closed __pyx_string_tab[116]
#define __pyx_n_u_cls __pyx_string_tab[117]
#define __pyx_n_u_code __pyx_string_tab[118]
#define __pyx_n_u_contextlib __pyx_string_tab[119]
#define __pyx_n_u_contextmanager __pyx_string_tab[120]
#define __pyx_n_u_cstr __pyx_string_tab[121]
#define __pyx_n_u_cursor __pyx_string_tab[122]
#define __pyx_n_u_cusec __pyx_string_tab[123]
#define __pyx_n_u_cysystemd_reader __pyx_string_tab[124]
#define __pyx_n_u_date __pyx_string_tab[125]
#define __pyx_n_u_datetime __pyx_string_tab[126]
#define __pyx_n_u_decode __pyx_string_tab[127]
#define __pyx_n_u_dict __pyx_string_tab[128]
#define __pyx_n_u_dict_2 __pyx_string_tab[129]
#define __pyx_n_u_doc __pyx_string_tab[130]
#define __pyx_n_u_encode __pyx_string_tab[131]
#define __pyx_n_u_enter __pyx_string_tab[132]
#define __pyx_n_u_enum __pyx_string_tab[133]
#define __pyx_n_u_enumerate __pyx_string_tab[134]
#define __pyx_n_u_errno __pyx_string_tab[135]
#define __pyx_n_u_error __pyx_string_tab[136]
#define __pyx_n_u_errorcode __pyx_string_tab[137]
#define __pyx_n_u_errors __pyx_string_tab[138]
#define __pyx_n_u_exists __pyx_string_tab[139]
#define __pyx_n_u_exit __pyx_string_tab[140]
#define __pyx_n_u_exp __pyx_string_tab[141]
#define __pyx_n_u_expression __pyx_string_tab[142]
#define __pyx_n_u_file_names __pyx_string_tab[143]
#define __pyx_n_u_flags __pyx_string_tab[144]
#define __pyx_n_u_fromtimestamp __pyx_string_tab[145]
#define __pyx_n_u_func __pyx_string_tab[146]
#define __pyx_n_u_getLogger __pyx_string_tab[147]
#define __pyx_n_u_get_catalog __pyx_string_tab[148]
#define __pyx_n_u_get_catalog_for_message_id __pyx_string_tab[149]
#define __pyx_n_u_get_monotonic_sec __pyx_string_tab[150]
#define __pyx_n_u_get_monotonic_usec __pyx_string_tab[151]
#define __pyx_n_u_get_realtime_sec __pyx_string_tab[152]
#define __pyx_n_u_get_realtime_usec __pyx_string_tab[153]
#define __pyx_n_u_getstate __pyx_string_tab[154]
#define __pyx_n_u_i __pyx_string_tab[155]
#define __pyx_n_u_id128 __pyx_string_tab[156]
#define __pyx_n_u_int __pyx_string_tab[157]
#define __pyx_n_u_is_coroutine __pyx_string_tab[158]
#define __pyx_n_u_isdir __pyx_string_tab[159]
#define __pyx_n_u_isfile __pyx_string_tab[160]
#define __pyx_n_u_islink __pyx_string_tab[161]
#define __pyx_n_u_items __pyx_string_tab[162]
#define __pyx_n_u_iter __pyx_string_tab[163]
#define __pyx_n_u_key __pyx_string_tab[164]
#define __pyx_n_u_length __pyx_string_tab[165]
#define __pyx_n_u_lock __pyx_string_tab[166]
#define __pyx_n_u_locked __pyx_string_tab[167]
#define __pyx_n_u_log __pyx_string_tab[168]
#define __pyx_n_u_logging __pyx_string_tab[169]
#define __pyx_n_u_main __pyx_string_tab[170]
#define __pyx_n_u_map __pyx_string_tab[171]
#define __pyx_n_u_max_message_size __pyx_string_tab[172]
#define __pyx_n_u_message_id __pyx_string_tab[173]
#define __pyx_n_u_metaclass __pyx_string_tab[174]
#define __pyx_n_u_missing __pyx_string_tab[175]
#define __pyx_n_u_module __pyx_string_tab[176]
#define __pyx_n_u_mro_entries __pyx_string_tab[177]
#define __pyx_n_u_n __pyx_string_tab[178]
#define __pyx_n_u_name __pyx_string_tab[179]
#define __pyx_n_u_name_2 __pyx_string_tab[180]
#define __pyx_n_u_new __pyx_string_tab[181]
#define __pyx_n_u_next __pyx_string_tab[182]
#define __pyx_n_u_open __pyx_string_tab[183]
#define __pyx_n_u_open_directory __pyx_string_tab[184]
#define __pyx_n_u_open_files __pyx_string_tab[185]
#define __pyx_n_u_opened __pyx_string_tab[186]
#define __pyx_n_u_opening __pyx_string_tab[187]
#define __pyx_n_u_operand __pyx_string_tab[188]
#define __pyx_n_u_os __pyx_string_tab[189]
#define __pyx_n_u_path __pyx_string_tab[190]
#define __pyx_n_u_pathlib __pyx_string_tab[191]
#define __pyx_n_u_paths __pyx_string_tab[192]
#define __pyx_n_u_pop __pyx_string_tab[193]
#define __pyx_n_u_prepare __pyx_string_tab[194]
#define __pyx_n_u_previous __pyx_string_tab[195]
#define __pyx_n_u_process_events __pyx_string_tab[196]
#define __pyx_n_u_pyx_checksum __pyx_string_tab[197]
#define __pyx_n_u_pyx_result __pyx_string_tab[198]
#define __pyx_n_u_pyx_state __pyx_string_tab[199]
#define __pyx_n_u_pyx_type __pyx_string_tab[200]
#define __pyx_n_u_pyx_unpickle_Rule __pyx_string_tab[201]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[202]
#define __pyx_n_u_qualname __pyx_string_tab[203]
#define __pyx_n_u_reader __pyx_string_tab[204]
#define __pyx_n_u_readlink __pyx_string_tab[205]
#define __pyx_n_u_reduce __pyx_string_tab[206]
#define __pyx_n_u_reduce_cython __pyx_string_tab[207]
#define __pyx_n_u_reduce_ex __pyx_string_tab[208]
#define __pyx_n_u_replace __pyx_string_tab[209]
#define __pyx_n_u_result __pyx_string_tab[210]
#define __pyx_n_u_return __pyx_string_tab[211]
#define __pyx_n_u_root __pyx_string_tab[212]
#define __pyx_n_u_rule __pyx_string_tab[213]
#define __pyx_n_u_s __pyx_string_tab[214]
#define __pyx_n_u_seek_cursor __pyx_string_tab[215]
#define __pyx_n_u_seek_head __pyx_string_tab[216]
#define __pyx_n_u_seek_monotonic_usec __pyx_string_tab[217]
#define __pyx_n_u_seek_realtime_usec __pyx_string_tab[218]
#define __pyx_n_u_seek_tail __pyx_string_tab[219]
#define __pyx_n_u_self __pyx_string_tab[220]
#define __pyx_n_u_send __pyx_string_tab[221]
#define __pyx_n_u_set_name __pyx_string_tab[222]
#define __pyx_n_u_setdefault __pyx_string_tab[223]
#define __pyx_n_u_setstate __pyx_string_tab[224]
#define __pyx_n_u_setstate_cython __pyx_string_tab[225]
#define __pyx_n_u_skip __pyx_string_tab[226]
#define __pyx_n_u_skip_next __pyx_string_tab[227]
#define __pyx_n_u_skip_previous __pyx_string_tab[228]
#define __pyx_n_u_stacklevel __pyx_string_tab[229]
#define __pyx_n_u_state __pyx_string_tab[230]
#define __pyx_n_u_strerror __pyx_string_tab[231]
#define __pyx_n_u_test __pyx_string_tab[232]
#define __pyx_n_u_throw __pyx_string_tab[233]
#define __pyx_n_u_timeout __pyx_string_tab[234]
#define __pyx_n_u_timezone __pyx_string_tab[235]
#define __pyx_n_u_typing __pyx_string_tab[236]
#define __pyx_n_u_update __pyx_string_tab[237]
#define __pyx_n_u_upper __pyx_string_tab[238]
#define __pyx_n_u_use_setstate __pyx_string_tab[239]
#define __pyx_n_u_usec __pyx_string_tab[240]
#define __pyx_n_u_utc __pyx_string_tab[241]
#define __pyx_n_u_uuid __pyx_string_tab[242]
#define __pyx_n_u_value __pyx_string_tab[243]
#define __pyx_n_u_values __pyx_string_tab[244]
#define __pyx_n_u_wait __pyx_string_tab[245]
#define __pyx_n_u_warn __pyx_string_tab[246]
#define __pyx_n_u_warning __pyx_string_tab[247]
#define __pyx_n_u_warnings __pyx_string_tab[248]
#define __pyx_n_u_wrap __pyx_string_tab[249]
#define __pyx_kp_b_iso88591_1_A_q_A __pyx_string_tab[250]
#define __pyx_kp_b_iso88591_1_Q_1D_q __pyx_string_tab[251]
#define __pyx_kp_b_iso88591_1_U_3a_1_1A_Rr_3b_CuIQa_1G1_q_Q __pyx_string_tab[252]
#define __pyx_kp_b_iso88591_1_q_a_IQ_q __pyx_string_tab[253]
#define __pyx_kp_b_iso88591_1_q_a_q __pyx_string_tab[254]
#define __pyx_kp_b_iso88591_31_a_q_2_4z_q __pyx_string_tab[255]
#define __pyx_kp_b_iso88591_5Ya_Yj_7_1_7_A_1_t1HG1 __pyx_string_tab[256]
#define __pyx_kp_b_iso88591_6 __pyx_string_tab[257]
#define __pyx_kp_b_iso88591_A_6_A_E_1_3a_j_1A __pyx_string_tab[258]
#define __pyx_kp_b_iso88591_A_T_1_1_t_2Q __pyx_string_tab[259]
#define __pyx_kp_b_iso88591_A_T_q __pyx_string_tab[260]
#define __pyx_kp_b_iso88591_A_a __pyx_string_tab[261]
#define __pyx_kp_b_iso88591_A_q __pyx_string_tab[262]
#define __pyx_kp_b_iso88591_A_t1 __pyx_string_tab[263]
#define __pyx_kp_b_iso88591_C1_q_31D_A_q __pyx_string_tab[264]
#define __pyx_kp_b_iso88591_I_AS_q_1O1AT_4vQ __pyx_string_tab[265]
#define __pyx_kp_b_iso88591_Q __pyx_string_tab[266]
#define __pyx_kp_b_iso88591_Q_q_Jaq_7_A_1_t1HG1 __pyx_string_tab[267]
#define __pyx_kp_b_iso88591_T_nD_4q_G1F_a_vWE_Q_q_t87_s_m7 __pyx_string_tab[268]
#define __pyx_kp_b_iso88591_V1_q_q_1_j_AT_q_1A __pyx_string_tab[269]
#define __pyx_kp_b_iso88591_XRq_q_Zq_1_AQ __pyx_string_tab[270]
#define __pyx_kp_b_iso88591__10 __pyx_string_tab[271]
#define __pyx_kp_b_iso88591_a_Q __pyx_string_tab[272]
#define __pyx_kp_b_iso88591_a_aq_q_4wa_A_6aq_JfA __pyx_string_tab[273]
#define __pyx_kp_b_iso88591_a_q_Qd_A_q __pyx_string_tab[274]
#define __pyx_kp_b_iso88591_q_0_kQR_4xq_7_awnA_1 __pyx_string_tab[275]
#define __pyx_kp_b_iso88591_q_j_q __pyx_string_tab[276]
#define __pyx_kp_b_iso88591_q_q_Qd_E_83nA_7q_A_AQ_S_a_7q_A __pyx_string_tab[277]
#define __pyx_kp_b_iso88591_q_q_q_Qd_A_Q_q_1A __pyx_string_tab[278]
#define __pyx_kp_b_iso88591_uCq_q_1A_uCq_k_IQgQ __pyx_string_tab[279]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_1 __pyx_number_tab[1]
#define __pyx_int_2 __pyx_number_tab[2]
#define __pyx_int_255 __pyx_number_tab[3]
#define __pyx_int_1048576 __pyx_number_tab[4]
#define __pyx_int_265362053 __pyx_number_tab[5]
#define __pyx_int_4294967295 __pyx_number_tab[6]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_CLEAR(clear_module_state->__pyx_ptype_9cysystemd_6reader_Rule);
  Py_CLEAR(clear_module_state->__pyx_type_9cysystemd_6reader_Rule);
  Py_CLEAR(clear_module_state->__pyx_ptype_9cysystemd_6reader_JournalEntry);
  Py_CLEAR(clear_module_state->__pyx_type_9cysystemd_6reader_JournalEntry);
  Py_CLEAR(clear_module_state->__pyx_ptype_9cysystemd_6reader_JournalReader);
  Py_CLEAR(clear_module_state->__pyx_type_9cysystemd_6reader_JournalReader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__);
  Py_CLEAR(clear_module_state->__pyx_type_9cysystemd_6reader___pyx_scope_struct____iter__);
  Py_CLEAR(clear_module_state->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock);
  Py_CLEAR(clear_module_state->__pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock);
  Py_CLEAR(clear_module_state->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path);
  Py_CLEAR(clear_module_state->__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path);
  Py_CLEAR(clear_module_state->__pyx_k__4);
  for (int i=0; i<3; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<34; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<280; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<7; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* Generator.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_GeneratorType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_VISIT(traverse_module_state->__pyx_ptype_9cysystemd_6reader_Rule);
  Py_VISIT(traverse_module_state->__pyx_type_9cysystemd_6reader_Rule);
  Py_VISIT(traverse_module_state->__pyx_ptype_9cysystemd_6reader_JournalEntry);
  Py_VISIT(traverse_module_state->__pyx_type_9cysystemd_6reader_JournalEntry);
  Py_VISIT(traverse_module_state->__pyx_ptype_9cysystemd_6reader_JournalReader);
  Py_VISIT(traverse_module_state->__pyx_type_9cysystemd_6reader_JournalReader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__);
  Py_VISIT(traverse_module_state->__pyx_type_9cysystemd_6reader___pyx_scope_struct____iter__);
  Py_VISIT(traverse_module_state->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock);
  Py_VISIT(traverse_module_state->__pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock);
  Py_VISIT(traverse_module_state->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path);
  Py_VISIT(traverse_module_state->__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path);
  Py_VISIT(traverse_module_state->__pyx_k__4);
  for (int i=0; i<3; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<34; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<280; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<7; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* Generator.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_GeneratorType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path")
 * cdef object __Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(str (*f)(object) ):
 *     def wrap(object path):             # <<<<<<<<<<<<<<
 *         """wrap(path) -> str"""
 *         return f(path)
*/

#line 67 "cfunc.to_py"


#line 67 "cfunc.to_py"
/* Python wrapper */

#line 67 "cfunc.to_py"
static PyObject *__pyx_pw_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_1wrap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/

#line 67 "cfunc.to_py"
PyDoc_STRVAR(__pyx_doc_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_wrap, "wrap(path) -> str");
static PyMethodDef __pyx_mdef_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_1wrap = 
#line 67 "cfunc.to_py"
{"wrap", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_1wrap, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_wrap};

#line 67 "cfunc.to_py"
static PyObject *__pyx_pw_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_1wrap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_path = 0
#line 67 "cfunc.to_py"
;

#line 67 "cfunc.to_py"
  #if !CYTHON_METH_FASTCALL

#line 67 "cfunc.to_py"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 67 "cfunc.to_py"
  #endif

#line 67 "cfunc.to_py"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 67 "cfunc.to_py"
  PyObject* values[1] = {0};

#line 67 "cfunc.to_py"
  int __pyx_lineno = 0;

#line 67 "cfunc.to_py"
  const char *__pyx_filename = NULL;

#line 67 "cfunc.to_py"
  int __pyx_clineno = 0;

#line 67 "cfunc.to_py"
  PyObject *__pyx_r = 0;

#line 67 "cfunc.to_py"
  __Pyx_RefNannyDeclarations

#line 67 "cfunc.to_py"
  __Pyx_RefNannySetupContext("wrap (wrapper)", 0);

#line 67 "cfunc.to_py"
  #if !CYTHON_METH_FASTCALL

#line 67 "cfunc.to_py"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 67 "cfunc.to_py"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 67 "cfunc.to_py"
  #else

#line 67 "cfunc.to_py"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 67 "cfunc.to_py"
  #endif

#line 67 "cfunc.to_py"
  #endif

#line 67 "cfunc.to_py"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 67 "cfunc.to_py"
  {

#line 67 "cfunc.to_py"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_path,0};

#line 67 "cfunc.to_py"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 67 "cfunc.to_py"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 67, __pyx_L3_error)

#line 67 "cfunc.to_py"
    if (__pyx_kwds_len > 0) {

#line 67 "cfunc.to_py"
      switch (__pyx_nargs) {

#line 67 "cfunc.to_py"
        case  1:

#line 67 "cfunc.to_py"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 67 "cfunc.to_py"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 67, __pyx_L3_error)

#line 67 "cfunc.to_py"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 67 "cfunc.to_py"
break;
        default: 
#line 67 "cfunc.to_py"
goto __pyx_L5_argtuple_error;

#line 67 "cfunc.to_py"
      }

#line 67 "cfunc.to_py"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 67 "cfunc.to_py"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "wrap", 0) < (0)) __PYX_ERR(1, 67, __pyx_L3_error)

#line 67 "cfunc.to_py"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 67 "cfunc.to_py"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("wrap", 1, 1, 1, i); __PYX_ERR(1, 67, __pyx_L3_error) }

#line 67 "cfunc.to_py"
      }

#line 67 "cfunc.to_py"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 67 "cfunc.to_py"
      goto __pyx_L5_argtuple_error;

#line 67 "cfunc.to_py"
    } else {

#line 67 "cfunc.to_py"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 67 "cfunc.to_py"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 67, __pyx_L3_error)

#line 67 "cfunc.to_py"
    }

#line 67 "cfunc.to_py"
    __pyx_v_path = values[0];

#line 67 "cfunc.to_py"
  }

#line 67 "cfunc.to_py"
  goto __pyx_L6_skip;

#line 67 "cfunc.to_py"
  __pyx_L5_argtuple_error:;

#line 67 "cfunc.to_py"
  __Pyx_RaiseArgtupleInvalid("wrap", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 67, __pyx_L3_error)

#line 67 "cfunc.to_py"
  __pyx_L6_skip:;

#line 67 "cfunc.to_py"
  goto __pyx_L4_argument_unpacking_done;

#line 67 "cfunc.to_py"
  __pyx_L3_error:;

#line 67 "cfunc.to_py"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 67 "cfunc.to_py"
    Py_XDECREF(values[__pyx_temp]);

#line 67 "cfunc.to_py"
  }

#line 67 "cfunc.to_py"
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 67 "cfunc.to_py"
  __Pyx_RefNannyFinishContext();

#line 67 "cfunc.to_py"
  return NULL;

#line 67 "cfunc.to_py"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 67 "cfunc.to_py"
__pyx_pf_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_wrap(__pyx_self, __pyx_v_path);

#line 67 "cfunc.to_py"


#line 67 "cfunc.to_py"
  /* function exit code */

#line 67 "cfunc.to_py"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 67 "cfunc.to_py"
    Py_XDECREF(values[__pyx_temp]);

#line 67 "cfunc.to_py"
  }

#line 67 "cfunc.to_py"
  __Pyx_RefNannyFinishContext();

#line 67 "cfunc.to_py"
  return __pyx_r;

#line 67 "cfunc.to_py"
}

#line 67 "cfunc.to_py"


#line 67 "cfunc.to_py"
static PyObject *__pyx_pf_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_wrap(PyObject *__pyx_self, PyObject *__pyx_v_path) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *__pyx_cur_scope
#line 67 "cfunc.to_py"
;
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *__pyx_outer_scope
#line 67 "cfunc.to_py"
;

#line 67 "cfunc.to_py"
  PyObject *__pyx_r = NULL;

#line 67 "cfunc.to_py"
  __Pyx_RefNannyDeclarations

#line 67 "cfunc.to_py"
  PyObject *__pyx_t_1 = NULL;

#line 67 "cfunc.to_py"
  int __pyx_lineno = 0;

#line 67 "cfunc.to_py"
  const char *__pyx_filename = NULL;

#line 67 "cfunc.to_py"
  int __pyx_clineno = 0;

#line 67 "cfunc.to_py"
  __Pyx_RefNannySetupContext("wrap", 0);

#line 67 "cfunc.to_py"
  __pyx_outer_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *) __Pyx_CyFunction_GetClosure(__pyx_self);

#line 67 "cfunc.to_py"
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cfunc.to_py":69
 *     def wrap(object path):
 *         """wrap(path) -> str"""
 *         return f(path)             # <<<<<<<<<<<<<<
 *     return wrap
 * 
*/

#line 69 "cfunc.to_py"
  __Pyx_XDECREF(__pyx_r);

#line 69 "cfunc.to_py"
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_f(__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 69, __pyx_L1_error)

#line 69 "cfunc.to_py"
  __Pyx_GOTREF(__pyx_t_1);

#line 69 "cfunc.to_py"
  __pyx_r = __pyx_t_1;

#line 69 "cfunc.to_py"
  __pyx_t_1 = 0;

#line 69 "cfunc.to_py"
  goto __pyx_L0;

  /* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path")
 * cdef object __Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(str (*f)(object) ):
 *     def wrap(object path):             # <<<<<<<<<<<<<<
 *         """wrap(path) -> str"""
 *         return f(path)
*/

#line 67 "cfunc.to_py"


#line 67 "cfunc.to_py"
  /* function exit code */

#line 67 "cfunc.to_py"
  __pyx_L1_error:;

#line 67 "cfunc.to_py"
  __Pyx_XDECREF(__pyx_t_1);

#line 67 "cfunc.to_py"
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 67 "cfunc.to_py"
  __pyx_r = NULL;

#line 67 "cfunc.to_py"
  __pyx_L0:;

#line 67 "cfunc.to_py"
  __Pyx_XGIVEREF(__pyx_r);

#line 67 "cfunc.to_py"
  __Pyx_RefNannyFinishContext();

#line 67 "cfunc.to_py"
  return __pyx_r;

#line 67 "cfunc.to_py"
}

/* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(str (*f)(object) ):
 *     def wrap(object path):
*/

#line 65 "cfunc.to_py"


#line 65 "cfunc.to_py"
static PyObject *__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(PyObject *(*__pyx_v_f)(PyObject *)) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *__pyx_cur_scope
#line 65 "cfunc.to_py"
;
  PyObject *__pyx_v_wrap = 0
#line 65 "cfunc.to_py"
;

#line 65 "cfunc.to_py"
  PyObject *__pyx_r = NULL;

#line 65 "cfunc.to_py"
  __Pyx_RefNannyDeclarations

#line 65 "cfunc.to_py"
  PyObject *__pyx_t_1 = NULL;

#line 65 "cfunc.to_py"
  int __pyx_lineno = 0;

#line 65 "cfunc.to_py"
  const char *__pyx_filename = NULL;

#line 65 "cfunc.to_py"
  int __pyx_clineno = 0;

#line 65 "cfunc.to_py"
  __Pyx_RefNannySetupContext("__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path", 0);

#line 65 "cfunc.to_py"
  __pyx_cur_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(__pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path, __pyx_mstate_global->__pyx_empty_tuple, NULL);

#line 65 "cfunc.to_py"
  if (unlikely(!__pyx_cur_scope)) {

#line 65 "cfunc.to_py"
    __pyx_cur_scope = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *)Py_None);

#line 65 "cfunc.to_py"
    __Pyx_INCREF(Py_None);

#line 65 "cfunc.to_py"
    __PYX_ERR(1, 65, __pyx_L1_error)

#line 65 "cfunc.to_py"
  } else {

#line 65 "cfunc.to_py"
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);

#line 65 "cfunc.to_py"
  }

#line 65 "cfunc.to_py"
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;

  /* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path")
 * cdef object __Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(str (*f)(object) ):
 *     def wrap(object path):             # <<<<<<<<<<<<<<
 *         """wrap(path) -> str"""
 *         return f(path)
*/

#line 67 "cfunc.to_py"
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_11cfunc_dot_to_py_68__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_1wrap, 0, __pyx_mstate_global->__pyx_n_u_Pyx_CFunc_9cysystemd_6reader_s, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_cfunc_to_py, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 67, __pyx_L1_error)

#line 67 "cfunc.to_py"
  __Pyx_GOTREF(__pyx_t_1);

#line 67 "cfunc.to_py"
  __pyx_v_wrap = __pyx_t_1;

#line 67 "cfunc.to_py"
  __pyx_t_1 = 0;

  /* "cfunc.to_py":70
 *         """wrap(path) -> str"""
 *         return f(path)
 *     return wrap             # <<<<<<<<<<<<<<
 * 
*/

#line 70 "cfunc.to_py"
  __Pyx_XDECREF(__pyx_r);

#line 70 "cfunc.to_py"
  __Pyx_INCREF(__pyx_v_wrap);

#line 70 "cfunc.to_py"
  __pyx_r = __pyx_v_wrap;

#line 70 "cfunc.to_py"
  goto __pyx_L0;

  /* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(str (*f)(object) ):
 *     def wrap(object path):
*/

#line 65 "cfunc.to_py"


#line 65 "cfunc.to_py"
  /* function exit code */

#line 65 "cfunc.to_py"
  __pyx_L1_error:;

#line 65 "cfunc.to_py"
  __Pyx_XDECREF(__pyx_t_1);

#line 65 "cfunc.to_py"
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 65 "cfunc.to_py"
  __pyx_r = 0;

#line 65 "cfunc.to_py"
  __pyx_L0:;

#line 65 "cfunc.to_py"
  __Pyx_XDECREF(__pyx_v_wrap);

#line 65 "cfunc.to_py"
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);

#line 65 "cfunc.to_py"
  __Pyx_XGIVEREF(__pyx_r);

#line 65 "cfunc.to_py"
  __Pyx_RefNannyFinishContext();

#line 65 "cfunc.to_py"
  return __pyx_r;

#line 65 "cfunc.to_py"
}

/* "carray.from_py":78
 *     object PyErr_Format(exc, const char *format, ...)
 * 
 * @cname("__Pyx_carray_from_py_uint8_t")             # <<<<<<<<<<<<<<
 * cdef int __Pyx_carray_from_py_uint8_t(object o, base_type *v, Py_ssize_t length) except -1:
 *     cdef Py_ssize_t i = length
*/

#line 78 "carray.from_py"


#line 78 "carray.from_py"
static int __Pyx_carray_from_py_uint8_t(PyObject *__pyx_v_o, uint8_t *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  Py_ssize_t __pyx_v_i
#line 78 "carray.from_py"
;
  PyObject *__pyx_v_item = NULL
#line 78 "carray.from_py"
;

#line 78 "carray.from_py"
  int __pyx_r;

#line 78 "carray.from_py"
  __Pyx_RefNannyDeclarations

#line 78 "carray.from_py"
  PyObject *__pyx_t_1 = NULL;

#line 78 "carray.from_py"
  PyObject *__pyx_t_2 = NULL;

#line 78 "carray.from_py"
  PyObject *__pyx_t_3 = NULL;

#line 78 "carray.from_py"
  Py_ssize_t __pyx_t_4;

#line 78 "carray.from_py"
  int __pyx_t_5;

#line 78 "carray.from_py"
  int __pyx_t_6;

#line 78 "carray.from_py"
  PyObject *__pyx_t_7 = NULL;

#line 78 "carray.from_py"
  Py_ssize_t __pyx_t_8;

#line 78 "carray.from_py"
  PyObject *(*__pyx_t_9)(PyObject *);

#line 78 "carray.from_py"
  PyObject *__pyx_t_10 = NULL;

#line 78 "carray.from_py"
  uint8_t __pyx_t_11;

#line 78 "carray.from_py"
  char const *__pyx_t_12;

#line 78 "carray.from_py"
  int __pyx_lineno = 0;

#line 78 "carray.from_py"
  const char *__pyx_filename = NULL;

#line 78 "carray.from_py"
  int __pyx_clineno = 0;

#line 78 "carray.from_py"
  __Pyx_RefNannySetupContext("__Pyx_carray_from_py_uint8_t", 0);

  /* "carray.from_py":80
 * @cname("__Pyx_carray_from_py_uint8_t")
 * cdef int __Pyx_carray_from_py_uint8_t(object o, base_type *v, Py_ssize_t length) except -1:
 *     cdef Py_ssize_t i = length             # <<<<<<<<<<<<<<
 *     try:
 *         i = len(o)
*/

#line 80 "carray.from_py"
  __pyx_v_i = __pyx_v_length;

  /* "carray.from_py":81
 * cdef int __Pyx_carray_from_py_uint8_t(object o, base_type *v, Py_ssize_t length) except -1:
 *     cdef Py_ssize_t i = length
 *     try:             # <<<<<<<<<<<<<<
 *         i = len(o)
 *     except (TypeError, OverflowError):
*/

#line 81 "carray.from_py"
  {

#line 81 "carray.from_py"
    __Pyx_PyThreadState_declare

#line 81 "carray.from_py"
    __Pyx_PyThreadState_assign

#line 81 "carray.from_py"
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);

#line 81 "carray.from_py"
    __Pyx_XGOTREF(__pyx_t_1);

#line 81 "carray.from_py"
    __Pyx_XGOTREF(__pyx_t_2);

#line 81 "carray.from_py"
    __Pyx_XGOTREF(__pyx_t_3);

#line 81 "carray.from_py"
    /*try:*/ {

      /* "carray.from_py":82
 *     cdef Py_ssize_t i = length
 *     try:
 *         i = len(o)             # <<<<<<<<<<<<<<
 *     except (TypeError, OverflowError):
 *         pass
*/

#line 82 "carray.from_py"
      __pyx_t_4 = PyObject_Length(__pyx_v_o); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 82, __pyx_L3_error)

#line 82 "carray.from_py"
      __pyx_v_i = __pyx_t_4;

      /* "carray.from_py":81
 * cdef int __Pyx_carray_from_py_uint8_t(object o, base_type *v, Py_ssize_t length) except -1:
 *     cdef Py_ssize_t i = length
 *     try:             # <<<<<<<<<<<<<<
 *         i = len(o)
 *     except (TypeError, OverflowError):
*/

#line 81 "carray.from_py"
    }

#line 81 "carray.from_py"
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 81 "carray.from_py"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 81 "carray.from_py"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 81 "carray.from_py"
    goto __pyx_L8_try_end;

#line 81 "carray.from_py"
    __pyx_L3_error:;

    /* "carray.from_py":83
 *     try:
 *         i = len(o)
 *     except (TypeError, OverflowError):             # <<<<<<<<<<<<<<
 *         pass
 *     if i == length:
*/

#line 83 "carray.from_py"
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches2(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), ((PyObject *)(((PyTypeObject*)PyExc_OverflowError))));

#line 83 "carray.from_py"
    if (__pyx_t_5) {

#line 83 "carray.from_py"
      __Pyx_ErrRestore(0,0,0);

#line 83 "carray.from_py"
      goto __pyx_L4_exception_handled;

#line 83 "carray.from_py"
    }

#line 83 "carray.from_py"
    goto __pyx_L5_except_error;

    /* "carray.from_py":81
 * cdef int __Pyx_carray_from_py_uint8_t(object o, base_type *v, Py_ssize_t length) except -1:
 *     cdef Py_ssize_t i = length
 *     try:             # <<<<<<<<<<<<<<
 *         i = len(o)
 *     except (TypeError, OverflowError):
*/

#line 81 "carray.from_py"
    __pyx_L5_except_error:;

#line 81 "carray.from_py"
    __Pyx_XGIVEREF(__pyx_t_1);

#line 81 "carray.from_py"
    __Pyx_XGIVEREF(__pyx_t_2);

#line 81 "carray.from_py"
    __Pyx_XGIVEREF(__pyx_t_3);

#line 81 "carray.from_py"
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);

#line 81 "carray.from_py"
    goto __pyx_L1_error;

#line 81 "carray.from_py"
    __pyx_L4_exception_handled:;

#line 81 "carray.from_py"
    __Pyx_XGIVEREF(__pyx_t_1);

#line 81 "carray.from_py"
    __Pyx_XGIVEREF(__pyx_t_2);

#line 81 "carray.from_py"
    __Pyx_XGIVEREF(__pyx_t_3);

#line 81 "carray.from_py"
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);

#line 81 "carray.from_py"
    __pyx_L8_try_end:;

#line 81 "carray.from_py"
  }

  /* "carray.from_py":85
 *     except (TypeError, OverflowError):
 *         pass
 *     if i == length:             # <<<<<<<<<<<<<<
 *         for i, item in enumerate(o):
 *             if i >= length:
*/

#line 85 "carray.from_py"
  __pyx_t_6 = (__pyx_v_i == __pyx_v_length);

#line 85 "carray.from_py"
  if (__pyx_t_6) {

    /* "carray.from_py":86
 *         pass
 *     if i == length:
 *         for i, item in enumerate(o):             # <<<<<<<<<<<<<<
 *             if i >= length:
 *                 break
*/

#line 86 "carray.from_py"
    __pyx_t_4 = 0;

#line 86 "carray.from_py"
    if (likely(PyList_CheckExact(__pyx_v_o)) || PyTuple_CheckExact(__pyx_v_o)) {

#line 86 "carray.from_py"
      __pyx_t_7 = __pyx_v_o; __Pyx_INCREF(__pyx_t_7);

#line 86 "carray.from_py"
      __pyx_t_8 = 0;

#line 86 "carray.from_py"
      __pyx_t_9 = NULL;

#line 86 "carray.from_py"
    } else {
      __pyx_t_8 = -1; 
#line 86 "carray.from_py"
__pyx_t_7 = PyObject_GetIter(__pyx_v_o); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 86, __pyx_L1_error)

#line 86 "carray.from_py"
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); 
#line 86 "carray.from_py"
if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 86, __pyx_L1_error)

#line 86 "carray.from_py"
    }
    for (;;
#line 86 "carray.from_py"
) {

#line 86 "carray.from_py"
      if (likely(!__pyx_t_9)) {

#line 86 "carray.from_py"
        if (likely(PyList_CheckExact(__pyx_t_7))) {

#line 86 "carray.from_py"
          {

#line 86 "carray.from_py"
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);

#line 86 "carray.from_py"
            #if !CYTHON_ASSUME_SAFE_SIZE

#line 86 "carray.from_py"
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 86, __pyx_L1_error)

#line 86 "carray.from_py"
            #endif

#line 86 "carray.from_py"
            if (__pyx_t_8 >= __pyx_temp) break;

#line 86 "carray.from_py"
          }

#line 86 "carray.from_py"
          __pyx_t_10 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);

#line 86 "carray.from_py"
          ++__pyx_t_8;

#line 86 "carray.from_py"
        } else {

#line 86 "carray.from_py"
          {

#line 86 "carray.from_py"
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);

#line 86 "carray.from_py"
            #if !CYTHON_ASSUME_SAFE_SIZE

#line 86 "carray.from_py"
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 86, __pyx_L1_error)

#line 86 "carray.from_py"
            #endif

#line 86 "carray.from_py"
            if (__pyx_t_8 >= __pyx_temp) break;

#line 86 "carray.from_py"
          }

#line 86 "carray.from_py"
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS

#line 86 "carray.from_py"
          __pyx_t_10 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_8));

#line 86 "carray.from_py"
          #else

#line 86 "carray.from_py"
          __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_8);

#line 86 "carray.from_py"
          #endif

#line 86 "carray.from_py"
          ++__pyx_t_8;

#line 86 "carray.from_py"
        }

#line 86 "carray.from_py"
        if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 86, __pyx_L1_error)
      } else 
#line 86 "carray.from_py"
{

#line 86 "carray.from_py"
        __pyx_t_10 = __pyx_t_9(__pyx_t_7);

#line 86 "carray.from_py"
        if (unlikely(!__pyx_t_10)) {

#line 86 "carray.from_py"
          PyObject* exc_type = PyErr_Occurred();

#line 86 "carray.from_py"
          if (exc_type) {

#line 86 "carray.from_py"
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(1, 86, __pyx_L1_error)

#line 86 "carray.from_py"
            PyErr_Clear();

#line 86 "carray.from_py"
          }

#line 86 "carray.from_py"
          break;

#line 86 "carray.from_py"
        }

#line 86 "carray.from_py"
      }

#line 86 "carray.from_py"
      __Pyx_GOTREF(__pyx_t_10);

#line 86 "carray.from_py"
      __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_10);

#line 86 "carray.from_py"
      __pyx_t_10 = 0;

#line 86 "carray.from_py"
      __pyx_v_i = __pyx_t_4;

#line 86 "carray.from_py"
      __pyx_t_4 = (__pyx_t_4 + 1);

      /* "carray.from_py":87
 *     if i == length:
 *         for i, item in enumerate(o):
 *             if i >= length:             # <<<<<<<<<<<<<<
 *                 break
 *             v[i] = item
*/

#line 87 "carray.from_py"
      __pyx_t_6 = (__pyx_v_i >= __pyx_v_length);

#line 87 "carray.from_py"
      if (__pyx_t_6) {

        /* "carray.from_py":88
 *         for i, item in enumerate(o):
 *             if i >= length:
 *                 break             # <<<<<<<<<<<<<<
 *             v[i] = item
 *         else:
*/

#line 88 "carray.from_py"
        goto __pyx_L13_break;

        /* "carray.from_py":87
 *     if i == length:
 *         for i, item in enumerate(o):
 *             if i >= length:             # <<<<<<<<<<<<<<
 *                 break
 *             v[i] = item
*/

#line 87 "carray.from_py"
      }

      /* "carray.from_py":89
 *             if i >= length:
 *                 break
 *             v[i] = item             # <<<<<<<<<<<<<<
 *         else:
 *             i += 1  # convert index to length
*/

#line 89 "carray.from_py"
      __pyx_t_11 = __Pyx_PyLong_As_uint8_t(__pyx_v_item); if (unlikely((__pyx_t_11 == ((uint8_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 89, __pyx_L1_error)

#line 89 "carray.from_py"
      (__pyx_v_v[__pyx_v_i]) = __pyx_t_11;

      /* "carray.from_py":86
 *         pass
 *     if i == length:
 *         for i, item in enumerate(o):             # <<<<<<<<<<<<<<
 *             if i >= length:
 *                 break
*/

#line 86 "carray.from_py"
    }

#line 86 "carray.from_py"
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 86 "carray.from_py"
    goto __pyx_L15_for_else;

#line 86 "carray.from_py"
    __pyx_L13_break:;

#line 86 "carray.from_py"
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 86 "carray.from_py"
    goto __pyx_L16_for_end;

#line 86 "carray.from_py"
    /*else*/ {

#line 86 "carray.from_py"
      __pyx_L15_for_else:;

      /* "carray.from_py":91
 *             v[i] = item
 *         else:
 *             i += 1  # convert index to length             # <<<<<<<<<<<<<<
 *             if i == length:
 *                 return 0
*/

#line 91 "carray.from_py"
      __pyx_v_i = (__pyx_v_i + 1);

      /* "carray.from_py":92
 *         else:
 *             i += 1  # convert index to length
 *             if i == length:             # <<<<<<<<<<<<<<
 *                 return 0
 * 
*/

#line 92 "carray.from_py"
      __pyx_t_6 = (__pyx_v_i == __pyx_v_length);

#line 92 "carray.from_py"
      if (__pyx_t_6) {

        /* "carray.from_py":93
 *             i += 1  # convert index to length
 *             if i == length:
 *                 return 0             # <<<<<<<<<<<<<<
 * 
 *     PyErr_Format(
*/

#line 93 "carray.from_py"
        __pyx_r = 0;

#line 93 "carray.from_py"
        goto __pyx_L0;

        /* "carray.from_py":92
 *         else:
 *             i += 1  # convert index to length
 *             if i == length:             # <<<<<<<<<<<<<<
 *                 return 0
 * 
*/

#line 92 "carray.from_py"
      }

#line 92 "carray.from_py"
    }

#line 92 "carray.from_py"
    __pyx_L16_for_end:;

    /* "carray.from_py":85
 *     except (TypeError, OverflowError):
 *         pass
 *     if i == length:             # <<<<<<<<<<<<<<
 *         for i, item in enumerate(o):
 *             if i >= length:
*/

#line 85 "carray.from_py"
  }

  /* "carray.from_py":98
 *         IndexError,
 *         ("too many values found during array assignment, expected %zd"
 *          if i >= length else             # <<<<<<<<<<<<<<
 *          "not enough values found during array assignment, expected %zd, got %zd"),
 *         length, i)
*/

#line 98 "carray.from_py"
  __pyx_t_6 = (__pyx_v_i >= __pyx_v_length);

#line 98 "carray.from_py"
  if (__pyx_t_6) {

#line 98 "carray.from_py"
    __pyx_t_12 = __pyx_k_too_many_values_found_during_arr;

#line 98 "carray.from_py"
  } else {

#line 98 "carray.from_py"
    __pyx_t_12 = __pyx_k_not_enough_values_found_during_a;

#line 98 "carray.from_py"
  }

  /* "carray.from_py":95
 *                 return 0
 * 
 *     PyErr_Format(             # <<<<<<<<<<<<<<
 *         IndexError,
 *         ("too many values found during array assignment, expected %zd"
*/

#line 95 "carray.from_py"
  __pyx_t_7 = PyErr_Format(((PyObject *)(((PyTypeObject*)PyExc_IndexError))), __pyx_t_12, __pyx_v_length, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 95, __pyx_L1_error)

#line 95 "carray.from_py"
  __Pyx_GOTREF(__pyx_t_7);

#line 95 "carray.from_py"
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "carray.from_py":78
 *     object PyErr_Format(exc, const char *format, ...)
 * 
 * @cname("__Pyx_carray_from_py_uint8_t")             # <<<<<<<<<<<<<<
 * cdef int __Pyx_carray_from_py_uint8_t(object o, base_type *v, Py_ssize_t length) except -1:
 *     cdef Py_ssize_t i = length
*/

#line 78 "carray.from_py"


#line 78 "carray.from_py"
  /* function exit code */

#line 78 "carray.from_py"
  __pyx_r = 0;

#line 78 "carray.from_py"
  goto __pyx_L0;

#line 78 "carray.from_py"
  __pyx_L1_error:;

#line 78 "carray.from_py"
  __Pyx_XDECREF(__pyx_t_7);

#line 78 "carray.from_py"
  __Pyx_XDECREF(__pyx_t_10);

#line 78 "carray.from_py"
  __Pyx_AddTraceback("carray.from_py.__Pyx_carray_from_py_uint8_t", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 78 "carray.from_py"
  __pyx_r = -1;

#line 78 "carray.from_py"
  __pyx_L0:;

#line 78 "carray.from_py"
  __Pyx_XDECREF(__pyx_v_item);

#line 78 "carray.from_py"
  __Pyx_RefNannyFinishContext();

#line 78 "carray.from_py"
  return __pyx_r;

#line 78 "carray.from_py"
}

/* "cpython/complex.pxd":20
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
*/

#line 20 "cpython/complex.pxd"


#line 20 "cpython/complex.pxd"
#if !CYTHON_COMPILING_IN_LIMITED_API

#line 20 "cpython/complex.pxd"
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self) {

#line 20 "cpython/complex.pxd"
  double __pyx_r;

  /* "cpython/complex.pxd":23
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
 *             return self.cval.real             # <<<<<<<<<<<<<<
 * 
 *         # unavailable in limited API
*/

#line 23 "cpython/complex.pxd"
  __pyx_r = __pyx_v_self->cval.real;

#line 23 "cpython/complex.pxd"
  goto __pyx_L0;

  /* "cpython/complex.pxd":20
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
*/

#line 20 "cpython/complex.pxd"


#line 20 "cpython/complex.pxd"
  /* function exit code */

#line 20 "cpython/complex.pxd"
  __pyx_L0:;

#line 20 "cpython/complex.pxd"
  return __pyx_r;

#line 20 "cpython/complex.pxd"
}

#line 20 "cpython/complex.pxd"
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/complex.pxd":26
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
*/

#line 26 "cpython/complex.pxd"


#line 26 "cpython/complex.pxd"
#if !CYTHON_COMPILING_IN_LIMITED_API

#line 26 "cpython/complex.pxd"
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self) {

#line 26 "cpython/complex.pxd"
  double __pyx_r;

  /* "cpython/complex.pxd":29
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
 *             return self.cval.imag             # <<<<<<<<<<<<<<
 * 
 *     # PyTypeObject PyComplex_Type
*/

#line 29 "cpython/complex.pxd"
  __pyx_r = __pyx_v_self->cval.imag;

#line 29 "cpython/complex.pxd"
  goto __pyx_L0;

  /* "cpython/complex.pxd":26
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
*/

#line 26 "cpython/complex.pxd"


#line 26 "cpython/complex.pxd"
  /* function exit code */

#line 26 "cpython/complex.pxd"
  __pyx_L0:;

#line 26 "cpython/complex.pxd"
  return __pyx_r;

#line 26 "cpython/complex.pxd"
}

#line 26 "cpython/complex.pxd"
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/contextvars.pxd":115
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#line 115 "cpython/contextvars.pxd"


#line 115 "cpython/contextvars.pxd"
#if !CYTHON_COMPILING_IN_LIMITED_API

#line 115 "cpython/contextvars.pxd"
static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value *__pyx_optional_args) {

  /* "cpython/contextvars.pxd":116
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
*/

#line 116 "cpython/contextvars.pxd"
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value
#line 116 "cpython/contextvars.pxd"
;
  PyObject *__pyx_v_pyvalue = NULL
#line 116 "cpython/contextvars.pxd"
;

#line 116 "cpython/contextvars.pxd"
  PyObject *__pyx_r = NULL;

#line 116 "cpython/contextvars.pxd"
  __Pyx_RefNannyDeclarations

#line 116 "cpython/contextvars.pxd"
  int __pyx_t_1;

#line 116 "cpython/contextvars.pxd"
  int __pyx_t_2;

#line 116 "cpython/contextvars.pxd"
  PyObject *__pyx_t_3 = NULL;

#line 116 "cpython/contextvars.pxd"
  int __pyx_lineno = 0;

#line 116 "cpython/contextvars.pxd"
  const char *__pyx_filename = NULL;

#line 116 "cpython/contextvars.pxd"
  int __pyx_clineno = 0;

#line 116 "cpython/contextvars.pxd"
  __Pyx_RefNannySetupContext("get_value", 0);

#line 116 "cpython/contextvars.pxd"
  if (__pyx_optional_args) {

#line 116 "cpython/contextvars.pxd"
    if (__pyx_optional_args->__pyx_n > 0) {

#line 116 "cpython/contextvars.pxd"
      __pyx_v_default_value = __pyx_optional_args->default_value;

#line 116 "cpython/contextvars.pxd"
    }

#line 116 "cpython/contextvars.pxd"
  }

  /* "cpython/contextvars.pxd":121
 *     or None if no such value or default was found.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:
*/

#line 121 "cpython/contextvars.pxd"
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":122
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)             # <<<<<<<<<<<<<<
 *     if value is NULL:
 *         # context variable does not have a default
*/

#line 122 "cpython/contextvars.pxd"
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, NULL, (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 122, __pyx_L1_error)

  /* "cpython/contextvars.pxd":123
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
*/

#line 123 "cpython/contextvars.pxd"
  __pyx_t_2 = (__pyx_v_value == NULL);

#line 123 "cpython/contextvars.pxd"
  if (__pyx_t_2) {

    /* "cpython/contextvars.pxd":125
 *     if value is NULL:
 *         # context variable does not have a default
 *         pyvalue = default_value             # <<<<<<<<<<<<<<
 *     else:
 *         # value or default value of context variable
*/

#line 125 "cpython/contextvars.pxd"
    __Pyx_INCREF(__pyx_v_default_value);

#line 125 "cpython/contextvars.pxd"
    __pyx_v_pyvalue = __pyx_v_default_value;

    /* "cpython/contextvars.pxd":123
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
*/

#line 123 "cpython/contextvars.pxd"
    goto __pyx_L3;

#line 123 "cpython/contextvars.pxd"
  }

  /* "cpython/contextvars.pxd":128
 *     else:
 *         # value or default value of context variable
 *         pyvalue = <object>value             # <<<<<<<<<<<<<<
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
*/

#line 128 "cpython/contextvars.pxd"
  /*else*/ {

#line 128 "cpython/contextvars.pxd"
    __pyx_t_3 = ((PyObject *)__pyx_v_value);

#line 128 "cpython/contextvars.pxd"
    __Pyx_INCREF(__pyx_t_3);

#line 128 "cpython/contextvars.pxd"
    __pyx_v_pyvalue = __pyx_t_3;

#line 128 "cpython/contextvars.pxd"
    __pyx_t_3 = 0;

    /* "cpython/contextvars.pxd":129
 *         # value or default value of context variable
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
 * 
*/

#line 129 "cpython/contextvars.pxd"
    Py_XDECREF(__pyx_v_value);

#line 129 "cpython/contextvars.pxd"
  }

#line 129 "cpython/contextvars.pxd"
  __pyx_L3:;

  /* "cpython/contextvars.pxd":130
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 130 "cpython/contextvars.pxd"
  __Pyx_XDECREF(__pyx_r);

#line 130 "cpython/contextvars.pxd"
  __Pyx_INCREF(__pyx_v_pyvalue);

#line 130 "cpython/contextvars.pxd"
  __pyx_r = __pyx_v_pyvalue;

#line 130 "cpython/contextvars.pxd"
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":115
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#line 115 "cpython/contextvars.pxd"


#line 115 "cpython/contextvars.pxd"
  /* function exit code */

#line 115 "cpython/contextvars.pxd"
  __pyx_L1_error:;

#line 115 "cpython/contextvars.pxd"
  __Pyx_XDECREF(__pyx_t_3);

#line 115 "cpython/contextvars.pxd"
  __Pyx_AddTraceback("cpython.contextvars.get_value", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 115 "cpython/contextvars.pxd"
  __pyx_r = 0;

#line 115 "cpython/contextvars.pxd"
  __pyx_L0:;

#line 115 "cpython/contextvars.pxd"
  __Pyx_XDECREF(__pyx_v_pyvalue);

#line 115 "cpython/contextvars.pxd"
  __Pyx_XGIVEREF(__pyx_r);

#line 115 "cpython/contextvars.pxd"
  __Pyx_RefNannyFinishContext();

#line 115 "cpython/contextvars.pxd"
  return __pyx_r;

#line 115 "cpython/contextvars.pxd"
}

#line 115 "cpython/contextvars.pxd"
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/contextvars.pxd":133
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value_no_default(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#line 133 "cpython/contextvars.pxd"


#line 133 "cpython/contextvars.pxd"
#if !CYTHON_COMPILING_IN_LIMITED_API

#line 133 "cpython/contextvars.pxd"
static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value_no_default(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default *__pyx_optional_args) {

  /* "cpython/contextvars.pxd":134
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
*/

#line 134 "cpython/contextvars.pxd"
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value
#line 134 "cpython/contextvars.pxd"
;
  PyObject *__pyx_v_pyvalue = NULL
#line 134 "cpython/contextvars.pxd"
;

#line 134 "cpython/contextvars.pxd"
  PyObject *__pyx_r = NULL;

#line 134 "cpython/contextvars.pxd"
  __Pyx_RefNannyDeclarations

#line 134 "cpython/contextvars.pxd"
  int __pyx_t_1;

#line 134 "cpython/contextvars.pxd"
  PyObject *__pyx_t_2 = NULL;

#line 134 "cpython/contextvars.pxd"
  int __pyx_lineno = 0;

#line 134 "cpython/contextvars.pxd"
  const char *__pyx_filename = NULL;

#line 134 "cpython/contextvars.pxd"
  int __pyx_clineno = 0;

#line 134 "cpython/contextvars.pxd"
  __Pyx_RefNannySetupContext("get_value_no_default", 0);

#line 134 "cpython/contextvars.pxd"
  if (__pyx_optional_args) {

#line 134 "cpython/contextvars.pxd"
    if (__pyx_optional_args->__pyx_n > 0) {

#line 134 "cpython/contextvars.pxd"
      __pyx_v_default_value = __pyx_optional_args->default_value;

#line 134 "cpython/contextvars.pxd"
    }

#line 134 "cpython/contextvars.pxd"
  }

  /* "cpython/contextvars.pxd":140
 *     Ignores the default value of the context variable, if any.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
*/

#line 140 "cpython/contextvars.pxd"
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":141
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)             # <<<<<<<<<<<<<<
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
*/

#line 141 "cpython/contextvars.pxd"
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, ((PyObject *)__pyx_v_default_value), (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 141, __pyx_L1_error)

  /* "cpython/contextvars.pxd":143
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value             # <<<<<<<<<<<<<<
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
*/

#line 143 "cpython/contextvars.pxd"
  __pyx_t_2 = ((PyObject *)__pyx_v_value);

#line 143 "cpython/contextvars.pxd"
  __Pyx_INCREF(__pyx_t_2);

#line 143 "cpython/contextvars.pxd"
  __pyx_v_pyvalue = __pyx_t_2;

#line 143 "cpython/contextvars.pxd"
  __pyx_t_2 = 0;

  /* "cpython/contextvars.pxd":144
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
*/

#line 144 "cpython/contextvars.pxd"
  Py_XDECREF(__pyx_v_value);

  /* "cpython/contextvars.pxd":145
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
*/

#line 145 "cpython/contextvars.pxd"
  __Pyx_XDECREF(__pyx_r);

#line 145 "cpython/contextvars.pxd"
  __Pyx_INCREF(__pyx_v_pyvalue);

#line 145 "cpython/contextvars.pxd"
  __pyx_r = __pyx_v_pyvalue;

#line 145 "cpython/contextvars.pxd"
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":133
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value_no_default(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#line 133 "cpython/contextvars.pxd"


#line 133 "cpython/contextvars.pxd"
  /* function exit code */

#line 133 "cpython/contextvars.pxd"
  __pyx_L1_error:;

#line 133 "cpython/contextvars.pxd"
  __Pyx_XDECREF(__pyx_t_2);

#line 133 "cpython/contextvars.pxd"
  __Pyx_AddTraceback("cpython.contextvars.get_value_no_default", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 133 "cpython/contextvars.pxd"
  __pyx_r = 0;

#line 133 "cpython/contextvars.pxd"
  __pyx_L0:;

#line 133 "cpython/contextvars.pxd"
  __Pyx_XDECREF(__pyx_v_pyvalue);

#line 133 "cpython/contextvars.pxd"
  __Pyx_XGIVEREF(__pyx_r);

#line 133 "cpython/contextvars.pxd"
  __Pyx_RefNannyFinishContext();

#line 133 "cpython/contextvars.pxd"
  return __pyx_r;

#line 133 "cpython/contextvars.pxd"
}

#line 133 "cpython/contextvars.pxd"
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cysystemd/reader.pyx":60
 *     cdef object _operand
 * 
 *     def __init__(self, str key, str value):             # <<<<<<<<<<<<<<
 *         cdef str exp = "=".join((key.upper(), value))
 * 
*/

#line 60 "cysystemd/reader.pyx"


#line 60 "cysystemd/reader.pyx"
/* Python wrapper */

#line 60 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/

#line 60 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_key = 0
#line 60 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_value = 0
#line 60 "cysystemd/reader.pyx"
;

#line 60 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 60 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 60 "cysystemd/reader.pyx"
  PyObject* values[2] = {0,0};

#line 60 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 60 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 60 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 60 "cysystemd/reader.pyx"
  int __pyx_r;

#line 60 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 60 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);

#line 60 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 60 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 60 "cysystemd/reader.pyx"
  #else

#line 60 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;

#line 60 "cysystemd/reader.pyx"
  #endif

#line 60 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 60 "cysystemd/reader.pyx"
  {

#line 60 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_key,&__pyx_mstate_global->__pyx_n_u_value,0};

#line 60 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;

#line 60 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 60, __pyx_L3_error)

#line 60 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 60 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 60 "cysystemd/reader.pyx"
        case  2:

#line 60 "cysystemd/reader.pyx"
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);

#line 60 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 60, __pyx_L3_error)

#line 60 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;

#line 60 "cysystemd/reader.pyx"
        case  1:

#line 60 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);

#line 60 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 60, __pyx_L3_error)

#line 60 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 60 "cysystemd/reader.pyx"
break;
        default: 
#line 60 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 60 "cysystemd/reader.pyx"
      }

#line 60 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 60 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 60, __pyx_L3_error)

#line 60 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {

#line 60 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 60, __pyx_L3_error) }

#line 60 "cysystemd/reader.pyx"
      }

#line 60 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 2)) {

#line 60 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 60 "cysystemd/reader.pyx"
    } else {

#line 60 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);

#line 60 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 60, __pyx_L3_error)

#line 60 "cysystemd/reader.pyx"
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);

#line 60 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 60, __pyx_L3_error)

#line 60 "cysystemd/reader.pyx"
    }

#line 60 "cysystemd/reader.pyx"
    __pyx_v_key = ((PyObject*)values[0]);

#line 60 "cysystemd/reader.pyx"
    __pyx_v_value = ((PyObject*)values[1]);

#line 60 "cysystemd/reader.pyx"
  }

#line 60 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 60 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 60 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 60, __pyx_L3_error)

#line 60 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 60 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 60 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 60 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 60 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 60 "cysystemd/reader.pyx"
  }

#line 60 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 60 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 60 "cysystemd/reader.pyx"
  return -1;

#line 60 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;

#line 60 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_key), (&PyUnicode_Type), 1, "key", 1))) __PYX_ERR(0, 60, __pyx_L1_error)

#line 60 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_value), (&PyUnicode_Type), 1, "value", 1))) __PYX_ERR(0, 60, __pyx_L1_error)
  __pyx_r = 
#line 60 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule___init__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self), __pyx_v_key, __pyx_v_value);

#line 60 "cysystemd/reader.pyx"


#line 60 "cysystemd/reader.pyx"
  /* function exit code */

#line 60 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 60 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 60 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 60 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 60 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 60 "cysystemd/reader.pyx"
  }

#line 60 "cysystemd/reader.pyx"
  goto __pyx_L7_cleaned_up;

#line 60 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 60 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 60 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 60 "cysystemd/reader.pyx"
  }

#line 60 "cysystemd/reader.pyx"
  __pyx_L7_cleaned_up:;

#line 60 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 60 "cysystemd/reader.pyx"
  return __pyx_r;

#line 60 "cysystemd/reader.pyx"
}

#line 60 "cysystemd/reader.pyx"


#line 60 "cysystemd/reader.pyx"
static int __pyx_pf_9cysystemd_6reader_4Rule___init__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_exp = 0
#line 60 "cysystemd/reader.pyx"
;

#line 60 "cysystemd/reader.pyx"
  int __pyx_r;

#line 60 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 60 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 60 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 60 "cysystemd/reader.pyx"
  int __pyx_t_3;

#line 60 "cysystemd/reader.pyx"
  size_t __pyx_t_4;

#line 60 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 60 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 60 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 60 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cysystemd/reader.pyx":61
 * 
 *     def __init__(self, str key, str value):
 *         cdef str exp = "=".join((key.upper(), value))             # <<<<<<<<<<<<<<
 * 
 *         if '\0' in exp:
*/

#line 61 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__upper, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 61, __pyx_L1_error)

#line 61 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 61 "cysystemd/reader.pyx"
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 61, __pyx_L1_error)

#line 61 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 61 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 61 "cysystemd/reader.pyx"
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 61, __pyx_L1_error);

#line 61 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_value);

#line 61 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_v_value);

#line 61 "cysystemd/reader.pyx"
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_value) != (0)) __PYX_ERR(0, 61, __pyx_L1_error);

#line 61 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 61 "cysystemd/reader.pyx"
  __pyx_t_1 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u_, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 61, __pyx_L1_error)

#line 61 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 61 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 61 "cysystemd/reader.pyx"
  __pyx_v_exp = ((PyObject*)__pyx_t_1);

#line 61 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":63
 *         cdef str exp = "=".join((key.upper(), value))
 * 
 *         if '\0' in exp:             # <<<<<<<<<<<<<<
 *             raise ValueError("Expression must not contains \\0 character")
 * 
*/

#line 63 "cysystemd/reader.pyx"
  if (unlikely(__pyx_v_exp == Py_None)) {

#line 63 "cysystemd/reader.pyx"
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");

#line 63 "cysystemd/reader.pyx"
    __PYX_ERR(0, 63, __pyx_L1_error)

#line 63 "cysystemd/reader.pyx"
  }

#line 63 "cysystemd/reader.pyx"
  __pyx_t_3 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_kp_u__2, __pyx_v_exp, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 63, __pyx_L1_error)

#line 63 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_3)) {

    /* "cysystemd/reader.pyx":64
 * 
 *         if '\0' in exp:
 *             raise ValueError("Expression must not contains \\0 character")             # <<<<<<<<<<<<<<
 * 
 *         self._expression = exp.encode()
*/

#line 64 "cysystemd/reader.pyx"
    __pyx_t_2 = NULL;

#line 64 "cysystemd/reader.pyx"
    __pyx_t_4 = 1;

#line 64 "cysystemd/reader.pyx"
    {

#line 64 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Expression_must_not_contains_0_c};

#line 64 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 64 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 64 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L1_error)

#line 64 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 64 "cysystemd/reader.pyx"
    }

#line 64 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 64 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 64 "cysystemd/reader.pyx"
    __PYX_ERR(0, 64, __pyx_L1_error)

    /* "cysystemd/reader.pyx":63
 *         cdef str exp = "=".join((key.upper(), value))
 * 
 *         if '\0' in exp:             # <<<<<<<<<<<<<<
 *             raise ValueError("Expression must not contains \\0 character")
 * 
*/

#line 63 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":66
 *             raise ValueError("Expression must not contains \\0 character")
 * 
 *         self._expression = exp.encode()             # <<<<<<<<<<<<<<
 *         self._child = None
 *         self._root = self
*/

#line 66 "cysystemd/reader.pyx"
  if (unlikely(__pyx_v_exp == Py_None)) {

#line 66 "cysystemd/reader.pyx"
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");

#line 66 "cysystemd/reader.pyx"
    __PYX_ERR(0, 66, __pyx_L1_error)

#line 66 "cysystemd/reader.pyx"
  }

#line 66 "cysystemd/reader.pyx"
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_exp, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 66, __pyx_L1_error)

#line 66 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 66 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 66 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_expression);

#line 66 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_expression);

#line 66 "cysystemd/reader.pyx"
  __pyx_v_self->_expression = __pyx_t_1;

#line 66 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":67
 * 
 *         self._expression = exp.encode()
 *         self._child = None             # <<<<<<<<<<<<<<
 *         self._root = self
 *         self._operand = MatchOperation.AND
*/

#line 67 "cysystemd/reader.pyx"
  __Pyx_INCREF(Py_None);

#line 67 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(Py_None);

#line 67 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_child);

#line 67 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_child);

#line 67 "cysystemd/reader.pyx"
  __pyx_v_self->_child = Py_None;

  /* "cysystemd/reader.pyx":68
 *         self._expression = exp.encode()
 *         self._child = None
 *         self._root = self             # <<<<<<<<<<<<<<
 *         self._operand = MatchOperation.AND
 * 
*/

#line 68 "cysystemd/reader.pyx"
  __Pyx_INCREF((PyObject *)__pyx_v_self);

#line 68 "cysystemd/reader.pyx"
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);

#line 68 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_root);

#line 68 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_root);

#line 68 "cysystemd/reader.pyx"
  __pyx_v_self->_root = ((PyObject *)__pyx_v_self);

  /* "cysystemd/reader.pyx":69
 *         self._child = None
 *         self._root = self
 *         self._operand = MatchOperation.AND             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 69 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_MatchOperation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 69, __pyx_L1_error)

#line 69 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 69 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_AND); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 69, __pyx_L1_error)

#line 69 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 69 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 69 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_2);

#line 69 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_operand);

#line 69 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_operand);

#line 69 "cysystemd/reader.pyx"
  __pyx_v_self->_operand = __pyx_t_2;

#line 69 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":60
 *     cdef object _operand
 * 
 *     def __init__(self, str key, str value):             # <<<<<<<<<<<<<<
 *         cdef str exp = "=".join((key.upper(), value))
 * 
*/

#line 60 "cysystemd/reader.pyx"


#line 60 "cysystemd/reader.pyx"
  /* function exit code */

#line 60 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 60 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 60 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 60 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 60 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 60 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 60 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 60 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 60 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_exp);

#line 60 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 60 "cysystemd/reader.pyx"
  return __pyx_r;

#line 60 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":71
 *         self._operand = MatchOperation.AND
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def expression(self) -> bytes:
 *         return self._expression
*/

#line 71 "cysystemd/reader.pyx"


#line 71 "cysystemd/reader.pyx"
/* Python wrapper */

#line 71 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_10expression_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 71 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_10expression_1__get__(PyObject *__pyx_v_self) {

#line 71 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 71 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 71 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 71 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 71 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 71 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_10expression___get__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self));

#line 71 "cysystemd/reader.pyx"


#line 71 "cysystemd/reader.pyx"
  /* function exit code */

#line 71 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 71 "cysystemd/reader.pyx"
  return __pyx_r;

#line 71 "cysystemd/reader.pyx"
}

#line 71 "cysystemd/reader.pyx"


#line 71 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_10expression___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self) {

#line 71 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 71 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 71 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":73
 *     @property
 *     def expression(self) -> bytes:
 *         return self._expression             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 73 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 73 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_self->_expression);

#line 73 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->_expression;

#line 73 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":71
 *         self._operand = MatchOperation.AND
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def expression(self) -> bytes:
 *         return self._expression
*/

#line 71 "cysystemd/reader.pyx"


#line 71 "cysystemd/reader.pyx"
  /* function exit code */

#line 71 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 71 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 71 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 71 "cysystemd/reader.pyx"
  return __pyx_r;

#line 71 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":75
 *         return self._expression
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def child(self) -> Rule:
 *         return self._child
*/

#line 75 "cysystemd/reader.pyx"


#line 75 "cysystemd/reader.pyx"
/* Python wrapper */

#line 75 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_5child_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 75 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_5child_1__get__(PyObject *__pyx_v_self) {

#line 75 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 75 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 75 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 75 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 75 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 75 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_5child___get__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self));

#line 75 "cysystemd/reader.pyx"


#line 75 "cysystemd/reader.pyx"
  /* function exit code */

#line 75 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 75 "cysystemd/reader.pyx"
  return __pyx_r;

#line 75 "cysystemd/reader.pyx"
}

#line 75 "cysystemd/reader.pyx"


#line 75 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_5child___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self) {

#line 75 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 75 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 75 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":77
 *     @property
 *     def child(self) -> Rule:
 *         return self._child             # <<<<<<<<<<<<<<
 * 
 *     @child.setter
*/

#line 77 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 77 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_self->_child);

#line 77 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->_child;

#line 77 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":75
 *         return self._expression
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def child(self) -> Rule:
 *         return self._child
*/

#line 75 "cysystemd/reader.pyx"


#line 75 "cysystemd/reader.pyx"
  /* function exit code */

#line 75 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 75 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 75 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 75 "cysystemd/reader.pyx"
  return __pyx_r;

#line 75 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":79
 *         return self._child
 * 
 *     @child.setter             # <<<<<<<<<<<<<<
 *     def child(self, Rule child) -> None:
 *         self._child = child
*/

#line 79 "cysystemd/reader.pyx"


#line 79 "cysystemd/reader.pyx"
/* Python wrapper */

#line 79 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_5child_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_child); /*proto*/

#line 79 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_5child_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_child) {

#line 79 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 79 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 79 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 79 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 79 "cysystemd/reader.pyx"
  int __pyx_r;

#line 79 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 79 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);

#line 79 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 79 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_child), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, 1, "child", 0))) __PYX_ERR(0, 80, __pyx_L1_error)
  __pyx_r = 
#line 79 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_5child_2__set__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self), ((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_child));

#line 79 "cysystemd/reader.pyx"


#line 79 "cysystemd/reader.pyx"
  /* function exit code */

#line 79 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 79 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 79 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 79 "cysystemd/reader.pyx"
  goto __pyx_L5_cleaned_up;

#line 79 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 79 "cysystemd/reader.pyx"
  __pyx_L5_cleaned_up:;

#line 79 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 79 "cysystemd/reader.pyx"
  return __pyx_r;

#line 79 "cysystemd/reader.pyx"
}

#line 79 "cysystemd/reader.pyx"


#line 79 "cysystemd/reader.pyx"
static int __pyx_pf_9cysystemd_6reader_4Rule_5child_2__set__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_child) {

#line 79 "cysystemd/reader.pyx"
  int __pyx_r;

#line 79 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 79 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "cysystemd/reader.pyx":81
 *     @child.setter
 *     def child(self, Rule child) -> None:
 *         self._child = child             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 81 "cysystemd/reader.pyx"
  __Pyx_INCREF((PyObject *)__pyx_v_child);

#line 81 "cysystemd/reader.pyx"
  __Pyx_GIVEREF((PyObject *)__pyx_v_child);

#line 81 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_child);

#line 81 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_child);

#line 81 "cysystemd/reader.pyx"
  __pyx_v_self->_child = ((PyObject *)__pyx_v_child);

  /* "cysystemd/reader.pyx":79
 *         return self._child
 * 
 *     @child.setter             # <<<<<<<<<<<<<<
 *     def child(self, Rule child) -> None:
 *         self._child = child
*/

#line 79 "cysystemd/reader.pyx"


#line 79 "cysystemd/reader.pyx"
  /* function exit code */

#line 79 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 79 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 79 "cysystemd/reader.pyx"
  return __pyx_r;

#line 79 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":83
 *         self._child = child
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def root(self) -> Rule:
 *         return self._root
*/

#line 83 "cysystemd/reader.pyx"


#line 83 "cysystemd/reader.pyx"
/* Python wrapper */

#line 83 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_4root_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 83 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_4root_1__get__(PyObject *__pyx_v_self) {

#line 83 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 83 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 83 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 83 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 83 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 83 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_4root___get__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self));

#line 83 "cysystemd/reader.pyx"


#line 83 "cysystemd/reader.pyx"
  /* function exit code */

#line 83 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 83 "cysystemd/reader.pyx"
  return __pyx_r;

#line 83 "cysystemd/reader.pyx"
}

#line 83 "cysystemd/reader.pyx"


#line 83 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_4root___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self) {

#line 83 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 83 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 83 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":85
 *     @property
 *     def root(self) -> Rule:
 *         return self._root             # <<<<<<<<<<<<<<
 * 
 *     @root.setter
*/

#line 85 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 85 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_self->_root);

#line 85 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->_root;

#line 85 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":83
 *         self._child = child
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def root(self) -> Rule:
 *         return self._root
*/

#line 83 "cysystemd/reader.pyx"


#line 83 "cysystemd/reader.pyx"
  /* function exit code */

#line 83 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 83 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 83 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 83 "cysystemd/reader.pyx"
  return __pyx_r;

#line 83 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":87
 *         return self._root
 * 
 *     @root.setter             # <<<<<<<<<<<<<<
 *     def root(self, Rule root) -> None:
 *         self._root = root
*/

#line 87 "cysystemd/reader.pyx"


#line 87 "cysystemd/reader.pyx"
/* Python wrapper */

#line 87 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_4root_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_root); /*proto*/

#line 87 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_4root_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_root) {

#line 87 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 87 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 87 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 87 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 87 "cysystemd/reader.pyx"
  int __pyx_r;

#line 87 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 87 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);

#line 87 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 87 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, 1, "root", 0))) __PYX_ERR(0, 88, __pyx_L1_error)
  __pyx_r = 
#line 87 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_4root_2__set__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self), ((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_root));

#line 87 "cysystemd/reader.pyx"


#line 87 "cysystemd/reader.pyx"
  /* function exit code */

#line 87 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 87 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 87 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 87 "cysystemd/reader.pyx"
  goto __pyx_L5_cleaned_up;

#line 87 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 87 "cysystemd/reader.pyx"
  __pyx_L5_cleaned_up:;

#line 87 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 87 "cysystemd/reader.pyx"
  return __pyx_r;

#line 87 "cysystemd/reader.pyx"
}

#line 87 "cysystemd/reader.pyx"


#line 87 "cysystemd/reader.pyx"
static int __pyx_pf_9cysystemd_6reader_4Rule_4root_2__set__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_root) {

#line 87 "cysystemd/reader.pyx"
  int __pyx_r;

#line 87 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 87 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "cysystemd/reader.pyx":89
 *     @root.setter
 *     def root(self, Rule root) -> None:
 *         self._root = root             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 89 "cysystemd/reader.pyx"
  __Pyx_INCREF((PyObject *)__pyx_v_root);

#line 89 "cysystemd/reader.pyx"
  __Pyx_GIVEREF((PyObject *)__pyx_v_root);

#line 89 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_root);

#line 89 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_root);

#line 89 "cysystemd/reader.pyx"
  __pyx_v_self->_root = ((PyObject *)__pyx_v_root);

  /* "cysystemd/reader.pyx":87
 *         return self._root
 * 
 *     @root.setter             # <<<<<<<<<<<<<<
 *     def root(self, Rule root) -> None:
 *         self._root = root
*/

#line 87 "cysystemd/reader.pyx"


#line 87 "cysystemd/reader.pyx"
  /* function exit code */

#line 87 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 87 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 87 "cysystemd/reader.pyx"
  return __pyx_r;

#line 87 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":91
 *         self._root = root
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def operand(self) -> MatchOperation:
 *         return self._operand
*/

#line 91 "cysystemd/reader.pyx"


#line 91 "cysystemd/reader.pyx"
/* Python wrapper */

#line 91 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_7operand_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 91 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_7operand_1__get__(PyObject *__pyx_v_self) {

#line 91 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 91 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 91 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 91 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 91 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 91 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_7operand___get__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self));

#line 91 "cysystemd/reader.pyx"


#line 91 "cysystemd/reader.pyx"
  /* function exit code */

#line 91 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 91 "cysystemd/reader.pyx"
  return __pyx_r;

#line 91 "cysystemd/reader.pyx"
}

#line 91 "cysystemd/reader.pyx"


#line 91 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_7operand___get__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self) {

#line 91 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 91 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 91 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":93
 *     @property
 *     def operand(self) -> MatchOperation:
 *         return self._operand             # <<<<<<<<<<<<<<
 * 
 *     @operand.setter
*/

#line 93 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 93 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_self->_operand);

#line 93 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->_operand;

#line 93 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":91
 *         self._root = root
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def operand(self) -> MatchOperation:
 *         return self._operand
*/

#line 91 "cysystemd/reader.pyx"


#line 91 "cysystemd/reader.pyx"
  /* function exit code */

#line 91 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 91 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 91 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 91 "cysystemd/reader.pyx"
  return __pyx_r;

#line 91 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":95
 *         return self._operand
 * 
 *     @operand.setter             # <<<<<<<<<<<<<<
 *     def operand(self, uint8_t op) -> None:
 *         self._operand = MatchOperation(op)
*/

#line 95 "cysystemd/reader.pyx"


#line 95 "cysystemd/reader.pyx"
/* Python wrapper */

#line 95 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_7operand_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_op); /*proto*/

#line 95 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_4Rule_7operand_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_op) {
  uint8_t __pyx_v_op
#line 95 "cysystemd/reader.pyx"
;

#line 95 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 95 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 95 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 95 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 95 "cysystemd/reader.pyx"
  int __pyx_r;

#line 95 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 95 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);

#line 95 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 95 "cysystemd/reader.pyx"
  assert(__pyx_arg_op); {

#line 95 "cysystemd/reader.pyx"
    __pyx_v_op = __Pyx_PyLong_As_uint8_t(__pyx_arg_op); if (unlikely((__pyx_v_op == ((uint8_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 96, __pyx_L3_error)

#line 95 "cysystemd/reader.pyx"
  }

#line 95 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 95 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 95 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.operand.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 95 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 95 "cysystemd/reader.pyx"
  return -1;

#line 95 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 95 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_7operand_2__set__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self), ((uint8_t)__pyx_v_op));

#line 95 "cysystemd/reader.pyx"


#line 95 "cysystemd/reader.pyx"
  /* function exit code */

#line 95 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 95 "cysystemd/reader.pyx"
  return __pyx_r;

#line 95 "cysystemd/reader.pyx"
}

#line 95 "cysystemd/reader.pyx"


#line 95 "cysystemd/reader.pyx"
static int __pyx_pf_9cysystemd_6reader_4Rule_7operand_2__set__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, uint8_t __pyx_v_op) {

#line 95 "cysystemd/reader.pyx"
  int __pyx_r;

#line 95 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 95 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 95 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 95 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 95 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 95 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 95 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 95 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 95 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 95 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "cysystemd/reader.pyx":97
 *     @operand.setter
 *     def operand(self, uint8_t op) -> None:
 *         self._operand = MatchOperation(op)             # <<<<<<<<<<<<<<
 * 
 *     def __and__(self, Rule other) -> Rule:
*/

#line 97 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 97 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchOperation); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 97, __pyx_L1_error)

#line 97 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 97 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_uint8_t(__pyx_v_op); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 97, __pyx_L1_error)

#line 97 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 97 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 97 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 97 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 97 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 97 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 97 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 97 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 97 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 97 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 97 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 97 "cysystemd/reader.pyx"
  }

#line 97 "cysystemd/reader.pyx"
  #endif

#line 97 "cysystemd/reader.pyx"
  {

#line 97 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 97 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 97 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 97 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 97 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 97 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)

#line 97 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 97 "cysystemd/reader.pyx"
  }

#line 97 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 97 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_operand);

#line 97 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_operand);

#line 97 "cysystemd/reader.pyx"
  __pyx_v_self->_operand = __pyx_t_1;

#line 97 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":95
 *         return self._operand
 * 
 *     @operand.setter             # <<<<<<<<<<<<<<
 *     def operand(self, uint8_t op) -> None:
 *         self._operand = MatchOperation(op)
*/

#line 95 "cysystemd/reader.pyx"


#line 95 "cysystemd/reader.pyx"
  /* function exit code */

#line 95 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 95 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 95 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 95 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 95 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 95 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 95 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 95 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.operand.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 95 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 95 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 95 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 95 "cysystemd/reader.pyx"
  return __pyx_r;

#line 95 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":99
 *         self._operand = MatchOperation(op)
 * 
 *     def __and__(self, Rule other) -> Rule:             # <<<<<<<<<<<<<<
 *         self.operand = MatchOperation.AND
 *         self.child = other
*/

#line 99 "cysystemd/reader.pyx"


#line 99 "cysystemd/reader.pyx"
/* Python wrapper */

#line 99 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_3__and__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/

#line 99 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_3__and__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {

#line 99 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 99 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 99 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 99 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 99 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 99 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 99 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__and__ (wrapper)", 0);

#line 99 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 99 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, 1, "other", 0))) __PYX_ERR(0, 99, __pyx_L1_error)
  __pyx_r = 
#line 99 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_2__and__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self), ((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_other));

#line 99 "cysystemd/reader.pyx"


#line 99 "cysystemd/reader.pyx"
  /* function exit code */

#line 99 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 99 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 99 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 99 "cysystemd/reader.pyx"
  goto __pyx_L5_cleaned_up;

#line 99 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 99 "cysystemd/reader.pyx"
  __pyx_L5_cleaned_up:;

#line 99 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 99 "cysystemd/reader.pyx"
  return __pyx_r;

#line 99 "cysystemd/reader.pyx"
}

#line 99 "cysystemd/reader.pyx"


#line 99 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_2__and__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_other) {

#line 99 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 99 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 99 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 99 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 99 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 99 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 99 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 99 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__and__", 0);

  /* "cysystemd/reader.pyx":100
 * 
 *     def __and__(self, Rule other) -> Rule:
 *         self.operand = MatchOperation.AND             # <<<<<<<<<<<<<<
 *         self.child = other
 *         other.root = self.root
*/

#line 100 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_MatchOperation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 100, __pyx_L1_error)

#line 100 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 100 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_AND); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)

#line 100 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 100 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 100 "cysystemd/reader.pyx"
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_operand, __pyx_t_2) < (0)) __PYX_ERR(0, 100, __pyx_L1_error)

#line 100 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":101
 *     def __and__(self, Rule other) -> Rule:
 *         self.operand = MatchOperation.AND
 *         self.child = other             # <<<<<<<<<<<<<<
 *         other.root = self.root
 * 
*/

#line 101 "cysystemd/reader.pyx"
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_child, ((PyObject *)__pyx_v_other)) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)

  /* "cysystemd/reader.pyx":102
 *         self.operand = MatchOperation.AND
 *         self.child = other
 *         other.root = self.root             # <<<<<<<<<<<<<<
 * 
 *         return other
*/

#line 102 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_root); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 102, __pyx_L1_error)

#line 102 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 102 "cysystemd/reader.pyx"
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_other), __pyx_mstate_global->__pyx_n_u_root, __pyx_t_2) < (0)) __PYX_ERR(0, 102, __pyx_L1_error)

#line 102 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":104
 *         other.root = self.root
 * 
 *         return other             # <<<<<<<<<<<<<<
 * 
 *     def __or__(self, Rule other) -> Rule:
*/

#line 104 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 104 "cysystemd/reader.pyx"
  __Pyx_INCREF((PyObject *)__pyx_v_other);

#line 104 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject *)__pyx_v_other);

#line 104 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":99
 *         self._operand = MatchOperation(op)
 * 
 *     def __and__(self, Rule other) -> Rule:             # <<<<<<<<<<<<<<
 *         self.operand = MatchOperation.AND
 *         self.child = other
*/

#line 99 "cysystemd/reader.pyx"


#line 99 "cysystemd/reader.pyx"
  /* function exit code */

#line 99 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 99 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 99 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 99 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__and__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 99 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 99 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 99 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 99 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 99 "cysystemd/reader.pyx"
  return __pyx_r;

#line 99 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":106
 *         return other
 * 
 *     def __or__(self, Rule other) -> Rule:             # <<<<<<<<<<<<<<
 *         self.operand = MatchOperation.OR
 *         self.child = other
*/

#line 106 "cysystemd/reader.pyx"


#line 106 "cysystemd/reader.pyx"
/* Python wrapper */

#line 106 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_5__or__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/

#line 106 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_5__or__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {

#line 106 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 106 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 106 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 106 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 106 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 106 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 106 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__or__ (wrapper)", 0);

#line 106 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 106 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, 1, "other", 0))) __PYX_ERR(0, 106, __pyx_L1_error)
  __pyx_r = 
#line 106 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_4__or__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self), ((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_other));

#line 106 "cysystemd/reader.pyx"


#line 106 "cysystemd/reader.pyx"
  /* function exit code */

#line 106 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 106 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 106 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 106 "cysystemd/reader.pyx"
  goto __pyx_L5_cleaned_up;

#line 106 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 106 "cysystemd/reader.pyx"
  __pyx_L5_cleaned_up:;

#line 106 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 106 "cysystemd/reader.pyx"
  return __pyx_r;

#line 106 "cysystemd/reader.pyx"
}

#line 106 "cysystemd/reader.pyx"


#line 106 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_4__or__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_other) {

#line 106 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 106 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 106 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 106 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 106 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 106 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 106 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 106 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__or__", 0);

  /* "cysystemd/reader.pyx":107
 * 
 *     def __or__(self, Rule other) -> Rule:
 *         self.operand = MatchOperation.OR             # <<<<<<<<<<<<<<
 *         self.child = other
 *         other.root = self.root
*/

#line 107 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_MatchOperation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 107, __pyx_L1_error)

#line 107 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 107 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OR); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)

#line 107 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 107 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 107 "cysystemd/reader.pyx"
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_operand, __pyx_t_2) < (0)) __PYX_ERR(0, 107, __pyx_L1_error)

#line 107 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":108
 *     def __or__(self, Rule other) -> Rule:
 *         self.operand = MatchOperation.OR
 *         self.child = other             # <<<<<<<<<<<<<<
 *         other.root = self.root
 * 
*/

#line 108 "cysystemd/reader.pyx"
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_child, ((PyObject *)__pyx_v_other)) < (0)) __PYX_ERR(0, 108, __pyx_L1_error)

  /* "cysystemd/reader.pyx":109
 *         self.operand = MatchOperation.OR
 *         self.child = other
 *         other.root = self.root             # <<<<<<<<<<<<<<
 * 
 *         return other
*/

#line 109 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_root); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 109, __pyx_L1_error)

#line 109 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 109 "cysystemd/reader.pyx"
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_other), __pyx_mstate_global->__pyx_n_u_root, __pyx_t_2) < (0)) __PYX_ERR(0, 109, __pyx_L1_error)

#line 109 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":111
 *         other.root = self.root
 * 
 *         return other             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self) -> str:
*/

#line 111 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 111 "cysystemd/reader.pyx"
  __Pyx_INCREF((PyObject *)__pyx_v_other);

#line 111 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject *)__pyx_v_other);

#line 111 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":106
 *         return other
 * 
 *     def __or__(self, Rule other) -> Rule:             # <<<<<<<<<<<<<<
 *         self.operand = MatchOperation.OR
 *         self.child = other
*/

#line 106 "cysystemd/reader.pyx"


#line 106 "cysystemd/reader.pyx"
  /* function exit code */

#line 106 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 106 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 106 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 106 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__or__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 106 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 106 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 106 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 106 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 106 "cysystemd/reader.pyx"
  return __pyx_r;

#line 106 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":113
 *         return other
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         ret = []
 *         for opcode, exp in self:
*/

#line 113 "cysystemd/reader.pyx"


#line 113 "cysystemd/reader.pyx"
/* Python wrapper */

#line 113 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_7__repr__(PyObject *__pyx_v_self); /*proto*/

#line 113 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_7__repr__(PyObject *__pyx_v_self) {

#line 113 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 113 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 113 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 113 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);

#line 113 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 113 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_6__repr__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self));

#line 113 "cysystemd/reader.pyx"


#line 113 "cysystemd/reader.pyx"
  /* function exit code */

#line 113 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 113 "cysystemd/reader.pyx"
  return __pyx_r;

#line 113 "cysystemd/reader.pyx"
}

#line 113 "cysystemd/reader.pyx"


#line 113 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_6__repr__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self) {
  PyObject *__pyx_v_ret = NULL
#line 113 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_opcode = NULL
#line 113 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_exp = NULL
#line 113 "cysystemd/reader.pyx"
;

#line 113 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 113 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 113 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 113 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_2;

#line 113 "cysystemd/reader.pyx"
  PyObject *(*__pyx_t_3)(PyObject *);

#line 113 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 113 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 113 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 113 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 113 "cysystemd/reader.pyx"
  PyObject *(*__pyx_t_8)(PyObject *);

#line 113 "cysystemd/reader.pyx"
  size_t __pyx_t_9;

#line 113 "cysystemd/reader.pyx"
  int __pyx_t_10;

#line 113 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 113 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 113 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 113 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "cysystemd/reader.pyx":114
 * 
 *     def __repr__(self) -> str:
 *         ret = []             # <<<<<<<<<<<<<<
 *         for opcode, exp in self:
 *             ret.append("%r" % exp.decode())
*/

#line 114 "cysystemd/reader.pyx"
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L1_error)

#line 114 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 114 "cysystemd/reader.pyx"
  __pyx_v_ret = ((PyObject*)__pyx_t_1);

#line 114 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":115
 *     def __repr__(self) -> str:
 *         ret = []
 *         for opcode, exp in self:             # <<<<<<<<<<<<<<
 *             ret.append("%r" % exp.decode())
 *             ret.append(opcode.name)
*/

#line 115 "cysystemd/reader.pyx"
  if (likely(PyList_CheckExact(((PyObject *)__pyx_v_self))) || PyTuple_CheckExact(((PyObject *)__pyx_v_self))) {

#line 115 "cysystemd/reader.pyx"
    __pyx_t_1 = ((PyObject *)__pyx_v_self); __Pyx_INCREF(__pyx_t_1);

#line 115 "cysystemd/reader.pyx"
    __pyx_t_2 = 0;

#line 115 "cysystemd/reader.pyx"
    __pyx_t_3 = NULL;

#line 115 "cysystemd/reader.pyx"
  } else {
    __pyx_t_2 = -1; 
#line 115 "cysystemd/reader.pyx"
__pyx_t_1 = PyObject_GetIter(((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); 
#line 115 "cysystemd/reader.pyx"
if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
  }
  for (;;
#line 115 "cysystemd/reader.pyx"
) {

#line 115 "cysystemd/reader.pyx"
    if (likely(!__pyx_t_3)) {

#line 115 "cysystemd/reader.pyx"
      if (likely(PyList_CheckExact(__pyx_t_1))) {

#line 115 "cysystemd/reader.pyx"
        {

#line 115 "cysystemd/reader.pyx"
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);

#line 115 "cysystemd/reader.pyx"
          #if !CYTHON_ASSUME_SAFE_SIZE

#line 115 "cysystemd/reader.pyx"
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
          #endif

#line 115 "cysystemd/reader.pyx"
          if (__pyx_t_2 >= __pyx_temp) break;

#line 115 "cysystemd/reader.pyx"
        }

#line 115 "cysystemd/reader.pyx"
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);

#line 115 "cysystemd/reader.pyx"
        ++__pyx_t_2;

#line 115 "cysystemd/reader.pyx"
      } else {

#line 115 "cysystemd/reader.pyx"
        {

#line 115 "cysystemd/reader.pyx"
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);

#line 115 "cysystemd/reader.pyx"
          #if !CYTHON_ASSUME_SAFE_SIZE

#line 115 "cysystemd/reader.pyx"
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
          #endif

#line 115 "cysystemd/reader.pyx"
          if (__pyx_t_2 >= __pyx_temp) break;

#line 115 "cysystemd/reader.pyx"
        }

#line 115 "cysystemd/reader.pyx"
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS

#line 115 "cysystemd/reader.pyx"
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));

#line 115 "cysystemd/reader.pyx"
        #else

#line 115 "cysystemd/reader.pyx"
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);

#line 115 "cysystemd/reader.pyx"
        #endif

#line 115 "cysystemd/reader.pyx"
        ++__pyx_t_2;

#line 115 "cysystemd/reader.pyx"
      }

#line 115 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
    } else 
#line 115 "cysystemd/reader.pyx"
{

#line 115 "cysystemd/reader.pyx"
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);

#line 115 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_4)) {

#line 115 "cysystemd/reader.pyx"
        PyObject* exc_type = PyErr_Occurred();

#line 115 "cysystemd/reader.pyx"
        if (exc_type) {

#line 115 "cysystemd/reader.pyx"
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
          PyErr_Clear();

#line 115 "cysystemd/reader.pyx"
        }

#line 115 "cysystemd/reader.pyx"
        break;

#line 115 "cysystemd/reader.pyx"
      }

#line 115 "cysystemd/reader.pyx"
    }

#line 115 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 115 "cysystemd/reader.pyx"
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {

#line 115 "cysystemd/reader.pyx"
      PyObject* sequence = __pyx_t_4;

#line 115 "cysystemd/reader.pyx"
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);

#line 115 "cysystemd/reader.pyx"
      if (unlikely(size != 2)) {

#line 115 "cysystemd/reader.pyx"
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);

#line 115 "cysystemd/reader.pyx"
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);

#line 115 "cysystemd/reader.pyx"
        __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
      }

#line 115 "cysystemd/reader.pyx"
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS

#line 115 "cysystemd/reader.pyx"
      if (likely(PyTuple_CheckExact(sequence))) {

#line 115 "cysystemd/reader.pyx"
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);

#line 115 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_5);

#line 115 "cysystemd/reader.pyx"
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);

#line 115 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_6);

#line 115 "cysystemd/reader.pyx"
      } else {

#line 115 "cysystemd/reader.pyx"
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);

#line 115 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_5);

#line 115 "cysystemd/reader.pyx"
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);

#line 115 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_6);

#line 115 "cysystemd/reader.pyx"
      }

#line 115 "cysystemd/reader.pyx"
      #else

#line 115 "cysystemd/reader.pyx"
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_5);

#line 115 "cysystemd/reader.pyx"
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_6);

#line 115 "cysystemd/reader.pyx"
      #endif

#line 115 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 115 "cysystemd/reader.pyx"
    } else {

#line 115 "cysystemd/reader.pyx"
      Py_ssize_t index = -1;

#line 115 "cysystemd/reader.pyx"
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_7);

#line 115 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 115 "cysystemd/reader.pyx"
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) 
#line 115 "cysystemd/reader.pyx"
goto __pyx_L5_unpacking_failed;

#line 115 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) 
#line 115 "cysystemd/reader.pyx"
goto __pyx_L5_unpacking_failed;

#line 115 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_6);

#line 115 "cysystemd/reader.pyx"
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
      __pyx_t_8 = NULL;

#line 115 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 115 "cysystemd/reader.pyx"
      goto __pyx_L6_unpacking_done;

#line 115 "cysystemd/reader.pyx"
      __pyx_L5_unpacking_failed:;

#line 115 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 115 "cysystemd/reader.pyx"
      __pyx_t_8 = NULL;

#line 115 "cysystemd/reader.pyx"
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);

#line 115 "cysystemd/reader.pyx"
      __PYX_ERR(0, 115, __pyx_L1_error)

#line 115 "cysystemd/reader.pyx"
      __pyx_L6_unpacking_done:;

#line 115 "cysystemd/reader.pyx"
    }

#line 115 "cysystemd/reader.pyx"
    __Pyx_XDECREF_SET(__pyx_v_opcode, __pyx_t_5);

#line 115 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 115 "cysystemd/reader.pyx"
    __Pyx_XDECREF_SET(__pyx_v_exp, __pyx_t_6);

#line 115 "cysystemd/reader.pyx"
    __pyx_t_6 = 0;

    /* "cysystemd/reader.pyx":116
 *         ret = []
 *         for opcode, exp in self:
 *             ret.append("%r" % exp.decode())             # <<<<<<<<<<<<<<
 *             ret.append(opcode.name)
 * 
*/

#line 116 "cysystemd/reader.pyx"
    __pyx_t_6 = __pyx_v_exp;

#line 116 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_6);

#line 116 "cysystemd/reader.pyx"
    __pyx_t_9 = 0;

#line 116 "cysystemd/reader.pyx"
    {

#line 116 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};

#line 116 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_decode, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 116 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 116 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 116, __pyx_L1_error)

#line 116 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 116 "cysystemd/reader.pyx"
    }

#line 116 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_r, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 116, __pyx_L1_error)

#line 116 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 116 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 116 "cysystemd/reader.pyx"
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_6); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 116, __pyx_L1_error)

#line 116 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cysystemd/reader.pyx":117
 *         for opcode, exp in self:
 *             ret.append("%r" % exp.decode())
 *             ret.append(opcode.name)             # <<<<<<<<<<<<<<
 * 
 *         return 'Rule(%r)' % ' '.join(ret[:-1])
*/

#line 117 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_opcode, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 117, __pyx_L1_error)

#line 117 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 117 "cysystemd/reader.pyx"
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_6); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 117, __pyx_L1_error)

#line 117 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cysystemd/reader.pyx":115
 *     def __repr__(self) -> str:
 *         ret = []
 *         for opcode, exp in self:             # <<<<<<<<<<<<<<
 *             ret.append("%r" % exp.decode())
 *             ret.append(opcode.name)
*/

#line 115 "cysystemd/reader.pyx"
  }

#line 115 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":119
 *             ret.append(opcode.name)
 * 
 *         return 'Rule(%r)' % ' '.join(ret[:-1])             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self) -> Iterator[Tuple[MatchOperation, bytes]]:
*/

#line 119 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 119 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyList_GetSlice(__pyx_v_ret, 0, -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)

#line 119 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 119 "cysystemd/reader.pyx"
  __pyx_t_6 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__3, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 119, __pyx_L1_error)

#line 119 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 119 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 119 "cysystemd/reader.pyx"
  __pyx_t_1 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Rule_r, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)

#line 119 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 119 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 119 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 119 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 119 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":113
 *         return other
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         ret = []
 *         for opcode, exp in self:
*/

#line 113 "cysystemd/reader.pyx"


#line 113 "cysystemd/reader.pyx"
  /* function exit code */

#line 113 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_7);

#line 113 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 113 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 113 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_ret);

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_opcode);

#line 113 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_exp);

#line 113 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 113 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 113 "cysystemd/reader.pyx"
  return __pyx_r;

#line 113 "cysystemd/reader.pyx"
}

#line 113 "cysystemd/reader.pyx"
static PyObject *__pyx_gb_9cysystemd_6reader_4Rule_10generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cysystemd/reader.pyx":121
 *         return 'Rule(%r)' % ' '.join(ret[:-1])
 * 
 *     def __iter__(self) -> Iterator[Tuple[MatchOperation, bytes]]:             # <<<<<<<<<<<<<<
 *         rule = self.root
 * 
*/

#line 121 "cysystemd/reader.pyx"


#line 121 "cysystemd/reader.pyx"
/* Python wrapper */

#line 121 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_9__iter__(PyObject *__pyx_v_self); /*proto*/

#line 121 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_9__iter__(PyObject *__pyx_v_self) {

#line 121 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 121 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);

#line 121 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 121 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_4Rule_8__iter__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self));

#line 121 "cysystemd/reader.pyx"


#line 121 "cysystemd/reader.pyx"
  /* function exit code */

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 121 "cysystemd/reader.pyx"
  return __pyx_r;

#line 121 "cysystemd/reader.pyx"
}

#line 121 "cysystemd/reader.pyx"


#line 121 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_8__iter__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self) {
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *__pyx_cur_scope
#line 121 "cysystemd/reader.pyx"
;

#line 121 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 121 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 121 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 121 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__iter__", 0);

#line 121 "cysystemd/reader.pyx"
  __pyx_cur_scope = (struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *)__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct____iter__(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__, __pyx_mstate_global->__pyx_empty_tuple, NULL);

#line 121 "cysystemd/reader.pyx"
  if (unlikely(!__pyx_cur_scope)) {

#line 121 "cysystemd/reader.pyx"
    __pyx_cur_scope = ((struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *)Py_None);

#line 121 "cysystemd/reader.pyx"
    __Pyx_INCREF(Py_None);

#line 121 "cysystemd/reader.pyx"
    __PYX_ERR(0, 121, __pyx_L1_error)

#line 121 "cysystemd/reader.pyx"
  } else {

#line 121 "cysystemd/reader.pyx"
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);

#line 121 "cysystemd/reader.pyx"
  }

#line 121 "cysystemd/reader.pyx"
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;

#line 121 "cysystemd/reader.pyx"
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

#line 121 "cysystemd/reader.pyx"
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

#line 121 "cysystemd/reader.pyx"
  {

#line 121 "cysystemd/reader.pyx"
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9cysystemd_6reader_4Rule_10generator, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_iter, __pyx_mstate_global->__pyx_n_u_Rule___iter, __pyx_mstate_global->__pyx_n_u_cysystemd_reader); if (unlikely(!gen)) __PYX_ERR(0, 121, __pyx_L1_error)

#line 121 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_cur_scope);

#line 121 "cysystemd/reader.pyx"
    __Pyx_RefNannyFinishContext();

#line 121 "cysystemd/reader.pyx"
    return (PyObject *) gen;

#line 121 "cysystemd/reader.pyx"
  }

#line 121 "cysystemd/reader.pyx"


#line 121 "cysystemd/reader.pyx"
  /* function exit code */

#line 121 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 121 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 121 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 121 "cysystemd/reader.pyx"
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);

#line 121 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 121 "cysystemd/reader.pyx"
  return __pyx_r;

#line 121 "cysystemd/reader.pyx"
}

#line 121 "cysystemd/reader.pyx"


#line 121 "cysystemd/reader.pyx"
static PyObject *__pyx_gb_9cysystemd_6reader_4Rule_10generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{

#line 121 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *__pyx_cur_scope = ((struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *)__pyx_generator->closure);

#line 121 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 121 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 121 "cysystemd/reader.pyx"
  int __pyx_t_2;

#line 121 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 121 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 121 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 121 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 121 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__iter__", 0);

#line 121 "cysystemd/reader.pyx"
  switch (__pyx_generator->resume_label) {

#line 121 "cysystemd/reader.pyx"
    case 0: goto __pyx_L3_first_run;

#line 121 "cysystemd/reader.pyx"
    case 1: goto __pyx_L6_resume_from_yield;

#line 121 "cysystemd/reader.pyx"
    default: /* CPython raises the right error here */

#line 121 "cysystemd/reader.pyx"
    __Pyx_RefNannyFinishContext();

#line 121 "cysystemd/reader.pyx"
    return NULL;

#line 121 "cysystemd/reader.pyx"
  }

#line 121 "cysystemd/reader.pyx"
  __pyx_L3_first_run:;

#line 121 "cysystemd/reader.pyx"
  if (unlikely(__pyx_sent_value != Py_None)) {

#line 121 "cysystemd/reader.pyx"
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");

#line 121 "cysystemd/reader.pyx"
    __PYX_ERR(0, 121, __pyx_L1_error)

#line 121 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":122
 * 
 *     def __iter__(self) -> Iterator[Tuple[MatchOperation, bytes]]:
 *         rule = self.root             # <<<<<<<<<<<<<<
 * 
 *         while rule is not None:
*/

#line 122 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_mstate_global->__pyx_n_u_root); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 122, __pyx_L1_error)

#line 122 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 122 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 122 "cysystemd/reader.pyx"
  __pyx_cur_scope->__pyx_v_rule = __pyx_t_1;

#line 122 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":124
 *         rule = self.root
 * 
 *         while rule is not None:             # <<<<<<<<<<<<<<
 *             yield rule.operand, rule.expression
 *             rule = rule.child
*/

#line 124 "cysystemd/reader.pyx"
  while (1) {

#line 124 "cysystemd/reader.pyx"
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_rule != Py_None);

#line 124 "cysystemd/reader.pyx"
    if (!__pyx_t_2) break;

    /* "cysystemd/reader.pyx":125
 * 
 *         while rule is not None:
 *             yield rule.operand, rule.expression             # <<<<<<<<<<<<<<
 *             rule = rule.child
 * 
*/

#line 125 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rule, __pyx_mstate_global->__pyx_n_u_operand); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 125, __pyx_L1_error)

#line 125 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 125 "cysystemd/reader.pyx"
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rule, __pyx_mstate_global->__pyx_n_u_expression); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 125, __pyx_L1_error)

#line 125 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_3);

#line 125 "cysystemd/reader.pyx"
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 125, __pyx_L1_error)

#line 125 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 125 "cysystemd/reader.pyx"
    __Pyx_GIVEREF(__pyx_t_1);

#line 125 "cysystemd/reader.pyx"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 125, __pyx_L1_error);

#line 125 "cysystemd/reader.pyx"
    __Pyx_GIVEREF(__pyx_t_3);

#line 125 "cysystemd/reader.pyx"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3) != (0)) __PYX_ERR(0, 125, __pyx_L1_error);

#line 125 "cysystemd/reader.pyx"
    __pyx_t_1 = 0;

#line 125 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 125 "cysystemd/reader.pyx"
    __pyx_r = __pyx_t_4;

#line 125 "cysystemd/reader.pyx"
    __pyx_t_4 = 0;

#line 125 "cysystemd/reader.pyx"
    __Pyx_XGIVEREF(__pyx_r);

#line 125 "cysystemd/reader.pyx"
    __Pyx_RefNannyFinishContext();

#line 125 "cysystemd/reader.pyx"
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);

#line 125 "cysystemd/reader.pyx"
    /* return from generator, yielding value */

#line 125 "cysystemd/reader.pyx"
    __pyx_generator->resume_label = 1;

#line 125 "cysystemd/reader.pyx"
    return __pyx_r;

#line 125 "cysystemd/reader.pyx"
    __pyx_L6_resume_from_yield:;

#line 125 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 125, __pyx_L1_error)

    /* "cysystemd/reader.pyx":126
 *         while rule is not None:
 *             yield rule.operand, rule.expression
 *             rule = rule.child             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 126 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rule, __pyx_mstate_global->__pyx_n_u_child); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 126, __pyx_L1_error)

#line 126 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 126 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_rule);

#line 126 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_rule, __pyx_t_4);

#line 126 "cysystemd/reader.pyx"
    __Pyx_GIVEREF(__pyx_t_4);

#line 126 "cysystemd/reader.pyx"
    __pyx_t_4 = 0;

#line 126 "cysystemd/reader.pyx"
  }

#line 126 "cysystemd/reader.pyx"
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cysystemd/reader.pyx":121
 *         return 'Rule(%r)' % ' '.join(ret[:-1])
 * 
 *     def __iter__(self) -> Iterator[Tuple[MatchOperation, bytes]]:             # <<<<<<<<<<<<<<
 *         rule = self.root
 * 
*/

#line 121 "cysystemd/reader.pyx"


#line 121 "cysystemd/reader.pyx"
  /* function exit code */

#line 121 "cysystemd/reader.pyx"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 121 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 121 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 121 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 121 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 121 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 121 "cysystemd/reader.pyx"
  if (__Pyx_PyErr_Occurred()) {

#line 121 "cysystemd/reader.pyx"
    __Pyx_Generator_Replace_StopIteration(0);

#line 121 "cysystemd/reader.pyx"
    __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 121 "cysystemd/reader.pyx"
  }

#line 121 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 121 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 121 "cysystemd/reader.pyx"
  #if !CYTHON_USE_EXC_INFO_STACK

#line 121 "cysystemd/reader.pyx"
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);

#line 121 "cysystemd/reader.pyx"
  #endif

#line 121 "cysystemd/reader.pyx"
  __pyx_generator->resume_label = -1;

#line 121 "cysystemd/reader.pyx"
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);

#line 121 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 121 "cysystemd/reader.pyx"
  return __pyx_r;

#line 121 "cysystemd/reader.pyx"
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
/* Python wrapper */

#line 1 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_12__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_4Rule_12__reduce_cython__ = 
#line 1 "(tree fragment)"
{"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_4Rule_12__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 1 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_12__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 1 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 1 "(tree fragment)"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 1 "(tree fragment)"
  PyObject *__pyx_r = 0;

#line 1 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 1 "(tree fragment)"
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);

#line 1 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 1 "(tree fragment)"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 1 "(tree fragment)"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 1 "(tree fragment)"
  #else

#line 1 "(tree fragment)"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 1 "(tree fragment)"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }

#line 1 "(tree fragment)"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 1 "(tree fragment)"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 1 "(tree fragment)"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 1 "(tree fragment)"
__pyx_pf_9cysystemd_6reader_4Rule_11__reduce_cython__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self));

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
  /* function exit code */

#line 1 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 1 "(tree fragment)"
  return __pyx_r;

#line 1 "(tree fragment)"
}

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_11__reduce_cython__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self) {
  PyObject *__pyx_v_state = 0
#line 1 "(tree fragment)"
;
  PyObject *__pyx_v__dict = 0
#line 1 "(tree fragment)"
;
  int __pyx_v_use_setstate
#line 1 "(tree fragment)"
;

#line 1 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 1 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 1 "(tree fragment)"
  PyObject *__pyx_t_1 = NULL;

#line 1 "(tree fragment)"
  int __pyx_t_2;

#line 1 "(tree fragment)"
  int __pyx_t_3;

#line 1 "(tree fragment)"
  PyObject *__pyx_t_4 = NULL;

#line 1 "(tree fragment)"
  PyObject *__pyx_t_5 = NULL;

#line 1 "(tree fragment)"
  int __pyx_lineno = 0;

#line 1 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 1 "(tree fragment)"
  int __pyx_clineno = 0;

#line 1 "(tree fragment)"
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self._child, self._expression, self._operand, self._root)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/

#line 5 "(tree fragment)"
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)

#line 5 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_1);

#line 5 "(tree fragment)"
  __Pyx_INCREF(__pyx_v_self->_child);

#line 5 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_v_self->_child);

#line 5 "(tree fragment)"
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->_child) != (0)) __PYX_ERR(1, 5, __pyx_L1_error);

#line 5 "(tree fragment)"
  __Pyx_INCREF(__pyx_v_self->_expression);

#line 5 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_v_self->_expression);

#line 5 "(tree fragment)"
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->_expression) != (0)) __PYX_ERR(1, 5, __pyx_L1_error);

#line 5 "(tree fragment)"
  __Pyx_INCREF(__pyx_v_self->_operand);

#line 5 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_v_self->_operand);

#line 5 "(tree fragment)"
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->_operand) != (0)) __PYX_ERR(1, 5, __pyx_L1_error);

#line 5 "(tree fragment)"
  __Pyx_INCREF(__pyx_v_self->_root);

#line 5 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_v_self->_root);

#line 5 "(tree fragment)"
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_self->_root) != (0)) __PYX_ERR(1, 5, __pyx_L1_error);

#line 5 "(tree fragment)"
  __pyx_v_state = ((PyObject*)__pyx_t_1);

#line 5 "(tree fragment)"
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self._child, self._expression, self._operand, self._root)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/

#line 6 "(tree fragment)"
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)

#line 6 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_1);

#line 6 "(tree fragment)"
  __pyx_v__dict = __pyx_t_1;

#line 6 "(tree fragment)"
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self._child, self._expression, self._operand, self._root)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/

#line 7 "(tree fragment)"
  __pyx_t_3 = (__pyx_v__dict != Py_None);

#line 7 "(tree fragment)"
  if (__pyx_t_3) {

#line 7 "(tree fragment)"
  } else {

#line 7 "(tree fragment)"
    __pyx_t_2 = __pyx_t_3;

#line 7 "(tree fragment)"
    goto __pyx_L4_bool_binop_done;

#line 7 "(tree fragment)"
  }

#line 7 "(tree fragment)"
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(1, 7, __pyx_L1_error)

#line 7 "(tree fragment)"
  __pyx_t_2 = __pyx_t_3;

#line 7 "(tree fragment)"
  __pyx_L4_bool_binop_done:;

#line 7 "(tree fragment)"
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/

#line 8 "(tree fragment)"
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)

#line 8 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_1);

#line 8 "(tree fragment)"
    __Pyx_INCREF(__pyx_v__dict);

#line 8 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_v__dict);

#line 8 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(1, 8, __pyx_L1_error);

#line 8 "(tree fragment)"
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)

#line 8 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_4);

#line 8 "(tree fragment)"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 8 "(tree fragment)"
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));

#line 8 "(tree fragment)"
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._child is not None or self._expression is not None or self._operand is not None or self._root is not None
*/

#line 9 "(tree fragment)"
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self._child, self._expression, self._operand, self._root)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/

#line 7 "(tree fragment)"
    goto __pyx_L3;

#line 7 "(tree fragment)"
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self._child is not None or self._expression is not None or self._operand is not None or self._root is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, None), state
*/

#line 11 "(tree fragment)"
  /*else*/ {

#line 11 "(tree fragment)"
    __pyx_t_3 = (__pyx_v_self->_child != Py_None);

#line 11 "(tree fragment)"
    if (!__pyx_t_3) {

#line 11 "(tree fragment)"
    } else {

#line 11 "(tree fragment)"
      __pyx_t_2 = __pyx_t_3;

#line 11 "(tree fragment)"
      goto __pyx_L6_bool_binop_done;

#line 11 "(tree fragment)"
    }

#line 11 "(tree fragment)"
    __pyx_t_3 = (__pyx_v_self->_expression != Py_None);

#line 11 "(tree fragment)"
    if (!__pyx_t_3) {

#line 11 "(tree fragment)"
    } else {

#line 11 "(tree fragment)"
      __pyx_t_2 = __pyx_t_3;

#line 11 "(tree fragment)"
      goto __pyx_L6_bool_binop_done;

#line 11 "(tree fragment)"
    }

#line 11 "(tree fragment)"
    __pyx_t_3 = (__pyx_v_self->_operand != Py_None);

#line 11 "(tree fragment)"
    if (!__pyx_t_3) {

#line 11 "(tree fragment)"
    } else {

#line 11 "(tree fragment)"
      __pyx_t_2 = __pyx_t_3;

#line 11 "(tree fragment)"
      goto __pyx_L6_bool_binop_done;

#line 11 "(tree fragment)"
    }

#line 11 "(tree fragment)"
    __pyx_t_3 = (__pyx_v_self->_root != Py_None);

#line 11 "(tree fragment)"
    __pyx_t_2 = __pyx_t_3;

#line 11 "(tree fragment)"
    __pyx_L6_bool_binop_done:;

#line 11 "(tree fragment)"
    __pyx_v_use_setstate = __pyx_t_2;

#line 11 "(tree fragment)"
  }

#line 11 "(tree fragment)"
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._child is not None or self._expression is not None or self._operand is not None or self._root is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, None), state
 *     else:
*/

#line 12 "(tree fragment)"
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self._child is not None or self._expression is not None or self._operand is not None or self._root is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, state)
*/

#line 13 "(tree fragment)"
    __Pyx_XDECREF(__pyx_r);

#line 13 "(tree fragment)"
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Rule); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)

#line 13 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_4);

#line 13 "(tree fragment)"
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)

#line 13 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_1);

#line 13 "(tree fragment)"
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));

#line 13 "(tree fragment)"
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));

#line 13 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(1, 13, __pyx_L1_error);

#line 13 "(tree fragment)"
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_265362053);

#line 13 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_265362053);

#line 13 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_265362053) != (0)) __PYX_ERR(1, 13, __pyx_L1_error);

#line 13 "(tree fragment)"
    __Pyx_INCREF(Py_None);

#line 13 "(tree fragment)"
    __Pyx_GIVEREF(Py_None);

#line 13 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(1, 13, __pyx_L1_error);

#line 13 "(tree fragment)"
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)

#line 13 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_5);

#line 13 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_t_4);

#line 13 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(1, 13, __pyx_L1_error);

#line 13 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_t_1);

#line 13 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(1, 13, __pyx_L1_error);

#line 13 "(tree fragment)"
    __Pyx_INCREF(__pyx_v_state);

#line 13 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_v_state);

#line 13 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(1, 13, __pyx_L1_error);

#line 13 "(tree fragment)"
    __pyx_t_4 = 0;

#line 13 "(tree fragment)"
    __pyx_t_1 = 0;

#line 13 "(tree fragment)"
    __pyx_r = __pyx_t_5;

#line 13 "(tree fragment)"
    __pyx_t_5 = 0;

#line 13 "(tree fragment)"
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._child is not None or self._expression is not None or self._operand is not None or self._root is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, None), state
 *     else:
*/

#line 12 "(tree fragment)"
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, None), state
 *     else:
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Rule__set_state(self, __pyx_state)
*/

#line 15 "(tree fragment)"
  /*else*/ {

#line 15 "(tree fragment)"
    __Pyx_XDECREF(__pyx_r);

#line 15 "(tree fragment)"
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Rule); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)

#line 15 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_5);

#line 15 "(tree fragment)"
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)

#line 15 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_1);

#line 15 "(tree fragment)"
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));

#line 15 "(tree fragment)"
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));

#line 15 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(1, 15, __pyx_L1_error);

#line 15 "(tree fragment)"
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_265362053);

#line 15 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_265362053);

#line 15 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_265362053) != (0)) __PYX_ERR(1, 15, __pyx_L1_error);

#line 15 "(tree fragment)"
    __Pyx_INCREF(__pyx_v_state);

#line 15 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_v_state);

#line 15 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(1, 15, __pyx_L1_error);

#line 15 "(tree fragment)"
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)

#line 15 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_4);

#line 15 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_t_5);

#line 15 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(1, 15, __pyx_L1_error);

#line 15 "(tree fragment)"
    __Pyx_GIVEREF(__pyx_t_1);

#line 15 "(tree fragment)"
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(1, 15, __pyx_L1_error);

#line 15 "(tree fragment)"
    __pyx_t_5 = 0;

#line 15 "(tree fragment)"
    __pyx_t_1 = 0;

#line 15 "(tree fragment)"
    __pyx_r = __pyx_t_4;

#line 15 "(tree fragment)"
    __pyx_t_4 = 0;

#line 15 "(tree fragment)"
    goto __pyx_L0;

#line 15 "(tree fragment)"
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
  /* function exit code */

#line 1 "(tree fragment)"
  __pyx_L1_error:;

#line 1 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_1);

#line 1 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_4);

#line 1 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_5);

#line 1 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 1 "(tree fragment)"
  __pyx_r = NULL;

#line 1 "(tree fragment)"
  __pyx_L0:;

#line 1 "(tree fragment)"
  __Pyx_XDECREF(__pyx_v_state);

#line 1 "(tree fragment)"
  __Pyx_XDECREF(__pyx_v__dict);

#line 1 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 1 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 1 "(tree fragment)"
  return __pyx_r;

#line 1 "(tree fragment)"
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Rule__set_state(self, __pyx_state)
*/

#line 16 "(tree fragment)"


#line 16 "(tree fragment)"
/* Python wrapper */

#line 16 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_14__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_4Rule_14__setstate_cython__ = 
#line 16 "(tree fragment)"
{"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_4Rule_14__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 16 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_4Rule_14__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0
#line 16 "(tree fragment)"
;

#line 16 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 16 "(tree fragment)"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 16 "(tree fragment)"
  #endif

#line 16 "(tree fragment)"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 16 "(tree fragment)"
  PyObject* values[1] = {0};

#line 16 "(tree fragment)"
  int __pyx_lineno = 0;

#line 16 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 16 "(tree fragment)"
  int __pyx_clineno = 0;

#line 16 "(tree fragment)"
  PyObject *__pyx_r = 0;

#line 16 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 16 "(tree fragment)"
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);

#line 16 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 16 "(tree fragment)"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 16 "(tree fragment)"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 16 "(tree fragment)"
  #else

#line 16 "(tree fragment)"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 16 "(tree fragment)"
  #endif

#line 16 "(tree fragment)"
  #endif

#line 16 "(tree fragment)"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 16 "(tree fragment)"
  {

#line 16 "(tree fragment)"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};

#line 16 "(tree fragment)"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 16 "(tree fragment)"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 16, __pyx_L3_error)

#line 16 "(tree fragment)"
    if (__pyx_kwds_len > 0) {

#line 16 "(tree fragment)"
      switch (__pyx_nargs) {

#line 16 "(tree fragment)"
        case  1:

#line 16 "(tree fragment)"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 16 "(tree fragment)"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 16, __pyx_L3_error)

#line 16 "(tree fragment)"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 16 "(tree fragment)"
break;
        default: 
#line 16 "(tree fragment)"
goto __pyx_L5_argtuple_error;

#line 16 "(tree fragment)"
      }

#line 16 "(tree fragment)"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 16 "(tree fragment)"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(1, 16, __pyx_L3_error)

#line 16 "(tree fragment)"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 16 "(tree fragment)"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(1, 16, __pyx_L3_error) }

#line 16 "(tree fragment)"
      }

#line 16 "(tree fragment)"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 16 "(tree fragment)"
      goto __pyx_L5_argtuple_error;

#line 16 "(tree fragment)"
    } else {

#line 16 "(tree fragment)"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 16 "(tree fragment)"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 16, __pyx_L3_error)

#line 16 "(tree fragment)"
    }

#line 16 "(tree fragment)"
    __pyx_v___pyx_state = values[0];

#line 16 "(tree fragment)"
  }

#line 16 "(tree fragment)"
  goto __pyx_L6_skip;

#line 16 "(tree fragment)"
  __pyx_L5_argtuple_error:;

#line 16 "(tree fragment)"
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)

#line 16 "(tree fragment)"
  __pyx_L6_skip:;

#line 16 "(tree fragment)"
  goto __pyx_L4_argument_unpacking_done;

#line 16 "(tree fragment)"
  __pyx_L3_error:;

#line 16 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 16 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 16 "(tree fragment)"
  }

#line 16 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 16 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 16 "(tree fragment)"
  return NULL;

#line 16 "(tree fragment)"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 16 "(tree fragment)"
__pyx_pf_9cysystemd_6reader_4Rule_13__setstate_cython__(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v_self), __pyx_v___pyx_state);

#line 16 "(tree fragment)"


#line 16 "(tree fragment)"
  /* function exit code */

#line 16 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 16 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 16 "(tree fragment)"
  }

#line 16 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 16 "(tree fragment)"
  return __pyx_r;

#line 16 "(tree fragment)"
}

#line 16 "(tree fragment)"


#line 16 "(tree fragment)"
static PyObject *__pyx_pf_9cysystemd_6reader_4Rule_13__setstate_cython__(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_self, PyObject *__pyx_v___pyx_state) {

#line 16 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 16 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 16 "(tree fragment)"
  PyObject *__pyx_t_1 = NULL;

#line 16 "(tree fragment)"
  PyObject *__pyx_t_2 = NULL;

#line 16 "(tree fragment)"
  int __pyx_lineno = 0;

#line 16 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 16 "(tree fragment)"
  int __pyx_clineno = 0;

#line 16 "(tree fragment)"
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Rule__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/

#line 17 "(tree fragment)"
  __pyx_t_1 = __pyx_v___pyx_state;

#line 17 "(tree fragment)"
  __Pyx_INCREF(__pyx_t_1);

#line 17 "(tree fragment)"
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(1, 17, __pyx_L1_error)

#line 17 "(tree fragment)"
  if (unlikely(__pyx_t_1 == Py_None)) {

#line 17 "(tree fragment)"
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");

#line 17 "(tree fragment)"
    __PYX_ERR(1, 17, __pyx_L1_error)

#line 17 "(tree fragment)"
  }

#line 17 "(tree fragment)"
  __pyx_t_2 = __pyx_f_9cysystemd_6reader___pyx_unpickle_Rule__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 17, __pyx_L1_error)

#line 17 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_2);

#line 17 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 17 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Rule__set_state(self, __pyx_state)
*/

#line 16 "(tree fragment)"


#line 16 "(tree fragment)"
  /* function exit code */

#line 16 "(tree fragment)"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 16 "(tree fragment)"
  goto __pyx_L0;

#line 16 "(tree fragment)"
  __pyx_L1_error:;

#line 16 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_1);

#line 16 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_2);

#line 16 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.Rule.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 16 "(tree fragment)"
  __pyx_r = NULL;

#line 16 "(tree fragment)"
  __pyx_L0:;

#line 16 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 16 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 16 "(tree fragment)"
  return __pyx_r;

#line 16 "(tree fragment)"
}

/* "cysystemd/reader.pyx":129
 * 
 * 
 * def check_error_code(int code) -> int:             # <<<<<<<<<<<<<<
 *     if code >= 0:
 *         return code
*/

#line 129 "cysystemd/reader.pyx"


#line 129 "cysystemd/reader.pyx"
/* Python wrapper */

#line 129 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_1check_error_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_1check_error_code = 
#line 129 "cysystemd/reader.pyx"
{"check_error_code", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_1check_error_code, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 129 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_1check_error_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_code
#line 129 "cysystemd/reader.pyx"
;

#line 129 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 129 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 129 "cysystemd/reader.pyx"
  #endif

#line 129 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 129 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 129 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 129 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 129 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 129 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 129 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("check_error_code (wrapper)", 0);

#line 129 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 129 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 129 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 129 "cysystemd/reader.pyx"
  #else

#line 129 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 129 "cysystemd/reader.pyx"
  #endif

#line 129 "cysystemd/reader.pyx"
  #endif

#line 129 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 129 "cysystemd/reader.pyx"
  {

#line 129 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_code,0};

#line 129 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 129 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 129, __pyx_L3_error)

#line 129 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 129 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 129 "cysystemd/reader.pyx"
        case  1:

#line 129 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 129 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 129, __pyx_L3_error)

#line 129 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 129 "cysystemd/reader.pyx"
break;
        default: 
#line 129 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 129 "cysystemd/reader.pyx"
      }

#line 129 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 129 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "check_error_code", 0) < (0)) __PYX_ERR(0, 129, __pyx_L3_error)

#line 129 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 129 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("check_error_code", 1, 1, 1, i); __PYX_ERR(0, 129, __pyx_L3_error) }

#line 129 "cysystemd/reader.pyx"
      }

#line 129 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 129 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 129 "cysystemd/reader.pyx"
    } else {

#line 129 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 129 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 129, __pyx_L3_error)

#line 129 "cysystemd/reader.pyx"
    }

#line 129 "cysystemd/reader.pyx"
    __pyx_v_code = __Pyx_PyLong_As_int(values[0]); if (unlikely((__pyx_v_code == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 129, __pyx_L3_error)

#line 129 "cysystemd/reader.pyx"
  }

#line 129 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 129 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 129 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("check_error_code", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 129, __pyx_L3_error)

#line 129 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 129 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 129 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 129 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 129 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 129 "cysystemd/reader.pyx"
  }

#line 129 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.check_error_code", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 129 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 129 "cysystemd/reader.pyx"
  return NULL;

#line 129 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 129 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_check_error_code(__pyx_self, __pyx_v_code);

#line 129 "cysystemd/reader.pyx"


#line 129 "cysystemd/reader.pyx"
  /* function exit code */

#line 129 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 129 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 129 "cysystemd/reader.pyx"
  }

#line 129 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 129 "cysystemd/reader.pyx"
  return __pyx_r;

#line 129 "cysystemd/reader.pyx"
}

#line 129 "cysystemd/reader.pyx"


#line 129 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_check_error_code(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_code) {
  PyObject *__pyx_v_error = NULL
#line 129 "cysystemd/reader.pyx"
;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 129 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 129 "cysystemd/reader.pyx"
  int __pyx_t_1;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 129 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 129 "cysystemd/reader.pyx"
  size_t __pyx_t_8;

#line 129 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 129 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 129 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 129 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("check_error_code", 0);

  /* "cysystemd/reader.pyx":130
 * 
 * def check_error_code(int code) -> int:
 *     if code >= 0:             # <<<<<<<<<<<<<<
 *         return code
 * 
*/

#line 130 "cysystemd/reader.pyx"
  __pyx_t_1 = (__pyx_v_code >= 0);

#line 130 "cysystemd/reader.pyx"
  if (__pyx_t_1) {

    /* "cysystemd/reader.pyx":131
 * def check_error_code(int code) -> int:
 *     if code >= 0:
 *         return code             # <<<<<<<<<<<<<<
 * 
 *     code = -code
*/

#line 131 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_r);

#line 131 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)

#line 131 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 131 "cysystemd/reader.pyx"
    if (__Pyx_PyInt_FromNumber(&__pyx_t_2, NULL, 0) < (0)) __PYX_ERR(0, 131, __pyx_L1_error)

#line 131 "cysystemd/reader.pyx"
    __pyx_r = ((PyObject*)__pyx_t_2);

#line 131 "cysystemd/reader.pyx"
    __pyx_t_2 = 0;

#line 131 "cysystemd/reader.pyx"
    goto __pyx_L0;

    /* "cysystemd/reader.pyx":130
 * 
 * def check_error_code(int code) -> int:
 *     if code >= 0:             # <<<<<<<<<<<<<<
 *         return code
 * 
*/

#line 130 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":133
 *         return code
 * 
 *     code = -code             # <<<<<<<<<<<<<<
 * 
 *     if code in errorcode:
*/

#line 133 "cysystemd/reader.pyx"
  __pyx_v_code = (-__pyx_v_code);

  /* "cysystemd/reader.pyx":135
 *     code = -code
 * 
 *     if code in errorcode:             # <<<<<<<<<<<<<<
 *         error = errorcode[code]
 *         raise SystemError(os.strerror(code), error)
*/

#line 135 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 135, __pyx_L1_error)

#line 135 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 135 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_errorcode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 135, __pyx_L1_error)

#line 135 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 135 "cysystemd/reader.pyx"
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_t_3, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 135, __pyx_L1_error)

#line 135 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 135 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 135 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_1)) {

    /* "cysystemd/reader.pyx":136
 * 
 *     if code in errorcode:
 *         error = errorcode[code]             # <<<<<<<<<<<<<<
 *         raise SystemError(os.strerror(code), error)
 * 
*/

#line 136 "cysystemd/reader.pyx"
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_errorcode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 136, __pyx_L1_error)

#line 136 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_3);

#line 136 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_3, __pyx_v_code, int, 1, __Pyx_PyLong_From_int, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L1_error)

#line 136 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 136 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 136 "cysystemd/reader.pyx"
    __pyx_v_error = __pyx_t_2;

#line 136 "cysystemd/reader.pyx"
    __pyx_t_2 = 0;

    /* "cysystemd/reader.pyx":137
 *     if code in errorcode:
 *         error = errorcode[code]
 *         raise SystemError(os.strerror(code), error)             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 137 "cysystemd/reader.pyx"
    __pyx_t_3 = NULL;

#line 137 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 137 "cysystemd/reader.pyx"
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 137, __pyx_L1_error)

#line 137 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 137 "cysystemd/reader.pyx"
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_strerror); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 137, __pyx_L1_error)

#line 137 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_7);

#line 137 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 137 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyLong_From_int(__pyx_v_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 137, __pyx_L1_error)

#line 137 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 137 "cysystemd/reader.pyx"
    __pyx_t_8 = 1;

#line 137 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 137 "cysystemd/reader.pyx"
    if (unlikely(PyMethod_Check(__pyx_t_7))) {

#line 137 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);

#line 137 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 137 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);

#line 137 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 137 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 137 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);

#line 137 "cysystemd/reader.pyx"
      __pyx_t_8 = 0;

#line 137 "cysystemd/reader.pyx"
    }

#line 137 "cysystemd/reader.pyx"
    #endif

#line 137 "cysystemd/reader.pyx"
    {

#line 137 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};

#line 137 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 137 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 137 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 137 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 137 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 137, __pyx_L1_error)

#line 137 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 137 "cysystemd/reader.pyx"
    }

#line 137 "cysystemd/reader.pyx"
    __pyx_t_8 = 1;

#line 137 "cysystemd/reader.pyx"
    {

#line 137 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_4, __pyx_v_error};

#line 137 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_SystemError)), __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 137 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 137 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 137 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 137, __pyx_L1_error)

#line 137 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 137 "cysystemd/reader.pyx"
    }

#line 137 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);

#line 137 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 137 "cysystemd/reader.pyx"
    __PYX_ERR(0, 137, __pyx_L1_error)

    /* "cysystemd/reader.pyx":135
 *     code = -code
 * 
 *     if code in errorcode:             # <<<<<<<<<<<<<<
 *         error = errorcode[code]
 *         raise SystemError(os.strerror(code), error)
*/

#line 135 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":129
 * 
 * 
 * def check_error_code(int code) -> int:             # <<<<<<<<<<<<<<
 *     if code >= 0:
 *         return code
*/

#line 129 "cysystemd/reader.pyx"


#line 129 "cysystemd/reader.pyx"
  /* function exit code */

#line 129 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);

#line 129 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 129 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 129 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 129 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 129 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 129 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 129 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 129 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_7);

#line 129 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.check_error_code", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 129 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 129 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 129 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_error);

#line 129 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 129 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 129 "cysystemd/reader.pyx"
  return __pyx_r;

#line 129 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":147
 *     CURRENT_USER = SD_JOURNAL_CURRENT_USER
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _missing_(cls, value) -> 'JournalOpenMode':
 *         if value == SD_JOURNAL_SYSTEM_ONLY:
*/

#line 147 "cysystemd/reader.pyx"


#line 147 "cysystemd/reader.pyx"
/* Python wrapper */

#line 147 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_15JournalOpenMode_1_missing_(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_15JournalOpenMode_1_missing_ = 
#line 147 "cysystemd/reader.pyx"
{"_missing_", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_15JournalOpenMode_1_missing_, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 147 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_15JournalOpenMode_1_missing_(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0
#line 147 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_value = 0
#line 147 "cysystemd/reader.pyx"
;

#line 147 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 147 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 147 "cysystemd/reader.pyx"
  #endif

#line 147 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 147 "cysystemd/reader.pyx"
  PyObject* values[2] = {0,0};

#line 147 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 147 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 147 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 147 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 147 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 147 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("_missing_ (wrapper)", 0);

#line 147 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 147 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 147 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 147 "cysystemd/reader.pyx"
  #else

#line 147 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 147 "cysystemd/reader.pyx"
  #endif

#line 147 "cysystemd/reader.pyx"
  #endif

#line 147 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 147 "cysystemd/reader.pyx"
  {

#line 147 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_value,0};

#line 147 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 147 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 147, __pyx_L3_error)

#line 147 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 147 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 147 "cysystemd/reader.pyx"
        case  2:

#line 147 "cysystemd/reader.pyx"
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);

#line 147 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 147, __pyx_L3_error)

#line 147 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;

#line 147 "cysystemd/reader.pyx"
        case  1:

#line 147 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 147 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 147, __pyx_L3_error)

#line 147 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 147 "cysystemd/reader.pyx"
break;
        default: 
#line 147 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 147 "cysystemd/reader.pyx"
      }

#line 147 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 147 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_missing_", 0) < (0)) __PYX_ERR(0, 147, __pyx_L3_error)

#line 147 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {

#line 147 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_missing_", 1, 2, 2, i); __PYX_ERR(0, 147, __pyx_L3_error) }

#line 147 "cysystemd/reader.pyx"
      }

#line 147 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 2)) {

#line 147 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 147 "cysystemd/reader.pyx"
    } else {

#line 147 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 147 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 147, __pyx_L3_error)

#line 147 "cysystemd/reader.pyx"
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);

#line 147 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 147, __pyx_L3_error)

#line 147 "cysystemd/reader.pyx"
    }

#line 147 "cysystemd/reader.pyx"
    __pyx_v_cls = values[0];

#line 147 "cysystemd/reader.pyx"
    __pyx_v_value = values[1];

#line 147 "cysystemd/reader.pyx"
  }

#line 147 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 147 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 147 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("_missing_", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 147, __pyx_L3_error)

#line 147 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 147 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 147 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 147 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 147 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 147 "cysystemd/reader.pyx"
  }

#line 147 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalOpenMode._missing_", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 147 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 147 "cysystemd/reader.pyx"
  return NULL;

#line 147 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 147 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_15JournalOpenMode__missing_(__pyx_self, __pyx_v_cls, __pyx_v_value);

#line 147 "cysystemd/reader.pyx"


#line 147 "cysystemd/reader.pyx"
  /* function exit code */

#line 147 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 147 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 147 "cysystemd/reader.pyx"
  }

#line 147 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 147 "cysystemd/reader.pyx"
  return __pyx_r;

#line 147 "cysystemd/reader.pyx"
}

#line 147 "cysystemd/reader.pyx"


#line 147 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_15JournalOpenMode__missing_(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value) {

#line 147 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 147 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 147 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 147 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 147 "cysystemd/reader.pyx"
  int __pyx_t_3;

#line 147 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 147 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 147 "cysystemd/reader.pyx"
  size_t __pyx_t_6;

#line 147 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 147 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 147 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 147 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("_missing_", 0);

  /* "cysystemd/reader.pyx":149
 *     @classmethod
 *     def _missing_(cls, value) -> 'JournalOpenMode':
 *         if value == SD_JOURNAL_SYSTEM_ONLY:             # <<<<<<<<<<<<<<
 *             warnings.warn(
 *                 "The JournalOpenMode.SYSTEM_ONLY is deprecated and the alias of "
*/

#line 149 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_SYSTEM_ONLY); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 149, __pyx_L1_error)

#line 149 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 149 "cysystemd/reader.pyx"
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_value, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 149, __pyx_L1_error)

#line 149 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 149 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 149, __pyx_L1_error)

#line 149 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 149 "cysystemd/reader.pyx"
  if (__pyx_t_3) {

    /* "cysystemd/reader.pyx":150
 *     def _missing_(cls, value) -> 'JournalOpenMode':
 *         if value == SD_JOURNAL_SYSTEM_ONLY:
 *             warnings.warn(             # <<<<<<<<<<<<<<
 *                 "The JournalOpenMode.SYSTEM_ONLY is deprecated and the alias of "
 *                 "JournalOpenMode.SYSTEM in the systemd library.",
*/

#line 150 "cysystemd/reader.pyx"
    __pyx_t_1 = NULL;

#line 150 "cysystemd/reader.pyx"
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_warnings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 150, __pyx_L1_error)

#line 150 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 150 "cysystemd/reader.pyx"
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 150, __pyx_L1_error)

#line 150 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_5);

#line 150 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cysystemd/reader.pyx":153
 *                 "The JournalOpenMode.SYSTEM_ONLY is deprecated and the alias of "
 *                 "JournalOpenMode.SYSTEM in the systemd library.",
 *                 DeprecationWarning,             # <<<<<<<<<<<<<<
 *                 stacklevel=2
 *             )
*/

#line 153 "cysystemd/reader.pyx"
    __pyx_t_6 = 1;

#line 153 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 153 "cysystemd/reader.pyx"
    if (unlikely(PyMethod_Check(__pyx_t_5))) {

#line 153 "cysystemd/reader.pyx"
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);

#line 153 "cysystemd/reader.pyx"
      assert(__pyx_t_1);

#line 153 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);

#line 153 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_1);

#line 153 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 153 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);

#line 153 "cysystemd/reader.pyx"
      __pyx_t_6 = 0;

#line 153 "cysystemd/reader.pyx"
    }

#line 153 "cysystemd/reader.pyx"
    #endif

#line 153 "cysystemd/reader.pyx"
    {

#line 153 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_The_JournalOpenMode_SYSTEM_ONLY, ((PyObject *)(((PyTypeObject*)PyExc_DeprecationWarning)))};

#line 153 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 150, __pyx_L1_error)

#line 153 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 153 "cysystemd/reader.pyx"
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stacklevel, __pyx_mstate_global->__pyx_int_2, __pyx_t_4, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)

#line 153 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);

#line 153 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 153 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 153 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 153 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)

#line 153 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 153 "cysystemd/reader.pyx"
    }

#line 153 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cysystemd/reader.pyx":156
 *                 stacklevel=2
 *             )
 *             return cls.SYSTEM             # <<<<<<<<<<<<<<
 *         raise ValueError(f"{value} is not a valid open mode")
 * 
*/

#line 156 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_r);

#line 156 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_mstate_global->__pyx_n_u_SYSTEM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)

#line 156 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 156 "cysystemd/reader.pyx"
    __pyx_r = __pyx_t_2;

#line 156 "cysystemd/reader.pyx"
    __pyx_t_2 = 0;

#line 156 "cysystemd/reader.pyx"
    goto __pyx_L0;

    /* "cysystemd/reader.pyx":149
 *     @classmethod
 *     def _missing_(cls, value) -> 'JournalOpenMode':
 *         if value == SD_JOURNAL_SYSTEM_ONLY:             # <<<<<<<<<<<<<<
 *             warnings.warn(
 *                 "The JournalOpenMode.SYSTEM_ONLY is deprecated and the alias of "
*/

#line 149 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":157
 *             )
 *             return cls.SYSTEM
 *         raise ValueError(f"{value} is not a valid open mode")             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 157 "cysystemd/reader.pyx"
  __pyx_t_5 = NULL;

#line 157 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_value, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 157, __pyx_L1_error)

#line 157 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 157 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_is_not_a_valid_open_mode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)

#line 157 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 157 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 157 "cysystemd/reader.pyx"
  __pyx_t_6 = 1;

#line 157 "cysystemd/reader.pyx"
  {

#line 157 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_1};

#line 157 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 157 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 157 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 157 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)

#line 157 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 157 "cysystemd/reader.pyx"
  }

#line 157 "cysystemd/reader.pyx"
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);

#line 157 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 157 "cysystemd/reader.pyx"
  __PYX_ERR(0, 157, __pyx_L1_error)

  /* "cysystemd/reader.pyx":147
 *     CURRENT_USER = SD_JOURNAL_CURRENT_USER
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _missing_(cls, value) -> 'JournalOpenMode':
 *         if value == SD_JOURNAL_SYSTEM_ONLY:
*/

#line 147 "cysystemd/reader.pyx"


#line 147 "cysystemd/reader.pyx"
  /* function exit code */

#line 147 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 147 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 147 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 147 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 147 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 147 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalOpenMode._missing_", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 147 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 147 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 147 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 147 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 147 "cysystemd/reader.pyx"
  return __pyx_r;

#line 147 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":167
 * 
 * 
 * cdef str _check_dir_path(object path):             # <<<<<<<<<<<<<<
 *     path = str(path)
 * 
*/

#line 167 "cysystemd/reader.pyx"


#line 167 "cysystemd/reader.pyx"
static PyObject *__pyx_f_9cysystemd_6reader__check_dir_path(PyObject *__pyx_v_path) {
  PyObject *__pyx_v_c = NULL
#line 167 "cysystemd/reader.pyx"
;

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 167 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 167 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 167 "cysystemd/reader.pyx"
  int __pyx_t_6;

#line 167 "cysystemd/reader.pyx"
  int __pyx_t_7;

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 167 "cysystemd/reader.pyx"
  PyObject *__pyx_t_10 = NULL;

#line 167 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 167 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 167 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 167 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("_check_dir_path", 0);

#line 167 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_path);

  /* "cysystemd/reader.pyx":168
 * 
 * cdef str _check_dir_path(object path):
 *     path = str(path)             # <<<<<<<<<<<<<<
 * 
 *     if not os.path.exists(path):
*/

#line 168 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 168, __pyx_L1_error)

#line 168 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 168 "cysystemd/reader.pyx"
  __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);

#line 168 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":170
 *     path = str(path)
 * 
 *     if not os.path.exists(path):             # <<<<<<<<<<<<<<
 *         raise OSError('Directory not found')
 *     elif os.path.islink(path):
*/

#line 170 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 170, __pyx_L1_error)

#line 170 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 170 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 170, __pyx_L1_error)

#line 170 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 170 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 170 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_4;

#line 170 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_2);

#line 170 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;

#line 170 "cysystemd/reader.pyx"
  {

#line 170 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_path};

#line 170 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exists, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 170 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 170 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 170 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 170, __pyx_L1_error)

#line 170 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 170 "cysystemd/reader.pyx"
  }

#line 170 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 170, __pyx_L1_error)

#line 170 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 170 "cysystemd/reader.pyx"
  __pyx_t_7 = (!__pyx_t_6);

#line 170 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_7)) {

    /* "cysystemd/reader.pyx":171
 * 
 *     if not os.path.exists(path):
 *         raise OSError('Directory not found')             # <<<<<<<<<<<<<<
 *     elif os.path.islink(path):
 *         c = 0
*/

#line 171 "cysystemd/reader.pyx"
    __pyx_t_4 = NULL;

#line 171 "cysystemd/reader.pyx"
    __pyx_t_5 = 1;

#line 171 "cysystemd/reader.pyx"
    {

#line 171 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Directory_not_found};

#line 171 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_OSError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 171 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 171 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 171, __pyx_L1_error)

#line 171 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 171 "cysystemd/reader.pyx"
    }

#line 171 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 171 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 171 "cysystemd/reader.pyx"
    __PYX_ERR(0, 171, __pyx_L1_error)

    /* "cysystemd/reader.pyx":170
 *     path = str(path)
 * 
 *     if not os.path.exists(path):             # <<<<<<<<<<<<<<
 *         raise OSError('Directory not found')
 *     elif os.path.islink(path):
*/

#line 170 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":172
 *     if not os.path.exists(path):
 *         raise OSError('Directory not found')
 *     elif os.path.islink(path):             # <<<<<<<<<<<<<<
 *         c = 0
 *         while not os.path.islink(path):
*/

#line 172 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)

#line 172 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 172 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 172, __pyx_L1_error)

#line 172 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 172 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 172 "cysystemd/reader.pyx"
  __pyx_t_4 = __pyx_t_3;

#line 172 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_4);

#line 172 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;

#line 172 "cysystemd/reader.pyx"
  {

#line 172 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_path};

#line 172 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_islink, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 172 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 172 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 172 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 172, __pyx_L1_error)

#line 172 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 172 "cysystemd/reader.pyx"
  }

#line 172 "cysystemd/reader.pyx"
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 172, __pyx_L1_error)

#line 172 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 172 "cysystemd/reader.pyx"
  if (__pyx_t_7) {

    /* "cysystemd/reader.pyx":173
 *         raise OSError('Directory not found')
 *     elif os.path.islink(path):
 *         c = 0             # <<<<<<<<<<<<<<
 *         while not os.path.islink(path):
 *             path = os.path.abspath(os.readlink(path))
*/

#line 173 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);

#line 173 "cysystemd/reader.pyx"
    __pyx_v_c = __pyx_mstate_global->__pyx_int_0;

    /* "cysystemd/reader.pyx":174
 *     elif os.path.islink(path):
 *         c = 0
 *         while not os.path.islink(path):             # <<<<<<<<<<<<<<
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1
*/

#line 174 "cysystemd/reader.pyx"
    while (1) {

#line 174 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 174, __pyx_L1_error)

#line 174 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 174 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)

#line 174 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 174 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 174 "cysystemd/reader.pyx"
      __pyx_t_3 = __pyx_t_2;

#line 174 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_3);

#line 174 "cysystemd/reader.pyx"
      __pyx_t_5 = 0;

#line 174 "cysystemd/reader.pyx"
      {

#line 174 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};

#line 174 "cysystemd/reader.pyx"
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_islink, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 174 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 174 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 174 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)

#line 174 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_1);

#line 174 "cysystemd/reader.pyx"
      }

#line 174 "cysystemd/reader.pyx"
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 174, __pyx_L1_error)

#line 174 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 174 "cysystemd/reader.pyx"
      __pyx_t_6 = (!__pyx_t_7);

#line 174 "cysystemd/reader.pyx"
      if (!__pyx_t_6) break;

      /* "cysystemd/reader.pyx":175
 *         c = 0
 *         while not os.path.islink(path):
 *             path = os.path.abspath(os.readlink(path))             # <<<<<<<<<<<<<<
 *             c += 1
 *             if c > 255:
*/

#line 175 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 175, __pyx_L1_error)

#line 175 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_3);

#line 175 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 175, __pyx_L1_error)

#line 175 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 175 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 175 "cysystemd/reader.pyx"
      __pyx_t_2 = __pyx_t_4;

#line 175 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_2);

#line 175 "cysystemd/reader.pyx"
      __pyx_t_8 = NULL;

#line 175 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 175, __pyx_L1_error)

#line 175 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_9);

#line 175 "cysystemd/reader.pyx"
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_readlink); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 175, __pyx_L1_error)

#line 175 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_10);

#line 175 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 175 "cysystemd/reader.pyx"
      __pyx_t_5 = 1;

#line 175 "cysystemd/reader.pyx"
      #if CYTHON_UNPACK_METHODS

#line 175 "cysystemd/reader.pyx"
      if (unlikely(PyMethod_Check(__pyx_t_10))) {

#line 175 "cysystemd/reader.pyx"
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);

#line 175 "cysystemd/reader.pyx"
        assert(__pyx_t_8);

#line 175 "cysystemd/reader.pyx"
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);

#line 175 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_8);

#line 175 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx__function);

#line 175 "cysystemd/reader.pyx"
        __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);

#line 175 "cysystemd/reader.pyx"
        __pyx_t_5 = 0;

#line 175 "cysystemd/reader.pyx"
      }

#line 175 "cysystemd/reader.pyx"
      #endif

#line 175 "cysystemd/reader.pyx"
      {

#line 175 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_path};

#line 175 "cysystemd/reader.pyx"
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 175 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 175 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

#line 175 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 175, __pyx_L1_error)

#line 175 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_3);

#line 175 "cysystemd/reader.pyx"
      }

#line 175 "cysystemd/reader.pyx"
      __pyx_t_5 = 0;

#line 175 "cysystemd/reader.pyx"
      {

#line 175 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};

#line 175 "cysystemd/reader.pyx"
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_abspath, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 175 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 175 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 175 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 175 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 175, __pyx_L1_error)

#line 175 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_1);

#line 175 "cysystemd/reader.pyx"
      }

#line 175 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);

#line 175 "cysystemd/reader.pyx"
      __pyx_t_1 = 0;

      /* "cysystemd/reader.pyx":176
 *         while not os.path.islink(path):
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1             # <<<<<<<<<<<<<<
 *             if c > 255:
 *                 raise OSError("Link recursive reslolution error")
*/

#line 176 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyLong_AddObjC(__pyx_v_c, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)

#line 176 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 176 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_v_c, __pyx_t_1);

#line 176 "cysystemd/reader.pyx"
      __pyx_t_1 = 0;

      /* "cysystemd/reader.pyx":177
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1
 *             if c > 255:             # <<<<<<<<<<<<<<
 *                 raise OSError("Link recursive reslolution error")
 * 
*/

#line 177 "cysystemd/reader.pyx"
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_c, __pyx_mstate_global->__pyx_int_255, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)

#line 177 "cysystemd/reader.pyx"
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 177, __pyx_L1_error)

#line 177 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 177 "cysystemd/reader.pyx"
      if (unlikely(__pyx_t_6)) {

        /* "cysystemd/reader.pyx":178
 *             c += 1
 *             if c > 255:
 *                 raise OSError("Link recursive reslolution error")             # <<<<<<<<<<<<<<
 * 
 *         return _check_dir_path(path)
*/

#line 178 "cysystemd/reader.pyx"
        __pyx_t_4 = NULL;

#line 178 "cysystemd/reader.pyx"
        __pyx_t_5 = 1;

#line 178 "cysystemd/reader.pyx"
        {

#line 178 "cysystemd/reader.pyx"
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Link_recursive_reslolution_error};

#line 178 "cysystemd/reader.pyx"
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_OSError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 178 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 178 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 178, __pyx_L1_error)

#line 178 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_1);

#line 178 "cysystemd/reader.pyx"
        }

#line 178 "cysystemd/reader.pyx"
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 178 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 178 "cysystemd/reader.pyx"
        __PYX_ERR(0, 178, __pyx_L1_error)

        /* "cysystemd/reader.pyx":177
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1
 *             if c > 255:             # <<<<<<<<<<<<<<
 *                 raise OSError("Link recursive reslolution error")
 * 
*/

#line 177 "cysystemd/reader.pyx"
      }

#line 177 "cysystemd/reader.pyx"
    }

    /* "cysystemd/reader.pyx":180
 *                 raise OSError("Link recursive reslolution error")
 * 
 *         return _check_dir_path(path)             # <<<<<<<<<<<<<<
 *     elif not os.path.isdir(path):
 *         raise OSError("It's not a directory")
*/

#line 180 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_r);

#line 180 "cysystemd/reader.pyx"
    __pyx_t_1 = __pyx_f_9cysystemd_6reader__check_dir_path(__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)

#line 180 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 180 "cysystemd/reader.pyx"
    __pyx_r = ((PyObject*)__pyx_t_1);

#line 180 "cysystemd/reader.pyx"
    __pyx_t_1 = 0;

#line 180 "cysystemd/reader.pyx"
    goto __pyx_L0;

    /* "cysystemd/reader.pyx":172
 *     if not os.path.exists(path):
 *         raise OSError('Directory not found')
 *     elif os.path.islink(path):             # <<<<<<<<<<<<<<
 *         c = 0
 *         while not os.path.islink(path):
*/

#line 172 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":181
 * 
 *         return _check_dir_path(path)
 *     elif not os.path.isdir(path):             # <<<<<<<<<<<<<<
 *         raise OSError("It's not a directory")
 *     else:
*/

#line 181 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 181, __pyx_L1_error)

#line 181 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 181 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)

#line 181 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 181 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 181 "cysystemd/reader.pyx"
  __pyx_t_4 = __pyx_t_2;

#line 181 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_4);

#line 181 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;

#line 181 "cysystemd/reader.pyx"
  {

#line 181 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_path};

#line 181 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_isdir, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 181 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 181 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 181 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)

#line 181 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 181 "cysystemd/reader.pyx"
  }

#line 181 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 181, __pyx_L1_error)

#line 181 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 181 "cysystemd/reader.pyx"
  __pyx_t_7 = (!__pyx_t_6);

#line 181 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_7)) {

    /* "cysystemd/reader.pyx":182
 *         return _check_dir_path(path)
 *     elif not os.path.isdir(path):
 *         raise OSError("It's not a directory")             # <<<<<<<<<<<<<<
 *     else:
 *         path = os.path.abspath(path)
*/

#line 182 "cysystemd/reader.pyx"
    __pyx_t_2 = NULL;

#line 182 "cysystemd/reader.pyx"
    __pyx_t_5 = 1;

#line 182 "cysystemd/reader.pyx"
    {

#line 182 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_It_s_not_a_directory};

#line 182 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_OSError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 182 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 182 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)

#line 182 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 182 "cysystemd/reader.pyx"
    }

#line 182 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 182 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 182 "cysystemd/reader.pyx"
    __PYX_ERR(0, 182, __pyx_L1_error)

    /* "cysystemd/reader.pyx":181
 * 
 *         return _check_dir_path(path)
 *     elif not os.path.isdir(path):             # <<<<<<<<<<<<<<
 *         raise OSError("It's not a directory")
 *     else:
*/

#line 181 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":184
 *         raise OSError("It's not a directory")
 *     else:
 *         path = os.path.abspath(path)             # <<<<<<<<<<<<<<
 * 
 *     return path
*/

#line 184 "cysystemd/reader.pyx"
  /*else*/ {

#line 184 "cysystemd/reader.pyx"
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 184, __pyx_L1_error)

#line 184 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 184 "cysystemd/reader.pyx"
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 184, __pyx_L1_error)

#line 184 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_3);

#line 184 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 184 "cysystemd/reader.pyx"
    __pyx_t_2 = __pyx_t_3;

#line 184 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 184 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 184 "cysystemd/reader.pyx"
    {

#line 184 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_path};

#line 184 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_abspath, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 184 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 184 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 184 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)

#line 184 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 184 "cysystemd/reader.pyx"
    }

#line 184 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);

#line 184 "cysystemd/reader.pyx"
    __pyx_t_1 = 0;

#line 184 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":186
 *         path = os.path.abspath(path)
 * 
 *     return path             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 186 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 186 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_v_path;

#line 186 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_1);

#line 186 "cysystemd/reader.pyx"
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_1))) __PYX_ERR(0, 186, __pyx_L1_error)

#line 186 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject*)__pyx_t_1);

#line 186 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 186 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":167
 * 
 * 
 * cdef str _check_dir_path(object path):             # <<<<<<<<<<<<<<
 *     path = str(path)
 * 
*/

#line 167 "cysystemd/reader.pyx"


#line 167 "cysystemd/reader.pyx"
  /* function exit code */

#line 167 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_8);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_9);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_10);

#line 167 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader._check_dir_path", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 167 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 167 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_c);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_path);

#line 167 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 167 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 167 "cysystemd/reader.pyx"
  return __pyx_r;

#line 167 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":189
 * 
 * 
 * cdef str _check_file_path(object path):             # <<<<<<<<<<<<<<
 *     path = str(path)
 * 
*/

#line 189 "cysystemd/reader.pyx"


#line 189 "cysystemd/reader.pyx"
static PyObject *__pyx_f_9cysystemd_6reader__check_file_path(PyObject *__pyx_v_path) {
  PyObject *__pyx_v_c = NULL
#line 189 "cysystemd/reader.pyx"
;

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 189 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 189 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 189 "cysystemd/reader.pyx"
  int __pyx_t_6;

#line 189 "cysystemd/reader.pyx"
  int __pyx_t_7;

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 189 "cysystemd/reader.pyx"
  PyObject *__pyx_t_10 = NULL;

#line 189 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 189 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 189 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 189 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("_check_file_path", 0);

#line 189 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_path);

  /* "cysystemd/reader.pyx":190
 * 
 * cdef str _check_file_path(object path):
 *     path = str(path)             # <<<<<<<<<<<<<<
 * 
 *     if not os.path.exists(path):
*/

#line 190 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 190, __pyx_L1_error)

#line 190 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 190 "cysystemd/reader.pyx"
  __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);

#line 190 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":192
 *     path = str(path)
 * 
 *     if not os.path.exists(path):             # <<<<<<<<<<<<<<
 *         raise OSError('File not found')
 *     elif os.path.islink(path):
*/

#line 192 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 192, __pyx_L1_error)

#line 192 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 192 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 192, __pyx_L1_error)

#line 192 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 192 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 192 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_4;

#line 192 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_2);

#line 192 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;

#line 192 "cysystemd/reader.pyx"
  {

#line 192 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_path};

#line 192 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exists, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 192 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 192 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 192 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 192, __pyx_L1_error)

#line 192 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 192 "cysystemd/reader.pyx"
  }

#line 192 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 192, __pyx_L1_error)

#line 192 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 192 "cysystemd/reader.pyx"
  __pyx_t_7 = (!__pyx_t_6);

#line 192 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_7)) {

    /* "cysystemd/reader.pyx":193
 * 
 *     if not os.path.exists(path):
 *         raise OSError('File not found')             # <<<<<<<<<<<<<<
 *     elif os.path.islink(path):
 *         c = 0
*/

#line 193 "cysystemd/reader.pyx"
    __pyx_t_4 = NULL;

#line 193 "cysystemd/reader.pyx"
    __pyx_t_5 = 1;

#line 193 "cysystemd/reader.pyx"
    {

#line 193 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_File_not_found};

#line 193 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_OSError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 193 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 193 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 193, __pyx_L1_error)

#line 193 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 193 "cysystemd/reader.pyx"
    }

#line 193 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 193 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 193 "cysystemd/reader.pyx"
    __PYX_ERR(0, 193, __pyx_L1_error)

    /* "cysystemd/reader.pyx":192
 *     path = str(path)
 * 
 *     if not os.path.exists(path):             # <<<<<<<<<<<<<<
 *         raise OSError('File not found')
 *     elif os.path.islink(path):
*/

#line 192 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":194
 *     if not os.path.exists(path):
 *         raise OSError('File not found')
 *     elif os.path.islink(path):             # <<<<<<<<<<<<<<
 *         c = 0
 *         while not os.path.islink(path):
*/

#line 194 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 194, __pyx_L1_error)

#line 194 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 194 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 194, __pyx_L1_error)

#line 194 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 194 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 194 "cysystemd/reader.pyx"
  __pyx_t_4 = __pyx_t_3;

#line 194 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_4);

#line 194 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;

#line 194 "cysystemd/reader.pyx"
  {

#line 194 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_path};

#line 194 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_islink, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 194 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 194 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 194 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)

#line 194 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 194 "cysystemd/reader.pyx"
  }

#line 194 "cysystemd/reader.pyx"
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 194, __pyx_L1_error)

#line 194 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 194 "cysystemd/reader.pyx"
  if (__pyx_t_7) {

    /* "cysystemd/reader.pyx":195
 *         raise OSError('File not found')
 *     elif os.path.islink(path):
 *         c = 0             # <<<<<<<<<<<<<<
 *         while not os.path.islink(path):
 *             path = os.path.abspath(os.readlink(path))
*/

#line 195 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);

#line 195 "cysystemd/reader.pyx"
    __pyx_v_c = __pyx_mstate_global->__pyx_int_0;

    /* "cysystemd/reader.pyx":196
 *     elif os.path.islink(path):
 *         c = 0
 *         while not os.path.islink(path):             # <<<<<<<<<<<<<<
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1
*/

#line 196 "cysystemd/reader.pyx"
    while (1) {

#line 196 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 196, __pyx_L1_error)

#line 196 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 196 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)

#line 196 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 196 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 196 "cysystemd/reader.pyx"
      __pyx_t_3 = __pyx_t_2;

#line 196 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_3);

#line 196 "cysystemd/reader.pyx"
      __pyx_t_5 = 0;

#line 196 "cysystemd/reader.pyx"
      {

#line 196 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};

#line 196 "cysystemd/reader.pyx"
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_islink, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 196 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 196 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 196 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 196, __pyx_L1_error)

#line 196 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_1);

#line 196 "cysystemd/reader.pyx"
      }

#line 196 "cysystemd/reader.pyx"
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 196, __pyx_L1_error)

#line 196 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 196 "cysystemd/reader.pyx"
      __pyx_t_6 = (!__pyx_t_7);

#line 196 "cysystemd/reader.pyx"
      if (!__pyx_t_6) break;

      /* "cysystemd/reader.pyx":197
 *         c = 0
 *         while not os.path.islink(path):
 *             path = os.path.abspath(os.readlink(path))             # <<<<<<<<<<<<<<
 *             c += 1
 *             if c > 255:
*/

#line 197 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 197, __pyx_L1_error)

#line 197 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_3);

#line 197 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 197, __pyx_L1_error)

#line 197 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 197 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 197 "cysystemd/reader.pyx"
      __pyx_t_2 = __pyx_t_4;

#line 197 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_2);

#line 197 "cysystemd/reader.pyx"
      __pyx_t_8 = NULL;

#line 197 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 197, __pyx_L1_error)

#line 197 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_9);

#line 197 "cysystemd/reader.pyx"
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_readlink); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 197, __pyx_L1_error)

#line 197 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_10);

#line 197 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 197 "cysystemd/reader.pyx"
      __pyx_t_5 = 1;

#line 197 "cysystemd/reader.pyx"
      #if CYTHON_UNPACK_METHODS

#line 197 "cysystemd/reader.pyx"
      if (unlikely(PyMethod_Check(__pyx_t_10))) {

#line 197 "cysystemd/reader.pyx"
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);

#line 197 "cysystemd/reader.pyx"
        assert(__pyx_t_8);

#line 197 "cysystemd/reader.pyx"
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);

#line 197 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_8);

#line 197 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx__function);

#line 197 "cysystemd/reader.pyx"
        __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);

#line 197 "cysystemd/reader.pyx"
        __pyx_t_5 = 0;

#line 197 "cysystemd/reader.pyx"
      }

#line 197 "cysystemd/reader.pyx"
      #endif

#line 197 "cysystemd/reader.pyx"
      {

#line 197 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_path};

#line 197 "cysystemd/reader.pyx"
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 197 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 197 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

#line 197 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 197, __pyx_L1_error)

#line 197 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_3);

#line 197 "cysystemd/reader.pyx"
      }

#line 197 "cysystemd/reader.pyx"
      __pyx_t_5 = 0;

#line 197 "cysystemd/reader.pyx"
      {

#line 197 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};

#line 197 "cysystemd/reader.pyx"
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_abspath, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 197 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 197 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 197 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 197 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)

#line 197 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_1);

#line 197 "cysystemd/reader.pyx"
      }

#line 197 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);

#line 197 "cysystemd/reader.pyx"
      __pyx_t_1 = 0;

      /* "cysystemd/reader.pyx":198
 *         while not os.path.islink(path):
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1             # <<<<<<<<<<<<<<
 *             if c > 255:
 *                 raise OSError("Link recursive reslolution error")
*/

#line 198 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyLong_AddObjC(__pyx_v_c, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 198, __pyx_L1_error)

#line 198 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 198 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_v_c, __pyx_t_1);

#line 198 "cysystemd/reader.pyx"
      __pyx_t_1 = 0;

      /* "cysystemd/reader.pyx":199
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1
 *             if c > 255:             # <<<<<<<<<<<<<<
 *                 raise OSError("Link recursive reslolution error")
 * 
*/

#line 199 "cysystemd/reader.pyx"
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_c, __pyx_mstate_global->__pyx_int_255, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 199, __pyx_L1_error)

#line 199 "cysystemd/reader.pyx"
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 199, __pyx_L1_error)

#line 199 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 199 "cysystemd/reader.pyx"
      if (unlikely(__pyx_t_6)) {

        /* "cysystemd/reader.pyx":200
 *             c += 1
 *             if c > 255:
 *                 raise OSError("Link recursive reslolution error")             # <<<<<<<<<<<<<<
 * 
 *         return _check_file_path(path)
*/

#line 200 "cysystemd/reader.pyx"
        __pyx_t_4 = NULL;

#line 200 "cysystemd/reader.pyx"
        __pyx_t_5 = 1;

#line 200 "cysystemd/reader.pyx"
        {

#line 200 "cysystemd/reader.pyx"
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Link_recursive_reslolution_error};

#line 200 "cysystemd/reader.pyx"
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_OSError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 200 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 200 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 200, __pyx_L1_error)

#line 200 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_1);

#line 200 "cysystemd/reader.pyx"
        }

#line 200 "cysystemd/reader.pyx"
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 200 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 200 "cysystemd/reader.pyx"
        __PYX_ERR(0, 200, __pyx_L1_error)

        /* "cysystemd/reader.pyx":199
 *             path = os.path.abspath(os.readlink(path))
 *             c += 1
 *             if c > 255:             # <<<<<<<<<<<<<<
 *                 raise OSError("Link recursive reslolution error")
 * 
*/

#line 199 "cysystemd/reader.pyx"
      }

#line 199 "cysystemd/reader.pyx"
    }

    /* "cysystemd/reader.pyx":202
 *                 raise OSError("Link recursive reslolution error")
 * 
 *         return _check_file_path(path)             # <<<<<<<<<<<<<<
 *     elif not os.path.isfile(path):
 *         raise OSError("It's not a regular file")
*/

#line 202 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_r);

#line 202 "cysystemd/reader.pyx"
    __pyx_t_1 = __pyx_f_9cysystemd_6reader__check_file_path(__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)

#line 202 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 202 "cysystemd/reader.pyx"
    __pyx_r = ((PyObject*)__pyx_t_1);

#line 202 "cysystemd/reader.pyx"
    __pyx_t_1 = 0;

#line 202 "cysystemd/reader.pyx"
    goto __pyx_L0;

    /* "cysystemd/reader.pyx":194
 *     if not os.path.exists(path):
 *         raise OSError('File not found')
 *     elif os.path.islink(path):             # <<<<<<<<<<<<<<
 *         c = 0
 *         while not os.path.islink(path):
*/

#line 194 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":203
 * 
 *         return _check_file_path(path)
 *     elif not os.path.isfile(path):             # <<<<<<<<<<<<<<
 *         raise OSError("It's not a regular file")
 *     else:
*/

#line 203 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 203, __pyx_L1_error)

#line 203 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 203 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)

#line 203 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 203 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 203 "cysystemd/reader.pyx"
  __pyx_t_4 = __pyx_t_2;

#line 203 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_4);

#line 203 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;

#line 203 "cysystemd/reader.pyx"
  {

#line 203 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_path};

#line 203 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_isfile, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 203 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 203 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 203 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 203, __pyx_L1_error)

#line 203 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 203 "cysystemd/reader.pyx"
  }

#line 203 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 203, __pyx_L1_error)

#line 203 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 203 "cysystemd/reader.pyx"
  __pyx_t_7 = (!__pyx_t_6);

#line 203 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_7)) {

    /* "cysystemd/reader.pyx":204
 *         return _check_file_path(path)
 *     elif not os.path.isfile(path):
 *         raise OSError("It's not a regular file")             # <<<<<<<<<<<<<<
 *     else:
 *         path = os.path.abspath(path)
*/

#line 204 "cysystemd/reader.pyx"
    __pyx_t_2 = NULL;

#line 204 "cysystemd/reader.pyx"
    __pyx_t_5 = 1;

#line 204 "cysystemd/reader.pyx"
    {

#line 204 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_It_s_not_a_regular_file};

#line 204 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_OSError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 204 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 204 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)

#line 204 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 204 "cysystemd/reader.pyx"
    }

#line 204 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 204 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 204 "cysystemd/reader.pyx"
    __PYX_ERR(0, 204, __pyx_L1_error)

    /* "cysystemd/reader.pyx":203
 * 
 *         return _check_file_path(path)
 *     elif not os.path.isfile(path):             # <<<<<<<<<<<<<<
 *         raise OSError("It's not a regular file")
 *     else:
*/

#line 203 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":206
 *         raise OSError("It's not a regular file")
 *     else:
 *         path = os.path.abspath(path)             # <<<<<<<<<<<<<<
 * 
 *     return path
*/

#line 206 "cysystemd/reader.pyx"
  /*else*/ {

#line 206 "cysystemd/reader.pyx"
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 206, __pyx_L1_error)

#line 206 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 206 "cysystemd/reader.pyx"
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 206, __pyx_L1_error)

#line 206 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_3);

#line 206 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 206 "cysystemd/reader.pyx"
    __pyx_t_2 = __pyx_t_3;

#line 206 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 206 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 206 "cysystemd/reader.pyx"
    {

#line 206 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_path};

#line 206 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_abspath, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 206 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 206 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 206 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)

#line 206 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 206 "cysystemd/reader.pyx"
    }

#line 206 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);

#line 206 "cysystemd/reader.pyx"
    __pyx_t_1 = 0;

#line 206 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":208
 *         path = os.path.abspath(path)
 * 
 *     return path             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 208 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 208 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_v_path;

#line 208 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_1);

#line 208 "cysystemd/reader.pyx"
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_1))) __PYX_ERR(0, 208, __pyx_L1_error)

#line 208 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject*)__pyx_t_1);

#line 208 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 208 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":189
 * 
 * 
 * cdef str _check_file_path(object path):             # <<<<<<<<<<<<<<
 *     path = str(path)
 * 
*/

#line 189 "cysystemd/reader.pyx"


#line 189 "cysystemd/reader.pyx"
  /* function exit code */

#line 189 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_8);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_9);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_10);

#line 189 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader._check_file_path", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 189 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 189 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_c);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_path);

#line 189 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 189 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 189 "cysystemd/reader.pyx"
  return __pyx_r;

#line 189 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":223
 *     max_message_size = 2**20
 * 
 *     def __cinit__(self, JournalReader reader):             # <<<<<<<<<<<<<<
 *         cdef const void *data
 *         cdef size_t length = 0
*/

#line 223 "cysystemd/reader.pyx"


#line 223 "cysystemd/reader.pyx"
/* Python wrapper */

#line 223 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_12JournalEntry_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/

#line 223 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_12JournalEntry_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_reader = 0
#line 223 "cysystemd/reader.pyx"
;

#line 223 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 223 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 223 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 223 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 223 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 223 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 223 "cysystemd/reader.pyx"
  int __pyx_r;

#line 223 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 223 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);

#line 223 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 223 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 223 "cysystemd/reader.pyx"
  #else

#line 223 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;

#line 223 "cysystemd/reader.pyx"
  #endif

#line 223 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 223 "cysystemd/reader.pyx"
  {

#line 223 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_reader,0};

#line 223 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;

#line 223 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 223, __pyx_L3_error)

#line 223 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 223 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 223 "cysystemd/reader.pyx"
        case  1:

#line 223 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);

#line 223 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 223, __pyx_L3_error)

#line 223 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 223 "cysystemd/reader.pyx"
break;
        default: 
#line 223 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 223 "cysystemd/reader.pyx"
      }

#line 223 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 223 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(0, 223, __pyx_L3_error)

#line 223 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 223 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, i); __PYX_ERR(0, 223, __pyx_L3_error) }

#line 223 "cysystemd/reader.pyx"
      }

#line 223 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 223 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 223 "cysystemd/reader.pyx"
    } else {

#line 223 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);

#line 223 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 223, __pyx_L3_error)

#line 223 "cysystemd/reader.pyx"
    }

#line 223 "cysystemd/reader.pyx"
    __pyx_v_reader = ((struct __pyx_obj_9cysystemd_6reader_JournalReader *)values[0]);

#line 223 "cysystemd/reader.pyx"
  }

#line 223 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 223 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 223 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 223, __pyx_L3_error)

#line 223 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 223 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 223 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 223 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 223 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 223 "cysystemd/reader.pyx"
  }

#line 223 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 223 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 223 "cysystemd/reader.pyx"
  return -1;

#line 223 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;

#line 223 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_reader), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, 1, "reader", 0))) __PYX_ERR(0, 223, __pyx_L1_error)
  __pyx_r = 
#line 223 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry___cinit__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self), __pyx_v_reader);

#line 223 "cysystemd/reader.pyx"


#line 223 "cysystemd/reader.pyx"
  /* function exit code */

#line 223 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 223 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 223 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 223 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 223 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 223 "cysystemd/reader.pyx"
  }

#line 223 "cysystemd/reader.pyx"
  goto __pyx_L7_cleaned_up;

#line 223 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 223 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 223 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 223 "cysystemd/reader.pyx"
  }

#line 223 "cysystemd/reader.pyx"
  __pyx_L7_cleaned_up:;

#line 223 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 223 "cysystemd/reader.pyx"
  return __pyx_r;

#line 223 "cysystemd/reader.pyx"
}

#line 223 "cysystemd/reader.pyx"


#line 223 "cysystemd/reader.pyx"
static int __pyx_pf_9cysystemd_6reader_12JournalEntry___cinit__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_reader) {
  void const *__pyx_v_data
#line 223 "cysystemd/reader.pyx"
;
  size_t __pyx_v_length
#line 223 "cysystemd/reader.pyx"
;
  int __pyx_v_result
#line 223 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_value = NULL
#line 223 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_key = NULL
#line 223 "cysystemd/reader.pyx"
;

#line 223 "cysystemd/reader.pyx"
  int __pyx_r;

#line 223 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 223 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 223 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 223 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 223 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 223 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 223 "cysystemd/reader.pyx"
  int __pyx_t_6;

#line 223 "cysystemd/reader.pyx"
  int __pyx_t_7;

#line 223 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 223 "cysystemd/reader.pyx"
  int __pyx_t_9;

#line 223 "cysystemd/reader.pyx"
  double __pyx_t_10;

#line 223 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 223 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 223 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 223 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 223 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "cysystemd/reader.pyx":225
 *     def __cinit__(self, JournalReader reader):
 *         cdef const void *data
 *         cdef size_t length = 0             # <<<<<<<<<<<<<<
 * 
 *         self.__data = {}
*/

#line 225 "cysystemd/reader.pyx"
  __pyx_v_length = 0;

  /* "cysystemd/reader.pyx":227
 *         cdef size_t length = 0
 * 
 *         self.__data = {}             # <<<<<<<<<<<<<<
 *         check_error_code(sd_journal_get_realtime_usec(reader.context, &self.realtime_usec))
 *         check_error_code(sd_journal_get_monotonic_usec(reader.context, &self.monotonic_usec, &self.__boot_id))
*/

#line 227 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)

#line 227 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 227 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 227 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_JournalEntry__data);

#line 227 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_JournalEntry__data);

#line 227 "cysystemd/reader.pyx"
  __pyx_v_self->_JournalEntry__data = ((PyObject*)__pyx_t_1);

#line 227 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":228
 * 
 *         self.__data = {}
 *         check_error_code(sd_journal_get_realtime_usec(reader.context, &self.realtime_usec))             # <<<<<<<<<<<<<<
 *         check_error_code(sd_journal_get_monotonic_usec(reader.context, &self.monotonic_usec, &self.__boot_id))
 *         check_error_code(sd_journal_get_cursor(reader.context, &self.cursor))
*/

#line 228 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 228 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 228, __pyx_L1_error)

#line 228 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 228 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_int(sd_journal_get_realtime_usec(__pyx_v_reader->context, (&__pyx_v_self->realtime_usec))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 228, __pyx_L1_error)

#line 228 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 228 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 228 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 228 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 228 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 228 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 228 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 228 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 228 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 228 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 228 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 228 "cysystemd/reader.pyx"
  }

#line 228 "cysystemd/reader.pyx"
  #endif

#line 228 "cysystemd/reader.pyx"
  {

#line 228 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 228 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 228 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 228 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 228 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 228 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 228, __pyx_L1_error)

#line 228 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 228 "cysystemd/reader.pyx"
  }

#line 228 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":229
 *         self.__data = {}
 *         check_error_code(sd_journal_get_realtime_usec(reader.context, &self.realtime_usec))
 *         check_error_code(sd_journal_get_monotonic_usec(reader.context, &self.monotonic_usec, &self.__boot_id))             # <<<<<<<<<<<<<<
 *         check_error_code(sd_journal_get_cursor(reader.context, &self.cursor))
 * 
*/

#line 229 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 229 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 229, __pyx_L1_error)

#line 229 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 229 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From_int(sd_journal_get_monotonic_usec(__pyx_v_reader->context, (&__pyx_v_self->monotonic_usec), (&__pyx_v_self->_JournalEntry__boot_id))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)

#line 229 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 229 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 229 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 229 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 229 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 229 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 229 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 229 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 229 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 229 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 229 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 229 "cysystemd/reader.pyx"
  }

#line 229 "cysystemd/reader.pyx"
  #endif

#line 229 "cysystemd/reader.pyx"
  {

#line 229 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};

#line 229 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 229 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 229 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 229 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 229 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)

#line 229 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 229 "cysystemd/reader.pyx"
  }

#line 229 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":230
 *         check_error_code(sd_journal_get_realtime_usec(reader.context, &self.realtime_usec))
 *         check_error_code(sd_journal_get_monotonic_usec(reader.context, &self.monotonic_usec, &self.__boot_id))
 *         check_error_code(sd_journal_get_cursor(reader.context, &self.cursor))             # <<<<<<<<<<<<<<
 * 
 *         sd_journal_restart_data(reader.context)
*/

#line 230 "cysystemd/reader.pyx"
  __pyx_t_4 = NULL;

#line 230 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 230, __pyx_L1_error)

#line 230 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 230 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_PyLong_From_int(sd_journal_get_cursor(__pyx_v_reader->context, (&__pyx_v_self->cursor))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 230, __pyx_L1_error)

#line 230 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 230 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 230 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 230 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_2))) {

#line 230 "cysystemd/reader.pyx"
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);

#line 230 "cysystemd/reader.pyx"
    assert(__pyx_t_4);

#line 230 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);

#line 230 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_4);

#line 230 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 230 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);

#line 230 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 230 "cysystemd/reader.pyx"
  }

#line 230 "cysystemd/reader.pyx"
  #endif

#line 230 "cysystemd/reader.pyx"
  {

#line 230 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};

#line 230 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 230 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 230 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 230 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 230 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)

#line 230 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 230 "cysystemd/reader.pyx"
  }

#line 230 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":232
 *         check_error_code(sd_journal_get_cursor(reader.context, &self.cursor))
 * 
 *         sd_journal_restart_data(reader.context)             # <<<<<<<<<<<<<<
 * 
 *         while True:
*/

#line 232 "cysystemd/reader.pyx"
  sd_journal_restart_data(__pyx_v_reader->context);

  /* "cysystemd/reader.pyx":234
 *         sd_journal_restart_data(reader.context)
 * 
 *         while True:             # <<<<<<<<<<<<<<
 * 
 *             length = 0
*/

#line 234 "cysystemd/reader.pyx"
  while (1) {

    /* "cysystemd/reader.pyx":236
 *         while True:
 * 
 *             length = 0             # <<<<<<<<<<<<<<
 * 
 *             result = sd_journal_enumerate_data(reader.context, <const void **>&data, &length)
*/

#line 236 "cysystemd/reader.pyx"
    __pyx_v_length = 0;

    /* "cysystemd/reader.pyx":238
 *             length = 0
 * 
 *             result = sd_journal_enumerate_data(reader.context, <const void **>&data, &length)             # <<<<<<<<<<<<<<
 * 
 *             if result == 0 or length == 0:
*/

#line 238 "cysystemd/reader.pyx"
    __pyx_v_result = sd_journal_enumerate_data(__pyx_v_reader->context, ((void const **)(&__pyx_v_data)), (&__pyx_v_length));

    /* "cysystemd/reader.pyx":240
 *             result = sd_journal_enumerate_data(reader.context, <const void **>&data, &length)
 * 
 *             if result == 0 or length == 0:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/

#line 240 "cysystemd/reader.pyx"
    __pyx_t_7 = (__pyx_v_result == 0);

#line 240 "cysystemd/reader.pyx"
    if (!__pyx_t_7) {

#line 240 "cysystemd/reader.pyx"
    } else {

#line 240 "cysystemd/reader.pyx"
      __pyx_t_6 = __pyx_t_7;

#line 240 "cysystemd/reader.pyx"
      goto __pyx_L6_bool_binop_done;

#line 240 "cysystemd/reader.pyx"
    }

#line 240 "cysystemd/reader.pyx"
    __pyx_t_7 = (__pyx_v_length == 0);

#line 240 "cysystemd/reader.pyx"
    __pyx_t_6 = __pyx_t_7;

#line 240 "cysystemd/reader.pyx"
    __pyx_L6_bool_binop_done:;

#line 240 "cysystemd/reader.pyx"
    if (__pyx_t_6) {

      /* "cysystemd/reader.pyx":241
 * 
 *             if result == 0 or length == 0:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             if length > self.max_message_size:
*/

#line 241 "cysystemd/reader.pyx"
      goto __pyx_L4_break;

      /* "cysystemd/reader.pyx":240
 *             result = sd_journal_enumerate_data(reader.context, <const void **>&data, &length)
 * 
 *             if result == 0 or length == 0:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/

#line 240 "cysystemd/reader.pyx"
    }

    /* "cysystemd/reader.pyx":243
 *                 break
 * 
 *             if length > self.max_message_size:             # <<<<<<<<<<<<<<
 *                 log.warning("got message with enormous length %d", length)
 *                 break
*/

#line 243 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyLong_FromSize_t(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)

#line 243 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 243 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_max_message_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 243, __pyx_L1_error)

#line 243 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 243 "cysystemd/reader.pyx"
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 243, __pyx_L1_error)

#line 243 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 243 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 243 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 243, __pyx_L1_error)

#line 243 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 243 "cysystemd/reader.pyx"
    if (__pyx_t_6) {

      /* "cysystemd/reader.pyx":244
 * 
 *             if length > self.max_message_size:
 *                 log.warning("got message with enormous length %d", length)             # <<<<<<<<<<<<<<
 *                 break
 * 
*/

#line 244 "cysystemd/reader.pyx"
      __pyx_t_2 = NULL;

#line 244 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_log); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)

#line 244 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 244 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_warning); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 244, __pyx_L1_error)

#line 244 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 244 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 244 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyLong_FromSize_t(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)

#line 244 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 244 "cysystemd/reader.pyx"
      __pyx_t_5 = 1;

#line 244 "cysystemd/reader.pyx"
      #if CYTHON_UNPACK_METHODS

#line 244 "cysystemd/reader.pyx"
      if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 244 "cysystemd/reader.pyx"
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);

#line 244 "cysystemd/reader.pyx"
        assert(__pyx_t_2);

#line 244 "cysystemd/reader.pyx"
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 244 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_2);

#line 244 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx__function);

#line 244 "cysystemd/reader.pyx"
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 244 "cysystemd/reader.pyx"
        __pyx_t_5 = 0;

#line 244 "cysystemd/reader.pyx"
      }

#line 244 "cysystemd/reader.pyx"
      #endif

#line 244 "cysystemd/reader.pyx"
      {

#line 244 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_got_message_with_enormous_length, __pyx_t_1};

#line 244 "cysystemd/reader.pyx"
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 244 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 244 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 244 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 244 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 244, __pyx_L1_error)

#line 244 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_3);

#line 244 "cysystemd/reader.pyx"
      }

#line 244 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cysystemd/reader.pyx":245
 *             if length > self.max_message_size:
 *                 log.warning("got message with enormous length %d", length)
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             value = bytes((<char*> data)[:length]).decode(errors='replace')
*/

#line 245 "cysystemd/reader.pyx"
      goto __pyx_L4_break;

      /* "cysystemd/reader.pyx":243
 *                 break
 * 
 *             if length > self.max_message_size:             # <<<<<<<<<<<<<<
 *                 log.warning("got message with enormous length %d", length)
 *                 break
*/

#line 243 "cysystemd/reader.pyx"
    }

    /* "cysystemd/reader.pyx":247
 *                 break
 * 
 *             value = bytes((<char*> data)[:length]).decode(errors='replace')             # <<<<<<<<<<<<<<
 *             if '=' not in value:
 *                 log.warning("got unexpected %r from sd_journal_enumerate_data", value)
*/

#line 247 "cysystemd/reader.pyx"
    __pyx_t_2 = NULL;

#line 247 "cysystemd/reader.pyx"
    __pyx_t_8 = __Pyx_PyBytes_FromStringAndSize(((char *)__pyx_v_data) + 0, __pyx_v_length - 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 247, __pyx_L1_error)

#line 247 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_8);

#line 247 "cysystemd/reader.pyx"
    __pyx_t_5 = 1;

#line 247 "cysystemd/reader.pyx"
    {

#line 247 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_8};

#line 247 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 247 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 247 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 247 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)

#line 247 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 247 "cysystemd/reader.pyx"
    }

#line 247 "cysystemd/reader.pyx"
    __pyx_t_4 = __pyx_t_1;

#line 247 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_4);

#line 247 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 247 "cysystemd/reader.pyx"
    {

#line 247 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, NULL};

#line 247 "cysystemd/reader.pyx"
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 247, __pyx_L1_error)

#line 247 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_8);

#line 247 "cysystemd/reader.pyx"
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_errors, __pyx_mstate_global->__pyx_n_u_replace, __pyx_t_8, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 247, __pyx_L1_error)

#line 247 "cysystemd/reader.pyx"
      __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_decode, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);

#line 247 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 247 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 247 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 247 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 247, __pyx_L1_error)

#line 247 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_3);

#line 247 "cysystemd/reader.pyx"
    }

#line 247 "cysystemd/reader.pyx"
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_3);

#line 247 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

    /* "cysystemd/reader.pyx":248
 * 
 *             value = bytes((<char*> data)[:length]).decode(errors='replace')
 *             if '=' not in value:             # <<<<<<<<<<<<<<
 *                 log.warning("got unexpected %r from sd_journal_enumerate_data", value)
 *                 break
*/

#line 248 "cysystemd/reader.pyx"
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u_, __pyx_v_value, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 248, __pyx_L1_error)

#line 248 "cysystemd/reader.pyx"
    if (__pyx_t_6) {

      /* "cysystemd/reader.pyx":249
 *             value = bytes((<char*> data)[:length]).decode(errors='replace')
 *             if '=' not in value:
 *                 log.warning("got unexpected %r from sd_journal_enumerate_data", value)             # <<<<<<<<<<<<<<
 *                 break
 *             key, value = value.split("=", 1)
*/

#line 249 "cysystemd/reader.pyx"
      __pyx_t_1 = NULL;

#line 249 "cysystemd/reader.pyx"
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_log); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 249, __pyx_L1_error)

#line 249 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_8);

#line 249 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_warning); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L1_error)

#line 249 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 249 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 249 "cysystemd/reader.pyx"
      __pyx_t_5 = 1;

#line 249 "cysystemd/reader.pyx"
      #if CYTHON_UNPACK_METHODS

#line 249 "cysystemd/reader.pyx"
      if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 249 "cysystemd/reader.pyx"
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);

#line 249 "cysystemd/reader.pyx"
        assert(__pyx_t_1);

#line 249 "cysystemd/reader.pyx"
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 249 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_1);

#line 249 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx__function);

#line 249 "cysystemd/reader.pyx"
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 249 "cysystemd/reader.pyx"
        __pyx_t_5 = 0;

#line 249 "cysystemd/reader.pyx"
      }

#line 249 "cysystemd/reader.pyx"
      #endif

#line 249 "cysystemd/reader.pyx"
      {

#line 249 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_got_unexpected_r_from_sd_journal, __pyx_v_value};

#line 249 "cysystemd/reader.pyx"
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 249 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 249 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 249 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 249, __pyx_L1_error)

#line 249 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_3);

#line 249 "cysystemd/reader.pyx"
      }

#line 249 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cysystemd/reader.pyx":250
 *             if '=' not in value:
 *                 log.warning("got unexpected %r from sd_journal_enumerate_data", value)
 *                 break             # <<<<<<<<<<<<<<
 *             key, value = value.split("=", 1)
 * 
*/

#line 250 "cysystemd/reader.pyx"
      goto __pyx_L4_break;

      /* "cysystemd/reader.pyx":248
 * 
 *             value = bytes((<char*> data)[:length]).decode(errors='replace')
 *             if '=' not in value:             # <<<<<<<<<<<<<<
 *                 log.warning("got unexpected %r from sd_journal_enumerate_data", value)
 *                 break
*/

#line 248 "cysystemd/reader.pyx"
    }

    /* "cysystemd/reader.pyx":251
 *                 log.warning("got unexpected %r from sd_journal_enumerate_data", value)
 *                 break
 *             key, value = value.split("=", 1)             # <<<<<<<<<<<<<<
 * 
 *             if key in self.__data:
*/

#line 251 "cysystemd/reader.pyx"
    __pyx_t_3 = PyUnicode_Split(__pyx_v_value, __pyx_mstate_global->__pyx_kp_u_, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 251, __pyx_L1_error)

#line 251 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_3);

#line 251 "cysystemd/reader.pyx"
    if (1) {

#line 251 "cysystemd/reader.pyx"
      PyObject* sequence = __pyx_t_3;

#line 251 "cysystemd/reader.pyx"
      Py_ssize_t size = __Pyx_PyList_GET_SIZE(sequence);

#line 251 "cysystemd/reader.pyx"
      if (unlikely(size != 2)) {

#line 251 "cysystemd/reader.pyx"
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);

#line 251 "cysystemd/reader.pyx"
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);

#line 251 "cysystemd/reader.pyx"
        __PYX_ERR(0, 251, __pyx_L1_error)

#line 251 "cysystemd/reader.pyx"
      }

#line 251 "cysystemd/reader.pyx"
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS

#line 251 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);

#line 251 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 251, __pyx_L1_error)

#line 251 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_4);

#line 251 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);

#line 251 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 251, __pyx_L1_error)

#line 251 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_1);

#line 251 "cysystemd/reader.pyx"
      #else

#line 251 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 251, __pyx_L1_error)

#line 251 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 251 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 251, __pyx_L1_error)

#line 251 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 251 "cysystemd/reader.pyx"
      #endif

#line 251 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 251 "cysystemd/reader.pyx"
    }

#line 251 "cysystemd/reader.pyx"
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_4);

#line 251 "cysystemd/reader.pyx"
    __pyx_t_4 = 0;

#line 251 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_1);

#line 251 "cysystemd/reader.pyx"
    __pyx_t_1 = 0;

    /* "cysystemd/reader.pyx":253
 *             key, value = value.split("=", 1)
 * 
 *             if key in self.__data:             # <<<<<<<<<<<<<<
 *                 if not isinstance(self.__data[key], list):
 *                     self.__data[key] = [self.__data[key]]
*/

#line 253 "cysystemd/reader.pyx"
    if (unlikely(__pyx_v_self->_JournalEntry__data == Py_None)) {

#line 253 "cysystemd/reader.pyx"
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");

#line 253 "cysystemd/reader.pyx"
      __PYX_ERR(0, 253, __pyx_L1_error)

#line 253 "cysystemd/reader.pyx"
    }

#line 253 "cysystemd/reader.pyx"
    __pyx_t_6 = (__Pyx_PyDict_ContainsTF(__pyx_v_key, __pyx_v_self->_JournalEntry__data, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 253, __pyx_L1_error)

#line 253 "cysystemd/reader.pyx"
    if (__pyx_t_6) {

      /* "cysystemd/reader.pyx":254
 * 
 *             if key in self.__data:
 *                 if not isinstance(self.__data[key], list):             # <<<<<<<<<<<<<<
 *                     self.__data[key] = [self.__data[key]]
 *                 self.__data[key].append(value)
*/

#line 254 "cysystemd/reader.pyx"
      if (unlikely(__pyx_v_self->_JournalEntry__data == Py_None)) {

#line 254 "cysystemd/reader.pyx"
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");

#line 254 "cysystemd/reader.pyx"
        __PYX_ERR(0, 254, __pyx_L1_error)

#line 254 "cysystemd/reader.pyx"
      }

#line 254 "cysystemd/reader.pyx"
      __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_self->_JournalEntry__data, __pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)

#line 254 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_3);

#line 254 "cysystemd/reader.pyx"
      __pyx_t_6 = PyList_Check(__pyx_t_3); 

#line 254 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 254 "cysystemd/reader.pyx"
      __pyx_t_7 = (!__pyx_t_6);

#line 254 "cysystemd/reader.pyx"
      if (__pyx_t_7) {

        /* "cysystemd/reader.pyx":255
 *             if key in self.__data:
 *                 if not isinstance(self.__data[key], list):
 *                     self.__data[key] = [self.__data[key]]             # <<<<<<<<<<<<<<
 *                 self.__data[key].append(value)
 *             else:
*/

#line 255 "cysystemd/reader.pyx"
        if (unlikely(__pyx_v_self->_JournalEntry__data == Py_None)) {

#line 255 "cysystemd/reader.pyx"
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");

#line 255 "cysystemd/reader.pyx"
          __PYX_ERR(0, 255, __pyx_L1_error)

#line 255 "cysystemd/reader.pyx"
        }

#line 255 "cysystemd/reader.pyx"
        __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_self->_JournalEntry__data, __pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 255, __pyx_L1_error)

#line 255 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_3);

#line 255 "cysystemd/reader.pyx"
        __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 255, __pyx_L1_error)

#line 255 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_1);

#line 255 "cysystemd/reader.pyx"
        __Pyx_GIVEREF(__pyx_t_3);

#line 255 "cysystemd/reader.pyx"
        if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 255, __pyx_L1_error);

#line 255 "cysystemd/reader.pyx"
        __pyx_t_3 = 0;

#line 255 "cysystemd/reader.pyx"
        if (unlikely(__pyx_v_self->_JournalEntry__data == Py_None)) {

#line 255 "cysystemd/reader.pyx"
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");

#line 255 "cysystemd/reader.pyx"
          __PYX_ERR(0, 255, __pyx_L1_error)

#line 255 "cysystemd/reader.pyx"
        }

#line 255 "cysystemd/reader.pyx"
        if (unlikely((PyDict_SetItem(__pyx_v_self->_JournalEntry__data, __pyx_v_key, __pyx_t_1) < 0))) __PYX_ERR(0, 255, __pyx_L1_error)

#line 255 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cysystemd/reader.pyx":254
 * 
 *             if key in self.__data:
 *                 if not isinstance(self.__data[key], list):             # <<<<<<<<<<<<<<
 *                     self.__data[key] = [self.__data[key]]
 *                 self.__data[key].append(value)
*/

#line 254 "cysystemd/reader.pyx"
      }

      /* "cysystemd/reader.pyx":256
 *                 if not isinstance(self.__data[key], list):
 *                     self.__data[key] = [self.__data[key]]
 *                 self.__data[key].append(value)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.__data[key] = value
*/

#line 256 "cysystemd/reader.pyx"
      if (unlikely(__pyx_v_self->_JournalEntry__data == Py_None)) {

#line 256 "cysystemd/reader.pyx"
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");

#line 256 "cysystemd/reader.pyx"
        __PYX_ERR(0, 256, __pyx_L1_error)

#line 256 "cysystemd/reader.pyx"
      }

#line 256 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_JournalEntry__data, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 256, __pyx_L1_error)

#line 256 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 256 "cysystemd/reader.pyx"
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_value); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 256, __pyx_L1_error)

#line 256 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cysystemd/reader.pyx":253
 *             key, value = value.split("=", 1)
 * 
 *             if key in self.__data:             # <<<<<<<<<<<<<<
 *                 if not isinstance(self.__data[key], list):
 *                     self.__data[key] = [self.__data[key]]
*/

#line 253 "cysystemd/reader.pyx"
      goto __pyx_L10;

#line 253 "cysystemd/reader.pyx"
    }

    /* "cysystemd/reader.pyx":258
 *                 self.__data[key].append(value)
 *             else:
 *                 self.__data[key] = value             # <<<<<<<<<<<<<<
 * 
 *         self._data = self.__data
*/

#line 258 "cysystemd/reader.pyx"
    /*else*/ {

#line 258 "cysystemd/reader.pyx"
      if (unlikely(__pyx_v_self->_JournalEntry__data == Py_None)) {

#line 258 "cysystemd/reader.pyx"
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");

#line 258 "cysystemd/reader.pyx"
        __PYX_ERR(0, 258, __pyx_L1_error)

#line 258 "cysystemd/reader.pyx"
      }

#line 258 "cysystemd/reader.pyx"
      if (unlikely((PyDict_SetItem(__pyx_v_self->_JournalEntry__data, __pyx_v_key, __pyx_v_value) < 0))) __PYX_ERR(0, 258, __pyx_L1_error)

#line 258 "cysystemd/reader.pyx"
    }

#line 258 "cysystemd/reader.pyx"
    __pyx_L10:;

#line 258 "cysystemd/reader.pyx"
  }

#line 258 "cysystemd/reader.pyx"
  __pyx_L4_break:;

  /* "cysystemd/reader.pyx":260
 *                 self.__data[key] = value
 * 
 *         self._data = self.__data             # <<<<<<<<<<<<<<
 *         self.__boot_uuid = UUID(bytes=self.__boot_id.bytes[:16])
 *         self.__date = datetime.fromtimestamp(self.get_realtime_sec(), timezone.utc)
*/

#line 260 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_v_self->_JournalEntry__data;

#line 260 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_1);

#line 260 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 260 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_data);

#line 260 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_data);

#line 260 "cysystemd/reader.pyx"
  __pyx_v_self->_data = __pyx_t_1;

#line 260 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":261
 * 
 *         self._data = self.__data
 *         self.__boot_uuid = UUID(bytes=self.__boot_id.bytes[:16])             # <<<<<<<<<<<<<<
 *         self.__date = datetime.fromtimestamp(self.get_realtime_sec(), timezone.utc)
 * 
*/

#line 261 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 261 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_UUID); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 261, __pyx_L1_error)

#line 261 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 261 "cysystemd/reader.pyx"
  __pyx_t_8 = __Pyx_PyBytes_FromStringAndSize(((char const *)__pyx_v_self->_JournalEntry__boot_id.bytes) + 0, 16 - 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 261, __pyx_L1_error)

#line 261 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_8);

#line 261 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 261 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 261 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 261 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 261 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 261 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 261 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 261 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 261 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 261 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 261 "cysystemd/reader.pyx"
  }

#line 261 "cysystemd/reader.pyx"
  #endif

#line 261 "cysystemd/reader.pyx"
  {

#line 261 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, NULL};

#line 261 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 261, __pyx_L1_error)

#line 261 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 261 "cysystemd/reader.pyx"
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_bytes, __pyx_t_8, __pyx_t_2, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)

#line 261 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);

#line 261 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 261 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 261 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 261 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 261 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 261, __pyx_L1_error)

#line 261 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 261 "cysystemd/reader.pyx"
  }

#line 261 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 261 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_JournalEntry__boot_uuid);

#line 261 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_JournalEntry__boot_uuid);

#line 261 "cysystemd/reader.pyx"
  __pyx_v_self->_JournalEntry__boot_uuid = __pyx_t_1;

#line 261 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":262
 *         self._data = self.__data
 *         self.__boot_uuid = UUID(bytes=self.__boot_id.bytes[:16])
 *         self.__date = datetime.fromtimestamp(self.get_realtime_sec(), timezone.utc)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 262 "cysystemd/reader.pyx"
  __pyx_t_4 = NULL;

#line 262 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 262, __pyx_L1_error)

#line 262 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 262 "cysystemd/reader.pyx"
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_fromtimestamp); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 262, __pyx_L1_error)

#line 262 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_8);

#line 262 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 262 "cysystemd/reader.pyx"
  __pyx_t_10 = ((struct __pyx_vtabstruct_9cysystemd_6reader_JournalEntry *)__pyx_v_self->__pyx_vtab)->get_realtime_sec(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 262, __pyx_L1_error)

#line 262 "cysystemd/reader.pyx"
  __pyx_t_2 = PyFloat_FromDouble(__pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 262, __pyx_L1_error)

#line 262 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 262 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_timezone); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 262, __pyx_L1_error)

#line 262 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 262 "cysystemd/reader.pyx"
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_utc); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 262, __pyx_L1_error)

#line 262 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_11);

#line 262 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 262 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 262 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 262 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_8))) {

#line 262 "cysystemd/reader.pyx"
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);

#line 262 "cysystemd/reader.pyx"
    assert(__pyx_t_4);

#line 262 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);

#line 262 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_4);

#line 262 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 262 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);

#line 262 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 262 "cysystemd/reader.pyx"
  }

#line 262 "cysystemd/reader.pyx"
  #endif

#line 262 "cysystemd/reader.pyx"
  {

#line 262 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_t_11};

#line 262 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 262 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 262 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 262 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

#line 262 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 262 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)

#line 262 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 262 "cysystemd/reader.pyx"
  }

#line 262 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 262 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->_JournalEntry__date);

#line 262 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->_JournalEntry__date);

#line 262 "cysystemd/reader.pyx"
  __pyx_v_self->_JournalEntry__date = __pyx_t_1;

#line 262 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":223
 *     max_message_size = 2**20
 * 
 *     def __cinit__(self, JournalReader reader):             # <<<<<<<<<<<<<<
 *         cdef const void *data
 *         cdef size_t length = 0
*/

#line 223 "cysystemd/reader.pyx"


#line 223 "cysystemd/reader.pyx"
  /* function exit code */

#line 223 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 223 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 223 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_8);

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_11);

#line 223 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 223 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 223 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_value);

#line 223 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_key);

#line 223 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 223 "cysystemd/reader.pyx"
  return __pyx_r;

#line 223 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":264
 *         self.__date = datetime.fromtimestamp(self.get_realtime_sec(), timezone.utc)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def cursor(self) -> bytes:
 *         return self.cursor
*/

#line 264 "cysystemd/reader.pyx"


#line 264 "cysystemd/reader.pyx"
/* Python wrapper */

#line 264 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_6cursor_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 264 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_6cursor_1__get__(PyObject *__pyx_v_self) {

#line 264 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 264 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 264 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 264 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 264 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 264 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_6cursor___get__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 264 "cysystemd/reader.pyx"


#line 264 "cysystemd/reader.pyx"
  /* function exit code */

#line 264 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 264 "cysystemd/reader.pyx"
  return __pyx_r;

#line 264 "cysystemd/reader.pyx"
}

#line 264 "cysystemd/reader.pyx"


#line 264 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_6cursor___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 264 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 264 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 264 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 264 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 264 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 264 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 264 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":266
 *     @property
 *     def cursor(self) -> bytes:
 *         return self.cursor             # <<<<<<<<<<<<<<
 * 
 *     cpdef double get_realtime_sec(self):
*/

#line 266 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 266 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_self->cursor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 266, __pyx_L1_error)

#line 266 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 266 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 266 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 266 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":264
 *         self.__date = datetime.fromtimestamp(self.get_realtime_sec(), timezone.utc)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def cursor(self) -> bytes:
 *         return self.cursor
*/

#line 264 "cysystemd/reader.pyx"


#line 264 "cysystemd/reader.pyx"
  /* function exit code */

#line 264 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 264 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 264 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.cursor.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 264 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 264 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 264 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 264 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 264 "cysystemd/reader.pyx"
  return __pyx_r;

#line 264 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":268
 *         return self.cursor
 * 
 *     cpdef double get_realtime_sec(self):             # <<<<<<<<<<<<<<
 *         cdef double result = self.realtime_usec / 1000000.
 *         return result
*/

#line 268 "cysystemd/reader.pyx"


#line 268 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_3get_realtime_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/

#line 268 "cysystemd/reader.pyx"
static double __pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch) {
  double __pyx_v_result
#line 268 "cysystemd/reader.pyx"
;

#line 268 "cysystemd/reader.pyx"
  double __pyx_r;

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 268 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 268 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 268 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 268 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 268 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 268 "cysystemd/reader.pyx"
  double __pyx_t_6;

#line 268 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 268 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 268 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_realtime_sec", 0);

#line 268 "cysystemd/reader.pyx"
  /* Check if called by wrapper */

#line 268 "cysystemd/reader.pyx"
  if (unlikely(__pyx_skip_dispatch)) ;

#line 268 "cysystemd/reader.pyx"
  /* Check if overridden in Python */

#line 268 "cysystemd/reader.pyx"
  else if (

#line 268 "cysystemd/reader.pyx"
  #if !CYTHON_USE_TYPE_SLOTS

#line 268 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry &&

#line 268 "cysystemd/reader.pyx"
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))

#line 268 "cysystemd/reader.pyx"
  #else

#line 268 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))

#line 268 "cysystemd/reader.pyx"
  #endif

#line 268 "cysystemd/reader.pyx"
  ) {

#line 268 "cysystemd/reader.pyx"
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 268 "cysystemd/reader.pyx"
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 268 "cysystemd/reader.pyx"
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {

#line 268 "cysystemd/reader.pyx"
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 268 "cysystemd/reader.pyx"
      #endif

#line 268 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_realtime_sec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)

#line 268 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 268 "cysystemd/reader.pyx"
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9cysystemd_6reader_12JournalEntry_3get_realtime_sec)) {

#line 268 "cysystemd/reader.pyx"
        __pyx_t_3 = NULL;

#line 268 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_1);

#line 268 "cysystemd/reader.pyx"
        __pyx_t_4 = __pyx_t_1; 

#line 268 "cysystemd/reader.pyx"
        __pyx_t_5 = 1;

#line 268 "cysystemd/reader.pyx"
        #if CYTHON_UNPACK_METHODS

#line 268 "cysystemd/reader.pyx"
        if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 268 "cysystemd/reader.pyx"
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 268 "cysystemd/reader.pyx"
          assert(__pyx_t_3);

#line 268 "cysystemd/reader.pyx"
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 268 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx_t_3);

#line 268 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx__function);

#line 268 "cysystemd/reader.pyx"
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 268 "cysystemd/reader.pyx"
          __pyx_t_5 = 0;

#line 268 "cysystemd/reader.pyx"
        }

#line 268 "cysystemd/reader.pyx"
        #endif

#line 268 "cysystemd/reader.pyx"
        {

#line 268 "cysystemd/reader.pyx"
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};

#line 268 "cysystemd/reader.pyx"
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 268 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 268 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 268 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 268, __pyx_L1_error)

#line 268 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 268 "cysystemd/reader.pyx"
        }

#line 268 "cysystemd/reader.pyx"
        __pyx_t_6 = __Pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 268, __pyx_L1_error)

#line 268 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 268 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_6;

#line 268 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 268 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 268 "cysystemd/reader.pyx"
      }

#line 268 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 268 "cysystemd/reader.pyx"
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 268 "cysystemd/reader.pyx"
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));

#line 268 "cysystemd/reader.pyx"
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {

#line 268 "cysystemd/reader.pyx"
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 268 "cysystemd/reader.pyx"
      }

#line 268 "cysystemd/reader.pyx"
      #endif

#line 268 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 268 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 268 "cysystemd/reader.pyx"
    }

#line 268 "cysystemd/reader.pyx"
    #endif

#line 268 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":269
 * 
 *     cpdef double get_realtime_sec(self):
 *         cdef double result = self.realtime_usec / 1000000.             # <<<<<<<<<<<<<<
 *         return result
 * 
*/

#line 269 "cysystemd/reader.pyx"
  __pyx_v_result = (((double)__pyx_v_self->realtime_usec) / 1000000.);

  /* "cysystemd/reader.pyx":270
 *     cpdef double get_realtime_sec(self):
 *         cdef double result = self.realtime_usec / 1000000.
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef double get_monotonic_sec(self):
*/

#line 270 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_result;

#line 270 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":268
 *         return self.cursor
 * 
 *     cpdef double get_realtime_sec(self):             # <<<<<<<<<<<<<<
 *         cdef double result = self.realtime_usec / 1000000.
 *         return result
*/

#line 268 "cysystemd/reader.pyx"


#line 268 "cysystemd/reader.pyx"
  /* function exit code */

#line 268 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 268 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 268 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 268 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 268 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 268 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_realtime_sec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 268 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 268 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 268 "cysystemd/reader.pyx"
  return __pyx_r;

#line 268 "cysystemd/reader.pyx"
}

#line 268 "cysystemd/reader.pyx"


#line 268 "cysystemd/reader.pyx"
/* Python wrapper */

#line 268 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_3get_realtime_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_12JournalEntry_3get_realtime_sec = 
#line 268 "cysystemd/reader.pyx"
{"get_realtime_sec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_3get_realtime_sec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 268 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_3get_realtime_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 268 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 268 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 268 "cysystemd/reader.pyx"
  #endif

#line 268 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 268 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_realtime_sec (wrapper)", 0);

#line 268 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 268 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 268 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 268 "cysystemd/reader.pyx"
  #else

#line 268 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 268 "cysystemd/reader.pyx"
  #endif

#line 268 "cysystemd/reader.pyx"
  #endif

#line 268 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 268 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("get_realtime_sec", 1, 0, 0, __pyx_nargs); return NULL; }

#line 268 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 268 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 268 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("get_realtime_sec", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 268 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_2get_realtime_sec(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 268 "cysystemd/reader.pyx"


#line 268 "cysystemd/reader.pyx"
  /* function exit code */

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 268 "cysystemd/reader.pyx"
  return __pyx_r;

#line 268 "cysystemd/reader.pyx"
}

#line 268 "cysystemd/reader.pyx"


#line 268 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_2get_realtime_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 268 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 268 "cysystemd/reader.pyx"
  double __pyx_t_1;

#line 268 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 268 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 268 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 268 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_realtime_sec", 0);

#line 268 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 268 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_sec(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 268, __pyx_L1_error)

#line 268 "cysystemd/reader.pyx"
  __pyx_t_2 = PyFloat_FromDouble(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 268, __pyx_L1_error)

#line 268 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 268 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_2;

#line 268 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

#line 268 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 268 "cysystemd/reader.pyx"


#line 268 "cysystemd/reader.pyx"
  /* function exit code */

#line 268 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 268 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 268 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_realtime_sec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 268 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 268 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 268 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 268 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 268 "cysystemd/reader.pyx"
  return __pyx_r;

#line 268 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":272
 *         return result
 * 
 *     cpdef double get_monotonic_sec(self):             # <<<<<<<<<<<<<<
 *         cdef double result = self.monotonic_usec / 1000000.
 *         return self.monotonic_usec / 1000000.
*/

#line 272 "cysystemd/reader.pyx"


#line 272 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_5get_monotonic_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/

#line 272 "cysystemd/reader.pyx"
static double __pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch) {
  CYTHON_UNUSED double __pyx_v_result
#line 272 "cysystemd/reader.pyx"
;

#line 272 "cysystemd/reader.pyx"
  double __pyx_r;

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 272 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 272 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 272 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 272 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 272 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 272 "cysystemd/reader.pyx"
  double __pyx_t_6;

#line 272 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 272 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 272 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_monotonic_sec", 0);

#line 272 "cysystemd/reader.pyx"
  /* Check if called by wrapper */

#line 272 "cysystemd/reader.pyx"
  if (unlikely(__pyx_skip_dispatch)) ;

#line 272 "cysystemd/reader.pyx"
  /* Check if overridden in Python */

#line 272 "cysystemd/reader.pyx"
  else if (

#line 272 "cysystemd/reader.pyx"
  #if !CYTHON_USE_TYPE_SLOTS

#line 272 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry &&

#line 272 "cysystemd/reader.pyx"
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))

#line 272 "cysystemd/reader.pyx"
  #else

#line 272 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))

#line 272 "cysystemd/reader.pyx"
  #endif

#line 272 "cysystemd/reader.pyx"
  ) {

#line 272 "cysystemd/reader.pyx"
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 272 "cysystemd/reader.pyx"
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 272 "cysystemd/reader.pyx"
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {

#line 272 "cysystemd/reader.pyx"
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 272 "cysystemd/reader.pyx"
      #endif

#line 272 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_monotonic_sec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)

#line 272 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 272 "cysystemd/reader.pyx"
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9cysystemd_6reader_12JournalEntry_5get_monotonic_sec)) {

#line 272 "cysystemd/reader.pyx"
        __pyx_t_3 = NULL;

#line 272 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_1);

#line 272 "cysystemd/reader.pyx"
        __pyx_t_4 = __pyx_t_1; 

#line 272 "cysystemd/reader.pyx"
        __pyx_t_5 = 1;

#line 272 "cysystemd/reader.pyx"
        #if CYTHON_UNPACK_METHODS

#line 272 "cysystemd/reader.pyx"
        if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 272 "cysystemd/reader.pyx"
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 272 "cysystemd/reader.pyx"
          assert(__pyx_t_3);

#line 272 "cysystemd/reader.pyx"
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 272 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx_t_3);

#line 272 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx__function);

#line 272 "cysystemd/reader.pyx"
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 272 "cysystemd/reader.pyx"
          __pyx_t_5 = 0;

#line 272 "cysystemd/reader.pyx"
        }

#line 272 "cysystemd/reader.pyx"
        #endif

#line 272 "cysystemd/reader.pyx"
        {

#line 272 "cysystemd/reader.pyx"
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};

#line 272 "cysystemd/reader.pyx"
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 272 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 272 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 272 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 272, __pyx_L1_error)

#line 272 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 272 "cysystemd/reader.pyx"
        }

#line 272 "cysystemd/reader.pyx"
        __pyx_t_6 = __Pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 272, __pyx_L1_error)

#line 272 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 272 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_6;

#line 272 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 272 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 272 "cysystemd/reader.pyx"
      }

#line 272 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 272 "cysystemd/reader.pyx"
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 272 "cysystemd/reader.pyx"
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));

#line 272 "cysystemd/reader.pyx"
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {

#line 272 "cysystemd/reader.pyx"
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 272 "cysystemd/reader.pyx"
      }

#line 272 "cysystemd/reader.pyx"
      #endif

#line 272 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 272 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 272 "cysystemd/reader.pyx"
    }

#line 272 "cysystemd/reader.pyx"
    #endif

#line 272 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":273
 * 
 *     cpdef double get_monotonic_sec(self):
 *         cdef double result = self.monotonic_usec / 1000000.             # <<<<<<<<<<<<<<
 *         return self.monotonic_usec / 1000000.
 * 
*/

#line 273 "cysystemd/reader.pyx"
  __pyx_v_result = (((double)__pyx_v_self->monotonic_usec) / 1000000.);

  /* "cysystemd/reader.pyx":274
 *     cpdef double get_monotonic_sec(self):
 *         cdef double result = self.monotonic_usec / 1000000.
 *         return self.monotonic_usec / 1000000.             # <<<<<<<<<<<<<<
 * 
 *     cpdef uint64_t get_realtime_usec(self):
*/

#line 274 "cysystemd/reader.pyx"
  __pyx_r = (((double)__pyx_v_self->monotonic_usec) / 1000000.);

#line 274 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":272
 *         return result
 * 
 *     cpdef double get_monotonic_sec(self):             # <<<<<<<<<<<<<<
 *         cdef double result = self.monotonic_usec / 1000000.
 *         return self.monotonic_usec / 1000000.
*/

#line 272 "cysystemd/reader.pyx"


#line 272 "cysystemd/reader.pyx"
  /* function exit code */

#line 272 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 272 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 272 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 272 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 272 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 272 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_monotonic_sec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 272 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 272 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 272 "cysystemd/reader.pyx"
  return __pyx_r;

#line 272 "cysystemd/reader.pyx"
}

#line 272 "cysystemd/reader.pyx"


#line 272 "cysystemd/reader.pyx"
/* Python wrapper */

#line 272 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_5get_monotonic_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_12JournalEntry_5get_monotonic_sec = 
#line 272 "cysystemd/reader.pyx"
{"get_monotonic_sec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_5get_monotonic_sec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 272 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_5get_monotonic_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 272 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 272 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 272 "cysystemd/reader.pyx"
  #endif

#line 272 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 272 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_monotonic_sec (wrapper)", 0);

#line 272 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 272 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 272 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 272 "cysystemd/reader.pyx"
  #else

#line 272 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 272 "cysystemd/reader.pyx"
  #endif

#line 272 "cysystemd/reader.pyx"
  #endif

#line 272 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 272 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("get_monotonic_sec", 1, 0, 0, __pyx_nargs); return NULL; }

#line 272 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 272 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 272 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("get_monotonic_sec", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 272 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_4get_monotonic_sec(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 272 "cysystemd/reader.pyx"


#line 272 "cysystemd/reader.pyx"
  /* function exit code */

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 272 "cysystemd/reader.pyx"
  return __pyx_r;

#line 272 "cysystemd/reader.pyx"
}

#line 272 "cysystemd/reader.pyx"


#line 272 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_4get_monotonic_sec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 272 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 272 "cysystemd/reader.pyx"
  double __pyx_t_1;

#line 272 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 272 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 272 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 272 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_monotonic_sec", 0);

#line 272 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 272 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_sec(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 272, __pyx_L1_error)

#line 272 "cysystemd/reader.pyx"
  __pyx_t_2 = PyFloat_FromDouble(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 272, __pyx_L1_error)

#line 272 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 272 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_2;

#line 272 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

#line 272 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 272 "cysystemd/reader.pyx"


#line 272 "cysystemd/reader.pyx"
  /* function exit code */

#line 272 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 272 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 272 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_monotonic_sec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 272 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 272 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 272 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 272 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 272 "cysystemd/reader.pyx"
  return __pyx_r;

#line 272 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":276
 *         return self.monotonic_usec / 1000000.
 * 
 *     cpdef uint64_t get_realtime_usec(self):             # <<<<<<<<<<<<<<
 *         return self.realtime_usec
 * 
*/

#line 276 "cysystemd/reader.pyx"


#line 276 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_7get_realtime_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/

#line 276 "cysystemd/reader.pyx"
static uint64_t __pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch) {

#line 276 "cysystemd/reader.pyx"
  uint64_t __pyx_r;

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 276 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 276 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 276 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 276 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 276 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 276 "cysystemd/reader.pyx"
  uint64_t __pyx_t_6;

#line 276 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 276 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 276 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_realtime_usec", 0);

#line 276 "cysystemd/reader.pyx"
  /* Check if called by wrapper */

#line 276 "cysystemd/reader.pyx"
  if (unlikely(__pyx_skip_dispatch)) ;

#line 276 "cysystemd/reader.pyx"
  /* Check if overridden in Python */

#line 276 "cysystemd/reader.pyx"
  else if (

#line 276 "cysystemd/reader.pyx"
  #if !CYTHON_USE_TYPE_SLOTS

#line 276 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry &&

#line 276 "cysystemd/reader.pyx"
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))

#line 276 "cysystemd/reader.pyx"
  #else

#line 276 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))

#line 276 "cysystemd/reader.pyx"
  #endif

#line 276 "cysystemd/reader.pyx"
  ) {

#line 276 "cysystemd/reader.pyx"
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 276 "cysystemd/reader.pyx"
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 276 "cysystemd/reader.pyx"
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {

#line 276 "cysystemd/reader.pyx"
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 276 "cysystemd/reader.pyx"
      #endif

#line 276 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_realtime_usec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)

#line 276 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 276 "cysystemd/reader.pyx"
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9cysystemd_6reader_12JournalEntry_7get_realtime_usec)) {

#line 276 "cysystemd/reader.pyx"
        __pyx_t_3 = NULL;

#line 276 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_1);

#line 276 "cysystemd/reader.pyx"
        __pyx_t_4 = __pyx_t_1; 

#line 276 "cysystemd/reader.pyx"
        __pyx_t_5 = 1;

#line 276 "cysystemd/reader.pyx"
        #if CYTHON_UNPACK_METHODS

#line 276 "cysystemd/reader.pyx"
        if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 276 "cysystemd/reader.pyx"
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 276 "cysystemd/reader.pyx"
          assert(__pyx_t_3);

#line 276 "cysystemd/reader.pyx"
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 276 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx_t_3);

#line 276 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx__function);

#line 276 "cysystemd/reader.pyx"
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 276 "cysystemd/reader.pyx"
          __pyx_t_5 = 0;

#line 276 "cysystemd/reader.pyx"
        }

#line 276 "cysystemd/reader.pyx"
        #endif

#line 276 "cysystemd/reader.pyx"
        {

#line 276 "cysystemd/reader.pyx"
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};

#line 276 "cysystemd/reader.pyx"
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 276 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 276 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 276 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)

#line 276 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 276 "cysystemd/reader.pyx"
        }

#line 276 "cysystemd/reader.pyx"
        __pyx_t_6 = __Pyx_PyLong_As_uint64_t(__pyx_t_2); if (unlikely((__pyx_t_6 == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 276, __pyx_L1_error)

#line 276 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 276 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_6;

#line 276 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 276 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 276 "cysystemd/reader.pyx"
      }

#line 276 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 276 "cysystemd/reader.pyx"
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 276 "cysystemd/reader.pyx"
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));

#line 276 "cysystemd/reader.pyx"
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {

#line 276 "cysystemd/reader.pyx"
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 276 "cysystemd/reader.pyx"
      }

#line 276 "cysystemd/reader.pyx"
      #endif

#line 276 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 276 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 276 "cysystemd/reader.pyx"
    }

#line 276 "cysystemd/reader.pyx"
    #endif

#line 276 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":277
 * 
 *     cpdef uint64_t get_realtime_usec(self):
 *         return self.realtime_usec             # <<<<<<<<<<<<<<
 * 
 *     cpdef uint64_t get_monotonic_usec(self):
*/

#line 277 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->realtime_usec;

#line 277 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":276
 *         return self.monotonic_usec / 1000000.
 * 
 *     cpdef uint64_t get_realtime_usec(self):             # <<<<<<<<<<<<<<
 *         return self.realtime_usec
 * 
*/

#line 276 "cysystemd/reader.pyx"


#line 276 "cysystemd/reader.pyx"
  /* function exit code */

#line 276 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 276 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 276 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 276 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 276 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 276 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_realtime_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 276 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 276 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 276 "cysystemd/reader.pyx"
  return __pyx_r;

#line 276 "cysystemd/reader.pyx"
}

#line 276 "cysystemd/reader.pyx"


#line 276 "cysystemd/reader.pyx"
/* Python wrapper */

#line 276 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_7get_realtime_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_12JournalEntry_7get_realtime_usec = 
#line 276 "cysystemd/reader.pyx"
{"get_realtime_usec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_7get_realtime_usec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 276 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_7get_realtime_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 276 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 276 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 276 "cysystemd/reader.pyx"
  #endif

#line 276 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 276 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_realtime_usec (wrapper)", 0);

#line 276 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 276 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 276 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 276 "cysystemd/reader.pyx"
  #else

#line 276 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 276 "cysystemd/reader.pyx"
  #endif

#line 276 "cysystemd/reader.pyx"
  #endif

#line 276 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 276 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("get_realtime_usec", 1, 0, 0, __pyx_nargs); return NULL; }

#line 276 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 276 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 276 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("get_realtime_usec", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 276 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_6get_realtime_usec(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 276 "cysystemd/reader.pyx"


#line 276 "cysystemd/reader.pyx"
  /* function exit code */

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 276 "cysystemd/reader.pyx"
  return __pyx_r;

#line 276 "cysystemd/reader.pyx"
}

#line 276 "cysystemd/reader.pyx"


#line 276 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_6get_realtime_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 276 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 276 "cysystemd/reader.pyx"
  uint64_t __pyx_t_1;

#line 276 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 276 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 276 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 276 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_realtime_usec", 0);

#line 276 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 276 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_usec(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 276, __pyx_L1_error)

#line 276 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From_uint64_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)

#line 276 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 276 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_2;

#line 276 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

#line 276 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 276 "cysystemd/reader.pyx"


#line 276 "cysystemd/reader.pyx"
  /* function exit code */

#line 276 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 276 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 276 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_realtime_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 276 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 276 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 276 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 276 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 276 "cysystemd/reader.pyx"
  return __pyx_r;

#line 276 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":279
 *         return self.realtime_usec
 * 
 *     cpdef uint64_t get_monotonic_usec(self):             # <<<<<<<<<<<<<<
 *         return self.monotonic_usec
 * 
*/

#line 279 "cysystemd/reader.pyx"


#line 279 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_9get_monotonic_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/

#line 279 "cysystemd/reader.pyx"
static uint64_t __pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, int __pyx_skip_dispatch) {

#line 279 "cysystemd/reader.pyx"
  uint64_t __pyx_r;

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 279 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 279 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 279 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 279 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 279 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 279 "cysystemd/reader.pyx"
  uint64_t __pyx_t_6;

#line 279 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 279 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 279 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_monotonic_usec", 0);

#line 279 "cysystemd/reader.pyx"
  /* Check if called by wrapper */

#line 279 "cysystemd/reader.pyx"
  if (unlikely(__pyx_skip_dispatch)) ;

#line 279 "cysystemd/reader.pyx"
  /* Check if overridden in Python */

#line 279 "cysystemd/reader.pyx"
  else if (

#line 279 "cysystemd/reader.pyx"
  #if !CYTHON_USE_TYPE_SLOTS

#line 279 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry &&

#line 279 "cysystemd/reader.pyx"
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))

#line 279 "cysystemd/reader.pyx"
  #else

#line 279 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))

#line 279 "cysystemd/reader.pyx"
  #endif

#line 279 "cysystemd/reader.pyx"
  ) {

#line 279 "cysystemd/reader.pyx"
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 279 "cysystemd/reader.pyx"
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 279 "cysystemd/reader.pyx"
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {

#line 279 "cysystemd/reader.pyx"
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 279 "cysystemd/reader.pyx"
      #endif

#line 279 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_monotonic_usec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 279, __pyx_L1_error)

#line 279 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 279 "cysystemd/reader.pyx"
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9cysystemd_6reader_12JournalEntry_9get_monotonic_usec)) {

#line 279 "cysystemd/reader.pyx"
        __pyx_t_3 = NULL;

#line 279 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_1);

#line 279 "cysystemd/reader.pyx"
        __pyx_t_4 = __pyx_t_1; 

#line 279 "cysystemd/reader.pyx"
        __pyx_t_5 = 1;

#line 279 "cysystemd/reader.pyx"
        #if CYTHON_UNPACK_METHODS

#line 279 "cysystemd/reader.pyx"
        if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 279 "cysystemd/reader.pyx"
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 279 "cysystemd/reader.pyx"
          assert(__pyx_t_3);

#line 279 "cysystemd/reader.pyx"
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 279 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx_t_3);

#line 279 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx__function);

#line 279 "cysystemd/reader.pyx"
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 279 "cysystemd/reader.pyx"
          __pyx_t_5 = 0;

#line 279 "cysystemd/reader.pyx"
        }

#line 279 "cysystemd/reader.pyx"
        #endif

#line 279 "cysystemd/reader.pyx"
        {

#line 279 "cysystemd/reader.pyx"
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};

#line 279 "cysystemd/reader.pyx"
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 279 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 279 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 279 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)

#line 279 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 279 "cysystemd/reader.pyx"
        }

#line 279 "cysystemd/reader.pyx"
        __pyx_t_6 = __Pyx_PyLong_As_uint64_t(__pyx_t_2); if (unlikely((__pyx_t_6 == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 279, __pyx_L1_error)

#line 279 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 279 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_6;

#line 279 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 279 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 279 "cysystemd/reader.pyx"
      }

#line 279 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 279 "cysystemd/reader.pyx"
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 279 "cysystemd/reader.pyx"
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));

#line 279 "cysystemd/reader.pyx"
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {

#line 279 "cysystemd/reader.pyx"
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 279 "cysystemd/reader.pyx"
      }

#line 279 "cysystemd/reader.pyx"
      #endif

#line 279 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 279 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 279 "cysystemd/reader.pyx"
    }

#line 279 "cysystemd/reader.pyx"
    #endif

#line 279 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":280
 * 
 *     cpdef uint64_t get_monotonic_usec(self):
 *         return self.monotonic_usec             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 280 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->monotonic_usec;

#line 280 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":279
 *         return self.realtime_usec
 * 
 *     cpdef uint64_t get_monotonic_usec(self):             # <<<<<<<<<<<<<<
 *         return self.monotonic_usec
 * 
*/

#line 279 "cysystemd/reader.pyx"


#line 279 "cysystemd/reader.pyx"
  /* function exit code */

#line 279 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 279 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 279 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 279 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 279 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 279 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_monotonic_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 279 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 279 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 279 "cysystemd/reader.pyx"
  return __pyx_r;

#line 279 "cysystemd/reader.pyx"
}

#line 279 "cysystemd/reader.pyx"


#line 279 "cysystemd/reader.pyx"
/* Python wrapper */

#line 279 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_9get_monotonic_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_12JournalEntry_9get_monotonic_usec = 
#line 279 "cysystemd/reader.pyx"
{"get_monotonic_usec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_9get_monotonic_usec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 279 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_9get_monotonic_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 279 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 279 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 279 "cysystemd/reader.pyx"
  #endif

#line 279 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 279 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_monotonic_usec (wrapper)", 0);

#line 279 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 279 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 279 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 279 "cysystemd/reader.pyx"
  #else

#line 279 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 279 "cysystemd/reader.pyx"
  #endif

#line 279 "cysystemd/reader.pyx"
  #endif

#line 279 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 279 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("get_monotonic_usec", 1, 0, 0, __pyx_nargs); return NULL; }

#line 279 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 279 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 279 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("get_monotonic_usec", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 279 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_8get_monotonic_usec(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 279 "cysystemd/reader.pyx"


#line 279 "cysystemd/reader.pyx"
  /* function exit code */

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 279 "cysystemd/reader.pyx"
  return __pyx_r;

#line 279 "cysystemd/reader.pyx"
}

#line 279 "cysystemd/reader.pyx"


#line 279 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_8get_monotonic_usec(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 279 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 279 "cysystemd/reader.pyx"
  uint64_t __pyx_t_1;

#line 279 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 279 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 279 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 279 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_monotonic_usec", 0);

#line 279 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 279 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_usec(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 279, __pyx_L1_error)

#line 279 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From_uint64_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)

#line 279 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 279 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_2;

#line 279 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

#line 279 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 279 "cysystemd/reader.pyx"


#line 279 "cysystemd/reader.pyx"
  /* function exit code */

#line 279 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 279 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 279 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.get_monotonic_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 279 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 279 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 279 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 279 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 279 "cysystemd/reader.pyx"
  return __pyx_r;

#line 279 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":282
 *         return self.monotonic_usec
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def boot_id(self) -> UUID:
 *         return self.__boot_uuid
*/

#line 282 "cysystemd/reader.pyx"


#line 282 "cysystemd/reader.pyx"
/* Python wrapper */

#line 282 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_7boot_id_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 282 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_7boot_id_1__get__(PyObject *__pyx_v_self) {

#line 282 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 282 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 282 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 282 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 282 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 282 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_7boot_id___get__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 282 "cysystemd/reader.pyx"


#line 282 "cysystemd/reader.pyx"
  /* function exit code */

#line 282 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 282 "cysystemd/reader.pyx"
  return __pyx_r;

#line 282 "cysystemd/reader.pyx"
}

#line 282 "cysystemd/reader.pyx"


#line 282 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_7boot_id___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 282 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 282 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 282 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":284
 *     @property
 *     def boot_id(self) -> UUID:
 *         return self.__boot_uuid             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 284 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 284 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_self->_JournalEntry__boot_uuid);

#line 284 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->_JournalEntry__boot_uuid;

#line 284 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":282
 *         return self.monotonic_usec
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def boot_id(self) -> UUID:
 *         return self.__boot_uuid
*/

#line 282 "cysystemd/reader.pyx"


#line 282 "cysystemd/reader.pyx"
  /* function exit code */

#line 282 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 282 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 282 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 282 "cysystemd/reader.pyx"
  return __pyx_r;

#line 282 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":286
 *         return self.__boot_uuid
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def date(self) -> datetime:
 *         return self.__date
*/

#line 286 "cysystemd/reader.pyx"


#line 286 "cysystemd/reader.pyx"
/* Python wrapper */

#line 286 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_4date_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 286 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_4date_1__get__(PyObject *__pyx_v_self) {

#line 286 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 286 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 286 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 286 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 286 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 286 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_4date___get__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 286 "cysystemd/reader.pyx"


#line 286 "cysystemd/reader.pyx"
  /* function exit code */

#line 286 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 286 "cysystemd/reader.pyx"
  return __pyx_r;

#line 286 "cysystemd/reader.pyx"
}

#line 286 "cysystemd/reader.pyx"


#line 286 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_4date___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 286 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 286 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 286 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":288
 *     @property
 *     def date(self) -> datetime:
 *         return self.__date             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 288 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 288 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_self->_JournalEntry__date);

#line 288 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->_JournalEntry__date;

#line 288 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":286
 *         return self.__boot_uuid
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def date(self) -> datetime:
 *         return self.__date
*/

#line 286 "cysystemd/reader.pyx"


#line 286 "cysystemd/reader.pyx"
  /* function exit code */

#line 286 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 286 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 286 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 286 "cysystemd/reader.pyx"
  return __pyx_r;

#line 286 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":290
 *         return self.__date
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def data(self) -> dict[str, str]:
 *         return self._data
*/

#line 290 "cysystemd/reader.pyx"


#line 290 "cysystemd/reader.pyx"
/* Python wrapper */

#line 290 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_4data_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 290 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_4data_1__get__(PyObject *__pyx_v_self) {

#line 290 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 290 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 290 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 290 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 290 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 290 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_4data___get__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 290 "cysystemd/reader.pyx"


#line 290 "cysystemd/reader.pyx"
  /* function exit code */

#line 290 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 290 "cysystemd/reader.pyx"
  return __pyx_r;

#line 290 "cysystemd/reader.pyx"
}

#line 290 "cysystemd/reader.pyx"


#line 290 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_4data___get__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 290 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 290 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 290 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":292
 *     @property
 *     def data(self) -> dict[str, str]:
 *         return self._data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
*/

#line 292 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 292 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_self->_data);

#line 292 "cysystemd/reader.pyx"
  __pyx_r = __pyx_v_self->_data;

#line 292 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":290
 *         return self.__date
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def data(self) -> dict[str, str]:
 *         return self._data
*/

#line 290 "cysystemd/reader.pyx"


#line 290 "cysystemd/reader.pyx"
  /* function exit code */

#line 290 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 290 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 290 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 290 "cysystemd/reader.pyx"
  return __pyx_r;

#line 290 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":294
 *         return self._data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         PyMem_Free(self.cursor)
 * 
*/

#line 294 "cysystemd/reader.pyx"


#line 294 "cysystemd/reader.pyx"
/* Python wrapper */

#line 294 "cysystemd/reader.pyx"
static void __pyx_pw_9cysystemd_6reader_12JournalEntry_11__dealloc__(PyObject *__pyx_v_self); /*proto*/

#line 294 "cysystemd/reader.pyx"
static void __pyx_pw_9cysystemd_6reader_12JournalEntry_11__dealloc__(PyObject *__pyx_v_self) {

#line 294 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 294 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 294 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);

#line 294 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 294 "cysystemd/reader.pyx"
  __pyx_pf_9cysystemd_6reader_12JournalEntry_10__dealloc__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 294 "cysystemd/reader.pyx"


#line 294 "cysystemd/reader.pyx"
  /* function exit code */

#line 294 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 294 "cysystemd/reader.pyx"
}

#line 294 "cysystemd/reader.pyx"


#line 294 "cysystemd/reader.pyx"
static void __pyx_pf_9cysystemd_6reader_12JournalEntry_10__dealloc__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

  /* "cysystemd/reader.pyx":295
 * 
 *     def __dealloc__(self):
 *         PyMem_Free(self.cursor)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self) -> str:
*/

#line 295 "cysystemd/reader.pyx"
  PyMem_Free(__pyx_v_self->cursor);

  /* "cysystemd/reader.pyx":294
 *         return self._data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         PyMem_Free(self.cursor)
 * 
*/

#line 294 "cysystemd/reader.pyx"


#line 294 "cysystemd/reader.pyx"
  /* function exit code */

#line 294 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":297
 *         PyMem_Free(self.cursor)
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         return "<JournalEntry: %r>" % self.date
 * 
*/

#line 297 "cysystemd/reader.pyx"


#line 297 "cysystemd/reader.pyx"
/* Python wrapper */

#line 297 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_13__repr__(PyObject *__pyx_v_self); /*proto*/

#line 297 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_13__repr__(PyObject *__pyx_v_self) {

#line 297 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 297 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 297 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 297 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);

#line 297 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 297 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_12__repr__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 297 "cysystemd/reader.pyx"


#line 297 "cysystemd/reader.pyx"
  /* function exit code */

#line 297 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 297 "cysystemd/reader.pyx"
  return __pyx_r;

#line 297 "cysystemd/reader.pyx"
}

#line 297 "cysystemd/reader.pyx"


#line 297 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_12__repr__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 297 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 297 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 297 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 297 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 297 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 297 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 297 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 297 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "cysystemd/reader.pyx":298
 * 
 *     def __repr__(self) -> str:
 *         return "<JournalEntry: %r>" % self.date             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, str key) -> str:
*/

#line 298 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 298 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 298, __pyx_L1_error)

#line 298 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 298 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_JournalEntry_r, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 298, __pyx_L1_error)

#line 298 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 298 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 298 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_2;

#line 298 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

#line 298 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":297
 *         PyMem_Free(self.cursor)
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         return "<JournalEntry: %r>" % self.date
 * 
*/

#line 297 "cysystemd/reader.pyx"


#line 297 "cysystemd/reader.pyx"
  /* function exit code */

#line 297 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 297 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 297 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 297 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 297 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 297 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 297 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 297 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 297 "cysystemd/reader.pyx"
  return __pyx_r;

#line 297 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":300
 *         return "<JournalEntry: %r>" % self.date
 * 
 *     def __getitem__(self, str key) -> str:             # <<<<<<<<<<<<<<
 *         return self._data[key]
 * 
*/

#line 300 "cysystemd/reader.pyx"


#line 300 "cysystemd/reader.pyx"
/* Python wrapper */

#line 300 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_15__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/

#line 300 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_15__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {

#line 300 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 300 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 300 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 300 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 300 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 300 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 300 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);

#line 300 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 300 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_key), (&PyUnicode_Type), 1, "key", 1))) __PYX_ERR(0, 300, __pyx_L1_error)
  __pyx_r = 
#line 300 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_12JournalEntry_14__getitem__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self), ((PyObject*)__pyx_v_key));

#line 300 "cysystemd/reader.pyx"


#line 300 "cysystemd/reader.pyx"
  /* function exit code */

#line 300 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 300 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 300 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 300 "cysystemd/reader.pyx"
  goto __pyx_L5_cleaned_up;

#line 300 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 300 "cysystemd/reader.pyx"
  __pyx_L5_cleaned_up:;

#line 300 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 300 "cysystemd/reader.pyx"
  return __pyx_r;

#line 300 "cysystemd/reader.pyx"
}

#line 300 "cysystemd/reader.pyx"


#line 300 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_14__getitem__(struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, PyObject *__pyx_v_key) {

#line 300 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 300 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 300 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 300 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 300 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 300 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 300 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "cysystemd/reader.pyx":301
 * 
 *     def __getitem__(self, str key) -> str:
 *         return self._data[key]             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 301 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 301 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_data, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error)

#line 301 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 301 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 301 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 301 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":300
 *         return "<JournalEntry: %r>" % self.date
 * 
 *     def __getitem__(self, str key) -> str:             # <<<<<<<<<<<<<<
 *         return self._data[key]
 * 
*/

#line 300 "cysystemd/reader.pyx"


#line 300 "cysystemd/reader.pyx"
  /* function exit code */

#line 300 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 300 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 300 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 300 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 300 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 300 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 300 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 300 "cysystemd/reader.pyx"
  return __pyx_r;

#line 300 "cysystemd/reader.pyx"
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
/* Python wrapper */

#line 1 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_17__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_12JournalEntry_17__reduce_cython__ = 
#line 1 "(tree fragment)"
{"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_17__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 1 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_17__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 1 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 1 "(tree fragment)"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 1 "(tree fragment)"
  PyObject *__pyx_r = 0;

#line 1 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 1 "(tree fragment)"
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);

#line 1 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 1 "(tree fragment)"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 1 "(tree fragment)"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 1 "(tree fragment)"
  #else

#line 1 "(tree fragment)"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 1 "(tree fragment)"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }

#line 1 "(tree fragment)"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 1 "(tree fragment)"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 1 "(tree fragment)"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 1 "(tree fragment)"
__pyx_pf_9cysystemd_6reader_12JournalEntry_16__reduce_cython__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self));

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
  /* function exit code */

#line 1 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 1 "(tree fragment)"
  return __pyx_r;

#line 1 "(tree fragment)"
}

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self) {

#line 1 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 1 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 1 "(tree fragment)"
  int __pyx_lineno = 0;

#line 1 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 1 "(tree fragment)"
  int __pyx_clineno = 0;

#line 1 "(tree fragment)"
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

#line 2 "(tree fragment)"
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);

#line 2 "(tree fragment)"
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
  /* function exit code */

#line 1 "(tree fragment)"
  __pyx_L1_error:;

#line 1 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 1 "(tree fragment)"
  __pyx_r = NULL;

#line 1 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 1 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 1 "(tree fragment)"
  return __pyx_r;

#line 1 "(tree fragment)"
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
/* Python wrapper */

#line 3 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_19__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_12JournalEntry_19__setstate_cython__ = 
#line 3 "(tree fragment)"
{"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_19__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 3 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_12JournalEntry_19__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0
#line 3 "(tree fragment)"
;

#line 3 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 3 "(tree fragment)"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 3 "(tree fragment)"
  PyObject* values[1] = {0};

#line 3 "(tree fragment)"
  int __pyx_lineno = 0;

#line 3 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 3 "(tree fragment)"
  int __pyx_clineno = 0;

#line 3 "(tree fragment)"
  PyObject *__pyx_r = 0;

#line 3 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 3 "(tree fragment)"
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);

#line 3 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 3 "(tree fragment)"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 3 "(tree fragment)"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 3 "(tree fragment)"
  #else

#line 3 "(tree fragment)"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 3 "(tree fragment)"
  {

#line 3 "(tree fragment)"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};

#line 3 "(tree fragment)"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 3 "(tree fragment)"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
    if (__pyx_kwds_len > 0) {

#line 3 "(tree fragment)"
      switch (__pyx_nargs) {

#line 3 "(tree fragment)"
        case  1:

#line 3 "(tree fragment)"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 3 "(tree fragment)"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 3 "(tree fragment)"
break;
        default: 
#line 3 "(tree fragment)"
goto __pyx_L5_argtuple_error;

#line 3 "(tree fragment)"
      }

#line 3 "(tree fragment)"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 3 "(tree fragment)"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 3 "(tree fragment)"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(1, 3, __pyx_L3_error) }

#line 3 "(tree fragment)"
      }

#line 3 "(tree fragment)"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 3 "(tree fragment)"
      goto __pyx_L5_argtuple_error;

#line 3 "(tree fragment)"
    } else {

#line 3 "(tree fragment)"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 3 "(tree fragment)"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
    }

#line 3 "(tree fragment)"
    __pyx_v___pyx_state = values[0];

#line 3 "(tree fragment)"
  }

#line 3 "(tree fragment)"
  goto __pyx_L6_skip;

#line 3 "(tree fragment)"
  __pyx_L5_argtuple_error:;

#line 3 "(tree fragment)"
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
  __pyx_L6_skip:;

#line 3 "(tree fragment)"
  goto __pyx_L4_argument_unpacking_done;

#line 3 "(tree fragment)"
  __pyx_L3_error:;

#line 3 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 3 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 3 "(tree fragment)"
  }

#line 3 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 3 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 3 "(tree fragment)"
  return NULL;

#line 3 "(tree fragment)"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 3 "(tree fragment)"
__pyx_pf_9cysystemd_6reader_12JournalEntry_18__setstate_cython__(((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_v_self), __pyx_v___pyx_state);

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
  /* function exit code */

#line 3 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 3 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 3 "(tree fragment)"
  }

#line 3 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 3 "(tree fragment)"
  return __pyx_r;

#line 3 "(tree fragment)"
}

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
static PyObject *__pyx_pf_9cysystemd_6reader_12JournalEntry_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {

#line 3 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 3 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 3 "(tree fragment)"
  int __pyx_lineno = 0;

#line 3 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 3 "(tree fragment)"
  int __pyx_clineno = 0;

#line 3 "(tree fragment)"
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/

#line 4 "(tree fragment)"
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);

#line 4 "(tree fragment)"
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
  /* function exit code */

#line 3 "(tree fragment)"
  __pyx_L1_error:;

#line 3 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.JournalEntry.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 3 "(tree fragment)"
  __pyx_r = NULL;

#line 3 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 3 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 3 "(tree fragment)"
  return __pyx_r;

#line 3 "(tree fragment)"
}

/* "cysystemd/reader.pyx":309
 *     cdef object flags
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.state = READER_NULL
 *         self.flags = None
*/

#line 309 "cysystemd/reader.pyx"


#line 309 "cysystemd/reader.pyx"
/* Python wrapper */

#line 309 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_13JournalReader_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/

#line 309 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_13JournalReader_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {

#line 309 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 309 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 309 "cysystemd/reader.pyx"
  int __pyx_r;

#line 309 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 309 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);

#line 309 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 309 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 309 "cysystemd/reader.pyx"
  #else

#line 309 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;

#line 309 "cysystemd/reader.pyx"
  #endif

#line 309 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 309 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }

#line 309 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;

#line 309 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return -1;

#line 309 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = 
#line 309 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader___init__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 309 "cysystemd/reader.pyx"


#line 309 "cysystemd/reader.pyx"
  /* function exit code */

#line 309 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 309 "cysystemd/reader.pyx"
  return __pyx_r;

#line 309 "cysystemd/reader.pyx"
}

#line 309 "cysystemd/reader.pyx"


#line 309 "cysystemd/reader.pyx"
static int __pyx_pf_9cysystemd_6reader_13JournalReader___init__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 309 "cysystemd/reader.pyx"
  int __pyx_r;

#line 309 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 309 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cysystemd/reader.pyx":310
 * 
 *     def __init__(self):
 *         self.state = READER_NULL             # <<<<<<<<<<<<<<
 *         self.flags = None
 * 
*/

#line 310 "cysystemd/reader.pyx"
  __pyx_v_self->state = __pyx_e_9cysystemd_6reader_READER_NULL;

  /* "cysystemd/reader.pyx":311
 *     def __init__(self):
 *         self.state = READER_NULL
 *         self.flags = None             # <<<<<<<<<<<<<<
 * 
 *     def open(self, flags=JournalOpenMode.CURRENT_USER) -> int:
*/

#line 311 "cysystemd/reader.pyx"
  __Pyx_INCREF(Py_None);

#line 311 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(Py_None);

#line 311 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->flags);

#line 311 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->flags);

#line 311 "cysystemd/reader.pyx"
  __pyx_v_self->flags = Py_None;

  /* "cysystemd/reader.pyx":309
 *     cdef object flags
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.state = READER_NULL
 *         self.flags = None
*/

#line 309 "cysystemd/reader.pyx"


#line 309 "cysystemd/reader.pyx"
  /* function exit code */

#line 309 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 309 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 309 "cysystemd/reader.pyx"
  return __pyx_r;

#line 309 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":313
 *         self.flags = None
 * 
 *     def open(self, flags=JournalOpenMode.CURRENT_USER) -> int:             # <<<<<<<<<<<<<<
 *         self.flags = JournalOpenMode(int(flags))
 * 
*/

#line 313 "cysystemd/reader.pyx"


#line 313 "cysystemd/reader.pyx"
/* Python wrapper */

#line 313 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_3open(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_3open = 
#line 313 "cysystemd/reader.pyx"
{"open", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_3open, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 313 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_3open(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_flags = 0
#line 313 "cysystemd/reader.pyx"
;

#line 313 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 313 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 313 "cysystemd/reader.pyx"
  #endif

#line 313 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 313 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 313 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 313 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 313 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 313 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 313 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("open (wrapper)", 0);

#line 313 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 313 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 313 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 313 "cysystemd/reader.pyx"
  #else

#line 313 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 313 "cysystemd/reader.pyx"
  #endif

#line 313 "cysystemd/reader.pyx"
  #endif

#line 313 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 313 "cysystemd/reader.pyx"
  {

#line 313 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_flags,0};

#line 313 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 313 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 313, __pyx_L3_error)

#line 313 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 313 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 313 "cysystemd/reader.pyx"
        case  1:

#line 313 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 313 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 313, __pyx_L3_error)

#line 313 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 313 "cysystemd/reader.pyx"
break;
        default: 
#line 313 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 313 "cysystemd/reader.pyx"
      }

#line 313 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 313 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "open", 0) < (0)) __PYX_ERR(0, 313, __pyx_L3_error)

#line 313 "cysystemd/reader.pyx"
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__4);

#line 313 "cysystemd/reader.pyx"
    } else {

#line 313 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 313 "cysystemd/reader.pyx"
        case  1:

#line 313 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 313 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 313, __pyx_L3_error)

#line 313 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 313 "cysystemd/reader.pyx"
break;
        default: 
#line 313 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 313 "cysystemd/reader.pyx"
      }

#line 313 "cysystemd/reader.pyx"
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__4);

#line 313 "cysystemd/reader.pyx"
    }

#line 313 "cysystemd/reader.pyx"
    __pyx_v_flags = values[0];

#line 313 "cysystemd/reader.pyx"
  }

#line 313 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 313 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 313 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("open", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 313, __pyx_L3_error)

#line 313 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 313 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 313 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 313 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 313 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 313 "cysystemd/reader.pyx"
  }

#line 313 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.open", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 313 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 313 "cysystemd/reader.pyx"
  return NULL;

#line 313 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 313 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_2open(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_flags);

#line 313 "cysystemd/reader.pyx"


#line 313 "cysystemd/reader.pyx"
  /* function exit code */

#line 313 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 313 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 313 "cysystemd/reader.pyx"
  }

#line 313 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 313 "cysystemd/reader.pyx"
  return __pyx_r;

#line 313 "cysystemd/reader.pyx"
}

#line 313 "cysystemd/reader.pyx"


#line 313 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_2open(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_flags) {

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 313 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 313 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 313 "cysystemd/reader.pyx"
  int __pyx_t_10;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 313 "cysystemd/reader.pyx"
  int __pyx_t_12;

#line 313 "cysystemd/reader.pyx"
  int __pyx_t_13;

#line 313 "cysystemd/reader.pyx"
  PyObject *__pyx_t_14 = NULL;

#line 313 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 313 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 313 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 313 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("open", 0);

  /* "cysystemd/reader.pyx":314
 * 
 *     def open(self, flags=JournalOpenMode.CURRENT_USER) -> int:
 *         self.flags = JournalOpenMode(int(flags))             # <<<<<<<<<<<<<<
 * 
 *         with self._lock(opening=True):
*/

#line 314 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 314 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_JournalOpenMode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)

#line 314 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 314 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_v_flags); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 314, __pyx_L1_error)

#line 314 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 314 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 314 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 314 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 314 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 314 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 314 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 314 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 314 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 314 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 314 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 314 "cysystemd/reader.pyx"
  }

#line 314 "cysystemd/reader.pyx"
  #endif

#line 314 "cysystemd/reader.pyx"
  {

#line 314 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 314 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 314 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 314 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 314 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 314 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)

#line 314 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 314 "cysystemd/reader.pyx"
  }

#line 314 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_1);

#line 314 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_v_self->flags);

#line 314 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_self->flags);

#line 314 "cysystemd/reader.pyx"
  __pyx_v_self->flags = __pyx_t_1;

#line 314 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":316
 *         self.flags = JournalOpenMode(int(flags))
 * 
 *         with self._lock(opening=True):             # <<<<<<<<<<<<<<
 *             return check_error_code(sd_journal_open(&self.context, self.flags.value))
 * 
*/

#line 316 "cysystemd/reader.pyx"
  /*with:*/ {

#line 316 "cysystemd/reader.pyx"
    __pyx_t_3 = ((PyObject *)__pyx_v_self);

#line 316 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 316 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 316 "cysystemd/reader.pyx"
    {

#line 316 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, NULL};

#line 316 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 316, __pyx_L1_error)

#line 316 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 316 "cysystemd/reader.pyx"
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_opening, Py_True, __pyx_t_4, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 316, __pyx_L1_error)

#line 316 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);

#line 316 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 316 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 316 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)

#line 316 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 316 "cysystemd/reader.pyx"
    }

#line 316 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 316, __pyx_L1_error)

#line 316 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 316 "cysystemd/reader.pyx"
    __pyx_t_3 = NULL;

#line 316 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L3_error)

#line 316 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 316 "cysystemd/reader.pyx"
    __pyx_t_5 = 1;

#line 316 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 316 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_2))) {

#line 316 "cysystemd/reader.pyx"
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);

#line 316 "cysystemd/reader.pyx"
      assert(__pyx_t_3);

#line 316 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);

#line 316 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_3);

#line 316 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 316 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);

#line 316 "cysystemd/reader.pyx"
      __pyx_t_5 = 0;

#line 316 "cysystemd/reader.pyx"
    }

#line 316 "cysystemd/reader.pyx"
    #endif

#line 316 "cysystemd/reader.pyx"
    {

#line 316 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};

#line 316 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 316 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 316 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 316 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 316, __pyx_L3_error)

#line 316 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 316 "cysystemd/reader.pyx"
    }

#line 316 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 316 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 316 "cysystemd/reader.pyx"
    /*try:*/ {

#line 316 "cysystemd/reader.pyx"
      {

#line 316 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_declare

#line 316 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_assign

#line 316 "cysystemd/reader.pyx"
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_7);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_8);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_9);

#line 316 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":317
 * 
 *         with self._lock(opening=True):
 *             return check_error_code(sd_journal_open(&self.context, self.flags.value))             # <<<<<<<<<<<<<<
 * 
 *     def open_directory(self, path) -> None:
*/

#line 317 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_r);

#line 317 "cysystemd/reader.pyx"
          __pyx_t_4 = NULL;

#line 317 "cysystemd/reader.pyx"
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 317, __pyx_L7_error)

#line 317 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 317 "cysystemd/reader.pyx"
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->flags, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L7_error)

#line 317 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_3);

#line 317 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyLong_As_int(__pyx_t_3); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 317, __pyx_L7_error)

#line 317 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 317 "cysystemd/reader.pyx"
          __pyx_t_3 = __Pyx_PyLong_From_int(sd_journal_open((&__pyx_v_self->context), __pyx_t_10)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L7_error)

#line 317 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_3);

#line 317 "cysystemd/reader.pyx"
          __pyx_t_5 = 1;

#line 317 "cysystemd/reader.pyx"
          #if CYTHON_UNPACK_METHODS

#line 317 "cysystemd/reader.pyx"
          if (unlikely(PyMethod_Check(__pyx_t_2))) {

#line 317 "cysystemd/reader.pyx"
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);

#line 317 "cysystemd/reader.pyx"
            assert(__pyx_t_4);

#line 317 "cysystemd/reader.pyx"
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);

#line 317 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx_t_4);

#line 317 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx__function);

#line 317 "cysystemd/reader.pyx"
            __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);

#line 317 "cysystemd/reader.pyx"
            __pyx_t_5 = 0;

#line 317 "cysystemd/reader.pyx"
          }

#line 317 "cysystemd/reader.pyx"
          #endif

#line 317 "cysystemd/reader.pyx"
          {

#line 317 "cysystemd/reader.pyx"
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};

#line 317 "cysystemd/reader.pyx"
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 317 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 317 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 317 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 317 "cysystemd/reader.pyx"
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 317, __pyx_L7_error)

#line 317 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_1);

#line 317 "cysystemd/reader.pyx"
          }

#line 317 "cysystemd/reader.pyx"
          if (__Pyx_PyInt_FromNumber(&__pyx_t_1, NULL, 1) < (0)) __PYX_ERR(0, 317, __pyx_L7_error)

#line 317 "cysystemd/reader.pyx"
          __pyx_r = ((PyObject*)__pyx_t_1);

#line 317 "cysystemd/reader.pyx"
          __pyx_t_1 = 0;

#line 317 "cysystemd/reader.pyx"
          goto __pyx_L11_try_return;

          /* "cysystemd/reader.pyx":316
 *         self.flags = JournalOpenMode(int(flags))
 * 
 *         with self._lock(opening=True):             # <<<<<<<<<<<<<<
 *             return check_error_code(sd_journal_open(&self.context, self.flags.value))
 * 
*/

#line 316 "cysystemd/reader.pyx"
        }

#line 316 "cysystemd/reader.pyx"
        __pyx_L7_error:;

#line 316 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 316 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 316 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 316 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 316 "cysystemd/reader.pyx"
        /*except:*/ {

#line 316 "cysystemd/reader.pyx"
          __Pyx_AddTraceback("cysystemd.reader.JournalReader.open", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 316 "cysystemd/reader.pyx"
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(0, 316, __pyx_L9_except_error)

#line 316 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_1);

#line 316 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_2);

#line 316 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_3);

#line 316 "cysystemd/reader.pyx"
          __pyx_t_4 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 316, __pyx_L9_except_error)

#line 316 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_4);

#line 316 "cysystemd/reader.pyx"
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_4, NULL);

#line 316 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 316 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 316 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 316, __pyx_L9_except_error)

#line 316 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_11);

#line 316 "cysystemd/reader.pyx"
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_11);

#line 316 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

#line 316 "cysystemd/reader.pyx"
          if (__pyx_t_12 < (0)) __PYX_ERR(0, 316, __pyx_L9_except_error)

#line 316 "cysystemd/reader.pyx"
          __pyx_t_13 = (!__pyx_t_12);

#line 316 "cysystemd/reader.pyx"
          if (unlikely(__pyx_t_13)) {

#line 316 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_1);

#line 316 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_2);

#line 316 "cysystemd/reader.pyx"
            __Pyx_XGIVEREF(__pyx_t_3);

#line 316 "cysystemd/reader.pyx"
            __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_2, __pyx_t_3);

#line 316 "cysystemd/reader.pyx"
            __pyx_t_1 = 0;  __pyx_t_2 = 0;  __pyx_t_3 = 0; 

#line 316 "cysystemd/reader.pyx"
            __PYX_ERR(0, 316, __pyx_L9_except_error)

#line 316 "cysystemd/reader.pyx"
          }

#line 316 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 316 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 316 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 316 "cysystemd/reader.pyx"
          goto __pyx_L8_exception_handled;

#line 316 "cysystemd/reader.pyx"
        }

#line 316 "cysystemd/reader.pyx"
        __pyx_L9_except_error:;

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 316 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 316 "cysystemd/reader.pyx"
        goto __pyx_L1_error;

#line 316 "cysystemd/reader.pyx"
        __pyx_L11_try_return:;

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 316 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 316 "cysystemd/reader.pyx"
        goto __pyx_L4_return;

#line 316 "cysystemd/reader.pyx"
        __pyx_L8_exception_handled:;

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 316 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 316 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 316 "cysystemd/reader.pyx"
      }

#line 316 "cysystemd/reader.pyx"
    }

#line 316 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 316 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 316 "cysystemd/reader.pyx"
        if (__pyx_t_6) {

#line 316 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 316 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 316 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 316, __pyx_L1_error)

#line 316 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 316 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 316 "cysystemd/reader.pyx"
        }

#line 316 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 316 "cysystemd/reader.pyx"
      }

#line 316 "cysystemd/reader.pyx"
      __pyx_L4_return: {

#line 316 "cysystemd/reader.pyx"
        __pyx_t_14 = __pyx_r;

#line 316 "cysystemd/reader.pyx"
        __pyx_r = 0;

#line 316 "cysystemd/reader.pyx"
        if (__pyx_t_6) {

#line 316 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 316 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 316 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 316, __pyx_L1_error)

#line 316 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 316 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 316 "cysystemd/reader.pyx"
        }

#line 316 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_14;

#line 316 "cysystemd/reader.pyx"
        __pyx_t_14 = 0;

#line 316 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 316 "cysystemd/reader.pyx"
      }

#line 316 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 316 "cysystemd/reader.pyx"
    }

#line 316 "cysystemd/reader.pyx"
    goto __pyx_L16;

#line 316 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 316 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 316 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 316 "cysystemd/reader.pyx"
    __pyx_L16:;

#line 316 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":313
 *         self.flags = None
 * 
 *     def open(self, flags=JournalOpenMode.CURRENT_USER) -> int:             # <<<<<<<<<<<<<<
 *         self.flags = JournalOpenMode(int(flags))
 * 
*/

#line 313 "cysystemd/reader.pyx"


#line 313 "cysystemd/reader.pyx"
  /* function exit code */

#line 313 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);

#line 313 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 313 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 313 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 313 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 313 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 313 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 313 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.open", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 313 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 313 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 313 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 313 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 313 "cysystemd/reader.pyx"
  return __pyx_r;

#line 313 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":319
 *             return check_error_code(sd_journal_open(&self.context, self.flags.value))
 * 
 *     def open_directory(self, path) -> None:             # <<<<<<<<<<<<<<
 *         path = _check_dir_path(path)
 * 
*/

#line 319 "cysystemd/reader.pyx"


#line 319 "cysystemd/reader.pyx"
/* Python wrapper */

#line 319 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_5open_directory(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_5open_directory = 
#line 319 "cysystemd/reader.pyx"
{"open_directory", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_5open_directory, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 319 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_5open_directory(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_path = 0
#line 319 "cysystemd/reader.pyx"
;

#line 319 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 319 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 319 "cysystemd/reader.pyx"
  #endif

#line 319 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 319 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 319 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 319 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 319 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 319 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 319 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("open_directory (wrapper)", 0);

#line 319 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 319 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 319 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 319 "cysystemd/reader.pyx"
  #else

#line 319 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 319 "cysystemd/reader.pyx"
  #endif

#line 319 "cysystemd/reader.pyx"
  #endif

#line 319 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 319 "cysystemd/reader.pyx"
  {

#line 319 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_path,0};

#line 319 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 319 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 319, __pyx_L3_error)

#line 319 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 319 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 319 "cysystemd/reader.pyx"
        case  1:

#line 319 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 319 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 319, __pyx_L3_error)

#line 319 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 319 "cysystemd/reader.pyx"
break;
        default: 
#line 319 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 319 "cysystemd/reader.pyx"
      }

#line 319 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 319 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "open_directory", 0) < (0)) __PYX_ERR(0, 319, __pyx_L3_error)

#line 319 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 319 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("open_directory", 1, 1, 1, i); __PYX_ERR(0, 319, __pyx_L3_error) }

#line 319 "cysystemd/reader.pyx"
      }

#line 319 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 319 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 319 "cysystemd/reader.pyx"
    } else {

#line 319 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 319 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 319, __pyx_L3_error)

#line 319 "cysystemd/reader.pyx"
    }

#line 319 "cysystemd/reader.pyx"
    __pyx_v_path = values[0];

#line 319 "cysystemd/reader.pyx"
  }

#line 319 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 319 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 319 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("open_directory", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 319, __pyx_L3_error)

#line 319 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 319 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 319 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 319 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 319 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 319 "cysystemd/reader.pyx"
  }

#line 319 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.open_directory", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 319 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 319 "cysystemd/reader.pyx"
  return NULL;

#line 319 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 319 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_4open_directory(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_path);

#line 319 "cysystemd/reader.pyx"


#line 319 "cysystemd/reader.pyx"
  /* function exit code */

#line 319 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 319 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 319 "cysystemd/reader.pyx"
  }

#line 319 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 319 "cysystemd/reader.pyx"
  return __pyx_r;

#line 319 "cysystemd/reader.pyx"
}

#line 319 "cysystemd/reader.pyx"


#line 319 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_4open_directory(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_v_cstr = NULL
#line 319 "cysystemd/reader.pyx"
;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 319 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 319 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 319 "cysystemd/reader.pyx"
  char const *__pyx_t_10;

#line 319 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 319 "cysystemd/reader.pyx"
  int __pyx_t_12;

#line 319 "cysystemd/reader.pyx"
  int __pyx_t_13;

#line 319 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 319 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 319 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 319 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("open_directory", 0);

#line 319 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_path);

  /* "cysystemd/reader.pyx":320
 * 
 *     def open_directory(self, path) -> None:
 *         path = _check_dir_path(path)             # <<<<<<<<<<<<<<
 * 
 *         with self._lock(opening=True):
*/

#line 320 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_f_9cysystemd_6reader__check_dir_path(__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)

#line 320 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 320 "cysystemd/reader.pyx"
  __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);

#line 320 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":322
 *         path = _check_dir_path(path)
 * 
 *         with self._lock(opening=True):             # <<<<<<<<<<<<<<
 *             cstr = path.encode()
 *             check_error_code(sd_journal_open_directory(&self.context, cstr, 0))
*/

#line 322 "cysystemd/reader.pyx"
  /*with:*/ {

#line 322 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 322 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 322 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 322 "cysystemd/reader.pyx"
    {

#line 322 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, NULL};

#line 322 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 322, __pyx_L1_error)

#line 322 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 322 "cysystemd/reader.pyx"
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_opening, Py_True, __pyx_t_4, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 322, __pyx_L1_error)

#line 322 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);

#line 322 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 322 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 322 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 322, __pyx_L1_error)

#line 322 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 322 "cysystemd/reader.pyx"
    }

#line 322 "cysystemd/reader.pyx"
    __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 322, __pyx_L1_error)

#line 322 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_5);

#line 322 "cysystemd/reader.pyx"
    __pyx_t_2 = NULL;

#line 322 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 322, __pyx_L3_error)

#line 322 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 322 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 322 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 322 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 322 "cysystemd/reader.pyx"
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 322 "cysystemd/reader.pyx"
      assert(__pyx_t_2);

#line 322 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 322 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_2);

#line 322 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 322 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 322 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 322 "cysystemd/reader.pyx"
    }

#line 322 "cysystemd/reader.pyx"
    #endif

#line 322 "cysystemd/reader.pyx"
    {

#line 322 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 322 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 322 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 322 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 322 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 322, __pyx_L3_error)

#line 322 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 322 "cysystemd/reader.pyx"
    }

#line 322 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 322 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 322 "cysystemd/reader.pyx"
    /*try:*/ {

#line 322 "cysystemd/reader.pyx"
      {

#line 322 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_declare

#line 322 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_assign

#line 322 "cysystemd/reader.pyx"
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_7);

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_8);

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_9);

#line 322 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":323
 * 
 *         with self._lock(opening=True):
 *             cstr = path.encode()             # <<<<<<<<<<<<<<
 *             check_error_code(sd_journal_open_directory(&self.context, cstr, 0))
 * 
*/

#line 323 "cysystemd/reader.pyx"
          __pyx_t_4 = __pyx_v_path;

#line 323 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx_t_4);

#line 323 "cysystemd/reader.pyx"
          __pyx_t_3 = 0;

#line 323 "cysystemd/reader.pyx"
          {

#line 323 "cysystemd/reader.pyx"
            PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};

#line 323 "cysystemd/reader.pyx"
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 323 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 323 "cysystemd/reader.pyx"
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 323, __pyx_L7_error)

#line 323 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_1);

#line 323 "cysystemd/reader.pyx"
          }

#line 323 "cysystemd/reader.pyx"
          __pyx_v_cstr = __pyx_t_1;

#line 323 "cysystemd/reader.pyx"
          __pyx_t_1 = 0;

          /* "cysystemd/reader.pyx":324
 *         with self._lock(opening=True):
 *             cstr = path.encode()
 *             check_error_code(sd_journal_open_directory(&self.context, cstr, 0))             # <<<<<<<<<<<<<<
 * 
 *     def open_files(self, *file_names: Union[str, Path]) -> None:
*/

#line 324 "cysystemd/reader.pyx"
          __pyx_t_4 = NULL;

#line 324 "cysystemd/reader.pyx"
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 324, __pyx_L7_error)

#line 324 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_6);

#line 324 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyObject_AsString(__pyx_v_cstr); if (unlikely((!__pyx_t_10) && PyErr_Occurred())) __PYX_ERR(0, 324, __pyx_L7_error)

#line 324 "cysystemd/reader.pyx"
          __pyx_t_2 = __Pyx_PyLong_From_int(sd_journal_open_directory((&__pyx_v_self->context), __pyx_t_10, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L7_error)

#line 324 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 324 "cysystemd/reader.pyx"
          __pyx_t_3 = 1;

#line 324 "cysystemd/reader.pyx"
          #if CYTHON_UNPACK_METHODS

#line 324 "cysystemd/reader.pyx"
          if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 324 "cysystemd/reader.pyx"
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);

#line 324 "cysystemd/reader.pyx"
            assert(__pyx_t_4);

#line 324 "cysystemd/reader.pyx"
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 324 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx_t_4);

#line 324 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx__function);

#line 324 "cysystemd/reader.pyx"
            __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 324 "cysystemd/reader.pyx"
            __pyx_t_3 = 0;

#line 324 "cysystemd/reader.pyx"
          }

#line 324 "cysystemd/reader.pyx"
          #endif

#line 324 "cysystemd/reader.pyx"
          {

#line 324 "cysystemd/reader.pyx"
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};

#line 324 "cysystemd/reader.pyx"
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 324 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 324 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 324 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 324 "cysystemd/reader.pyx"
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L7_error)

#line 324 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_1);

#line 324 "cysystemd/reader.pyx"
          }

#line 324 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cysystemd/reader.pyx":322
 *         path = _check_dir_path(path)
 * 
 *         with self._lock(opening=True):             # <<<<<<<<<<<<<<
 *             cstr = path.encode()
 *             check_error_code(sd_journal_open_directory(&self.context, cstr, 0))
*/

#line 322 "cysystemd/reader.pyx"
        }

#line 322 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 322 "cysystemd/reader.pyx"
        goto __pyx_L12_try_end;

#line 322 "cysystemd/reader.pyx"
        __pyx_L7_error:;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 322 "cysystemd/reader.pyx"
        /*except:*/ {

#line 322 "cysystemd/reader.pyx"
          __Pyx_AddTraceback("cysystemd.reader.JournalReader.open_directory", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 322 "cysystemd/reader.pyx"
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_2) < 0) __PYX_ERR(0, 322, __pyx_L9_except_error)

#line 322 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_1);

#line 322 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_6);

#line 322 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_2);

#line 322 "cysystemd/reader.pyx"
          __pyx_t_4 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 322, __pyx_L9_except_error)

#line 322 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_4);

#line 322 "cysystemd/reader.pyx"
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL);

#line 322 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 322 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 322 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 322, __pyx_L9_except_error)

#line 322 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_11);

#line 322 "cysystemd/reader.pyx"
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_11);

#line 322 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

#line 322 "cysystemd/reader.pyx"
          if (__pyx_t_12 < (0)) __PYX_ERR(0, 322, __pyx_L9_except_error)

#line 322 "cysystemd/reader.pyx"
          __pyx_t_13 = (!__pyx_t_12);

#line 322 "cysystemd/reader.pyx"
          if (unlikely(__pyx_t_13)) {

#line 322 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_1);

#line 322 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_6);

#line 322 "cysystemd/reader.pyx"
            __Pyx_XGIVEREF(__pyx_t_2);

#line 322 "cysystemd/reader.pyx"
            __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_6, __pyx_t_2);

#line 322 "cysystemd/reader.pyx"
            __pyx_t_1 = 0;  __pyx_t_6 = 0;  __pyx_t_2 = 0; 

#line 322 "cysystemd/reader.pyx"
            __PYX_ERR(0, 322, __pyx_L9_except_error)

#line 322 "cysystemd/reader.pyx"
          }

#line 322 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 322 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 322 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 322 "cysystemd/reader.pyx"
          goto __pyx_L8_exception_handled;

#line 322 "cysystemd/reader.pyx"
        }

#line 322 "cysystemd/reader.pyx"
        __pyx_L9_except_error:;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 322 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 322 "cysystemd/reader.pyx"
        goto __pyx_L1_error;

#line 322 "cysystemd/reader.pyx"
        __pyx_L8_exception_handled:;

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 322 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 322 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 322 "cysystemd/reader.pyx"
        __pyx_L12_try_end:;

#line 322 "cysystemd/reader.pyx"
      }

#line 322 "cysystemd/reader.pyx"
    }

#line 322 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 322 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 322 "cysystemd/reader.pyx"
        if (__pyx_t_5) {

#line 322 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 322 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 322 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 322, __pyx_L1_error)

#line 322 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 322 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 322 "cysystemd/reader.pyx"
        }

#line 322 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 322 "cysystemd/reader.pyx"
      }

#line 322 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 322 "cysystemd/reader.pyx"
    }

#line 322 "cysystemd/reader.pyx"
    goto __pyx_L16;

#line 322 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 322 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 322 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 322 "cysystemd/reader.pyx"
    __pyx_L16:;

#line 322 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":319
 *             return check_error_code(sd_journal_open(&self.context, self.flags.value))
 * 
 *     def open_directory(self, path) -> None:             # <<<<<<<<<<<<<<
 *         path = _check_dir_path(path)
 * 
*/

#line 319 "cysystemd/reader.pyx"


#line 319 "cysystemd/reader.pyx"
  /* function exit code */

#line 319 "cysystemd/reader.pyx"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 319 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 319 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 319 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 319 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 319 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 319 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 319 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.open_directory", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 319 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 319 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 319 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_cstr);

#line 319 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_path);

#line 319 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 319 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 319 "cysystemd/reader.pyx"
  return __pyx_r;

#line 319 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":326
 *             check_error_code(sd_journal_open_directory(&self.context, cstr, 0))
 * 
 *     def open_files(self, *file_names: Union[str, Path]) -> None:             # <<<<<<<<<<<<<<
 *         file_names = tuple(map(_check_file_path, file_names))
 * 
*/

#line 326 "cysystemd/reader.pyx"


#line 326 "cysystemd/reader.pyx"
/* Python wrapper */

#line 326 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_7open_files(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_7open_files = 
#line 326 "cysystemd/reader.pyx"
{"open_files", (PyCFunction)(void(*)(void))(PyCFunctionWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_7open_files, METH_VARARGS|METH_KEYWORDS, 0};

#line 326 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_7open_files(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_file_names = 0
#line 326 "cysystemd/reader.pyx"
;

#line 326 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 326 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 326 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 326 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("open_files (wrapper)", 0);

#line 326 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 326 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 326 "cysystemd/reader.pyx"
  #else

#line 326 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 326 "cysystemd/reader.pyx"
  #endif

#line 326 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 326 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;

#line 326 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 326 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("open_files", __pyx_kwds); return NULL;}

#line 326 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_args);

#line 326 "cysystemd/reader.pyx"
  __pyx_v_file_names = __pyx_args;
  __pyx_r = 
#line 326 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_6open_files(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_file_names);

#line 326 "cysystemd/reader.pyx"


#line 326 "cysystemd/reader.pyx"
  /* function exit code */

#line 326 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_v_file_names);

#line 326 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 326 "cysystemd/reader.pyx"
  return __pyx_r;

#line 326 "cysystemd/reader.pyx"
}

#line 326 "cysystemd/reader.pyx"


#line 326 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6open_files(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_file_names) {
  size_t __pyx_v_n
#line 326 "cysystemd/reader.pyx"
;
  char const **__pyx_v_paths
#line 326 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_i = NULL
#line 326 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_s = NULL
#line 326 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_cstr = NULL
#line 326 "cysystemd/reader.pyx"
;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 326 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 326 "cysystemd/reader.pyx"
  size_t __pyx_t_4;

#line 326 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_5;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 326 "cysystemd/reader.pyx"
  char const *__pyx_t_7;

#line 326 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_8;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_10 = NULL;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_12 = NULL;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_13 = NULL;

#line 326 "cysystemd/reader.pyx"
  int __pyx_t_14;

#line 326 "cysystemd/reader.pyx"
  int __pyx_t_15;

#line 326 "cysystemd/reader.pyx"
  int __pyx_t_16;

#line 326 "cysystemd/reader.pyx"
  int __pyx_t_17;

#line 326 "cysystemd/reader.pyx"
  char const *__pyx_t_18;

#line 326 "cysystemd/reader.pyx"
  PyObject *__pyx_t_19 = NULL;

#line 326 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 326 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 326 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 326 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("open_files", 0);

#line 326 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_file_names);

  /* "cysystemd/reader.pyx":327
 * 
 *     def open_files(self, *file_names: Union[str, Path]) -> None:
 *         file_names = tuple(map(_check_file_path, file_names))             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t n = len(file_names)
*/

#line 327 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 327 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(__pyx_f_9cysystemd_6reader__check_file_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)

#line 327 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 327 "cysystemd/reader.pyx"
  __pyx_t_4 = 1;

#line 327 "cysystemd/reader.pyx"
  {

#line 327 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_3, __pyx_v_file_names};

#line 327 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_map, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 327 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 327 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 327 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)

#line 327 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 327 "cysystemd/reader.pyx"
  }

#line 327 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)

#line 327 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 327 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 327 "cysystemd/reader.pyx"
  __Pyx_DECREF_SET(__pyx_v_file_names, ((PyObject*)__pyx_t_3));

#line 327 "cysystemd/reader.pyx"
  __pyx_t_3 = 0;

  /* "cysystemd/reader.pyx":329
 *         file_names = tuple(map(_check_file_path, file_names))
 * 
 *         cdef size_t n = len(file_names)             # <<<<<<<<<<<<<<
 *         cdef const char **paths = <const char **>PyMem_Malloc((n + 1) * sizeof(char*))
 * 
*/

#line 329 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(__pyx_v_file_names); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 329, __pyx_L1_error)

#line 329 "cysystemd/reader.pyx"
  __pyx_v_n = __pyx_t_5;

  /* "cysystemd/reader.pyx":330
 * 
 *         cdef size_t n = len(file_names)
 *         cdef const char **paths = <const char **>PyMem_Malloc((n + 1) * sizeof(char*))             # <<<<<<<<<<<<<<
 * 
 *         for i, s in enumerate(file_names):
*/

#line 330 "cysystemd/reader.pyx"
  __pyx_v_paths = ((char const **)PyMem_Malloc(((__pyx_v_n + 1) * (sizeof(char *)))));

  /* "cysystemd/reader.pyx":332
 *         cdef const char **paths = <const char **>PyMem_Malloc((n + 1) * sizeof(char*))
 * 
 *         for i, s in enumerate(file_names):             # <<<<<<<<<<<<<<
 *             cstr = s.encode()
 *             paths[i] = cstr
*/

#line 332 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);

#line 332 "cysystemd/reader.pyx"
  __pyx_t_3 = __pyx_mstate_global->__pyx_int_0;

#line 332 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_v_file_names; __Pyx_INCREF(__pyx_t_1);

#line 332 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;
  for (;;
#line 332 "cysystemd/reader.pyx"
) {

#line 332 "cysystemd/reader.pyx"
    {

#line 332 "cysystemd/reader.pyx"
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);

#line 332 "cysystemd/reader.pyx"
      #if !CYTHON_ASSUME_SAFE_SIZE

#line 332 "cysystemd/reader.pyx"
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 332, __pyx_L1_error)

#line 332 "cysystemd/reader.pyx"
      #endif

#line 332 "cysystemd/reader.pyx"
      if (__pyx_t_5 >= __pyx_temp) break;

#line 332 "cysystemd/reader.pyx"
    }

#line 332 "cysystemd/reader.pyx"
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS

#line 332 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5));

#line 332 "cysystemd/reader.pyx"
    #else

#line 332 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5);

#line 332 "cysystemd/reader.pyx"
    #endif

#line 332 "cysystemd/reader.pyx"
    ++__pyx_t_5;

#line 332 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 332, __pyx_L1_error)

#line 332 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 332 "cysystemd/reader.pyx"
    __Pyx_XDECREF_SET(__pyx_v_s, __pyx_t_2);

#line 332 "cysystemd/reader.pyx"
    __pyx_t_2 = 0;

#line 332 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 332 "cysystemd/reader.pyx"
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);

#line 332 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyLong_AddObjC(__pyx_t_3, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 332, __pyx_L1_error)

#line 332 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 332 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3);

#line 332 "cysystemd/reader.pyx"
    __pyx_t_3 = __pyx_t_2;

#line 332 "cysystemd/reader.pyx"
    __pyx_t_2 = 0;

    /* "cysystemd/reader.pyx":333
 * 
 *         for i, s in enumerate(file_names):
 *             cstr = s.encode()             # <<<<<<<<<<<<<<
 *             paths[i] = cstr
 *         paths[n] = <char *>0
*/

#line 333 "cysystemd/reader.pyx"
    __pyx_t_6 = __pyx_v_s;

#line 333 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_6);

#line 333 "cysystemd/reader.pyx"
    __pyx_t_4 = 0;

#line 333 "cysystemd/reader.pyx"
    {

#line 333 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};

#line 333 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 333 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 333 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 333, __pyx_L1_error)

#line 333 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 333 "cysystemd/reader.pyx"
    }

#line 333 "cysystemd/reader.pyx"
    __Pyx_XDECREF_SET(__pyx_v_cstr, __pyx_t_2);

#line 333 "cysystemd/reader.pyx"
    __pyx_t_2 = 0;

    /* "cysystemd/reader.pyx":334
 *         for i, s in enumerate(file_names):
 *             cstr = s.encode()
 *             paths[i] = cstr             # <<<<<<<<<<<<<<
 *         paths[n] = <char *>0
 * 
*/

#line 334 "cysystemd/reader.pyx"
    __pyx_t_7 = __Pyx_PyObject_AsString(__pyx_v_cstr); if (unlikely((!__pyx_t_7) && PyErr_Occurred())) __PYX_ERR(0, 334, __pyx_L1_error)

#line 334 "cysystemd/reader.pyx"
    __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 334, __pyx_L1_error)

#line 334 "cysystemd/reader.pyx"
    (__pyx_v_paths[__pyx_t_8]) = __pyx_t_7;

    /* "cysystemd/reader.pyx":332
 *         cdef const char **paths = <const char **>PyMem_Malloc((n + 1) * sizeof(char*))
 * 
 *         for i, s in enumerate(file_names):             # <<<<<<<<<<<<<<
 *             cstr = s.encode()
 *             paths[i] = cstr
*/

#line 332 "cysystemd/reader.pyx"
  }

#line 332 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 332 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysystemd/reader.pyx":335
 *             cstr = s.encode()
 *             paths[i] = cstr
 *         paths[n] = <char *>0             # <<<<<<<<<<<<<<
 * 
 *         try:
*/

#line 335 "cysystemd/reader.pyx"
  (__pyx_v_paths[__pyx_v_n]) = ((char *)0);

  /* "cysystemd/reader.pyx":337
 *         paths[n] = <char *>0
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             with self._lock(opening=True):
 *                 check_error_code(sd_journal_open_files(&self.context, paths, 0))
*/

#line 337 "cysystemd/reader.pyx"
  /*try:*/ {

    /* "cysystemd/reader.pyx":338
 * 
 *         try:
 *             with self._lock(opening=True):             # <<<<<<<<<<<<<<
 *                 check_error_code(sd_journal_open_files(&self.context, paths, 0))
 *         finally:
*/

#line 338 "cysystemd/reader.pyx"
    /*with:*/ {

#line 338 "cysystemd/reader.pyx"
      __pyx_t_1 = ((PyObject *)__pyx_v_self);

#line 338 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_1);

#line 338 "cysystemd/reader.pyx"
      __pyx_t_4 = 0;

#line 338 "cysystemd/reader.pyx"
      {

#line 338 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, NULL};

#line 338 "cysystemd/reader.pyx"
        __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 338, __pyx_L7_error)

#line 338 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_2);

#line 338 "cysystemd/reader.pyx"
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_opening, Py_True, __pyx_t_2, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 338, __pyx_L7_error)

#line 338 "cysystemd/reader.pyx"
        __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);

#line 338 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 338 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 338 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 338, __pyx_L7_error)

#line 338 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_3);

#line 338 "cysystemd/reader.pyx"
      }

#line 338 "cysystemd/reader.pyx"
      __pyx_t_9 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 338, __pyx_L7_error)

#line 338 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_9);

#line 338 "cysystemd/reader.pyx"
      __pyx_t_1 = NULL;

#line 338 "cysystemd/reader.pyx"
      __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 338, __pyx_L9_error)

#line 338 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_6);

#line 338 "cysystemd/reader.pyx"
      __pyx_t_4 = 1;

#line 338 "cysystemd/reader.pyx"
      #if CYTHON_UNPACK_METHODS

#line 338 "cysystemd/reader.pyx"
      if (likely(PyMethod_Check(__pyx_t_6))) {

#line 338 "cysystemd/reader.pyx"
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);

#line 338 "cysystemd/reader.pyx"
        assert(__pyx_t_1);

#line 338 "cysystemd/reader.pyx"
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 338 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_1);

#line 338 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx__function);

#line 338 "cysystemd/reader.pyx"
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 338 "cysystemd/reader.pyx"
        __pyx_t_4 = 0;

#line 338 "cysystemd/reader.pyx"
      }

#line 338 "cysystemd/reader.pyx"
      #endif

#line 338 "cysystemd/reader.pyx"
      {

#line 338 "cysystemd/reader.pyx"
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};

#line 338 "cysystemd/reader.pyx"
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 338 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 338 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 338 "cysystemd/reader.pyx"
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 338, __pyx_L9_error)

#line 338 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_2);

#line 338 "cysystemd/reader.pyx"
      }

#line 338 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 338 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 338 "cysystemd/reader.pyx"
      /*try:*/ {

#line 338 "cysystemd/reader.pyx"
        {

#line 338 "cysystemd/reader.pyx"
          __Pyx_PyThreadState_declare

#line 338 "cysystemd/reader.pyx"
          __Pyx_PyThreadState_assign

#line 338 "cysystemd/reader.pyx"
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_10);

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_11);

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_12);

#line 338 "cysystemd/reader.pyx"
          /*try:*/ {

            /* "cysystemd/reader.pyx":339
 *         try:
 *             with self._lock(opening=True):
 *                 check_error_code(sd_journal_open_files(&self.context, paths, 0))             # <<<<<<<<<<<<<<
 *         finally:
 *             PyMem_Free(paths)
*/

#line 339 "cysystemd/reader.pyx"
            __pyx_t_2 = NULL;

#line 339 "cysystemd/reader.pyx"
            __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 339, __pyx_L13_error)

#line 339 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_6);

#line 339 "cysystemd/reader.pyx"
            __pyx_t_1 = __Pyx_PyLong_From_int(sd_journal_open_files((&__pyx_v_self->context), __pyx_v_paths, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 339, __pyx_L13_error)

#line 339 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_1);

#line 339 "cysystemd/reader.pyx"
            __pyx_t_4 = 1;

#line 339 "cysystemd/reader.pyx"
            #if CYTHON_UNPACK_METHODS

#line 339 "cysystemd/reader.pyx"
            if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 339 "cysystemd/reader.pyx"
              __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 339 "cysystemd/reader.pyx"
              assert(__pyx_t_2);

#line 339 "cysystemd/reader.pyx"
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 339 "cysystemd/reader.pyx"
              __Pyx_INCREF(__pyx_t_2);

#line 339 "cysystemd/reader.pyx"
              __Pyx_INCREF(__pyx__function);

#line 339 "cysystemd/reader.pyx"
              __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 339 "cysystemd/reader.pyx"
              __pyx_t_4 = 0;

#line 339 "cysystemd/reader.pyx"
            }

#line 339 "cysystemd/reader.pyx"
            #endif

#line 339 "cysystemd/reader.pyx"
            {

#line 339 "cysystemd/reader.pyx"
              PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};

#line 339 "cysystemd/reader.pyx"
              __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 339 "cysystemd/reader.pyx"
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 339 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 339 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 339 "cysystemd/reader.pyx"
              if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 339, __pyx_L13_error)

#line 339 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_3);

#line 339 "cysystemd/reader.pyx"
            }

#line 339 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "cysystemd/reader.pyx":338
 * 
 *         try:
 *             with self._lock(opening=True):             # <<<<<<<<<<<<<<
 *                 check_error_code(sd_journal_open_files(&self.context, paths, 0))
 *         finally:
*/

#line 338 "cysystemd/reader.pyx"
          }

#line 338 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 338 "cysystemd/reader.pyx"
          goto __pyx_L18_try_end;

#line 338 "cysystemd/reader.pyx"
          __pyx_L13_error:;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 338 "cysystemd/reader.pyx"
          /*except:*/ {

#line 338 "cysystemd/reader.pyx"
            __Pyx_AddTraceback("cysystemd.reader.JournalReader.open_files", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 338 "cysystemd/reader.pyx"
            if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_6, &__pyx_t_1) < 0) __PYX_ERR(0, 338, __pyx_L15_except_error)

#line 338 "cysystemd/reader.pyx"
            __Pyx_XGOTREF(__pyx_t_3);

#line 338 "cysystemd/reader.pyx"
            __Pyx_XGOTREF(__pyx_t_6);

#line 338 "cysystemd/reader.pyx"
            __Pyx_XGOTREF(__pyx_t_1);

#line 338 "cysystemd/reader.pyx"
            __pyx_t_2 = PyTuple_Pack(3, __pyx_t_3, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 338, __pyx_L15_except_error)

#line 338 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_2);

#line 338 "cysystemd/reader.pyx"
            __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_2, NULL);

#line 338 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 338 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 338 "cysystemd/reader.pyx"
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 338, __pyx_L15_except_error)

#line 338 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_13);

#line 338 "cysystemd/reader.pyx"
            __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_13);

#line 338 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

#line 338 "cysystemd/reader.pyx"
            if (__pyx_t_14 < (0)) __PYX_ERR(0, 338, __pyx_L15_except_error)

#line 338 "cysystemd/reader.pyx"
            __pyx_t_15 = (!__pyx_t_14);

#line 338 "cysystemd/reader.pyx"
            if (unlikely(__pyx_t_15)) {

#line 338 "cysystemd/reader.pyx"
              __Pyx_GIVEREF(__pyx_t_3);

#line 338 "cysystemd/reader.pyx"
              __Pyx_GIVEREF(__pyx_t_6);

#line 338 "cysystemd/reader.pyx"
              __Pyx_XGIVEREF(__pyx_t_1);

#line 338 "cysystemd/reader.pyx"
              __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_6, __pyx_t_1);

#line 338 "cysystemd/reader.pyx"
              __pyx_t_3 = 0;  __pyx_t_6 = 0;  __pyx_t_1 = 0; 

#line 338 "cysystemd/reader.pyx"
              __PYX_ERR(0, 338, __pyx_L15_except_error)

#line 338 "cysystemd/reader.pyx"
            }

#line 338 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 338 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 338 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 338 "cysystemd/reader.pyx"
            goto __pyx_L14_exception_handled;

#line 338 "cysystemd/reader.pyx"
          }

#line 338 "cysystemd/reader.pyx"
          __pyx_L15_except_error:;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGIVEREF(__pyx_t_10);

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGIVEREF(__pyx_t_11);

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGIVEREF(__pyx_t_12);

#line 338 "cysystemd/reader.pyx"
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);

#line 338 "cysystemd/reader.pyx"
          goto __pyx_L7_error;

#line 338 "cysystemd/reader.pyx"
          __pyx_L14_exception_handled:;

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGIVEREF(__pyx_t_10);

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGIVEREF(__pyx_t_11);

#line 338 "cysystemd/reader.pyx"
          __Pyx_XGIVEREF(__pyx_t_12);

#line 338 "cysystemd/reader.pyx"
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);

#line 338 "cysystemd/reader.pyx"
          __pyx_L18_try_end:;

#line 338 "cysystemd/reader.pyx"
        }

#line 338 "cysystemd/reader.pyx"
      }

#line 338 "cysystemd/reader.pyx"
      /*finally:*/ {

#line 338 "cysystemd/reader.pyx"
        /*normal exit:*/{

#line 338 "cysystemd/reader.pyx"
          if (__pyx_t_9) {

#line 338 "cysystemd/reader.pyx"
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 338 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 338 "cysystemd/reader.pyx"
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 338, __pyx_L7_error)

#line 338 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_12);

#line 338 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 338 "cysystemd/reader.pyx"
          }

#line 338 "cysystemd/reader.pyx"
          goto __pyx_L12;

#line 338 "cysystemd/reader.pyx"
        }

#line 338 "cysystemd/reader.pyx"
        __pyx_L12:;

#line 338 "cysystemd/reader.pyx"
      }

#line 338 "cysystemd/reader.pyx"
      goto __pyx_L22;

#line 338 "cysystemd/reader.pyx"
      __pyx_L9_error:;

#line 338 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 338 "cysystemd/reader.pyx"
      goto __pyx_L7_error;

#line 338 "cysystemd/reader.pyx"
      __pyx_L22:;

#line 338 "cysystemd/reader.pyx"
    }

#line 338 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":341
 *                 check_error_code(sd_journal_open_files(&self.context, paths, 0))
 *         finally:
 *             PyMem_Free(paths)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 341 "cysystemd/reader.pyx"
  /*finally:*/ {

#line 341 "cysystemd/reader.pyx"
    /*normal exit:*/{

#line 341 "cysystemd/reader.pyx"
      PyMem_Free(__pyx_v_paths);

#line 341 "cysystemd/reader.pyx"
      goto __pyx_L8;

#line 341 "cysystemd/reader.pyx"
    }

#line 341 "cysystemd/reader.pyx"
    __pyx_L7_error:;

#line 341 "cysystemd/reader.pyx"
    /*exception exit:*/{

#line 341 "cysystemd/reader.pyx"
      __Pyx_PyThreadState_declare

#line 341 "cysystemd/reader.pyx"
      __Pyx_PyThreadState_assign

#line 341 "cysystemd/reader.pyx"
      __pyx_t_9 = 0; __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_13 = 0; __pyx_t_19 = 0;

#line 341 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 341 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 341 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 341 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 341 "cysystemd/reader.pyx"
       __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_13, &__pyx_t_19);

#line 341 "cysystemd/reader.pyx"
      if ( unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_12, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_12, &__pyx_t_11);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_9);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_12);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_11);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_10);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_13);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_19);

#line 341 "cysystemd/reader.pyx"
      __pyx_t_16 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;

#line 341 "cysystemd/reader.pyx"
      {

#line 341 "cysystemd/reader.pyx"
        PyMem_Free(__pyx_v_paths);

#line 341 "cysystemd/reader.pyx"
      }

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_10);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_13);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_19);

#line 341 "cysystemd/reader.pyx"
      __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_13, __pyx_t_19);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_9);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_12);

#line 341 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_11);

#line 341 "cysystemd/reader.pyx"
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_12, __pyx_t_11);

#line 341 "cysystemd/reader.pyx"
      __pyx_t_9 = 0; __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_13 = 0; __pyx_t_19 = 0;

#line 341 "cysystemd/reader.pyx"
      __pyx_lineno = __pyx_t_16; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;

#line 341 "cysystemd/reader.pyx"
      goto __pyx_L1_error;

#line 341 "cysystemd/reader.pyx"
    }

#line 341 "cysystemd/reader.pyx"
    __pyx_L8:;

#line 341 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":326
 *             check_error_code(sd_journal_open_directory(&self.context, cstr, 0))
 * 
 *     def open_files(self, *file_names: Union[str, Path]) -> None:             # <<<<<<<<<<<<<<
 *         file_names = tuple(map(_check_file_path, file_names))
 * 
*/

#line 326 "cysystemd/reader.pyx"


#line 326 "cysystemd/reader.pyx"
  /* function exit code */

#line 326 "cysystemd/reader.pyx"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 326 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 326 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 326 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.open_files", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 326 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 326 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_file_names);

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_i);

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_s);

#line 326 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_cstr);

#line 326 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 326 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 326 "cysystemd/reader.pyx"
  return __pyx_r;

#line 326 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":343
 *             PyMem_Free(paths)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def data_threshold(self) -> int:
 *         cdef size_t result
*/

#line 343 "cysystemd/reader.pyx"


#line 343 "cysystemd/reader.pyx"
/* Python wrapper */

#line 343 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_14data_threshold_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 343 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_14data_threshold_1__get__(PyObject *__pyx_v_self) {

#line 343 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 343 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 343 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 343 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 343 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 343 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_14data_threshold___get__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 343 "cysystemd/reader.pyx"


#line 343 "cysystemd/reader.pyx"
  /* function exit code */

#line 343 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 343 "cysystemd/reader.pyx"
  return __pyx_r;

#line 343 "cysystemd/reader.pyx"
}

#line 343 "cysystemd/reader.pyx"


#line 343 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_14data_threshold___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {
  size_t __pyx_v_result
#line 343 "cysystemd/reader.pyx"
;
  int __pyx_v_rcode
#line 343 "cysystemd/reader.pyx"
;

#line 343 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 343 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 343 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 343 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 343 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 343 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 343 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 343 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 343 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 343 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 343 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":348
 *         cdef int rcode
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rcode = sd_journal_get_data_threshold(self.context, &result)
 * 
*/

#line 348 "cysystemd/reader.pyx"
  {

#line 348 "cysystemd/reader.pyx"
      PyThreadState * _save;

#line 348 "cysystemd/reader.pyx"
      _save = PyEval_SaveThread();

#line 348 "cysystemd/reader.pyx"
      __Pyx_FastGIL_Remember();

#line 348 "cysystemd/reader.pyx"
      /*try:*/ {

        /* "cysystemd/reader.pyx":349
 * 
 *         with nogil:
 *             rcode = sd_journal_get_data_threshold(self.context, &result)             # <<<<<<<<<<<<<<
 * 
 *         check_error_code(rcode)
*/

#line 349 "cysystemd/reader.pyx"
        __pyx_v_rcode = sd_journal_get_data_threshold(__pyx_v_self->context, (&__pyx_v_result));

#line 349 "cysystemd/reader.pyx"
      }

      /* "cysystemd/reader.pyx":348
 *         cdef int rcode
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rcode = sd_journal_get_data_threshold(self.context, &result)
 * 
*/

#line 348 "cysystemd/reader.pyx"
      /*finally:*/ {

#line 348 "cysystemd/reader.pyx"
        /*normal exit:*/{

#line 348 "cysystemd/reader.pyx"
          __Pyx_FastGIL_Forget();

#line 348 "cysystemd/reader.pyx"
          PyEval_RestoreThread(_save);

#line 348 "cysystemd/reader.pyx"
          goto __pyx_L5;

#line 348 "cysystemd/reader.pyx"
        }

#line 348 "cysystemd/reader.pyx"
        __pyx_L5:;

#line 348 "cysystemd/reader.pyx"
      }

#line 348 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":351
 *             rcode = sd_journal_get_data_threshold(self.context, &result)
 * 
 *         check_error_code(rcode)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/

#line 351 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 351 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 351, __pyx_L1_error)

#line 351 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 351 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_int(__pyx_v_rcode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 351, __pyx_L1_error)

#line 351 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 351 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 351 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 351 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 351 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 351 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 351 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 351 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 351 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 351 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 351 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 351 "cysystemd/reader.pyx"
  }

#line 351 "cysystemd/reader.pyx"
  #endif

#line 351 "cysystemd/reader.pyx"
  {

#line 351 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 351 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 351 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 351 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 351 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 351 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 351, __pyx_L1_error)

#line 351 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 351 "cysystemd/reader.pyx"
  }

#line 351 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":352
 * 
 *         check_error_code(rcode)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @data_threshold.setter
*/

#line 352 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 352 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyLong_FromSize_t(__pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)

#line 352 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 352 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 352 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 352 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":343
 *             PyMem_Free(paths)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def data_threshold(self) -> int:
 *         cdef size_t result
*/

#line 343 "cysystemd/reader.pyx"


#line 343 "cysystemd/reader.pyx"
  /* function exit code */

#line 343 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 343 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 343 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 343 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 343 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 343 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.data_threshold.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 343 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 343 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 343 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 343 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 343 "cysystemd/reader.pyx"
  return __pyx_r;

#line 343 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":354
 *         return result
 * 
 *     @data_threshold.setter             # <<<<<<<<<<<<<<
 *     def data_threshold(self, size) -> None:
 *         cdef size_t sz = size
*/

#line 354 "cysystemd/reader.pyx"


#line 354 "cysystemd/reader.pyx"
/* Python wrapper */

#line 354 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_13JournalReader_14data_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_size); /*proto*/

#line 354 "cysystemd/reader.pyx"
static int __pyx_pw_9cysystemd_6reader_13JournalReader_14data_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_size) {

#line 354 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 354 "cysystemd/reader.pyx"
  int __pyx_r;

#line 354 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 354 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);

#line 354 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 354 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_14data_threshold_2__set__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), ((PyObject *)__pyx_v_size));

#line 354 "cysystemd/reader.pyx"


#line 354 "cysystemd/reader.pyx"
  /* function exit code */

#line 354 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 354 "cysystemd/reader.pyx"
  return __pyx_r;

#line 354 "cysystemd/reader.pyx"
}

#line 354 "cysystemd/reader.pyx"


#line 354 "cysystemd/reader.pyx"
static int __pyx_pf_9cysystemd_6reader_13JournalReader_14data_threshold_2__set__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_size) {
  size_t __pyx_v_sz
#line 354 "cysystemd/reader.pyx"
;
  int __pyx_v_result
#line 354 "cysystemd/reader.pyx"
;

#line 354 "cysystemd/reader.pyx"
  int __pyx_r;

#line 354 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 354 "cysystemd/reader.pyx"
  size_t __pyx_t_1;

#line 354 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 354 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 354 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 354 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 354 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 354 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 354 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 354 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "cysystemd/reader.pyx":356
 *     @data_threshold.setter
 *     def data_threshold(self, size) -> None:
 *         cdef size_t sz = size             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 356 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyLong_As_size_t(__pyx_v_size); if (unlikely((__pyx_t_1 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 356, __pyx_L1_error)

#line 356 "cysystemd/reader.pyx"
  __pyx_v_sz = __pyx_t_1;

  /* "cysystemd/reader.pyx":359
 *         cdef int result
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = sd_journal_set_data_threshold(self.context, sz)
 * 
*/

#line 359 "cysystemd/reader.pyx"
  {

#line 359 "cysystemd/reader.pyx"
      PyThreadState * _save;

#line 359 "cysystemd/reader.pyx"
      _save = PyEval_SaveThread();

#line 359 "cysystemd/reader.pyx"
      __Pyx_FastGIL_Remember();

#line 359 "cysystemd/reader.pyx"
      /*try:*/ {

        /* "cysystemd/reader.pyx":360
 * 
 *         with nogil:
 *             result = sd_journal_set_data_threshold(self.context, sz)             # <<<<<<<<<<<<<<
 * 
 *         check_error_code(result)
*/

#line 360 "cysystemd/reader.pyx"
        __pyx_v_result = sd_journal_set_data_threshold(__pyx_v_self->context, __pyx_v_sz);

#line 360 "cysystemd/reader.pyx"
      }

      /* "cysystemd/reader.pyx":359
 *         cdef int result
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = sd_journal_set_data_threshold(self.context, sz)
 * 
*/

#line 359 "cysystemd/reader.pyx"
      /*finally:*/ {

#line 359 "cysystemd/reader.pyx"
        /*normal exit:*/{

#line 359 "cysystemd/reader.pyx"
          __Pyx_FastGIL_Forget();

#line 359 "cysystemd/reader.pyx"
          PyEval_RestoreThread(_save);

#line 359 "cysystemd/reader.pyx"
          goto __pyx_L5;

#line 359 "cysystemd/reader.pyx"
        }

#line 359 "cysystemd/reader.pyx"
        __pyx_L5:;

#line 359 "cysystemd/reader.pyx"
      }

#line 359 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":362
 *             result = sd_journal_set_data_threshold(self.context, sz)
 * 
 *         check_error_code(result)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 362 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 362 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 362, __pyx_L1_error)

#line 362 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 362 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 362, __pyx_L1_error)

#line 362 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 362 "cysystemd/reader.pyx"
  __pyx_t_1 = 1;

#line 362 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 362 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 362 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 362 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 362 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 362 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 362 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 362 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 362 "cysystemd/reader.pyx"
    __pyx_t_1 = 0;

#line 362 "cysystemd/reader.pyx"
  }

#line 362 "cysystemd/reader.pyx"
  #endif

#line 362 "cysystemd/reader.pyx"
  {

#line 362 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};

#line 362 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_1, (2-__pyx_t_1) | (__pyx_t_1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 362 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 362 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 362 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 362 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 362, __pyx_L1_error)

#line 362 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 362 "cysystemd/reader.pyx"
  }

#line 362 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":354
 *         return result
 * 
 *     @data_threshold.setter             # <<<<<<<<<<<<<<
 *     def data_threshold(self, size) -> None:
 *         cdef size_t sz = size
*/

#line 354 "cysystemd/reader.pyx"


#line 354 "cysystemd/reader.pyx"
  /* function exit code */

#line 354 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 354 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 354 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 354 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 354 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 354 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 354 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 354 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.data_threshold.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 354 "cysystemd/reader.pyx"
  __pyx_r = -1;

#line 354 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 354 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 354 "cysystemd/reader.pyx"
  return __pyx_r;

#line 354 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":364
 *         check_error_code(result)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def closed(self) -> bool:
 *         return self.state == READER_CLOSED
*/

#line 364 "cysystemd/reader.pyx"


#line 364 "cysystemd/reader.pyx"
/* Python wrapper */

#line 364 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_6closed_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 364 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_6closed_1__get__(PyObject *__pyx_v_self) {

#line 364 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 364 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 364 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 364 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 364 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 364 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_6closed___get__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 364 "cysystemd/reader.pyx"


#line 364 "cysystemd/reader.pyx"
  /* function exit code */

#line 364 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 364 "cysystemd/reader.pyx"
  return __pyx_r;

#line 364 "cysystemd/reader.pyx"
}

#line 364 "cysystemd/reader.pyx"


#line 364 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6closed___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 364 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 364 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 364 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 364 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 364 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 364 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 364 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":366
 *     @property
 *     def closed(self) -> bool:
 *         return self.state == READER_CLOSED             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 366 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 366 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->state == __pyx_e_9cysystemd_6reader_READER_CLOSED)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 366, __pyx_L1_error)

#line 366 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 366 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 366 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 366 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":364
 *         check_error_code(result)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def closed(self) -> bool:
 *         return self.state == READER_CLOSED
*/

#line 364 "cysystemd/reader.pyx"


#line 364 "cysystemd/reader.pyx"
  /* function exit code */

#line 364 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 364 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 364 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.closed.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 364 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 364 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 364 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 364 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 364 "cysystemd/reader.pyx"
  return __pyx_r;

#line 364 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":368
 *         return self.state == READER_CLOSED
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def locked(self) -> bool:
 *         return self.state == READER_LOCKED
*/

#line 368 "cysystemd/reader.pyx"


#line 368 "cysystemd/reader.pyx"
/* Python wrapper */

#line 368 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_6locked_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 368 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_6locked_1__get__(PyObject *__pyx_v_self) {

#line 368 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 368 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 368 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 368 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 368 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 368 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_6locked___get__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 368 "cysystemd/reader.pyx"


#line 368 "cysystemd/reader.pyx"
  /* function exit code */

#line 368 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 368 "cysystemd/reader.pyx"
  return __pyx_r;

#line 368 "cysystemd/reader.pyx"
}

#line 368 "cysystemd/reader.pyx"


#line 368 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6locked___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 368 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 368 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 368 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 368 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 368 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 368 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 368 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":370
 *     @property
 *     def locked(self) -> bool:
 *         return self.state == READER_LOCKED             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 370 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 370 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->state == __pyx_e_9cysystemd_6reader_READER_LOCKED)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)

#line 370 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 370 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 370 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 370 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":368
 *         return self.state == READER_CLOSED
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def locked(self) -> bool:
 *         return self.state == READER_LOCKED
*/

#line 368 "cysystemd/reader.pyx"


#line 368 "cysystemd/reader.pyx"
  /* function exit code */

#line 368 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 368 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 368 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.locked.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 368 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 368 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 368 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 368 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 368 "cysystemd/reader.pyx"
  return __pyx_r;

#line 368 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":372
 *         return self.state == READER_LOCKED
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def idle(self) -> bool:
 *         return self.state == READER_OPENED
*/

#line 372 "cysystemd/reader.pyx"


#line 372 "cysystemd/reader.pyx"
/* Python wrapper */

#line 372 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_4idle_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 372 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_4idle_1__get__(PyObject *__pyx_v_self) {

#line 372 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 372 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 372 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 372 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 372 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 372 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_4idle___get__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 372 "cysystemd/reader.pyx"


#line 372 "cysystemd/reader.pyx"
  /* function exit code */

#line 372 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 372 "cysystemd/reader.pyx"
  return __pyx_r;

#line 372 "cysystemd/reader.pyx"
}

#line 372 "cysystemd/reader.pyx"


#line 372 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_4idle___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 372 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 372 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 372 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 372 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 372 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 372 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 372 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":374
 *     @property
 *     def idle(self) -> bool:
 *         return self.state == READER_OPENED             # <<<<<<<<<<<<<<
 * 
 *     @contextmanager
*/

#line 374 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 374 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->state == __pyx_e_9cysystemd_6reader_READER_OPENED)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)

#line 374 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 374 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 374 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 374 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":372
 *         return self.state == READER_LOCKED
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def idle(self) -> bool:
 *         return self.state == READER_OPENED
*/

#line 372 "cysystemd/reader.pyx"


#line 372 "cysystemd/reader.pyx"
  /* function exit code */

#line 372 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 372 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 372 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.idle.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 372 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 372 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 372 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 372 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 372 "cysystemd/reader.pyx"
  return __pyx_r;

#line 372 "cysystemd/reader.pyx"
}

#line 372 "cysystemd/reader.pyx"
static PyObject *__pyx_gb_9cysystemd_6reader_13JournalReader_10generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cysystemd/reader.pyx":376
 *         return self.state == READER_OPENED
 * 
 *     @contextmanager             # <<<<<<<<<<<<<<
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:
*/

#line 376 "cysystemd/reader.pyx"


#line 376 "cysystemd/reader.pyx"
/* Python wrapper */

#line 376 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_9_lock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_9_lock = 
#line 376 "cysystemd/reader.pyx"
{"_lock", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_9_lock, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 376 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_9_lock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_opening = 0
#line 376 "cysystemd/reader.pyx"
;

#line 376 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 376 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 376 "cysystemd/reader.pyx"
  #endif

#line 376 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 376 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 376 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 376 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 376 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("_lock (wrapper)", 0);

#line 376 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 376 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 376 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 376 "cysystemd/reader.pyx"
  #else

#line 376 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 376 "cysystemd/reader.pyx"
  #endif

#line 376 "cysystemd/reader.pyx"
  #endif

#line 376 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 376 "cysystemd/reader.pyx"
  {

#line 376 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_opening,0};

#line 376 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 376 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 376, __pyx_L3_error)

#line 376 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 376 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 376 "cysystemd/reader.pyx"
        case  1:

#line 376 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 376 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 376, __pyx_L3_error)

#line 376 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 376 "cysystemd/reader.pyx"
break;
        default: 
#line 376 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 376 "cysystemd/reader.pyx"
      }

#line 376 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 376 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_lock", 0) < (0)) __PYX_ERR(0, 376, __pyx_L3_error)

      /* "cysystemd/reader.pyx":377
 * 
 *     @contextmanager
 *     def _lock(self, opening=False) -> None:             # <<<<<<<<<<<<<<
 *         if self.closed:
 *             raise RuntimeError("Can't lock closed reader")
*/

#line 377 "cysystemd/reader.pyx"
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_False));

#line 377 "cysystemd/reader.pyx"
    } else {

#line 377 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 377 "cysystemd/reader.pyx"
        case  1:

#line 377 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 377 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 376, __pyx_L3_error)

#line 377 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 377 "cysystemd/reader.pyx"
break;
        default: 
#line 377 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 377 "cysystemd/reader.pyx"
      }

#line 377 "cysystemd/reader.pyx"
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_False));

#line 377 "cysystemd/reader.pyx"
    }

#line 377 "cysystemd/reader.pyx"
    __pyx_v_opening = values[0];

#line 377 "cysystemd/reader.pyx"
  }

#line 377 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 377 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 377 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("_lock", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 376, __pyx_L3_error)

#line 377 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 377 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 377 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 377 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 377 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 377 "cysystemd/reader.pyx"
  }

#line 377 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader._lock", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 377 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 377 "cysystemd/reader.pyx"
  return NULL;

#line 377 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 377 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_8_lock(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_opening);

  /* "cysystemd/reader.pyx":376
 *         return self.state == READER_OPENED
 * 
 *     @contextmanager             # <<<<<<<<<<<<<<
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:
*/

#line 376 "cysystemd/reader.pyx"


#line 376 "cysystemd/reader.pyx"
  /* function exit code */

#line 376 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 376 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 376 "cysystemd/reader.pyx"
  }

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 376 "cysystemd/reader.pyx"
  return __pyx_r;

#line 376 "cysystemd/reader.pyx"
}

#line 376 "cysystemd/reader.pyx"


#line 376 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_8_lock(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_opening) {
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *__pyx_cur_scope
#line 376 "cysystemd/reader.pyx"
;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 376 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 376 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 376 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("_lock", 0);

#line 376 "cysystemd/reader.pyx"
  __pyx_cur_scope = (struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *)__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct_1__lock(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock, __pyx_mstate_global->__pyx_empty_tuple, NULL);

#line 376 "cysystemd/reader.pyx"
  if (unlikely(!__pyx_cur_scope)) {

#line 376 "cysystemd/reader.pyx"
    __pyx_cur_scope = ((struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *)Py_None);

#line 376 "cysystemd/reader.pyx"
    __Pyx_INCREF(Py_None);

#line 376 "cysystemd/reader.pyx"
    __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  } else {

#line 376 "cysystemd/reader.pyx"
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);

#line 376 "cysystemd/reader.pyx"
  }

#line 376 "cysystemd/reader.pyx"
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;

#line 376 "cysystemd/reader.pyx"
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

#line 376 "cysystemd/reader.pyx"
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

#line 376 "cysystemd/reader.pyx"
  __pyx_cur_scope->__pyx_v_opening = __pyx_v_opening;

#line 376 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_opening);

#line 376 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_opening);

#line 376 "cysystemd/reader.pyx"
  {

#line 376 "cysystemd/reader.pyx"
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9cysystemd_6reader_13JournalReader_10generator1, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_lock, __pyx_mstate_global->__pyx_n_u_JournalReader__lock, __pyx_mstate_global->__pyx_n_u_cysystemd_reader); if (unlikely(!gen)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_cur_scope);

#line 376 "cysystemd/reader.pyx"
    __Pyx_RefNannyFinishContext();

#line 376 "cysystemd/reader.pyx"
    return (PyObject *) gen;

#line 376 "cysystemd/reader.pyx"
  }

#line 376 "cysystemd/reader.pyx"


#line 376 "cysystemd/reader.pyx"
  /* function exit code */

#line 376 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 376 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader._lock", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 376 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 376 "cysystemd/reader.pyx"
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);

#line 376 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 376 "cysystemd/reader.pyx"
  return __pyx_r;

#line 376 "cysystemd/reader.pyx"
}

#line 376 "cysystemd/reader.pyx"


#line 376 "cysystemd/reader.pyx"
static PyObject *__pyx_gb_9cysystemd_6reader_13JournalReader_10generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{

#line 376 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *__pyx_cur_scope = ((struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *)__pyx_generator->closure);

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 376 "cysystemd/reader.pyx"
  int __pyx_t_2;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 376 "cysystemd/reader.pyx"
  size_t __pyx_t_4;

#line 376 "cysystemd/reader.pyx"
  int __pyx_t_5;

#line 376 "cysystemd/reader.pyx"
  int __pyx_t_6;

#line 376 "cysystemd/reader.pyx"
  int __pyx_t_7;

#line 376 "cysystemd/reader.pyx"
  char const *__pyx_t_8;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_10 = NULL;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_12 = NULL;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_13 = NULL;

#line 376 "cysystemd/reader.pyx"
  PyObject *__pyx_t_14 = NULL;

#line 376 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 376 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 376 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("_lock", 0);

#line 376 "cysystemd/reader.pyx"
  switch (__pyx_generator->resume_label) {

#line 376 "cysystemd/reader.pyx"
    case 0: goto __pyx_L3_first_run;

#line 376 "cysystemd/reader.pyx"
    case 1: goto __pyx_L10_resume_from_yield;

#line 376 "cysystemd/reader.pyx"
    default: /* CPython raises the right error here */

#line 376 "cysystemd/reader.pyx"
    __Pyx_RefNannyFinishContext();

#line 376 "cysystemd/reader.pyx"
    return NULL;

#line 376 "cysystemd/reader.pyx"
  }

#line 376 "cysystemd/reader.pyx"
  __pyx_L3_first_run:;

#line 376 "cysystemd/reader.pyx"
  if (unlikely(__pyx_sent_value != Py_None)) {

#line 376 "cysystemd/reader.pyx"
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");

#line 376 "cysystemd/reader.pyx"
    __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":378
 *     @contextmanager
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Can't lock closed reader")
 *         elif self.locked:
*/

#line 378 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_mstate_global->__pyx_n_u_closed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)

#line 378 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 378 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 378, __pyx_L1_error)

#line 378 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 378 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_2)) {

    /* "cysystemd/reader.pyx":379
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:
 *             raise RuntimeError("Can't lock closed reader")             # <<<<<<<<<<<<<<
 *         elif self.locked:
 *             raise RuntimeError("Reader locked")
*/

#line 379 "cysystemd/reader.pyx"
    __pyx_t_3 = NULL;

#line 379 "cysystemd/reader.pyx"
    __pyx_t_4 = 1;

#line 379 "cysystemd/reader.pyx"
    {

#line 379 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Can_t_lock_closed_reader};

#line 379 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 379 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 379 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)

#line 379 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 379 "cysystemd/reader.pyx"
    }

#line 379 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 379 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 379 "cysystemd/reader.pyx"
    __PYX_ERR(0, 379, __pyx_L1_error)

    /* "cysystemd/reader.pyx":378
 *     @contextmanager
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Can't lock closed reader")
 *         elif self.locked:
*/

#line 378 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":380
 *         if self.closed:
 *             raise RuntimeError("Can't lock closed reader")
 *         elif self.locked:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Reader locked")
 *         elif opening and self.state != READER_NULL:
*/

#line 380 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_mstate_global->__pyx_n_u_locked); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 380, __pyx_L1_error)

#line 380 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 380 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 380, __pyx_L1_error)

#line 380 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 380 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_2)) {

    /* "cysystemd/reader.pyx":381
 *             raise RuntimeError("Can't lock closed reader")
 *         elif self.locked:
 *             raise RuntimeError("Reader locked")             # <<<<<<<<<<<<<<
 *         elif opening and self.state != READER_NULL:
 *             raise RuntimeError("Can't reopen opened reader")
*/

#line 381 "cysystemd/reader.pyx"
    __pyx_t_3 = NULL;

#line 381 "cysystemd/reader.pyx"
    __pyx_t_4 = 1;

#line 381 "cysystemd/reader.pyx"
    {

#line 381 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Reader_locked};

#line 381 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 381 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 381 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)

#line 381 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 381 "cysystemd/reader.pyx"
    }

#line 381 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 381 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 381 "cysystemd/reader.pyx"
    __PYX_ERR(0, 381, __pyx_L1_error)

    /* "cysystemd/reader.pyx":380
 *         if self.closed:
 *             raise RuntimeError("Can't lock closed reader")
 *         elif self.locked:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Reader locked")
 *         elif opening and self.state != READER_NULL:
*/

#line 380 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":382
 *         elif self.locked:
 *             raise RuntimeError("Reader locked")
 *         elif opening and self.state != READER_NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Can't reopen opened reader")
 * 
*/

#line 382 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_opening); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 382, __pyx_L1_error)

#line 382 "cysystemd/reader.pyx"
  if (__pyx_t_5) {

#line 382 "cysystemd/reader.pyx"
  } else {

#line 382 "cysystemd/reader.pyx"
    __pyx_t_2 = __pyx_t_5;

#line 382 "cysystemd/reader.pyx"
    goto __pyx_L5_bool_binop_done;

#line 382 "cysystemd/reader.pyx"
  }

#line 382 "cysystemd/reader.pyx"
  __pyx_t_5 = (__pyx_cur_scope->__pyx_v_self->state != __pyx_e_9cysystemd_6reader_READER_NULL);

#line 382 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_5;

#line 382 "cysystemd/reader.pyx"
  __pyx_L5_bool_binop_done:;

#line 382 "cysystemd/reader.pyx"
  if (unlikely(__pyx_t_2)) {

    /* "cysystemd/reader.pyx":383
 *             raise RuntimeError("Reader locked")
 *         elif opening and self.state != READER_NULL:
 *             raise RuntimeError("Can't reopen opened reader")             # <<<<<<<<<<<<<<
 * 
 *         self.state = READER_LOCKED
*/

#line 383 "cysystemd/reader.pyx"
    __pyx_t_3 = NULL;

#line 383 "cysystemd/reader.pyx"
    __pyx_t_4 = 1;

#line 383 "cysystemd/reader.pyx"
    {

#line 383 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Can_t_reopen_opened_reader};

#line 383 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 383 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 383 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)

#line 383 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 383 "cysystemd/reader.pyx"
    }

#line 383 "cysystemd/reader.pyx"
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);

#line 383 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 383 "cysystemd/reader.pyx"
    __PYX_ERR(0, 383, __pyx_L1_error)

    /* "cysystemd/reader.pyx":382
 *         elif self.locked:
 *             raise RuntimeError("Reader locked")
 *         elif opening and self.state != READER_NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Can't reopen opened reader")
 * 
*/

#line 382 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":385
 *             raise RuntimeError("Can't reopen opened reader")
 * 
 *         self.state = READER_LOCKED             # <<<<<<<<<<<<<<
 * 
 *         try:
*/

#line 385 "cysystemd/reader.pyx"
  __pyx_cur_scope->__pyx_v_self->state = __pyx_e_9cysystemd_6reader_READER_LOCKED;

  /* "cysystemd/reader.pyx":387
 *         self.state = READER_LOCKED
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             yield
 *         finally:
*/

#line 387 "cysystemd/reader.pyx"
  /*try:*/ {

    /* "cysystemd/reader.pyx":388
 * 
 *         try:
 *             yield             # <<<<<<<<<<<<<<
 *         finally:
 *             self.state = READER_OPENED
*/

#line 388 "cysystemd/reader.pyx"
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 388 "cysystemd/reader.pyx"
    __Pyx_XGIVEREF(__pyx_r);

#line 388 "cysystemd/reader.pyx"
    __Pyx_RefNannyFinishContext();

#line 388 "cysystemd/reader.pyx"
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);

#line 388 "cysystemd/reader.pyx"
    /* return from generator, yielding value */

#line 388 "cysystemd/reader.pyx"
    __pyx_generator->resume_label = 1;

#line 388 "cysystemd/reader.pyx"
    return __pyx_r;

#line 388 "cysystemd/reader.pyx"
    __pyx_L10_resume_from_yield:;

#line 388 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 388, __pyx_L8_error)

#line 388 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":390
 *             yield
 *         finally:
 *             self.state = READER_OPENED             # <<<<<<<<<<<<<<
 * 
 *     def seek_head(self) -> bool:
*/

#line 390 "cysystemd/reader.pyx"
  /*finally:*/ {

#line 390 "cysystemd/reader.pyx"
    /*normal exit:*/{

#line 390 "cysystemd/reader.pyx"
      __pyx_cur_scope->__pyx_v_self->state = __pyx_e_9cysystemd_6reader_READER_OPENED;

#line 390 "cysystemd/reader.pyx"
      goto __pyx_L9;

#line 390 "cysystemd/reader.pyx"
    }

#line 390 "cysystemd/reader.pyx"
    __pyx_L8_error:;

#line 390 "cysystemd/reader.pyx"
    /*exception exit:*/{

#line 390 "cysystemd/reader.pyx"
      __Pyx_PyThreadState_assign

#line 390 "cysystemd/reader.pyx"
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;

#line 390 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 390 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 390 "cysystemd/reader.pyx"
       __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);

#line 390 "cysystemd/reader.pyx"
      if ( unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_9);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_10);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_11);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_12);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_13);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGOTREF(__pyx_t_14);

#line 390 "cysystemd/reader.pyx"
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;

#line 390 "cysystemd/reader.pyx"
      {

#line 390 "cysystemd/reader.pyx"
        __pyx_cur_scope->__pyx_v_self->state = __pyx_e_9cysystemd_6reader_READER_OPENED;

#line 390 "cysystemd/reader.pyx"
      }

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_12);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_13);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_14);

#line 390 "cysystemd/reader.pyx"
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_9);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_10);

#line 390 "cysystemd/reader.pyx"
      __Pyx_XGIVEREF(__pyx_t_11);

#line 390 "cysystemd/reader.pyx"
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);

#line 390 "cysystemd/reader.pyx"
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;

#line 390 "cysystemd/reader.pyx"
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;

#line 390 "cysystemd/reader.pyx"
      goto __pyx_L1_error;

#line 390 "cysystemd/reader.pyx"
    }

#line 390 "cysystemd/reader.pyx"
    __pyx_L9:;

#line 390 "cysystemd/reader.pyx"
  }

#line 390 "cysystemd/reader.pyx"
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cysystemd/reader.pyx":376
 *         return self.state == READER_OPENED
 * 
 *     @contextmanager             # <<<<<<<<<<<<<<
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:
*/

#line 376 "cysystemd/reader.pyx"


#line 376 "cysystemd/reader.pyx"
  /* function exit code */

#line 376 "cysystemd/reader.pyx"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 376 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 376 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 376 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 376 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 376 "cysystemd/reader.pyx"
  if (__Pyx_PyErr_Occurred()) {

#line 376 "cysystemd/reader.pyx"
    __Pyx_Generator_Replace_StopIteration(0);

#line 376 "cysystemd/reader.pyx"
    __Pyx_AddTraceback("_lock", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 376 "cysystemd/reader.pyx"
  }

#line 376 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 376 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 376 "cysystemd/reader.pyx"
  #if !CYTHON_USE_EXC_INFO_STACK

#line 376 "cysystemd/reader.pyx"
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);

#line 376 "cysystemd/reader.pyx"
  #endif

#line 376 "cysystemd/reader.pyx"
  __pyx_generator->resume_label = -1;

#line 376 "cysystemd/reader.pyx"
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);

#line 376 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 376 "cysystemd/reader.pyx"
  return __pyx_r;

#line 376 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":392
 *             self.state = READER_OPENED
 * 
 *     def seek_head(self) -> bool:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 392 "cysystemd/reader.pyx"


#line 392 "cysystemd/reader.pyx"
/* Python wrapper */

#line 392 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_12seek_head(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_12seek_head = 
#line 392 "cysystemd/reader.pyx"
{"seek_head", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_12seek_head, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 392 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_12seek_head(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 392 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 392 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 392 "cysystemd/reader.pyx"
  #endif

#line 392 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 392 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 392 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_head (wrapper)", 0);

#line 392 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 392 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 392 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 392 "cysystemd/reader.pyx"
  #else

#line 392 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 392 "cysystemd/reader.pyx"
  #endif

#line 392 "cysystemd/reader.pyx"
  #endif

#line 392 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 392 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("seek_head", 1, 0, 0, __pyx_nargs); return NULL; }

#line 392 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 392 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 392 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("seek_head", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 392 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_11seek_head(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 392 "cysystemd/reader.pyx"


#line 392 "cysystemd/reader.pyx"
  /* function exit code */

#line 392 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 392 "cysystemd/reader.pyx"
  return __pyx_r;

#line 392 "cysystemd/reader.pyx"
}

#line 392 "cysystemd/reader.pyx"


#line 392 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_11seek_head(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {
  int __pyx_v_result
#line 392 "cysystemd/reader.pyx"
;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 392 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 392 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 392 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 392 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 392 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 392 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 392 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_head", 0);

  /* "cysystemd/reader.pyx":395
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_head(self.context)
 * 
*/

#line 395 "cysystemd/reader.pyx"
  /*with:*/ {

#line 395 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 395 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 395 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 395 "cysystemd/reader.pyx"
    {

#line 395 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 395 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 395 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 395 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L1_error)

#line 395 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 395 "cysystemd/reader.pyx"
    }

#line 395 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 395, __pyx_L1_error)

#line 395 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 395 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 395 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 395, __pyx_L3_error)

#line 395 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 395 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 395 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 395 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 395 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 395 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 395 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 395 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 395 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 395 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 395 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 395 "cysystemd/reader.pyx"
    }

#line 395 "cysystemd/reader.pyx"
    #endif

#line 395 "cysystemd/reader.pyx"
    {

#line 395 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 395 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 395 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 395 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 395 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 395, __pyx_L3_error)

#line 395 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 395 "cysystemd/reader.pyx"
    }

#line 395 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 395 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 395 "cysystemd/reader.pyx"
    /*try:*/ {

#line 395 "cysystemd/reader.pyx"
      {

#line 395 "cysystemd/reader.pyx"
        (void)__pyx_t_7; (void)__pyx_t_8; (void)__pyx_t_9; /* mark used */

#line 395 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":396
 * 
 *         with self._lock():
 *             result = sd_journal_seek_head(self.context)             # <<<<<<<<<<<<<<
 * 
 *         check_error_code(result)
*/

#line 396 "cysystemd/reader.pyx"
          __pyx_v_result = sd_journal_seek_head(__pyx_v_self->context);

          /* "cysystemd/reader.pyx":395
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_head(self.context)
 * 
*/

#line 395 "cysystemd/reader.pyx"
        }

#line 395 "cysystemd/reader.pyx"
      }

#line 395 "cysystemd/reader.pyx"
    }

#line 395 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 395 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 395 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 395 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 395 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 395 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 395, __pyx_L1_error)

#line 395 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 395 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 395 "cysystemd/reader.pyx"
        }

#line 395 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 395 "cysystemd/reader.pyx"
      }

#line 395 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 395 "cysystemd/reader.pyx"
    }

#line 395 "cysystemd/reader.pyx"
    goto __pyx_L13;

#line 395 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 395 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 395 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 395 "cysystemd/reader.pyx"
    __pyx_L13:;

#line 395 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":398
 *             result = sd_journal_seek_head(self.context)
 * 
 *         check_error_code(result)             # <<<<<<<<<<<<<<
 * 
 *         return True
*/

#line 398 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 398 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 398, __pyx_L1_error)

#line 398 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 398 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 398, __pyx_L1_error)

#line 398 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 398 "cysystemd/reader.pyx"
  __pyx_t_3 = 1;

#line 398 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 398 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 398 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 398 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 398 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 398 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 398 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 398 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 398 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 398 "cysystemd/reader.pyx"
  }

#line 398 "cysystemd/reader.pyx"
  #endif

#line 398 "cysystemd/reader.pyx"
  {

#line 398 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};

#line 398 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 398 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 398 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 398 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 398 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)

#line 398 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 398 "cysystemd/reader.pyx"
  }

#line 398 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":400
 *         check_error_code(result)
 * 
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def seek_tail(self) -> bool:
*/

#line 400 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 400 "cysystemd/reader.pyx"
  __Pyx_INCREF(Py_True);

#line 400 "cysystemd/reader.pyx"
  __pyx_r = Py_True;

#line 400 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":392
 *             self.state = READER_OPENED
 * 
 *     def seek_head(self) -> bool:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 392 "cysystemd/reader.pyx"


#line 392 "cysystemd/reader.pyx"
  /* function exit code */

#line 392 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 392 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 392 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 392 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 392 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 392 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_head", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 392 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 392 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 392 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 392 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 392 "cysystemd/reader.pyx"
  return __pyx_r;

#line 392 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":402
 *         return True
 * 
 *     def seek_tail(self) -> bool:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 402 "cysystemd/reader.pyx"


#line 402 "cysystemd/reader.pyx"
/* Python wrapper */

#line 402 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_14seek_tail(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_14seek_tail = 
#line 402 "cysystemd/reader.pyx"
{"seek_tail", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_14seek_tail, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 402 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_14seek_tail(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 402 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 402 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 402 "cysystemd/reader.pyx"
  #endif

#line 402 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 402 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 402 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_tail (wrapper)", 0);

#line 402 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 402 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 402 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 402 "cysystemd/reader.pyx"
  #else

#line 402 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 402 "cysystemd/reader.pyx"
  #endif

#line 402 "cysystemd/reader.pyx"
  #endif

#line 402 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 402 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("seek_tail", 1, 0, 0, __pyx_nargs); return NULL; }

#line 402 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 402 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 402 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("seek_tail", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 402 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_13seek_tail(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 402 "cysystemd/reader.pyx"


#line 402 "cysystemd/reader.pyx"
  /* function exit code */

#line 402 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 402 "cysystemd/reader.pyx"
  return __pyx_r;

#line 402 "cysystemd/reader.pyx"
}

#line 402 "cysystemd/reader.pyx"


#line 402 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_13seek_tail(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {
  int __pyx_v_result
#line 402 "cysystemd/reader.pyx"
;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 402 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 402 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 402 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 402 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 402 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 402 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 402 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_tail", 0);

  /* "cysystemd/reader.pyx":405
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_tail(self.context)
 * 
*/

#line 405 "cysystemd/reader.pyx"
  /*with:*/ {

#line 405 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 405 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 405 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 405 "cysystemd/reader.pyx"
    {

#line 405 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 405 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 405 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 405 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L1_error)

#line 405 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 405 "cysystemd/reader.pyx"
    }

#line 405 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 405, __pyx_L1_error)

#line 405 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 405 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 405 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 405, __pyx_L3_error)

#line 405 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 405 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 405 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 405 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 405 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 405 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 405 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 405 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 405 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 405 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 405 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 405 "cysystemd/reader.pyx"
    }

#line 405 "cysystemd/reader.pyx"
    #endif

#line 405 "cysystemd/reader.pyx"
    {

#line 405 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 405 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 405 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 405 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 405 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 405, __pyx_L3_error)

#line 405 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 405 "cysystemd/reader.pyx"
    }

#line 405 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 405 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 405 "cysystemd/reader.pyx"
    /*try:*/ {

#line 405 "cysystemd/reader.pyx"
      {

#line 405 "cysystemd/reader.pyx"
        (void)__pyx_t_7; (void)__pyx_t_8; (void)__pyx_t_9; /* mark used */

#line 405 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":406
 * 
 *         with self._lock():
 *             result = sd_journal_seek_tail(self.context)             # <<<<<<<<<<<<<<
 * 
 *         check_error_code(result)
*/

#line 406 "cysystemd/reader.pyx"
          __pyx_v_result = sd_journal_seek_tail(__pyx_v_self->context);

          /* "cysystemd/reader.pyx":405
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_tail(self.context)
 * 
*/

#line 405 "cysystemd/reader.pyx"
        }

#line 405 "cysystemd/reader.pyx"
      }

#line 405 "cysystemd/reader.pyx"
    }

#line 405 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 405 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 405 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 405 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 405 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 405 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 405, __pyx_L1_error)

#line 405 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 405 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 405 "cysystemd/reader.pyx"
        }

#line 405 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 405 "cysystemd/reader.pyx"
      }

#line 405 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 405 "cysystemd/reader.pyx"
    }

#line 405 "cysystemd/reader.pyx"
    goto __pyx_L13;

#line 405 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 405 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 405 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 405 "cysystemd/reader.pyx"
    __pyx_L13:;

#line 405 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":408
 *             result = sd_journal_seek_tail(self.context)
 * 
 *         check_error_code(result)             # <<<<<<<<<<<<<<
 *         # have to call previous to get the last entry, otherwise it will have an unknown cursor
 *         self.previous()
*/

#line 408 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 408 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 408, __pyx_L1_error)

#line 408 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 408 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 408, __pyx_L1_error)

#line 408 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 408 "cysystemd/reader.pyx"
  __pyx_t_3 = 1;

#line 408 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 408 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 408 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 408 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 408 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 408 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 408 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 408 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 408 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 408 "cysystemd/reader.pyx"
  }

#line 408 "cysystemd/reader.pyx"
  #endif

#line 408 "cysystemd/reader.pyx"
  {

#line 408 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};

#line 408 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 408 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 408 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 408 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 408 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 408, __pyx_L1_error)

#line 408 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 408 "cysystemd/reader.pyx"
  }

#line 408 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":410
 *         check_error_code(result)
 *         # have to call previous to get the last entry, otherwise it will have an unknown cursor
 *         self.previous()             # <<<<<<<<<<<<<<
 *         return True
 * 
*/

#line 410 "cysystemd/reader.pyx"
  __pyx_t_6 = ((PyObject *)__pyx_v_self);

#line 410 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_t_6);

#line 410 "cysystemd/reader.pyx"
  __pyx_t_3 = 0;

#line 410 "cysystemd/reader.pyx"
  {

#line 410 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};

#line 410 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_previous, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 410 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 410 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 410, __pyx_L1_error)

#line 410 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 410 "cysystemd/reader.pyx"
  }

#line 410 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":411
 *         # have to call previous to get the last entry, otherwise it will have an unknown cursor
 *         self.previous()
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def seek_monotonic_usec(self, boot_id: UUID, uint64_t usec) -> bool:
*/

#line 411 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 411 "cysystemd/reader.pyx"
  __Pyx_INCREF(Py_True);

#line 411 "cysystemd/reader.pyx"
  __pyx_r = Py_True;

#line 411 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":402
 *         return True
 * 
 *     def seek_tail(self) -> bool:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 402 "cysystemd/reader.pyx"


#line 402 "cysystemd/reader.pyx"
  /* function exit code */

#line 402 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 402 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 402 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 402 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 402 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 402 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_tail", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 402 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 402 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 402 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 402 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 402 "cysystemd/reader.pyx"
  return __pyx_r;

#line 402 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":413
 *         return True
 * 
 *     def seek_monotonic_usec(self, boot_id: UUID, uint64_t usec) -> bool:             # <<<<<<<<<<<<<<
 *         cdef sd_id128_t cboot_id
 *         cdef int result
*/

#line 413 "cysystemd/reader.pyx"


#line 413 "cysystemd/reader.pyx"
/* Python wrapper */

#line 413 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_16seek_monotonic_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_16seek_monotonic_usec = 
#line 413 "cysystemd/reader.pyx"
{"seek_monotonic_usec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_16seek_monotonic_usec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 413 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_16seek_monotonic_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_boot_id = 0
#line 413 "cysystemd/reader.pyx"
;
  uint64_t __pyx_v_usec
#line 413 "cysystemd/reader.pyx"
;

#line 413 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 413 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 413 "cysystemd/reader.pyx"
  #endif

#line 413 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 413 "cysystemd/reader.pyx"
  PyObject* values[2] = {0,0};

#line 413 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 413 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 413 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 413 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 413 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_monotonic_usec (wrapper)", 0);

#line 413 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 413 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 413 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 413 "cysystemd/reader.pyx"
  #else

#line 413 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 413 "cysystemd/reader.pyx"
  #endif

#line 413 "cysystemd/reader.pyx"
  #endif

#line 413 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 413 "cysystemd/reader.pyx"
  {

#line 413 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_boot_id,&__pyx_mstate_global->__pyx_n_u_usec,0};

#line 413 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 413 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 413 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 413 "cysystemd/reader.pyx"
        case  2:

#line 413 "cysystemd/reader.pyx"
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);

#line 413 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;

#line 413 "cysystemd/reader.pyx"
        case  1:

#line 413 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 413 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 413 "cysystemd/reader.pyx"
break;
        default: 
#line 413 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 413 "cysystemd/reader.pyx"
      }

#line 413 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 413 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "seek_monotonic_usec", 0) < (0)) __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {

#line 413 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("seek_monotonic_usec", 1, 2, 2, i); __PYX_ERR(0, 413, __pyx_L3_error) }

#line 413 "cysystemd/reader.pyx"
      }

#line 413 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 2)) {

#line 413 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 413 "cysystemd/reader.pyx"
    } else {

#line 413 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 413 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);

#line 413 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
    }

#line 413 "cysystemd/reader.pyx"
    __pyx_v_boot_id = values[0];

#line 413 "cysystemd/reader.pyx"
    __pyx_v_usec = __Pyx_PyLong_As_uint64_t(values[1]); if (unlikely((__pyx_v_usec == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
  }

#line 413 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 413 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 413 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("seek_monotonic_usec", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 413, __pyx_L3_error)

#line 413 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 413 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 413 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 413 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 413 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 413 "cysystemd/reader.pyx"
  }

#line 413 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_monotonic_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 413 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 413 "cysystemd/reader.pyx"
  return NULL;

#line 413 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 413 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_15seek_monotonic_usec(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_boot_id, __pyx_v_usec);

#line 413 "cysystemd/reader.pyx"


#line 413 "cysystemd/reader.pyx"
  /* function exit code */

#line 413 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 413 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 413 "cysystemd/reader.pyx"
  }

#line 413 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 413 "cysystemd/reader.pyx"
  return __pyx_r;

#line 413 "cysystemd/reader.pyx"
}

#line 413 "cysystemd/reader.pyx"


#line 413 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_15seek_monotonic_usec(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_boot_id, uint64_t __pyx_v_usec) {
  sd_id128_t __pyx_v_cboot_id
#line 413 "cysystemd/reader.pyx"
;
  int __pyx_v_result
#line 413 "cysystemd/reader.pyx"
;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 413 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 413 "cysystemd/reader.pyx"
  uint8_t __pyx_t_2[16];

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 413 "cysystemd/reader.pyx"
  size_t __pyx_t_4;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 413 "cysystemd/reader.pyx"
  PyObject *__pyx_t_10 = NULL;

#line 413 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 413 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 413 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 413 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_monotonic_usec", 0);

  /* "cysystemd/reader.pyx":417
 *         cdef int result
 * 
 *         cboot_id.bytes = boot_id.bytes             # <<<<<<<<<<<<<<
 * 
 *         with self._lock():
*/

#line 417 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_boot_id, __pyx_mstate_global->__pyx_n_u_bytes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)

#line 417 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 417 "cysystemd/reader.pyx"
  if (unlikely((__Pyx_carray_from_py_uint8_t(__pyx_t_1, __pyx_t_2, 16) < 0))) __PYX_ERR(0, 417, __pyx_L1_error)

#line 417 "cysystemd/reader.pyx"
  memcpy(&(__pyx_v_cboot_id.bytes[0]), __pyx_t_2, sizeof(__pyx_v_cboot_id.bytes[0]) * (16));

#line 417 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":419
 *         cboot_id.bytes = boot_id.bytes
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_monotonic_usec(self.context, cboot_id, usec)
 * 
*/

#line 419 "cysystemd/reader.pyx"
  /*with:*/ {

#line 419 "cysystemd/reader.pyx"
    __pyx_t_3 = ((PyObject *)__pyx_v_self);

#line 419 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 419 "cysystemd/reader.pyx"
    __pyx_t_4 = 0;

#line 419 "cysystemd/reader.pyx"
    {

#line 419 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};

#line 419 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 419 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 419 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 419, __pyx_L1_error)

#line 419 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 419 "cysystemd/reader.pyx"
    }

#line 419 "cysystemd/reader.pyx"
    __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 419, __pyx_L1_error)

#line 419 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_5);

#line 419 "cysystemd/reader.pyx"
    __pyx_t_6 = NULL;

#line 419 "cysystemd/reader.pyx"
    __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 419, __pyx_L3_error)

#line 419 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_7);

#line 419 "cysystemd/reader.pyx"
    __pyx_t_4 = 1;

#line 419 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 419 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_7))) {

#line 419 "cysystemd/reader.pyx"
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);

#line 419 "cysystemd/reader.pyx"
      assert(__pyx_t_6);

#line 419 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);

#line 419 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_6);

#line 419 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 419 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);

#line 419 "cysystemd/reader.pyx"
      __pyx_t_4 = 0;

#line 419 "cysystemd/reader.pyx"
    }

#line 419 "cysystemd/reader.pyx"
    #endif

#line 419 "cysystemd/reader.pyx"
    {

#line 419 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};

#line 419 "cysystemd/reader.pyx"
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 419 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 419 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 419 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 419, __pyx_L3_error)

#line 419 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_3);

#line 419 "cysystemd/reader.pyx"
    }

#line 419 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 419 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 419 "cysystemd/reader.pyx"
    /*try:*/ {

#line 419 "cysystemd/reader.pyx"
      {

#line 419 "cysystemd/reader.pyx"
        (void)__pyx_t_8; (void)__pyx_t_9; (void)__pyx_t_10; /* mark used */

#line 419 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":420
 * 
 *         with self._lock():
 *             result = sd_journal_seek_monotonic_usec(self.context, cboot_id, usec)             # <<<<<<<<<<<<<<
 * 
 *         check_error_code(result)
*/

#line 420 "cysystemd/reader.pyx"
          __pyx_v_result = sd_journal_seek_monotonic_usec(__pyx_v_self->context, __pyx_v_cboot_id, __pyx_v_usec);

          /* "cysystemd/reader.pyx":419
 *         cboot_id.bytes = boot_id.bytes
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_monotonic_usec(self.context, cboot_id, usec)
 * 
*/

#line 419 "cysystemd/reader.pyx"
        }

#line 419 "cysystemd/reader.pyx"
      }

#line 419 "cysystemd/reader.pyx"
    }

#line 419 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 419 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 419 "cysystemd/reader.pyx"
        if (__pyx_t_5) {

#line 419 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 419 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 419 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 419, __pyx_L1_error)

#line 419 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_10);

#line 419 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

#line 419 "cysystemd/reader.pyx"
        }

#line 419 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 419 "cysystemd/reader.pyx"
      }

#line 419 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 419 "cysystemd/reader.pyx"
    }

#line 419 "cysystemd/reader.pyx"
    goto __pyx_L13;

#line 419 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 419 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 419 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 419 "cysystemd/reader.pyx"
    __pyx_L13:;

#line 419 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":422
 *             result = sd_journal_seek_monotonic_usec(self.context, cboot_id, usec)
 * 
 *         check_error_code(result)             # <<<<<<<<<<<<<<
 *         return True
 * 
*/

#line 422 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 422 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 422, __pyx_L1_error)

#line 422 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_7);

#line 422 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 422, __pyx_L1_error)

#line 422 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 422 "cysystemd/reader.pyx"
  __pyx_t_4 = 1;

#line 422 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 422 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_7))) {

#line 422 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);

#line 422 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 422 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);

#line 422 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 422 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 422 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);

#line 422 "cysystemd/reader.pyx"
    __pyx_t_4 = 0;

#line 422 "cysystemd/reader.pyx"
  }

#line 422 "cysystemd/reader.pyx"
  #endif

#line 422 "cysystemd/reader.pyx"
  {

#line 422 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};

#line 422 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 422 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 422 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 422 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 422 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 422, __pyx_L1_error)

#line 422 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 422 "cysystemd/reader.pyx"
  }

#line 422 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":423
 * 
 *         check_error_code(result)
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def seek_realtime_usec(self, uint64_t usec) -> bool:
*/

#line 423 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 423 "cysystemd/reader.pyx"
  __Pyx_INCREF(Py_True);

#line 423 "cysystemd/reader.pyx"
  __pyx_r = Py_True;

#line 423 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":413
 *         return True
 * 
 *     def seek_monotonic_usec(self, boot_id: UUID, uint64_t usec) -> bool:             # <<<<<<<<<<<<<<
 *         cdef sd_id128_t cboot_id
 *         cdef int result
*/

#line 413 "cysystemd/reader.pyx"


#line 413 "cysystemd/reader.pyx"
  /* function exit code */

#line 413 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 413 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 413 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 413 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 413 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_7);

#line 413 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_monotonic_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 413 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 413 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 413 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 413 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 413 "cysystemd/reader.pyx"
  return __pyx_r;

#line 413 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":425
 *         return True
 * 
 *     def seek_realtime_usec(self, uint64_t usec) -> bool:             # <<<<<<<<<<<<<<
 *         cdef uint64_t cusec = usec
 *         cdef int result
*/

#line 425 "cysystemd/reader.pyx"


#line 425 "cysystemd/reader.pyx"
/* Python wrapper */

#line 425 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_18seek_realtime_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_18seek_realtime_usec = 
#line 425 "cysystemd/reader.pyx"
{"seek_realtime_usec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_18seek_realtime_usec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 425 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_18seek_realtime_usec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  uint64_t __pyx_v_usec
#line 425 "cysystemd/reader.pyx"
;

#line 425 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 425 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 425 "cysystemd/reader.pyx"
  #endif

#line 425 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 425 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 425 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 425 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 425 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 425 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 425 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_realtime_usec (wrapper)", 0);

#line 425 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 425 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 425 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 425 "cysystemd/reader.pyx"
  #else

#line 425 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 425 "cysystemd/reader.pyx"
  #endif

#line 425 "cysystemd/reader.pyx"
  #endif

#line 425 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 425 "cysystemd/reader.pyx"
  {

#line 425 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_usec,0};

#line 425 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 425 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 425, __pyx_L3_error)

#line 425 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 425 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 425 "cysystemd/reader.pyx"
        case  1:

#line 425 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 425 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 425, __pyx_L3_error)

#line 425 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 425 "cysystemd/reader.pyx"
break;
        default: 
#line 425 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 425 "cysystemd/reader.pyx"
      }

#line 425 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 425 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "seek_realtime_usec", 0) < (0)) __PYX_ERR(0, 425, __pyx_L3_error)

#line 425 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 425 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("seek_realtime_usec", 1, 1, 1, i); __PYX_ERR(0, 425, __pyx_L3_error) }

#line 425 "cysystemd/reader.pyx"
      }

#line 425 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 425 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 425 "cysystemd/reader.pyx"
    } else {

#line 425 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 425 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 425, __pyx_L3_error)

#line 425 "cysystemd/reader.pyx"
    }

#line 425 "cysystemd/reader.pyx"
    __pyx_v_usec = __Pyx_PyLong_As_uint64_t(values[0]); if (unlikely((__pyx_v_usec == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)

#line 425 "cysystemd/reader.pyx"
  }

#line 425 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 425 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 425 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("seek_realtime_usec", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 425, __pyx_L3_error)

#line 425 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 425 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 425 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 425 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 425 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 425 "cysystemd/reader.pyx"
  }

#line 425 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_realtime_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 425 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 425 "cysystemd/reader.pyx"
  return NULL;

#line 425 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 425 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_17seek_realtime_usec(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_usec);

#line 425 "cysystemd/reader.pyx"


#line 425 "cysystemd/reader.pyx"
  /* function exit code */

#line 425 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 425 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 425 "cysystemd/reader.pyx"
  }

#line 425 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 425 "cysystemd/reader.pyx"
  return __pyx_r;

#line 425 "cysystemd/reader.pyx"
}

#line 425 "cysystemd/reader.pyx"


#line 425 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_17seek_realtime_usec(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_usec) {
  uint64_t __pyx_v_cusec
#line 425 "cysystemd/reader.pyx"
;
  int __pyx_v_result
#line 425 "cysystemd/reader.pyx"
;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 425 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 425 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 425 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 425 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 425 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 425 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 425 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_realtime_usec", 0);

  /* "cysystemd/reader.pyx":426
 * 
 *     def seek_realtime_usec(self, uint64_t usec) -> bool:
 *         cdef uint64_t cusec = usec             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 426 "cysystemd/reader.pyx"
  __pyx_v_cusec = __pyx_v_usec;

  /* "cysystemd/reader.pyx":429
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_realtime_usec(self.context, cusec)
 * 
*/

#line 429 "cysystemd/reader.pyx"
  /*with:*/ {

#line 429 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 429 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 429 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 429 "cysystemd/reader.pyx"
    {

#line 429 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 429 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 429 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 429 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)

#line 429 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 429 "cysystemd/reader.pyx"
    }

#line 429 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 429, __pyx_L1_error)

#line 429 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 429 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 429 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 429, __pyx_L3_error)

#line 429 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 429 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 429 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 429 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 429 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 429 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 429 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 429 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 429 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 429 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 429 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 429 "cysystemd/reader.pyx"
    }

#line 429 "cysystemd/reader.pyx"
    #endif

#line 429 "cysystemd/reader.pyx"
    {

#line 429 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 429 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 429 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 429 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 429 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L3_error)

#line 429 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 429 "cysystemd/reader.pyx"
    }

#line 429 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 429 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 429 "cysystemd/reader.pyx"
    /*try:*/ {

#line 429 "cysystemd/reader.pyx"
      {

#line 429 "cysystemd/reader.pyx"
        (void)__pyx_t_7; (void)__pyx_t_8; (void)__pyx_t_9; /* mark used */

#line 429 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":430
 * 
 *         with self._lock():
 *             result = sd_journal_seek_realtime_usec(self.context, cusec)             # <<<<<<<<<<<<<<
 * 
 *         check_error_code(result)
*/

#line 430 "cysystemd/reader.pyx"
          __pyx_v_result = sd_journal_seek_realtime_usec(__pyx_v_self->context, __pyx_v_cusec);

          /* "cysystemd/reader.pyx":429
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_realtime_usec(self.context, cusec)
 * 
*/

#line 429 "cysystemd/reader.pyx"
        }

#line 429 "cysystemd/reader.pyx"
      }

#line 429 "cysystemd/reader.pyx"
    }

#line 429 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 429 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 429 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 429 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 429 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 429 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 429, __pyx_L1_error)

#line 429 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 429 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 429 "cysystemd/reader.pyx"
        }

#line 429 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 429 "cysystemd/reader.pyx"
      }

#line 429 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 429 "cysystemd/reader.pyx"
    }

#line 429 "cysystemd/reader.pyx"
    goto __pyx_L13;

#line 429 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 429 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 429 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 429 "cysystemd/reader.pyx"
    __pyx_L13:;

#line 429 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":432
 *             result = sd_journal_seek_realtime_usec(self.context, cusec)
 * 
 *         check_error_code(result)             # <<<<<<<<<<<<<<
 *         return True
 * 
*/

#line 432 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 432 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 432, __pyx_L1_error)

#line 432 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 432 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 432, __pyx_L1_error)

#line 432 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 432 "cysystemd/reader.pyx"
  __pyx_t_3 = 1;

#line 432 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 432 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 432 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 432 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 432 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 432 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 432 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 432 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 432 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 432 "cysystemd/reader.pyx"
  }

#line 432 "cysystemd/reader.pyx"
  #endif

#line 432 "cysystemd/reader.pyx"
  {

#line 432 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};

#line 432 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 432 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 432 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 432 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 432 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 432, __pyx_L1_error)

#line 432 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 432 "cysystemd/reader.pyx"
  }

#line 432 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":433
 * 
 *         check_error_code(result)
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def seek_cursor(self, bytes cursor) -> bool:
*/

#line 433 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 433 "cysystemd/reader.pyx"
  __Pyx_INCREF(Py_True);

#line 433 "cysystemd/reader.pyx"
  __pyx_r = Py_True;

#line 433 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":425
 *         return True
 * 
 *     def seek_realtime_usec(self, uint64_t usec) -> bool:             # <<<<<<<<<<<<<<
 *         cdef uint64_t cusec = usec
 *         cdef int result
*/

#line 425 "cysystemd/reader.pyx"


#line 425 "cysystemd/reader.pyx"
  /* function exit code */

#line 425 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 425 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 425 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 425 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 425 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 425 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_realtime_usec", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 425 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 425 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 425 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 425 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 425 "cysystemd/reader.pyx"
  return __pyx_r;

#line 425 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":435
 *         return True
 * 
 *     def seek_cursor(self, bytes cursor) -> bool:             # <<<<<<<<<<<<<<
 *         cdef char* ccursor = cursor
 *         cdef int result
*/

#line 435 "cysystemd/reader.pyx"


#line 435 "cysystemd/reader.pyx"
/* Python wrapper */

#line 435 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_20seek_cursor(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_20seek_cursor = 
#line 435 "cysystemd/reader.pyx"
{"seek_cursor", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_20seek_cursor, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 435 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_20seek_cursor(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cursor = 0
#line 435 "cysystemd/reader.pyx"
;

#line 435 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 435 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 435 "cysystemd/reader.pyx"
  #endif

#line 435 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 435 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 435 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 435 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 435 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 435 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 435 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 435 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_cursor (wrapper)", 0);

#line 435 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 435 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 435 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 435 "cysystemd/reader.pyx"
  #else

#line 435 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 435 "cysystemd/reader.pyx"
  #endif

#line 435 "cysystemd/reader.pyx"
  #endif

#line 435 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 435 "cysystemd/reader.pyx"
  {

#line 435 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cursor,0};

#line 435 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 435 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 435, __pyx_L3_error)

#line 435 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 435 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 435 "cysystemd/reader.pyx"
        case  1:

#line 435 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 435 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 435, __pyx_L3_error)

#line 435 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 435 "cysystemd/reader.pyx"
break;
        default: 
#line 435 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 435 "cysystemd/reader.pyx"
      }

#line 435 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 435 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "seek_cursor", 0) < (0)) __PYX_ERR(0, 435, __pyx_L3_error)

#line 435 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 435 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("seek_cursor", 1, 1, 1, i); __PYX_ERR(0, 435, __pyx_L3_error) }

#line 435 "cysystemd/reader.pyx"
      }

#line 435 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 435 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 435 "cysystemd/reader.pyx"
    } else {

#line 435 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 435 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 435, __pyx_L3_error)

#line 435 "cysystemd/reader.pyx"
    }

#line 435 "cysystemd/reader.pyx"
    __pyx_v_cursor = ((PyObject*)values[0]);

#line 435 "cysystemd/reader.pyx"
  }

#line 435 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 435 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 435 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("seek_cursor", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 435, __pyx_L3_error)

#line 435 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 435 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 435 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 435 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 435 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 435 "cysystemd/reader.pyx"
  }

#line 435 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_cursor", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 435 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 435 "cysystemd/reader.pyx"
  return NULL;

#line 435 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;

#line 435 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_cursor), (&PyBytes_Type), 1, "cursor", 1))) __PYX_ERR(0, 435, __pyx_L1_error)
  __pyx_r = 
#line 435 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_19seek_cursor(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_cursor);

#line 435 "cysystemd/reader.pyx"


#line 435 "cysystemd/reader.pyx"
  /* function exit code */

#line 435 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 435 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 435 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 435 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 435 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 435 "cysystemd/reader.pyx"
  }

#line 435 "cysystemd/reader.pyx"
  goto __pyx_L7_cleaned_up;

#line 435 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 435 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 435 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 435 "cysystemd/reader.pyx"
  }

#line 435 "cysystemd/reader.pyx"
  __pyx_L7_cleaned_up:;

#line 435 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 435 "cysystemd/reader.pyx"
  return __pyx_r;

#line 435 "cysystemd/reader.pyx"
}

#line 435 "cysystemd/reader.pyx"


#line 435 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_19seek_cursor(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_cursor) {
  char *__pyx_v_ccursor
#line 435 "cysystemd/reader.pyx"
;
  int __pyx_v_result
#line 435 "cysystemd/reader.pyx"
;

#line 435 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 435 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 435 "cysystemd/reader.pyx"
  char *__pyx_t_1;

#line 435 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 435 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 435 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 435 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 435 "cysystemd/reader.pyx"
  size_t __pyx_t_6;

#line 435 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 435 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 435 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 435 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("seek_cursor", 0);

  /* "cysystemd/reader.pyx":436
 * 
 *     def seek_cursor(self, bytes cursor) -> bool:
 *         cdef char* ccursor = cursor             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 436 "cysystemd/reader.pyx"
  if (unlikely(__pyx_v_cursor == Py_None)) {

#line 436 "cysystemd/reader.pyx"
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");

#line 436 "cysystemd/reader.pyx"
    __PYX_ERR(0, 436, __pyx_L1_error)

#line 436 "cysystemd/reader.pyx"
  }

#line 436 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyBytes_AsWritableString(__pyx_v_cursor); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) __PYX_ERR(0, 436, __pyx_L1_error)

#line 436 "cysystemd/reader.pyx"
  __pyx_v_ccursor = __pyx_t_1;

  /* "cysystemd/reader.pyx":439
 *         cdef int result
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_cursor(self.context, ccursor)
 * 
*/

#line 439 "cysystemd/reader.pyx"
  {

#line 439 "cysystemd/reader.pyx"
      PyThreadState * _save;

#line 439 "cysystemd/reader.pyx"
      _save = PyEval_SaveThread();

#line 439 "cysystemd/reader.pyx"
      __Pyx_FastGIL_Remember();

#line 439 "cysystemd/reader.pyx"
      /*try:*/ {

        /* "cysystemd/reader.pyx":440
 * 
 *         with nogil:
 *             result = sd_journal_seek_cursor(self.context, ccursor)             # <<<<<<<<<<<<<<
 * 
 *         check_error_code(result)
*/

#line 440 "cysystemd/reader.pyx"
        __pyx_v_result = sd_journal_seek_cursor(__pyx_v_self->context, __pyx_v_ccursor);

#line 440 "cysystemd/reader.pyx"
      }

      /* "cysystemd/reader.pyx":439
 *         cdef int result
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = sd_journal_seek_cursor(self.context, ccursor)
 * 
*/

#line 439 "cysystemd/reader.pyx"
      /*finally:*/ {

#line 439 "cysystemd/reader.pyx"
        /*normal exit:*/{

#line 439 "cysystemd/reader.pyx"
          __Pyx_FastGIL_Forget();

#line 439 "cysystemd/reader.pyx"
          PyEval_RestoreThread(_save);

#line 439 "cysystemd/reader.pyx"
          goto __pyx_L5;

#line 439 "cysystemd/reader.pyx"
        }

#line 439 "cysystemd/reader.pyx"
        __pyx_L5:;

#line 439 "cysystemd/reader.pyx"
      }

#line 439 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":442
 *             result = sd_journal_seek_cursor(self.context, ccursor)
 * 
 *         check_error_code(result)             # <<<<<<<<<<<<<<
 *         return True
 * 
*/

#line 442 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 442 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L1_error)

#line 442 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 442 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 442, __pyx_L1_error)

#line 442 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 442 "cysystemd/reader.pyx"
  __pyx_t_6 = 1;

#line 442 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 442 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 442 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 442 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 442 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 442 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 442 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 442 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 442 "cysystemd/reader.pyx"
    __pyx_t_6 = 0;

#line 442 "cysystemd/reader.pyx"
  }

#line 442 "cysystemd/reader.pyx"
  #endif

#line 442 "cysystemd/reader.pyx"
  {

#line 442 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};

#line 442 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 442 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 442 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 442 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 442 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)

#line 442 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 442 "cysystemd/reader.pyx"
  }

#line 442 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":443
 * 
 *         check_error_code(result)
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     cpdef wait(self, uint32_t timeout = WAIT_MAX_TIME):
*/

#line 443 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 443 "cysystemd/reader.pyx"
  __Pyx_INCREF(Py_True);

#line 443 "cysystemd/reader.pyx"
  __pyx_r = Py_True;

#line 443 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":435
 *         return True
 * 
 *     def seek_cursor(self, bytes cursor) -> bool:             # <<<<<<<<<<<<<<
 *         cdef char* ccursor = cursor
 *         cdef int result
*/

#line 435 "cysystemd/reader.pyx"


#line 435 "cysystemd/reader.pyx"
  /* function exit code */

#line 435 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 435 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 435 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 435 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 435 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 435 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.seek_cursor", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 435 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 435 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 435 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 435 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 435 "cysystemd/reader.pyx"
  return __pyx_r;

#line 435 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":445
 *         return True
 * 
 *     cpdef wait(self, uint32_t timeout = WAIT_MAX_TIME):             # <<<<<<<<<<<<<<
 *         cdef uint64_t timeout_usec = timeout * 1000000
 *         cdef int result
*/

#line 445 "cysystemd/reader.pyx"


#line 445 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_22wait(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/

#line 445 "cysystemd/reader.pyx"
static PyObject *__pyx_f_9cysystemd_6reader_13JournalReader_wait(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_9cysystemd_6reader_13JournalReader_wait *__pyx_optional_args) {

#line 445 "cysystemd/reader.pyx"
  uint32_t __pyx_v_timeout = __pyx_mstate_global->__pyx_k__5;
  uint64_t __pyx_v_timeout_usec
#line 445 "cysystemd/reader.pyx"
;
  int __pyx_v_result
#line 445 "cysystemd/reader.pyx"
;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 445 "cysystemd/reader.pyx"
  size_t __pyx_t_6;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_10 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_12 = NULL;

#line 445 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 445 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 445 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("wait", 0);

#line 445 "cysystemd/reader.pyx"
  if (__pyx_optional_args) {

#line 445 "cysystemd/reader.pyx"
    if (__pyx_optional_args->__pyx_n > 0) {

#line 445 "cysystemd/reader.pyx"
      __pyx_v_timeout = __pyx_optional_args->timeout;

#line 445 "cysystemd/reader.pyx"
    }

#line 445 "cysystemd/reader.pyx"
  }

#line 445 "cysystemd/reader.pyx"
  /* Check if called by wrapper */

#line 445 "cysystemd/reader.pyx"
  if (unlikely(__pyx_skip_dispatch)) ;

#line 445 "cysystemd/reader.pyx"
  /* Check if overridden in Python */

#line 445 "cysystemd/reader.pyx"
  else if (

#line 445 "cysystemd/reader.pyx"
  #if !CYTHON_USE_TYPE_SLOTS

#line 445 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader &&

#line 445 "cysystemd/reader.pyx"
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))

#line 445 "cysystemd/reader.pyx"
  #else

#line 445 "cysystemd/reader.pyx"
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))

#line 445 "cysystemd/reader.pyx"
  #endif

#line 445 "cysystemd/reader.pyx"
  ) {

#line 445 "cysystemd/reader.pyx"
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 445 "cysystemd/reader.pyx"
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 445 "cysystemd/reader.pyx"
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {

#line 445 "cysystemd/reader.pyx"
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 445 "cysystemd/reader.pyx"
      #endif

#line 445 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 445 "cysystemd/reader.pyx"
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9cysystemd_6reader_13JournalReader_22wait)) {

#line 445 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_r);

#line 445 "cysystemd/reader.pyx"
        __pyx_t_3 = NULL;

#line 445 "cysystemd/reader.pyx"
        __Pyx_INCREF(__pyx_t_1);

#line 445 "cysystemd/reader.pyx"
        __pyx_t_4 = __pyx_t_1; 

#line 445 "cysystemd/reader.pyx"
        __pyx_t_5 = __Pyx_PyLong_From_uint32_t(__pyx_v_timeout); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
        __Pyx_GOTREF(__pyx_t_5);

#line 445 "cysystemd/reader.pyx"
        __pyx_t_6 = 1;

#line 445 "cysystemd/reader.pyx"
        #if CYTHON_UNPACK_METHODS

#line 445 "cysystemd/reader.pyx"
        if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 445 "cysystemd/reader.pyx"
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 445 "cysystemd/reader.pyx"
          assert(__pyx_t_3);

#line 445 "cysystemd/reader.pyx"
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 445 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx_t_3);

#line 445 "cysystemd/reader.pyx"
          __Pyx_INCREF(__pyx__function);

#line 445 "cysystemd/reader.pyx"
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 445 "cysystemd/reader.pyx"
          __pyx_t_6 = 0;

#line 445 "cysystemd/reader.pyx"
        }

#line 445 "cysystemd/reader.pyx"
        #endif

#line 445 "cysystemd/reader.pyx"
        {

#line 445 "cysystemd/reader.pyx"
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};

#line 445 "cysystemd/reader.pyx"
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 445 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 445 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 445 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 445 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 445 "cysystemd/reader.pyx"
        }

#line 445 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_2;

#line 445 "cysystemd/reader.pyx"
        __pyx_t_2 = 0;

#line 445 "cysystemd/reader.pyx"
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 445 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 445 "cysystemd/reader.pyx"
      }

#line 445 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 445 "cysystemd/reader.pyx"
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));

#line 445 "cysystemd/reader.pyx"
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));

#line 445 "cysystemd/reader.pyx"
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {

#line 445 "cysystemd/reader.pyx"
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;

#line 445 "cysystemd/reader.pyx"
      }

#line 445 "cysystemd/reader.pyx"
      #endif

#line 445 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 445 "cysystemd/reader.pyx"
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS

#line 445 "cysystemd/reader.pyx"
    }

#line 445 "cysystemd/reader.pyx"
    #endif

#line 445 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":446
 * 
 *     cpdef wait(self, uint32_t timeout = WAIT_MAX_TIME):
 *         cdef uint64_t timeout_usec = timeout * 1000000             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 446 "cysystemd/reader.pyx"
  __pyx_v_timeout_usec = (__pyx_v_timeout * 0xF4240);

  /* "cysystemd/reader.pyx":449
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 result = sd_journal_wait(self.context, timeout_usec)
*/

#line 449 "cysystemd/reader.pyx"
  /*with:*/ {

#line 449 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 449 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 449 "cysystemd/reader.pyx"
    __pyx_t_6 = 0;

#line 449 "cysystemd/reader.pyx"
    {

#line 449 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 449 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 449 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 449 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)

#line 449 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 449 "cysystemd/reader.pyx"
    }

#line 449 "cysystemd/reader.pyx"
    __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 449, __pyx_L1_error)

#line 449 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_7);

#line 449 "cysystemd/reader.pyx"
    __pyx_t_4 = NULL;

#line 449 "cysystemd/reader.pyx"
    __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 449, __pyx_L3_error)

#line 449 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_5);

#line 449 "cysystemd/reader.pyx"
    __pyx_t_6 = 1;

#line 449 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 449 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_5))) {

#line 449 "cysystemd/reader.pyx"
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);

#line 449 "cysystemd/reader.pyx"
      assert(__pyx_t_4);

#line 449 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);

#line 449 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_4);

#line 449 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 449 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);

#line 449 "cysystemd/reader.pyx"
      __pyx_t_6 = 0;

#line 449 "cysystemd/reader.pyx"
    }

#line 449 "cysystemd/reader.pyx"
    #endif

#line 449 "cysystemd/reader.pyx"
    {

#line 449 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};

#line 449 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 449 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 449 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 449 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 449, __pyx_L3_error)

#line 449 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 449 "cysystemd/reader.pyx"
    }

#line 449 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 449 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 449 "cysystemd/reader.pyx"
    /*try:*/ {

#line 449 "cysystemd/reader.pyx"
      {

#line 449 "cysystemd/reader.pyx"
        (void)__pyx_t_8; (void)__pyx_t_9; (void)__pyx_t_10; /* mark used */

#line 449 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":450
 * 
 *         with self._lock():
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_wait(self.context, timeout_usec)
 * 
*/

#line 450 "cysystemd/reader.pyx"
          {

#line 450 "cysystemd/reader.pyx"
              PyThreadState * _save;

#line 450 "cysystemd/reader.pyx"
              _save = PyEval_SaveThread();

#line 450 "cysystemd/reader.pyx"
              __Pyx_FastGIL_Remember();

#line 450 "cysystemd/reader.pyx"
              /*try:*/ {

                /* "cysystemd/reader.pyx":451
 *         with self._lock():
 *             with nogil:
 *                 result = sd_journal_wait(self.context, timeout_usec)             # <<<<<<<<<<<<<<
 * 
 *         return JournalEvent(check_error_code(result))
*/

#line 451 "cysystemd/reader.pyx"
                __pyx_v_result = sd_journal_wait(__pyx_v_self->context, __pyx_v_timeout_usec);

#line 451 "cysystemd/reader.pyx"
              }

              /* "cysystemd/reader.pyx":450
 * 
 *         with self._lock():
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_wait(self.context, timeout_usec)
 * 
*/

#line 450 "cysystemd/reader.pyx"
              /*finally:*/ {

#line 450 "cysystemd/reader.pyx"
                /*normal exit:*/{

#line 450 "cysystemd/reader.pyx"
                  __Pyx_FastGIL_Forget();

#line 450 "cysystemd/reader.pyx"
                  PyEval_RestoreThread(_save);

#line 450 "cysystemd/reader.pyx"
                  goto __pyx_L15;

#line 450 "cysystemd/reader.pyx"
                }

#line 450 "cysystemd/reader.pyx"
                __pyx_L15:;

#line 450 "cysystemd/reader.pyx"
              }

#line 450 "cysystemd/reader.pyx"
          }

          /* "cysystemd/reader.pyx":449
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 result = sd_journal_wait(self.context, timeout_usec)
*/

#line 449 "cysystemd/reader.pyx"
        }

#line 449 "cysystemd/reader.pyx"
      }

#line 449 "cysystemd/reader.pyx"
    }

#line 449 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 449 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 449 "cysystemd/reader.pyx"
        if (__pyx_t_7) {

#line 449 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 449 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 449 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 449, __pyx_L1_error)

#line 449 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_10);

#line 449 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

#line 449 "cysystemd/reader.pyx"
        }

#line 449 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 449 "cysystemd/reader.pyx"
      }

#line 449 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 449 "cysystemd/reader.pyx"
    }

#line 449 "cysystemd/reader.pyx"
    goto __pyx_L16;

#line 449 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 449 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 449 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 449 "cysystemd/reader.pyx"
    __pyx_L16:;

#line 449 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":453
 *                 result = sd_journal_wait(self.context, timeout_usec)
 * 
 *         return JournalEvent(check_error_code(result))             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self) -> Iterator[JournalEntry]:
*/

#line 453 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 453 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 453 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_JournalEvent); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 453, __pyx_L1_error)

#line 453 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 453 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 453 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 453, __pyx_L1_error)

#line 453 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_11);

#line 453 "cysystemd/reader.pyx"
  __pyx_t_12 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 453, __pyx_L1_error)

#line 453 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_12);

#line 453 "cysystemd/reader.pyx"
  __pyx_t_6 = 1;

#line 453 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 453 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_11))) {

#line 453 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_11);

#line 453 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 453 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);

#line 453 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 453 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 453 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);

#line 453 "cysystemd/reader.pyx"
    __pyx_t_6 = 0;

#line 453 "cysystemd/reader.pyx"
  }

#line 453 "cysystemd/reader.pyx"
  #endif

#line 453 "cysystemd/reader.pyx"
  {

#line 453 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_12};

#line 453 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 453 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 453 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 453 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

#line 453 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 453, __pyx_L1_error)

#line 453 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 453 "cysystemd/reader.pyx"
  }

#line 453 "cysystemd/reader.pyx"
  __pyx_t_6 = 1;

#line 453 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 453 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_5))) {

#line 453 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);

#line 453 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 453 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);

#line 453 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 453 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 453 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);

#line 453 "cysystemd/reader.pyx"
    __pyx_t_6 = 0;

#line 453 "cysystemd/reader.pyx"
  }

#line 453 "cysystemd/reader.pyx"
  #endif

#line 453 "cysystemd/reader.pyx"
  {

#line 453 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 453 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 453 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 453 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 453 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 453 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)

#line 453 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 453 "cysystemd/reader.pyx"
  }

#line 453 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 453 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 453 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":445
 *         return True
 * 
 *     cpdef wait(self, uint32_t timeout = WAIT_MAX_TIME):             # <<<<<<<<<<<<<<
 *         cdef uint64_t timeout_usec = timeout * 1000000
 *         cdef int result
*/

#line 445 "cysystemd/reader.pyx"


#line 445 "cysystemd/reader.pyx"
  /* function exit code */

#line 445 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_11);

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_12);

#line 445 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.wait", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 445 "cysystemd/reader.pyx"
  __pyx_r = 0;

#line 445 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 445 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 445 "cysystemd/reader.pyx"
  return __pyx_r;

#line 445 "cysystemd/reader.pyx"
}

#line 445 "cysystemd/reader.pyx"


#line 445 "cysystemd/reader.pyx"
/* Python wrapper */

#line 445 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_22wait(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_22wait = 
#line 445 "cysystemd/reader.pyx"
{"wait", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_22wait, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 445 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_22wait(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  uint32_t __pyx_v_timeout
#line 445 "cysystemd/reader.pyx"
;

#line 445 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 445 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 445 "cysystemd/reader.pyx"
  #endif

#line 445 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 445 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 445 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 445 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 445 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("wait (wrapper)", 0);

#line 445 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 445 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 445 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 445 "cysystemd/reader.pyx"
  #else

#line 445 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 445 "cysystemd/reader.pyx"
  #endif

#line 445 "cysystemd/reader.pyx"
  #endif

#line 445 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 445 "cysystemd/reader.pyx"
  {

#line 445 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_timeout,0};

#line 445 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 445 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 445, __pyx_L3_error)

#line 445 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 445 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 445 "cysystemd/reader.pyx"
        case  1:

#line 445 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 445 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 445, __pyx_L3_error)

#line 445 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 445 "cysystemd/reader.pyx"
break;
        default: 
#line 445 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 445 "cysystemd/reader.pyx"
      }

#line 445 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 445 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "wait", 0) < (0)) __PYX_ERR(0, 445, __pyx_L3_error)

#line 445 "cysystemd/reader.pyx"
    } else {

#line 445 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 445 "cysystemd/reader.pyx"
        case  1:

#line 445 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 445 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 445, __pyx_L3_error)

#line 445 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 445 "cysystemd/reader.pyx"
break;
        default: 
#line 445 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 445 "cysystemd/reader.pyx"
      }

#line 445 "cysystemd/reader.pyx"
    }

#line 445 "cysystemd/reader.pyx"
    if (values[0]) {

#line 445 "cysystemd/reader.pyx"
      __pyx_v_timeout = __Pyx_PyLong_As_uint32_t(values[0]); if (unlikely((__pyx_v_timeout == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 445, __pyx_L3_error)

#line 445 "cysystemd/reader.pyx"
    } else {

#line 445 "cysystemd/reader.pyx"
      __pyx_v_timeout = __pyx_mstate_global->__pyx_k__5;

#line 445 "cysystemd/reader.pyx"
    }

#line 445 "cysystemd/reader.pyx"
  }

#line 445 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 445 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 445 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("wait", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 445, __pyx_L3_error)

#line 445 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 445 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 445 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 445 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 445 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 445 "cysystemd/reader.pyx"
  }

#line 445 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.wait", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 445 "cysystemd/reader.pyx"
  return NULL;

#line 445 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 445 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_21wait(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_timeout);

#line 445 "cysystemd/reader.pyx"


#line 445 "cysystemd/reader.pyx"
  /* function exit code */

#line 445 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 445 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 445 "cysystemd/reader.pyx"
  }

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 445 "cysystemd/reader.pyx"
  return __pyx_r;

#line 445 "cysystemd/reader.pyx"
}

#line 445 "cysystemd/reader.pyx"


#line 445 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_21wait(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint32_t __pyx_v_timeout) {

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 445 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 445 "cysystemd/reader.pyx"
  struct __pyx_opt_args_9cysystemd_6reader_13JournalReader_wait __pyx_t_2;

#line 445 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 445 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 445 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("wait", 0);

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 445 "cysystemd/reader.pyx"
  __pyx_t_2.__pyx_n = 1;

#line 445 "cysystemd/reader.pyx"
  __pyx_t_2.timeout = __pyx_v_timeout;

#line 445 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_vtabptr_9cysystemd_6reader_JournalReader->wait(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 445 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 445 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 445 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 445 "cysystemd/reader.pyx"


#line 445 "cysystemd/reader.pyx"
  /* function exit code */

#line 445 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 445 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 445 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.wait", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 445 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 445 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 445 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 445 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 445 "cysystemd/reader.pyx"
  return __pyx_r;

#line 445 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":455
 *         return JournalEvent(check_error_code(result))
 * 
 *     def __iter__(self) -> Iterator[JournalEntry]:             # <<<<<<<<<<<<<<
 *         return iter(self.next, None)
 * 
*/

#line 455 "cysystemd/reader.pyx"


#line 455 "cysystemd/reader.pyx"
/* Python wrapper */

#line 455 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_24__iter__(PyObject *__pyx_v_self); /*proto*/

#line 455 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_24__iter__(PyObject *__pyx_v_self) {

#line 455 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 455 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 455 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 455 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);

#line 455 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 455 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_23__iter__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 455 "cysystemd/reader.pyx"


#line 455 "cysystemd/reader.pyx"
  /* function exit code */

#line 455 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 455 "cysystemd/reader.pyx"
  return __pyx_r;

#line 455 "cysystemd/reader.pyx"
}

#line 455 "cysystemd/reader.pyx"


#line 455 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_23__iter__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 455 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 455 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 455 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 455 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 455 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 455 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 455 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 455 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "cysystemd/reader.pyx":456
 * 
 *     def __iter__(self) -> Iterator[JournalEntry]:
 *         return iter(self.next, None)             # <<<<<<<<<<<<<<
 * 
 *     def next(self, uint64_t skip=0) -> JournalEntry:
*/

#line 456 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 456 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_next); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)

#line 456 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 456 "cysystemd/reader.pyx"
  __pyx_t_2 = PyCallIter_New(__pyx_t_1, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)

#line 456 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 456 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 456 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_2;

#line 456 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

#line 456 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":455
 *         return JournalEvent(check_error_code(result))
 * 
 *     def __iter__(self) -> Iterator[JournalEntry]:             # <<<<<<<<<<<<<<
 *         return iter(self.next, None)
 * 
*/

#line 455 "cysystemd/reader.pyx"


#line 455 "cysystemd/reader.pyx"
  /* function exit code */

#line 455 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 455 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 455 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 455 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 455 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 455 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 455 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 455 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 455 "cysystemd/reader.pyx"
  return __pyx_r;

#line 455 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":458
 *         return iter(self.next, None)
 * 
 *     def next(self, uint64_t skip=0) -> JournalEntry:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 458 "cysystemd/reader.pyx"


#line 458 "cysystemd/reader.pyx"
/* Python wrapper */

#line 458 "cysystemd/reader.pyx"
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pw_9cysystemd_6reader_13JournalReader_26next(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_26next = 
#line 458 "cysystemd/reader.pyx"
{"next", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_26next, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 458 "cysystemd/reader.pyx"
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pw_9cysystemd_6reader_13JournalReader_26next(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  uint64_t __pyx_v_skip
#line 458 "cysystemd/reader.pyx"
;

#line 458 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 458 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 458 "cysystemd/reader.pyx"
  #endif

#line 458 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 458 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 458 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 458 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 458 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 458 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_r = 0;

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("next (wrapper)", 0);

#line 458 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 458 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 458 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 458 "cysystemd/reader.pyx"
  #else

#line 458 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 458 "cysystemd/reader.pyx"
  #endif

#line 458 "cysystemd/reader.pyx"
  #endif

#line 458 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 458 "cysystemd/reader.pyx"
  {

#line 458 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_skip,0};

#line 458 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 458 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 458, __pyx_L3_error)

#line 458 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 458 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 458 "cysystemd/reader.pyx"
        case  1:

#line 458 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 458 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 458, __pyx_L3_error)

#line 458 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 458 "cysystemd/reader.pyx"
break;
        default: 
#line 458 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 458 "cysystemd/reader.pyx"
      }

#line 458 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 458 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "next", 0) < (0)) __PYX_ERR(0, 458, __pyx_L3_error)

#line 458 "cysystemd/reader.pyx"
    } else {

#line 458 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 458 "cysystemd/reader.pyx"
        case  1:

#line 458 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 458 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 458, __pyx_L3_error)

#line 458 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 458 "cysystemd/reader.pyx"
break;
        default: 
#line 458 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 458 "cysystemd/reader.pyx"
      }

#line 458 "cysystemd/reader.pyx"
    }

#line 458 "cysystemd/reader.pyx"
    if (values[0]) {

#line 458 "cysystemd/reader.pyx"
      __pyx_v_skip = __Pyx_PyLong_As_uint64_t(values[0]); if (unlikely((__pyx_v_skip == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 458, __pyx_L3_error)

#line 458 "cysystemd/reader.pyx"
    } else {

#line 458 "cysystemd/reader.pyx"
      __pyx_v_skip = ((uint64_t)0);

#line 458 "cysystemd/reader.pyx"
    }

#line 458 "cysystemd/reader.pyx"
  }

#line 458 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 458 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 458 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("next", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 458, __pyx_L3_error)

#line 458 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 458 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 458 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 458 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 458 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 458 "cysystemd/reader.pyx"
  }

#line 458 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.next", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 458 "cysystemd/reader.pyx"
  return NULL;

#line 458 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 458 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_25next(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_skip);

#line 458 "cysystemd/reader.pyx"


#line 458 "cysystemd/reader.pyx"
  /* function exit code */

#line 458 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 458 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 458 "cysystemd/reader.pyx"
  }

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 458 "cysystemd/reader.pyx"
  return __pyx_r;

#line 458 "cysystemd/reader.pyx"
}

#line 458 "cysystemd/reader.pyx"


#line 458 "cysystemd/reader.pyx"
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pf_9cysystemd_6reader_13JournalReader_25next(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip) {
  int __pyx_v_result
#line 458 "cysystemd/reader.pyx"
;

#line 458 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_r = NULL;

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 458 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 458 "cysystemd/reader.pyx"
  int __pyx_t_10;

#line 458 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 458 "cysystemd/reader.pyx"
  int __pyx_t_12;

#line 458 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_t_13 = NULL;

#line 458 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 458 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 458 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("next", 0);

  /* "cysystemd/reader.pyx":461
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             if skip:
 *                 result = sd_journal_next_skip(self.context, skip)
*/

#line 461 "cysystemd/reader.pyx"
  /*with:*/ {

#line 461 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 461 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 461 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 461 "cysystemd/reader.pyx"
    {

#line 461 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 461 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 461 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 461 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)

#line 461 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 461 "cysystemd/reader.pyx"
    }

#line 461 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L1_error)

#line 461 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 461 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 461 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 461, __pyx_L3_error)

#line 461 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 461 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 461 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 461 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 461 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 461 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 461 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 461 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 461 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 461 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 461 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 461 "cysystemd/reader.pyx"
    }

#line 461 "cysystemd/reader.pyx"
    #endif

#line 461 "cysystemd/reader.pyx"
    {

#line 461 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 461 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 461 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 461 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 461 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 461, __pyx_L3_error)

#line 461 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 461 "cysystemd/reader.pyx"
    }

#line 461 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 461 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 461 "cysystemd/reader.pyx"
    /*try:*/ {

#line 461 "cysystemd/reader.pyx"
      {

#line 461 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_declare

#line 461 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_assign

#line 461 "cysystemd/reader.pyx"
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_7);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_8);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":462
 * 
 *         with self._lock():
 *             if skip:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_next_skip(self.context, skip)
 *             else:
*/

#line 462 "cysystemd/reader.pyx"
          __pyx_t_10 = (__pyx_v_skip != 0);

#line 462 "cysystemd/reader.pyx"
          if (__pyx_t_10) {

            /* "cysystemd/reader.pyx":463
 *         with self._lock():
 *             if skip:
 *                 result = sd_journal_next_skip(self.context, skip)             # <<<<<<<<<<<<<<
 *             else:
 *                 result = sd_journal_next(self.context)
*/

#line 463 "cysystemd/reader.pyx"
            __pyx_v_result = sd_journal_next_skip(__pyx_v_self->context, __pyx_v_skip);

            /* "cysystemd/reader.pyx":462
 * 
 *         with self._lock():
 *             if skip:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_next_skip(self.context, skip)
 *             else:
*/

#line 462 "cysystemd/reader.pyx"
            goto __pyx_L13;

#line 462 "cysystemd/reader.pyx"
          }

          /* "cysystemd/reader.pyx":465
 *                 result = sd_journal_next_skip(self.context, skip)
 *             else:
 *                 result = sd_journal_next(self.context)             # <<<<<<<<<<<<<<
 * 
 *             if check_error_code(result) > 0:
*/

#line 465 "cysystemd/reader.pyx"
          /*else*/ {

#line 465 "cysystemd/reader.pyx"
            __pyx_v_result = sd_journal_next(__pyx_v_self->context);

#line 465 "cysystemd/reader.pyx"
          }

#line 465 "cysystemd/reader.pyx"
          __pyx_L13:;

          /* "cysystemd/reader.pyx":467
 *                 result = sd_journal_next(self.context)
 * 
 *             if check_error_code(result) > 0:             # <<<<<<<<<<<<<<
 *                 return JournalEntry(self)
 * 
*/

#line 467 "cysystemd/reader.pyx"
          __pyx_t_2 = NULL;

#line 467 "cysystemd/reader.pyx"
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 467, __pyx_L7_error)

#line 467 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_6);

#line 467 "cysystemd/reader.pyx"
          __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 467, __pyx_L7_error)

#line 467 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_5);

#line 467 "cysystemd/reader.pyx"
          __pyx_t_3 = 1;

#line 467 "cysystemd/reader.pyx"
          #if CYTHON_UNPACK_METHODS

#line 467 "cysystemd/reader.pyx"
          if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 467 "cysystemd/reader.pyx"
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 467 "cysystemd/reader.pyx"
            assert(__pyx_t_2);

#line 467 "cysystemd/reader.pyx"
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 467 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx_t_2);

#line 467 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx__function);

#line 467 "cysystemd/reader.pyx"
            __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 467 "cysystemd/reader.pyx"
            __pyx_t_3 = 0;

#line 467 "cysystemd/reader.pyx"
          }

#line 467 "cysystemd/reader.pyx"
          #endif

#line 467 "cysystemd/reader.pyx"
          {

#line 467 "cysystemd/reader.pyx"
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};

#line 467 "cysystemd/reader.pyx"
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 467 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 467 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 467 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 467 "cysystemd/reader.pyx"
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 467, __pyx_L7_error)

#line 467 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_1);

#line 467 "cysystemd/reader.pyx"
          }

#line 467 "cysystemd/reader.pyx"
          __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_mstate_global->__pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 467, __pyx_L7_error)

#line 467 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 467 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 467, __pyx_L7_error)

#line 467 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 467 "cysystemd/reader.pyx"
          if (__pyx_t_10) {

            /* "cysystemd/reader.pyx":468
 * 
 *             if check_error_code(result) > 0:
 *                 return JournalEntry(self)             # <<<<<<<<<<<<<<
 * 
 *     def skip_next(self, uint64_t skip) -> int:
*/

#line 468 "cysystemd/reader.pyx"
            __Pyx_XDECREF((PyObject *)__pyx_r);

#line 468 "cysystemd/reader.pyx"
            __pyx_t_1 = NULL;

#line 468 "cysystemd/reader.pyx"
            __pyx_t_3 = 1;

#line 468 "cysystemd/reader.pyx"
            {

#line 468 "cysystemd/reader.pyx"
              PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)__pyx_v_self)};

#line 468 "cysystemd/reader.pyx"
              __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 468 "cysystemd/reader.pyx"
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 468 "cysystemd/reader.pyx"
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 468, __pyx_L7_error)

#line 468 "cysystemd/reader.pyx"
              __Pyx_GOTREF((PyObject *)__pyx_t_6);

#line 468 "cysystemd/reader.pyx"
            }

#line 468 "cysystemd/reader.pyx"
            __pyx_r = ((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_t_6);

#line 468 "cysystemd/reader.pyx"
            __pyx_t_6 = 0;

#line 468 "cysystemd/reader.pyx"
            goto __pyx_L11_try_return;

            /* "cysystemd/reader.pyx":467
 *                 result = sd_journal_next(self.context)
 * 
 *             if check_error_code(result) > 0:             # <<<<<<<<<<<<<<
 *                 return JournalEntry(self)
 * 
*/

#line 467 "cysystemd/reader.pyx"
          }

          /* "cysystemd/reader.pyx":461
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             if skip:
 *                 result = sd_journal_next_skip(self.context, skip)
*/

#line 461 "cysystemd/reader.pyx"
        }

#line 461 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 461 "cysystemd/reader.pyx"
        goto __pyx_L12_try_end;

#line 461 "cysystemd/reader.pyx"
        __pyx_L7_error:;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 461 "cysystemd/reader.pyx"
        /*except:*/ {

#line 461 "cysystemd/reader.pyx"
          __Pyx_AddTraceback("cysystemd.reader.JournalReader.next", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 461 "cysystemd/reader.pyx"
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_5) < 0) __PYX_ERR(0, 461, __pyx_L9_except_error)

#line 461 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_6);

#line 461 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_1);

#line 461 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_5);

#line 461 "cysystemd/reader.pyx"
          __pyx_t_2 = PyTuple_Pack(3, __pyx_t_6, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 461, __pyx_L9_except_error)

#line 461 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 461 "cysystemd/reader.pyx"
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, NULL);

#line 461 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 461 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 461 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 461, __pyx_L9_except_error)

#line 461 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_11);

#line 461 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_11);

#line 461 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

#line 461 "cysystemd/reader.pyx"
          if (__pyx_t_10 < (0)) __PYX_ERR(0, 461, __pyx_L9_except_error)

#line 461 "cysystemd/reader.pyx"
          __pyx_t_12 = (!__pyx_t_10);

#line 461 "cysystemd/reader.pyx"
          if (unlikely(__pyx_t_12)) {

#line 461 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_6);

#line 461 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_1);

#line 461 "cysystemd/reader.pyx"
            __Pyx_XGIVEREF(__pyx_t_5);

#line 461 "cysystemd/reader.pyx"
            __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_1, __pyx_t_5);

#line 461 "cysystemd/reader.pyx"
            __pyx_t_6 = 0;  __pyx_t_1 = 0;  __pyx_t_5 = 0; 

#line 461 "cysystemd/reader.pyx"
            __PYX_ERR(0, 461, __pyx_L9_except_error)

#line 461 "cysystemd/reader.pyx"
          }

#line 461 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 461 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 461 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 461 "cysystemd/reader.pyx"
          goto __pyx_L8_exception_handled;

#line 461 "cysystemd/reader.pyx"
        }

#line 461 "cysystemd/reader.pyx"
        __pyx_L9_except_error:;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        goto __pyx_L1_error;

#line 461 "cysystemd/reader.pyx"
        __pyx_L11_try_return:;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        goto __pyx_L4_return;

#line 461 "cysystemd/reader.pyx"
        __pyx_L8_exception_handled:;

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 461 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 461 "cysystemd/reader.pyx"
        __pyx_L12_try_end:;

#line 461 "cysystemd/reader.pyx"
      }

#line 461 "cysystemd/reader.pyx"
    }

#line 461 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 461 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 461 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 461 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 461 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 461 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 461, __pyx_L1_error)

#line 461 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 461 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 461 "cysystemd/reader.pyx"
        }

#line 461 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 461 "cysystemd/reader.pyx"
      }

#line 461 "cysystemd/reader.pyx"
      __pyx_L4_return: {

#line 461 "cysystemd/reader.pyx"
        __pyx_t_13 = __pyx_r;

#line 461 "cysystemd/reader.pyx"
        __pyx_r = 0;

#line 461 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 461 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 461 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 461 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 461, __pyx_L1_error)

#line 461 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 461 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 461 "cysystemd/reader.pyx"
        }

#line 461 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_13;

#line 461 "cysystemd/reader.pyx"
        __pyx_t_13 = 0;

#line 461 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 461 "cysystemd/reader.pyx"
      }

#line 461 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 461 "cysystemd/reader.pyx"
    }

#line 461 "cysystemd/reader.pyx"
    goto __pyx_L18;

#line 461 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 461 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 461 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 461 "cysystemd/reader.pyx"
    __pyx_L18:;

#line 461 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":458
 *         return iter(self.next, None)
 * 
 *     def next(self, uint64_t skip=0) -> JournalEntry:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 458 "cysystemd/reader.pyx"


#line 458 "cysystemd/reader.pyx"
  /* function exit code */

#line 458 "cysystemd/reader.pyx"
  __pyx_r = ((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)Py_None); __Pyx_INCREF(Py_None);

#line 458 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 458 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 458 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 458 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 458 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 458 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 458 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.next", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 458 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 458 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 458 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF((PyObject *)__pyx_r);

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 458 "cysystemd/reader.pyx"
  return __pyx_r;

#line 458 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":470
 *                 return JournalEntry(self)
 * 
 *     def skip_next(self, uint64_t skip) -> int:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 470 "cysystemd/reader.pyx"


#line 470 "cysystemd/reader.pyx"
/* Python wrapper */

#line 470 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_28skip_next(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_28skip_next = 
#line 470 "cysystemd/reader.pyx"
{"skip_next", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_28skip_next, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 470 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_28skip_next(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  uint64_t __pyx_v_skip
#line 470 "cysystemd/reader.pyx"
;

#line 470 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 470 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 470 "cysystemd/reader.pyx"
  #endif

#line 470 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 470 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 470 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 470 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 470 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 470 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 470 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("skip_next (wrapper)", 0);

#line 470 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 470 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 470 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 470 "cysystemd/reader.pyx"
  #else

#line 470 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 470 "cysystemd/reader.pyx"
  #endif

#line 470 "cysystemd/reader.pyx"
  #endif

#line 470 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 470 "cysystemd/reader.pyx"
  {

#line 470 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_skip,0};

#line 470 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 470 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 470, __pyx_L3_error)

#line 470 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 470 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 470 "cysystemd/reader.pyx"
        case  1:

#line 470 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 470 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 470, __pyx_L3_error)

#line 470 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 470 "cysystemd/reader.pyx"
break;
        default: 
#line 470 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 470 "cysystemd/reader.pyx"
      }

#line 470 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 470 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "skip_next", 0) < (0)) __PYX_ERR(0, 470, __pyx_L3_error)

#line 470 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 470 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("skip_next", 1, 1, 1, i); __PYX_ERR(0, 470, __pyx_L3_error) }

#line 470 "cysystemd/reader.pyx"
      }

#line 470 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 470 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 470 "cysystemd/reader.pyx"
    } else {

#line 470 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 470 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 470, __pyx_L3_error)

#line 470 "cysystemd/reader.pyx"
    }

#line 470 "cysystemd/reader.pyx"
    __pyx_v_skip = __Pyx_PyLong_As_uint64_t(values[0]); if (unlikely((__pyx_v_skip == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 470, __pyx_L3_error)

#line 470 "cysystemd/reader.pyx"
  }

#line 470 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 470 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 470 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("skip_next", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 470, __pyx_L3_error)

#line 470 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 470 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 470 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 470 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 470 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 470 "cysystemd/reader.pyx"
  }

#line 470 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.skip_next", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 470 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 470 "cysystemd/reader.pyx"
  return NULL;

#line 470 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 470 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_27skip_next(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_skip);

#line 470 "cysystemd/reader.pyx"


#line 470 "cysystemd/reader.pyx"
  /* function exit code */

#line 470 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 470 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 470 "cysystemd/reader.pyx"
  }

#line 470 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 470 "cysystemd/reader.pyx"
  return __pyx_r;

#line 470 "cysystemd/reader.pyx"
}

#line 470 "cysystemd/reader.pyx"


#line 470 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_27skip_next(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip) {
  int __pyx_v_result
#line 470 "cysystemd/reader.pyx"
;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 470 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 470 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 470 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 470 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 470 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 470 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 470 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("skip_next", 0);

  /* "cysystemd/reader.pyx":473
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_next_skip(self.context, skip)
 * 
*/

#line 473 "cysystemd/reader.pyx"
  /*with:*/ {

#line 473 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 473 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 473 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 473 "cysystemd/reader.pyx"
    {

#line 473 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 473 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 473 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 473 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)

#line 473 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 473 "cysystemd/reader.pyx"
    }

#line 473 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 473, __pyx_L1_error)

#line 473 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 473 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 473 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 473, __pyx_L3_error)

#line 473 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 473 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 473 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 473 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 473 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 473 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 473 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 473 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 473 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 473 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 473 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 473 "cysystemd/reader.pyx"
    }

#line 473 "cysystemd/reader.pyx"
    #endif

#line 473 "cysystemd/reader.pyx"
    {

#line 473 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 473 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 473 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 473 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 473 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 473, __pyx_L3_error)

#line 473 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 473 "cysystemd/reader.pyx"
    }

#line 473 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 473 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 473 "cysystemd/reader.pyx"
    /*try:*/ {

#line 473 "cysystemd/reader.pyx"
      {

#line 473 "cysystemd/reader.pyx"
        (void)__pyx_t_7; (void)__pyx_t_8; (void)__pyx_t_9; /* mark used */

#line 473 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":474
 * 
 *         with self._lock():
 *             result = sd_journal_next_skip(self.context, skip)             # <<<<<<<<<<<<<<
 * 
 *         return check_error_code(result)
*/

#line 474 "cysystemd/reader.pyx"
          __pyx_v_result = sd_journal_next_skip(__pyx_v_self->context, __pyx_v_skip);

          /* "cysystemd/reader.pyx":473
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_next_skip(self.context, skip)
 * 
*/

#line 473 "cysystemd/reader.pyx"
        }

#line 473 "cysystemd/reader.pyx"
      }

#line 473 "cysystemd/reader.pyx"
    }

#line 473 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 473 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 473 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 473 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 473 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 473 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 473, __pyx_L1_error)

#line 473 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 473 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 473 "cysystemd/reader.pyx"
        }

#line 473 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 473 "cysystemd/reader.pyx"
      }

#line 473 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 473 "cysystemd/reader.pyx"
    }

#line 473 "cysystemd/reader.pyx"
    goto __pyx_L13;

#line 473 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 473 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 473 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 473 "cysystemd/reader.pyx"
    __pyx_L13:;

#line 473 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":476
 *             result = sd_journal_next_skip(self.context, skip)
 * 
 *         return check_error_code(result)             # <<<<<<<<<<<<<<
 * 
 *     def previous(self, uint64_t skip=0) -> JournalEntry:
*/

#line 476 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 476 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 476 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 476, __pyx_L1_error)

#line 476 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 476 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 476, __pyx_L1_error)

#line 476 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 476 "cysystemd/reader.pyx"
  __pyx_t_3 = 1;

#line 476 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 476 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 476 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 476 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 476 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 476 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 476 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 476 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 476 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 476 "cysystemd/reader.pyx"
  }

#line 476 "cysystemd/reader.pyx"
  #endif

#line 476 "cysystemd/reader.pyx"
  {

#line 476 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};

#line 476 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 476 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 476 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 476 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 476 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L1_error)

#line 476 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 476 "cysystemd/reader.pyx"
  }

#line 476 "cysystemd/reader.pyx"
  if (__Pyx_PyInt_FromNumber(&__pyx_t_1, NULL, 1) < (0)) __PYX_ERR(0, 476, __pyx_L1_error)

#line 476 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject*)__pyx_t_1);

#line 476 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 476 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":470
 *                 return JournalEntry(self)
 * 
 *     def skip_next(self, uint64_t skip) -> int:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 470 "cysystemd/reader.pyx"


#line 470 "cysystemd/reader.pyx"
  /* function exit code */

#line 470 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 470 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 470 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 470 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 470 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 470 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.skip_next", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 470 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 470 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 470 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 470 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 470 "cysystemd/reader.pyx"
  return __pyx_r;

#line 470 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":478
 *         return check_error_code(result)
 * 
 *     def previous(self, uint64_t skip=0) -> JournalEntry:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 478 "cysystemd/reader.pyx"


#line 478 "cysystemd/reader.pyx"
/* Python wrapper */

#line 478 "cysystemd/reader.pyx"
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pw_9cysystemd_6reader_13JournalReader_30previous(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_30previous = 
#line 478 "cysystemd/reader.pyx"
{"previous", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_30previous, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 478 "cysystemd/reader.pyx"
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pw_9cysystemd_6reader_13JournalReader_30previous(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  uint64_t __pyx_v_skip
#line 478 "cysystemd/reader.pyx"
;

#line 478 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 478 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 478 "cysystemd/reader.pyx"
  #endif

#line 478 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 478 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 478 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 478 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 478 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 478 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_r = 0;

#line 478 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 478 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("previous (wrapper)", 0);

#line 478 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 478 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 478 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 478 "cysystemd/reader.pyx"
  #else

#line 478 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 478 "cysystemd/reader.pyx"
  #endif

#line 478 "cysystemd/reader.pyx"
  #endif

#line 478 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 478 "cysystemd/reader.pyx"
  {

#line 478 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_skip,0};

#line 478 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 478 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 478, __pyx_L3_error)

#line 478 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 478 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 478 "cysystemd/reader.pyx"
        case  1:

#line 478 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 478 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 478, __pyx_L3_error)

#line 478 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 478 "cysystemd/reader.pyx"
break;
        default: 
#line 478 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 478 "cysystemd/reader.pyx"
      }

#line 478 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 478 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "previous", 0) < (0)) __PYX_ERR(0, 478, __pyx_L3_error)

#line 478 "cysystemd/reader.pyx"
    } else {

#line 478 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 478 "cysystemd/reader.pyx"
        case  1:

#line 478 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 478 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 478, __pyx_L3_error)

#line 478 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 478 "cysystemd/reader.pyx"
break;
        default: 
#line 478 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 478 "cysystemd/reader.pyx"
      }

#line 478 "cysystemd/reader.pyx"
    }

#line 478 "cysystemd/reader.pyx"
    if (values[0]) {

#line 478 "cysystemd/reader.pyx"
      __pyx_v_skip = __Pyx_PyLong_As_uint64_t(values[0]); if (unlikely((__pyx_v_skip == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 478, __pyx_L3_error)

#line 478 "cysystemd/reader.pyx"
    } else {

#line 478 "cysystemd/reader.pyx"
      __pyx_v_skip = ((uint64_t)0);

#line 478 "cysystemd/reader.pyx"
    }

#line 478 "cysystemd/reader.pyx"
  }

#line 478 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 478 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 478 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("previous", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 478, __pyx_L3_error)

#line 478 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 478 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 478 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 478 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 478 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 478 "cysystemd/reader.pyx"
  }

#line 478 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.previous", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 478 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 478 "cysystemd/reader.pyx"
  return NULL;

#line 478 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 478 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_29previous(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_skip);

#line 478 "cysystemd/reader.pyx"


#line 478 "cysystemd/reader.pyx"
  /* function exit code */

#line 478 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 478 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 478 "cysystemd/reader.pyx"
  }

#line 478 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 478 "cysystemd/reader.pyx"
  return __pyx_r;

#line 478 "cysystemd/reader.pyx"
}

#line 478 "cysystemd/reader.pyx"


#line 478 "cysystemd/reader.pyx"
static struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_pf_9cysystemd_6reader_13JournalReader_29previous(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip) {
  int __pyx_v_result
#line 478 "cysystemd/reader.pyx"
;

#line 478 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_r = NULL;

#line 478 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 478 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 478 "cysystemd/reader.pyx"
  int __pyx_t_10;

#line 478 "cysystemd/reader.pyx"
  PyObject *__pyx_t_11 = NULL;

#line 478 "cysystemd/reader.pyx"
  int __pyx_t_12;

#line 478 "cysystemd/reader.pyx"
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *__pyx_t_13 = NULL;

#line 478 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 478 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 478 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 478 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("previous", 0);

  /* "cysystemd/reader.pyx":481
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             if skip:
 *                 result = sd_journal_previous_skip(self.context, skip)
*/

#line 481 "cysystemd/reader.pyx"
  /*with:*/ {

#line 481 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 481 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 481 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 481 "cysystemd/reader.pyx"
    {

#line 481 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 481 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 481 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 481 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 481, __pyx_L1_error)

#line 481 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 481 "cysystemd/reader.pyx"
    }

#line 481 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 481, __pyx_L1_error)

#line 481 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 481 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 481 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 481, __pyx_L3_error)

#line 481 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 481 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 481 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 481 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 481 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 481 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 481 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 481 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 481 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 481 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 481 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 481 "cysystemd/reader.pyx"
    }

#line 481 "cysystemd/reader.pyx"
    #endif

#line 481 "cysystemd/reader.pyx"
    {

#line 481 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 481 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 481 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 481 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 481 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 481, __pyx_L3_error)

#line 481 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 481 "cysystemd/reader.pyx"
    }

#line 481 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 481 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 481 "cysystemd/reader.pyx"
    /*try:*/ {

#line 481 "cysystemd/reader.pyx"
      {

#line 481 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_declare

#line 481 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_assign

#line 481 "cysystemd/reader.pyx"
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_7);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_8);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":482
 * 
 *         with self._lock():
 *             if skip:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_previous_skip(self.context, skip)
 *             else:
*/

#line 482 "cysystemd/reader.pyx"
          __pyx_t_10 = (__pyx_v_skip != 0);

#line 482 "cysystemd/reader.pyx"
          if (__pyx_t_10) {

            /* "cysystemd/reader.pyx":483
 *         with self._lock():
 *             if skip:
 *                 result = sd_journal_previous_skip(self.context, skip)             # <<<<<<<<<<<<<<
 *             else:
 *                 result = sd_journal_previous(self.context)
*/

#line 483 "cysystemd/reader.pyx"
            __pyx_v_result = sd_journal_previous_skip(__pyx_v_self->context, __pyx_v_skip);

            /* "cysystemd/reader.pyx":482
 * 
 *         with self._lock():
 *             if skip:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_previous_skip(self.context, skip)
 *             else:
*/

#line 482 "cysystemd/reader.pyx"
            goto __pyx_L13;

#line 482 "cysystemd/reader.pyx"
          }

          /* "cysystemd/reader.pyx":485
 *                 result = sd_journal_previous_skip(self.context, skip)
 *             else:
 *                 result = sd_journal_previous(self.context)             # <<<<<<<<<<<<<<
 * 
 *             if check_error_code(result) > 0:
*/

#line 485 "cysystemd/reader.pyx"
          /*else*/ {

#line 485 "cysystemd/reader.pyx"
            __pyx_v_result = sd_journal_previous(__pyx_v_self->context);

#line 485 "cysystemd/reader.pyx"
          }

#line 485 "cysystemd/reader.pyx"
          __pyx_L13:;

          /* "cysystemd/reader.pyx":487
 *                 result = sd_journal_previous(self.context)
 * 
 *             if check_error_code(result) > 0:             # <<<<<<<<<<<<<<
 *                 return JournalEntry(self)
 * 
*/

#line 487 "cysystemd/reader.pyx"
          __pyx_t_2 = NULL;

#line 487 "cysystemd/reader.pyx"
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 487, __pyx_L7_error)

#line 487 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_6);

#line 487 "cysystemd/reader.pyx"
          __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 487, __pyx_L7_error)

#line 487 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_5);

#line 487 "cysystemd/reader.pyx"
          __pyx_t_3 = 1;

#line 487 "cysystemd/reader.pyx"
          #if CYTHON_UNPACK_METHODS

#line 487 "cysystemd/reader.pyx"
          if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 487 "cysystemd/reader.pyx"
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 487 "cysystemd/reader.pyx"
            assert(__pyx_t_2);

#line 487 "cysystemd/reader.pyx"
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 487 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx_t_2);

#line 487 "cysystemd/reader.pyx"
            __Pyx_INCREF(__pyx__function);

#line 487 "cysystemd/reader.pyx"
            __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 487 "cysystemd/reader.pyx"
            __pyx_t_3 = 0;

#line 487 "cysystemd/reader.pyx"
          }

#line 487 "cysystemd/reader.pyx"
          #endif

#line 487 "cysystemd/reader.pyx"
          {

#line 487 "cysystemd/reader.pyx"
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};

#line 487 "cysystemd/reader.pyx"
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 487 "cysystemd/reader.pyx"
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 487 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 487 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 487 "cysystemd/reader.pyx"
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 487, __pyx_L7_error)

#line 487 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_1);

#line 487 "cysystemd/reader.pyx"
          }

#line 487 "cysystemd/reader.pyx"
          __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_mstate_global->__pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 487, __pyx_L7_error)

#line 487 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 487 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 487, __pyx_L7_error)

#line 487 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 487 "cysystemd/reader.pyx"
          if (__pyx_t_10) {

            /* "cysystemd/reader.pyx":488
 * 
 *             if check_error_code(result) > 0:
 *                 return JournalEntry(self)             # <<<<<<<<<<<<<<
 * 
 *     def skip_previous(self, uint64_t skip) -> int:
*/

#line 488 "cysystemd/reader.pyx"
            __Pyx_XDECREF((PyObject *)__pyx_r);

#line 488 "cysystemd/reader.pyx"
            __pyx_t_1 = NULL;

#line 488 "cysystemd/reader.pyx"
            __pyx_t_3 = 1;

#line 488 "cysystemd/reader.pyx"
            {

#line 488 "cysystemd/reader.pyx"
              PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)__pyx_v_self)};

#line 488 "cysystemd/reader.pyx"
              __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 488 "cysystemd/reader.pyx"
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 488 "cysystemd/reader.pyx"
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 488, __pyx_L7_error)

#line 488 "cysystemd/reader.pyx"
              __Pyx_GOTREF((PyObject *)__pyx_t_6);

#line 488 "cysystemd/reader.pyx"
            }

#line 488 "cysystemd/reader.pyx"
            __pyx_r = ((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)__pyx_t_6);

#line 488 "cysystemd/reader.pyx"
            __pyx_t_6 = 0;

#line 488 "cysystemd/reader.pyx"
            goto __pyx_L11_try_return;

            /* "cysystemd/reader.pyx":487
 *                 result = sd_journal_previous(self.context)
 * 
 *             if check_error_code(result) > 0:             # <<<<<<<<<<<<<<
 *                 return JournalEntry(self)
 * 
*/

#line 487 "cysystemd/reader.pyx"
          }

          /* "cysystemd/reader.pyx":481
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             if skip:
 *                 result = sd_journal_previous_skip(self.context, skip)
*/

#line 481 "cysystemd/reader.pyx"
        }

#line 481 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 481 "cysystemd/reader.pyx"
        goto __pyx_L12_try_end;

#line 481 "cysystemd/reader.pyx"
        __pyx_L7_error:;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 481 "cysystemd/reader.pyx"
        /*except:*/ {

#line 481 "cysystemd/reader.pyx"
          __Pyx_AddTraceback("cysystemd.reader.JournalReader.previous", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 481 "cysystemd/reader.pyx"
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_5) < 0) __PYX_ERR(0, 481, __pyx_L9_except_error)

#line 481 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_6);

#line 481 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_1);

#line 481 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_5);

#line 481 "cysystemd/reader.pyx"
          __pyx_t_2 = PyTuple_Pack(3, __pyx_t_6, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 481, __pyx_L9_except_error)

#line 481 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_2);

#line 481 "cysystemd/reader.pyx"
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, NULL);

#line 481 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 481 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 481 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 481, __pyx_L9_except_error)

#line 481 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_11);

#line 481 "cysystemd/reader.pyx"
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_11);

#line 481 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

#line 481 "cysystemd/reader.pyx"
          if (__pyx_t_10 < (0)) __PYX_ERR(0, 481, __pyx_L9_except_error)

#line 481 "cysystemd/reader.pyx"
          __pyx_t_12 = (!__pyx_t_10);

#line 481 "cysystemd/reader.pyx"
          if (unlikely(__pyx_t_12)) {

#line 481 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_6);

#line 481 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_1);

#line 481 "cysystemd/reader.pyx"
            __Pyx_XGIVEREF(__pyx_t_5);

#line 481 "cysystemd/reader.pyx"
            __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_1, __pyx_t_5);

#line 481 "cysystemd/reader.pyx"
            __pyx_t_6 = 0;  __pyx_t_1 = 0;  __pyx_t_5 = 0; 

#line 481 "cysystemd/reader.pyx"
            __PYX_ERR(0, 481, __pyx_L9_except_error)

#line 481 "cysystemd/reader.pyx"
          }

#line 481 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 481 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 481 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 481 "cysystemd/reader.pyx"
          goto __pyx_L8_exception_handled;

#line 481 "cysystemd/reader.pyx"
        }

#line 481 "cysystemd/reader.pyx"
        __pyx_L9_except_error:;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        goto __pyx_L1_error;

#line 481 "cysystemd/reader.pyx"
        __pyx_L11_try_return:;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        goto __pyx_L4_return;

#line 481 "cysystemd/reader.pyx"
        __pyx_L8_exception_handled:;

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 481 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 481 "cysystemd/reader.pyx"
        __pyx_L12_try_end:;

#line 481 "cysystemd/reader.pyx"
      }

#line 481 "cysystemd/reader.pyx"
    }

#line 481 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 481 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 481 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 481 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 481 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 481 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 481, __pyx_L1_error)

#line 481 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 481 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 481 "cysystemd/reader.pyx"
        }

#line 481 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 481 "cysystemd/reader.pyx"
      }

#line 481 "cysystemd/reader.pyx"
      __pyx_L4_return: {

#line 481 "cysystemd/reader.pyx"
        __pyx_t_13 = __pyx_r;

#line 481 "cysystemd/reader.pyx"
        __pyx_r = 0;

#line 481 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 481 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 481 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 481 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 481, __pyx_L1_error)

#line 481 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 481 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 481 "cysystemd/reader.pyx"
        }

#line 481 "cysystemd/reader.pyx"
        __pyx_r = __pyx_t_13;

#line 481 "cysystemd/reader.pyx"
        __pyx_t_13 = 0;

#line 481 "cysystemd/reader.pyx"
        goto __pyx_L0;

#line 481 "cysystemd/reader.pyx"
      }

#line 481 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 481 "cysystemd/reader.pyx"
    }

#line 481 "cysystemd/reader.pyx"
    goto __pyx_L18;

#line 481 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 481 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 481 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 481 "cysystemd/reader.pyx"
    __pyx_L18:;

#line 481 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":478
 *         return check_error_code(result)
 * 
 *     def previous(self, uint64_t skip=0) -> JournalEntry:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 478 "cysystemd/reader.pyx"


#line 478 "cysystemd/reader.pyx"
  /* function exit code */

#line 478 "cysystemd/reader.pyx"
  __pyx_r = ((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)Py_None); __Pyx_INCREF(Py_None);

#line 478 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 478 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 478 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 478 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 478 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 478 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 478 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.previous", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 478 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 478 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 478 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF((PyObject *)__pyx_r);

#line 478 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 478 "cysystemd/reader.pyx"
  return __pyx_r;

#line 478 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":490
 *                 return JournalEntry(self)
 * 
 *     def skip_previous(self, uint64_t skip) -> int:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 490 "cysystemd/reader.pyx"


#line 490 "cysystemd/reader.pyx"
/* Python wrapper */

#line 490 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_32skip_previous(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_32skip_previous = 
#line 490 "cysystemd/reader.pyx"
{"skip_previous", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_32skip_previous, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 490 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_32skip_previous(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  uint64_t __pyx_v_skip
#line 490 "cysystemd/reader.pyx"
;

#line 490 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 490 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 490 "cysystemd/reader.pyx"
  #endif

#line 490 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 490 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 490 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 490 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 490 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 490 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 490 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("skip_previous (wrapper)", 0);

#line 490 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 490 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 490 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 490 "cysystemd/reader.pyx"
  #else

#line 490 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 490 "cysystemd/reader.pyx"
  #endif

#line 490 "cysystemd/reader.pyx"
  #endif

#line 490 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 490 "cysystemd/reader.pyx"
  {

#line 490 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_skip,0};

#line 490 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 490 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 490, __pyx_L3_error)

#line 490 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 490 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 490 "cysystemd/reader.pyx"
        case  1:

#line 490 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 490 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 490, __pyx_L3_error)

#line 490 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 490 "cysystemd/reader.pyx"
break;
        default: 
#line 490 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 490 "cysystemd/reader.pyx"
      }

#line 490 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 490 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "skip_previous", 0) < (0)) __PYX_ERR(0, 490, __pyx_L3_error)

#line 490 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 490 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("skip_previous", 1, 1, 1, i); __PYX_ERR(0, 490, __pyx_L3_error) }

#line 490 "cysystemd/reader.pyx"
      }

#line 490 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 490 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 490 "cysystemd/reader.pyx"
    } else {

#line 490 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 490 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 490, __pyx_L3_error)

#line 490 "cysystemd/reader.pyx"
    }

#line 490 "cysystemd/reader.pyx"
    __pyx_v_skip = __Pyx_PyLong_As_uint64_t(values[0]); if (unlikely((__pyx_v_skip == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L3_error)

#line 490 "cysystemd/reader.pyx"
  }

#line 490 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 490 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 490 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("skip_previous", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 490, __pyx_L3_error)

#line 490 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 490 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 490 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 490 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 490 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 490 "cysystemd/reader.pyx"
  }

#line 490 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.skip_previous", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 490 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 490 "cysystemd/reader.pyx"
  return NULL;

#line 490 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 490 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_31skip_previous(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_skip);

#line 490 "cysystemd/reader.pyx"


#line 490 "cysystemd/reader.pyx"
  /* function exit code */

#line 490 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 490 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 490 "cysystemd/reader.pyx"
  }

#line 490 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 490 "cysystemd/reader.pyx"
  return __pyx_r;

#line 490 "cysystemd/reader.pyx"
}

#line 490 "cysystemd/reader.pyx"


#line 490 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_31skip_previous(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, uint64_t __pyx_v_skip) {
  int __pyx_v_result
#line 490 "cysystemd/reader.pyx"
;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 490 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 490 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 490 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 490 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 490 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 490 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 490 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("skip_previous", 0);

  /* "cysystemd/reader.pyx":493
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_previous_skip(self.context, skip)
 * 
*/

#line 493 "cysystemd/reader.pyx"
  /*with:*/ {

#line 493 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 493 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 493 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 493 "cysystemd/reader.pyx"
    {

#line 493 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 493 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 493 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 493 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 493, __pyx_L1_error)

#line 493 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 493 "cysystemd/reader.pyx"
    }

#line 493 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 493, __pyx_L1_error)

#line 493 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 493 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 493 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 493, __pyx_L3_error)

#line 493 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 493 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 493 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 493 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 493 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 493 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 493 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 493 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 493 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 493 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 493 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 493 "cysystemd/reader.pyx"
    }

#line 493 "cysystemd/reader.pyx"
    #endif

#line 493 "cysystemd/reader.pyx"
    {

#line 493 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 493 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 493 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 493 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 493 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 493, __pyx_L3_error)

#line 493 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 493 "cysystemd/reader.pyx"
    }

#line 493 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 493 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 493 "cysystemd/reader.pyx"
    /*try:*/ {

#line 493 "cysystemd/reader.pyx"
      {

#line 493 "cysystemd/reader.pyx"
        (void)__pyx_t_7; (void)__pyx_t_8; (void)__pyx_t_9; /* mark used */

#line 493 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":494
 * 
 *         with self._lock():
 *             result = sd_journal_previous_skip(self.context, skip)             # <<<<<<<<<<<<<<
 * 
 *         return check_error_code(result)
*/

#line 494 "cysystemd/reader.pyx"
          __pyx_v_result = sd_journal_previous_skip(__pyx_v_self->context, __pyx_v_skip);

          /* "cysystemd/reader.pyx":493
 *         cdef int result
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             result = sd_journal_previous_skip(self.context, skip)
 * 
*/

#line 493 "cysystemd/reader.pyx"
        }

#line 493 "cysystemd/reader.pyx"
      }

#line 493 "cysystemd/reader.pyx"
    }

#line 493 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 493 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 493 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 493 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 493 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 493 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 493, __pyx_L1_error)

#line 493 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 493 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 493 "cysystemd/reader.pyx"
        }

#line 493 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 493 "cysystemd/reader.pyx"
      }

#line 493 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 493 "cysystemd/reader.pyx"
    }

#line 493 "cysystemd/reader.pyx"
    goto __pyx_L13;

#line 493 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 493 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 493 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 493 "cysystemd/reader.pyx"
    __pyx_L13:;

#line 493 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":496
 *             result = sd_journal_previous_skip(self.context, skip)
 * 
 *         return check_error_code(result)             # <<<<<<<<<<<<<<
 * 
 *     def add_filter(self, Rule rule) -> None:
*/

#line 496 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 496 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 496 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 496, __pyx_L1_error)

#line 496 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 496 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 496, __pyx_L1_error)

#line 496 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 496 "cysystemd/reader.pyx"
  __pyx_t_3 = 1;

#line 496 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 496 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 496 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);

#line 496 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 496 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 496 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 496 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 496 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 496 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 496 "cysystemd/reader.pyx"
  }

#line 496 "cysystemd/reader.pyx"
  #endif

#line 496 "cysystemd/reader.pyx"
  {

#line 496 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};

#line 496 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 496 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 496 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 496 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 496 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 496, __pyx_L1_error)

#line 496 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 496 "cysystemd/reader.pyx"
  }

#line 496 "cysystemd/reader.pyx"
  if (__Pyx_PyInt_FromNumber(&__pyx_t_1, NULL, 1) < (0)) __PYX_ERR(0, 496, __pyx_L1_error)

#line 496 "cysystemd/reader.pyx"
  __pyx_r = ((PyObject*)__pyx_t_1);

#line 496 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 496 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":490
 *                 return JournalEntry(self)
 * 
 *     def skip_previous(self, uint64_t skip) -> int:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 490 "cysystemd/reader.pyx"


#line 490 "cysystemd/reader.pyx"
  /* function exit code */

#line 490 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 490 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 490 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 490 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 490 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 490 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.skip_previous", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 490 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 490 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 490 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 490 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 490 "cysystemd/reader.pyx"
  return __pyx_r;

#line 490 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":498
 *         return check_error_code(result)
 * 
 *     def add_filter(self, Rule rule) -> None:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* exp
*/

#line 498 "cysystemd/reader.pyx"


#line 498 "cysystemd/reader.pyx"
/* Python wrapper */

#line 498 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_34add_filter(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_34add_filter = 
#line 498 "cysystemd/reader.pyx"
{"add_filter", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_34add_filter, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 498 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_34add_filter(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_rule = 0
#line 498 "cysystemd/reader.pyx"
;

#line 498 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 498 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 498 "cysystemd/reader.pyx"
  #endif

#line 498 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 498 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 498 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 498 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 498 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 498 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 498 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("add_filter (wrapper)", 0);

#line 498 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 498 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 498 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 498 "cysystemd/reader.pyx"
  #else

#line 498 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 498 "cysystemd/reader.pyx"
  #endif

#line 498 "cysystemd/reader.pyx"
  #endif

#line 498 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 498 "cysystemd/reader.pyx"
  {

#line 498 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_rule,0};

#line 498 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 498 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 498, __pyx_L3_error)

#line 498 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 498 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 498 "cysystemd/reader.pyx"
        case  1:

#line 498 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 498 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 498, __pyx_L3_error)

#line 498 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 498 "cysystemd/reader.pyx"
break;
        default: 
#line 498 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 498 "cysystemd/reader.pyx"
      }

#line 498 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 498 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "add_filter", 0) < (0)) __PYX_ERR(0, 498, __pyx_L3_error)

#line 498 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 498 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("add_filter", 1, 1, 1, i); __PYX_ERR(0, 498, __pyx_L3_error) }

#line 498 "cysystemd/reader.pyx"
      }

#line 498 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 498 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 498 "cysystemd/reader.pyx"
    } else {

#line 498 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 498 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 498, __pyx_L3_error)

#line 498 "cysystemd/reader.pyx"
    }

#line 498 "cysystemd/reader.pyx"
    __pyx_v_rule = ((struct __pyx_obj_9cysystemd_6reader_Rule *)values[0]);

#line 498 "cysystemd/reader.pyx"
  }

#line 498 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 498 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 498 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("add_filter", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 498, __pyx_L3_error)

#line 498 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 498 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 498 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 498 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 498 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 498 "cysystemd/reader.pyx"
  }

#line 498 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.add_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 498 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 498 "cysystemd/reader.pyx"
  return NULL;

#line 498 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;

#line 498 "cysystemd/reader.pyx"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_rule), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, 1, "rule", 0))) __PYX_ERR(0, 498, __pyx_L1_error)
  __pyx_r = 
#line 498 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_33add_filter(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_rule);

#line 498 "cysystemd/reader.pyx"


#line 498 "cysystemd/reader.pyx"
  /* function exit code */

#line 498 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 498 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 498 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 498 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 498 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 498 "cysystemd/reader.pyx"
  }

#line 498 "cysystemd/reader.pyx"
  goto __pyx_L7_cleaned_up;

#line 498 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 498 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 498 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 498 "cysystemd/reader.pyx"
  }

#line 498 "cysystemd/reader.pyx"
  __pyx_L7_cleaned_up:;

#line 498 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 498 "cysystemd/reader.pyx"
  return __pyx_r;

#line 498 "cysystemd/reader.pyx"
}

#line 498 "cysystemd/reader.pyx"


#line 498 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_33add_filter(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v_rule) {
  int __pyx_v_result
#line 498 "cysystemd/reader.pyx"
;
  char *__pyx_v_exp
#line 498 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_operand = NULL
#line 498 "cysystemd/reader.pyx"
;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 498 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 498 "cysystemd/reader.pyx"
  size_t __pyx_t_3;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_8 = NULL;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_9 = NULL;

#line 498 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_10;

#line 498 "cysystemd/reader.pyx"
  PyObject *(*__pyx_t_11)(PyObject *);

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_12 = NULL;

#line 498 "cysystemd/reader.pyx"
  PyObject *(*__pyx_t_13)(PyObject *);

#line 498 "cysystemd/reader.pyx"
  char *__pyx_t_14;

#line 498 "cysystemd/reader.pyx"
  int __pyx_t_15;

#line 498 "cysystemd/reader.pyx"
  PyObject *__pyx_t_16 = NULL;

#line 498 "cysystemd/reader.pyx"
  int __pyx_t_17;

#line 498 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 498 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 498 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 498 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("add_filter", 0);

  /* "cysystemd/reader.pyx":502
 *         cdef char* exp
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             for operand, exp in rule:
 *                 result = sd_journal_add_match(self.context, exp, 0)
*/

#line 502 "cysystemd/reader.pyx"
  /*with:*/ {

#line 502 "cysystemd/reader.pyx"
    __pyx_t_2 = ((PyObject *)__pyx_v_self);

#line 502 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 502 "cysystemd/reader.pyx"
    __pyx_t_3 = 0;

#line 502 "cysystemd/reader.pyx"
    {

#line 502 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};

#line 502 "cysystemd/reader.pyx"
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 502 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 502 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)

#line 502 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_1);

#line 502 "cysystemd/reader.pyx"
    }

#line 502 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 502, __pyx_L1_error)

#line 502 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 502 "cysystemd/reader.pyx"
    __pyx_t_5 = NULL;

#line 502 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 502, __pyx_L3_error)

#line 502 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 502 "cysystemd/reader.pyx"
    __pyx_t_3 = 1;

#line 502 "cysystemd/reader.pyx"
    #if CYTHON_UNPACK_METHODS

#line 502 "cysystemd/reader.pyx"
    if (likely(PyMethod_Check(__pyx_t_6))) {

#line 502 "cysystemd/reader.pyx"
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 502 "cysystemd/reader.pyx"
      assert(__pyx_t_5);

#line 502 "cysystemd/reader.pyx"
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 502 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx_t_5);

#line 502 "cysystemd/reader.pyx"
      __Pyx_INCREF(__pyx__function);

#line 502 "cysystemd/reader.pyx"
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 502 "cysystemd/reader.pyx"
      __pyx_t_3 = 0;

#line 502 "cysystemd/reader.pyx"
    }

#line 502 "cysystemd/reader.pyx"
    #endif

#line 502 "cysystemd/reader.pyx"
    {

#line 502 "cysystemd/reader.pyx"
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};

#line 502 "cysystemd/reader.pyx"
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 502 "cysystemd/reader.pyx"
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 502 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 502 "cysystemd/reader.pyx"
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L3_error)

#line 502 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_2);

#line 502 "cysystemd/reader.pyx"
    }

#line 502 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 502 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 502 "cysystemd/reader.pyx"
    /*try:*/ {

#line 502 "cysystemd/reader.pyx"
      {

#line 502 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_declare

#line 502 "cysystemd/reader.pyx"
        __Pyx_PyThreadState_assign

#line 502 "cysystemd/reader.pyx"
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_7);

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_8);

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGOTREF(__pyx_t_9);

#line 502 "cysystemd/reader.pyx"
        /*try:*/ {

          /* "cysystemd/reader.pyx":503
 * 
 *         with self._lock():
 *             for operand, exp in rule:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_add_match(self.context, exp, 0)
 *                 check_error_code(result)
*/

#line 503 "cysystemd/reader.pyx"
          if (likely(PyList_CheckExact(((PyObject *)__pyx_v_rule))) || PyTuple_CheckExact(((PyObject *)__pyx_v_rule))) {

#line 503 "cysystemd/reader.pyx"
            __pyx_t_1 = ((PyObject *)__pyx_v_rule); __Pyx_INCREF(__pyx_t_1);

#line 503 "cysystemd/reader.pyx"
            __pyx_t_10 = 0;

#line 503 "cysystemd/reader.pyx"
            __pyx_t_11 = NULL;

#line 503 "cysystemd/reader.pyx"
          } else {
            __pyx_t_10 = -1; 
#line 503 "cysystemd/reader.pyx"
__pyx_t_1 = PyObject_GetIter(((PyObject *)__pyx_v_rule)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); 
#line 503 "cysystemd/reader.pyx"
if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
          }
          for (;;
#line 503 "cysystemd/reader.pyx"
) {

#line 503 "cysystemd/reader.pyx"
            if (likely(!__pyx_t_11)) {

#line 503 "cysystemd/reader.pyx"
              if (likely(PyList_CheckExact(__pyx_t_1))) {

#line 503 "cysystemd/reader.pyx"
                {

#line 503 "cysystemd/reader.pyx"
                  Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);

#line 503 "cysystemd/reader.pyx"
                  #if !CYTHON_ASSUME_SAFE_SIZE

#line 503 "cysystemd/reader.pyx"
                  if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
                  #endif

#line 503 "cysystemd/reader.pyx"
                  if (__pyx_t_10 >= __pyx_temp) break;

#line 503 "cysystemd/reader.pyx"
                }

#line 503 "cysystemd/reader.pyx"
                __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);

#line 503 "cysystemd/reader.pyx"
                ++__pyx_t_10;

#line 503 "cysystemd/reader.pyx"
              } else {

#line 503 "cysystemd/reader.pyx"
                {

#line 503 "cysystemd/reader.pyx"
                  Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);

#line 503 "cysystemd/reader.pyx"
                  #if !CYTHON_ASSUME_SAFE_SIZE

#line 503 "cysystemd/reader.pyx"
                  if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
                  #endif

#line 503 "cysystemd/reader.pyx"
                  if (__pyx_t_10 >= __pyx_temp) break;

#line 503 "cysystemd/reader.pyx"
                }

#line 503 "cysystemd/reader.pyx"
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS

#line 503 "cysystemd/reader.pyx"
                __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_10));

#line 503 "cysystemd/reader.pyx"
                #else

#line 503 "cysystemd/reader.pyx"
                __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_10);

#line 503 "cysystemd/reader.pyx"
                #endif

#line 503 "cysystemd/reader.pyx"
                ++__pyx_t_10;

#line 503 "cysystemd/reader.pyx"
              }

#line 503 "cysystemd/reader.pyx"
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 503, __pyx_L7_error)
            } else 
#line 503 "cysystemd/reader.pyx"
{

#line 503 "cysystemd/reader.pyx"
              __pyx_t_2 = __pyx_t_11(__pyx_t_1);

#line 503 "cysystemd/reader.pyx"
              if (unlikely(!__pyx_t_2)) {

#line 503 "cysystemd/reader.pyx"
                PyObject* exc_type = PyErr_Occurred();

#line 503 "cysystemd/reader.pyx"
                if (exc_type) {

#line 503 "cysystemd/reader.pyx"
                  if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
                  PyErr_Clear();

#line 503 "cysystemd/reader.pyx"
                }

#line 503 "cysystemd/reader.pyx"
                break;

#line 503 "cysystemd/reader.pyx"
              }

#line 503 "cysystemd/reader.pyx"
            }

#line 503 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_2);

#line 503 "cysystemd/reader.pyx"
            if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {

#line 503 "cysystemd/reader.pyx"
              PyObject* sequence = __pyx_t_2;

#line 503 "cysystemd/reader.pyx"
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);

#line 503 "cysystemd/reader.pyx"
              if (unlikely(size != 2)) {

#line 503 "cysystemd/reader.pyx"
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);

#line 503 "cysystemd/reader.pyx"
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);

#line 503 "cysystemd/reader.pyx"
                __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
              }

#line 503 "cysystemd/reader.pyx"
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS

#line 503 "cysystemd/reader.pyx"
              if (likely(PyTuple_CheckExact(sequence))) {

#line 503 "cysystemd/reader.pyx"
                __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);

#line 503 "cysystemd/reader.pyx"
                __Pyx_INCREF(__pyx_t_6);

#line 503 "cysystemd/reader.pyx"
                __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);

#line 503 "cysystemd/reader.pyx"
                __Pyx_INCREF(__pyx_t_5);

#line 503 "cysystemd/reader.pyx"
              } else {

#line 503 "cysystemd/reader.pyx"
                __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);

#line 503 "cysystemd/reader.pyx"
                if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
                __Pyx_XGOTREF(__pyx_t_6);

#line 503 "cysystemd/reader.pyx"
                __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);

#line 503 "cysystemd/reader.pyx"
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
                __Pyx_XGOTREF(__pyx_t_5);

#line 503 "cysystemd/reader.pyx"
              }

#line 503 "cysystemd/reader.pyx"
              #else

#line 503 "cysystemd/reader.pyx"
              __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_6);

#line 503 "cysystemd/reader.pyx"
              __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_5);

#line 503 "cysystemd/reader.pyx"
              #endif

#line 503 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 503 "cysystemd/reader.pyx"
            } else {

#line 503 "cysystemd/reader.pyx"
              Py_ssize_t index = -1;

#line 503 "cysystemd/reader.pyx"
              __pyx_t_12 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_12);

#line 503 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 503 "cysystemd/reader.pyx"
              __pyx_t_13 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_12);
              index = 0; __pyx_t_6 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_6)) 
#line 503 "cysystemd/reader.pyx"
goto __pyx_L15_unpacking_failed;

#line 503 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_6);
              index = 1; __pyx_t_5 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_5)) 
#line 503 "cysystemd/reader.pyx"
goto __pyx_L15_unpacking_failed;

#line 503 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_5);

#line 503 "cysystemd/reader.pyx"
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_12), 2) < (0)) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
              __pyx_t_13 = NULL;

#line 503 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 503 "cysystemd/reader.pyx"
              goto __pyx_L16_unpacking_done;

#line 503 "cysystemd/reader.pyx"
              __pyx_L15_unpacking_failed:;

#line 503 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 503 "cysystemd/reader.pyx"
              __pyx_t_13 = NULL;

#line 503 "cysystemd/reader.pyx"
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);

#line 503 "cysystemd/reader.pyx"
              __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
              __pyx_L16_unpacking_done:;

#line 503 "cysystemd/reader.pyx"
            }

#line 503 "cysystemd/reader.pyx"
            __pyx_t_14 = __Pyx_PyObject_AsWritableString(__pyx_t_5); if (unlikely((!__pyx_t_14) && PyErr_Occurred())) __PYX_ERR(0, 503, __pyx_L7_error)

#line 503 "cysystemd/reader.pyx"
            __Pyx_XDECREF_SET(__pyx_v_operand, __pyx_t_6);

#line 503 "cysystemd/reader.pyx"
            __pyx_t_6 = 0;

#line 503 "cysystemd/reader.pyx"
            __pyx_v_exp = __pyx_t_14;

#line 503 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "cysystemd/reader.pyx":504
 *         with self._lock():
 *             for operand, exp in rule:
 *                 result = sd_journal_add_match(self.context, exp, 0)             # <<<<<<<<<<<<<<
 *                 check_error_code(result)
 * 
*/

#line 504 "cysystemd/reader.pyx"
            __pyx_v_result = sd_journal_add_match(__pyx_v_self->context, __pyx_v_exp, 0);

            /* "cysystemd/reader.pyx":505
 *             for operand, exp in rule:
 *                 result = sd_journal_add_match(self.context, exp, 0)
 *                 check_error_code(result)             # <<<<<<<<<<<<<<
 * 
 *                 if operand == MatchOperation.OR:
*/

#line 505 "cysystemd/reader.pyx"
            __pyx_t_5 = NULL;

#line 505 "cysystemd/reader.pyx"
            __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 505, __pyx_L7_error)

#line 505 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_6);

#line 505 "cysystemd/reader.pyx"
            __pyx_t_12 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 505, __pyx_L7_error)

#line 505 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_12);

#line 505 "cysystemd/reader.pyx"
            __pyx_t_3 = 1;

#line 505 "cysystemd/reader.pyx"
            #if CYTHON_UNPACK_METHODS

#line 505 "cysystemd/reader.pyx"
            if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 505 "cysystemd/reader.pyx"
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 505 "cysystemd/reader.pyx"
              assert(__pyx_t_5);

#line 505 "cysystemd/reader.pyx"
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 505 "cysystemd/reader.pyx"
              __Pyx_INCREF(__pyx_t_5);

#line 505 "cysystemd/reader.pyx"
              __Pyx_INCREF(__pyx__function);

#line 505 "cysystemd/reader.pyx"
              __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 505 "cysystemd/reader.pyx"
              __pyx_t_3 = 0;

#line 505 "cysystemd/reader.pyx"
            }

#line 505 "cysystemd/reader.pyx"
            #endif

#line 505 "cysystemd/reader.pyx"
            {

#line 505 "cysystemd/reader.pyx"
              PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_12};

#line 505 "cysystemd/reader.pyx"
              __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 505 "cysystemd/reader.pyx"
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 505 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 505 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 505 "cysystemd/reader.pyx"
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 505, __pyx_L7_error)

#line 505 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_2);

#line 505 "cysystemd/reader.pyx"
            }

#line 505 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "cysystemd/reader.pyx":507
 *                 check_error_code(result)
 * 
 *                 if operand == MatchOperation.OR:             # <<<<<<<<<<<<<<
 *                     result = sd_journal_add_disjunction(self.context)
 *                     check_error_code(result)
*/

#line 507 "cysystemd/reader.pyx"
            __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_MatchOperation); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L7_error)

#line 507 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_2);

#line 507 "cysystemd/reader.pyx"
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_OR); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 507, __pyx_L7_error)

#line 507 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_6);

#line 507 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 507 "cysystemd/reader.pyx"
            __pyx_t_2 = PyObject_RichCompare(__pyx_v_operand, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L7_error)

#line 507 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 507 "cysystemd/reader.pyx"
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 507, __pyx_L7_error)

#line 507 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 507 "cysystemd/reader.pyx"
            if (__pyx_t_15) {

              /* "cysystemd/reader.pyx":508
 * 
 *                 if operand == MatchOperation.OR:
 *                     result = sd_journal_add_disjunction(self.context)             # <<<<<<<<<<<<<<
 *                     check_error_code(result)
 * 
*/

#line 508 "cysystemd/reader.pyx"
              __pyx_v_result = sd_journal_add_disjunction(__pyx_v_self->context);

              /* "cysystemd/reader.pyx":509
 *                 if operand == MatchOperation.OR:
 *                     result = sd_journal_add_disjunction(self.context)
 *                     check_error_code(result)             # <<<<<<<<<<<<<<
 * 
 *                 elif operand == MatchOperation.AND:
*/

#line 509 "cysystemd/reader.pyx"
              __pyx_t_6 = NULL;

#line 509 "cysystemd/reader.pyx"
              __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 509, __pyx_L7_error)

#line 509 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_12);

#line 509 "cysystemd/reader.pyx"
              __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 509, __pyx_L7_error)

#line 509 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_5);

#line 509 "cysystemd/reader.pyx"
              __pyx_t_3 = 1;

#line 509 "cysystemd/reader.pyx"
              #if CYTHON_UNPACK_METHODS

#line 509 "cysystemd/reader.pyx"
              if (unlikely(PyMethod_Check(__pyx_t_12))) {

#line 509 "cysystemd/reader.pyx"
                __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_12);

#line 509 "cysystemd/reader.pyx"
                assert(__pyx_t_6);

#line 509 "cysystemd/reader.pyx"
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_12);

#line 509 "cysystemd/reader.pyx"
                __Pyx_INCREF(__pyx_t_6);

#line 509 "cysystemd/reader.pyx"
                __Pyx_INCREF(__pyx__function);

#line 509 "cysystemd/reader.pyx"
                __Pyx_DECREF_SET(__pyx_t_12, __pyx__function);

#line 509 "cysystemd/reader.pyx"
                __pyx_t_3 = 0;

#line 509 "cysystemd/reader.pyx"
              }

#line 509 "cysystemd/reader.pyx"
              #endif

#line 509 "cysystemd/reader.pyx"
              {

#line 509 "cysystemd/reader.pyx"
                PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};

#line 509 "cysystemd/reader.pyx"
                __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_12, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 509 "cysystemd/reader.pyx"
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 509 "cysystemd/reader.pyx"
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 509 "cysystemd/reader.pyx"
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 509 "cysystemd/reader.pyx"
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 509, __pyx_L7_error)

#line 509 "cysystemd/reader.pyx"
                __Pyx_GOTREF(__pyx_t_2);

#line 509 "cysystemd/reader.pyx"
              }

#line 509 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

              /* "cysystemd/reader.pyx":507
 *                 check_error_code(result)
 * 
 *                 if operand == MatchOperation.OR:             # <<<<<<<<<<<<<<
 *                     result = sd_journal_add_disjunction(self.context)
 *                     check_error_code(result)
*/

#line 507 "cysystemd/reader.pyx"
              goto __pyx_L17;

#line 507 "cysystemd/reader.pyx"
            }

            /* "cysystemd/reader.pyx":511
 *                     check_error_code(result)
 * 
 *                 elif operand == MatchOperation.AND:             # <<<<<<<<<<<<<<
 *                     result = sd_journal_add_conjunction(self.context)
 *                     check_error_code(result)
*/

#line 511 "cysystemd/reader.pyx"
            __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_MatchOperation); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L7_error)

#line 511 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_2);

#line 511 "cysystemd/reader.pyx"
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_AND); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 511, __pyx_L7_error)

#line 511 "cysystemd/reader.pyx"
            __Pyx_GOTREF(__pyx_t_12);

#line 511 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 511 "cysystemd/reader.pyx"
            __pyx_t_2 = PyObject_RichCompare(__pyx_v_operand, __pyx_t_12, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L7_error)

#line 511 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 511 "cysystemd/reader.pyx"
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 511, __pyx_L7_error)

#line 511 "cysystemd/reader.pyx"
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 511 "cysystemd/reader.pyx"
            if (likely(__pyx_t_15)) {

              /* "cysystemd/reader.pyx":512
 * 
 *                 elif operand == MatchOperation.AND:
 *                     result = sd_journal_add_conjunction(self.context)             # <<<<<<<<<<<<<<
 *                     check_error_code(result)
 * 
*/

#line 512 "cysystemd/reader.pyx"
              __pyx_v_result = sd_journal_add_conjunction(__pyx_v_self->context);

              /* "cysystemd/reader.pyx":513
 *                 elif operand == MatchOperation.AND:
 *                     result = sd_journal_add_conjunction(self.context)
 *                     check_error_code(result)             # <<<<<<<<<<<<<<
 * 
 *                 else:
*/

#line 513 "cysystemd/reader.pyx"
              __pyx_t_12 = NULL;

#line 513 "cysystemd/reader.pyx"
              __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 513, __pyx_L7_error)

#line 513 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_5);

#line 513 "cysystemd/reader.pyx"
              __pyx_t_6 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 513, __pyx_L7_error)

#line 513 "cysystemd/reader.pyx"
              __Pyx_GOTREF(__pyx_t_6);

#line 513 "cysystemd/reader.pyx"
              __pyx_t_3 = 1;

#line 513 "cysystemd/reader.pyx"
              #if CYTHON_UNPACK_METHODS

#line 513 "cysystemd/reader.pyx"
              if (unlikely(PyMethod_Check(__pyx_t_5))) {

#line 513 "cysystemd/reader.pyx"
                __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);

#line 513 "cysystemd/reader.pyx"
                assert(__pyx_t_12);

#line 513 "cysystemd/reader.pyx"
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);

#line 513 "cysystemd/reader.pyx"
                __Pyx_INCREF(__pyx_t_12);

#line 513 "cysystemd/reader.pyx"
                __Pyx_INCREF(__pyx__function);

#line 513 "cysystemd/reader.pyx"
                __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);

#line 513 "cysystemd/reader.pyx"
                __pyx_t_3 = 0;

#line 513 "cysystemd/reader.pyx"
              }

#line 513 "cysystemd/reader.pyx"
              #endif

#line 513 "cysystemd/reader.pyx"
              {

#line 513 "cysystemd/reader.pyx"
                PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_6};

#line 513 "cysystemd/reader.pyx"
                __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 513 "cysystemd/reader.pyx"
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 513 "cysystemd/reader.pyx"
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 513 "cysystemd/reader.pyx"
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 513 "cysystemd/reader.pyx"
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 513, __pyx_L7_error)

#line 513 "cysystemd/reader.pyx"
                __Pyx_GOTREF(__pyx_t_2);

#line 513 "cysystemd/reader.pyx"
              }

#line 513 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

              /* "cysystemd/reader.pyx":511
 *                     check_error_code(result)
 * 
 *                 elif operand == MatchOperation.AND:             # <<<<<<<<<<<<<<
 *                     result = sd_journal_add_conjunction(self.context)
 *                     check_error_code(result)
*/

#line 511 "cysystemd/reader.pyx"
              goto __pyx_L17;

#line 511 "cysystemd/reader.pyx"
            }

            /* "cysystemd/reader.pyx":516
 * 
 *                 else:
 *                     raise ValueError('Invalid operation')             # <<<<<<<<<<<<<<
 * 
 *     def clear_filter(self) -> None:
*/

#line 516 "cysystemd/reader.pyx"
            /*else*/ {

#line 516 "cysystemd/reader.pyx"
              __pyx_t_5 = NULL;

#line 516 "cysystemd/reader.pyx"
              __pyx_t_3 = 1;

#line 516 "cysystemd/reader.pyx"
              {

#line 516 "cysystemd/reader.pyx"
                PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_Invalid_operation};

#line 516 "cysystemd/reader.pyx"
                __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 516 "cysystemd/reader.pyx"
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 516 "cysystemd/reader.pyx"
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L7_error)

#line 516 "cysystemd/reader.pyx"
                __Pyx_GOTREF(__pyx_t_2);

#line 516 "cysystemd/reader.pyx"
              }

#line 516 "cysystemd/reader.pyx"
              __Pyx_Raise(__pyx_t_2, 0, 0, 0);

#line 516 "cysystemd/reader.pyx"
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 516 "cysystemd/reader.pyx"
              __PYX_ERR(0, 516, __pyx_L7_error)

#line 516 "cysystemd/reader.pyx"
            }

#line 516 "cysystemd/reader.pyx"
            __pyx_L17:;

            /* "cysystemd/reader.pyx":503
 * 
 *         with self._lock():
 *             for operand, exp in rule:             # <<<<<<<<<<<<<<
 *                 result = sd_journal_add_match(self.context, exp, 0)
 *                 check_error_code(result)
*/

#line 503 "cysystemd/reader.pyx"
          }

#line 503 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cysystemd/reader.pyx":502
 *         cdef char* exp
 * 
 *         with self._lock():             # <<<<<<<<<<<<<<
 *             for operand, exp in rule:
 *                 result = sd_journal_add_match(self.context, exp, 0)
*/

#line 502 "cysystemd/reader.pyx"
        }

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 502 "cysystemd/reader.pyx"
        goto __pyx_L12_try_end;

#line 502 "cysystemd/reader.pyx"
        __pyx_L7_error:;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 502 "cysystemd/reader.pyx"
        /*except:*/ {

#line 502 "cysystemd/reader.pyx"
          __Pyx_AddTraceback("cysystemd.reader.JournalReader.add_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 502 "cysystemd/reader.pyx"
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_2, &__pyx_t_5) < 0) __PYX_ERR(0, 502, __pyx_L9_except_error)

#line 502 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_1);

#line 502 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_2);

#line 502 "cysystemd/reader.pyx"
          __Pyx_XGOTREF(__pyx_t_5);

#line 502 "cysystemd/reader.pyx"
          __pyx_t_6 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 502, __pyx_L9_except_error)

#line 502 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_6);

#line 502 "cysystemd/reader.pyx"
          __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL);

#line 502 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 502 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 502 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 502, __pyx_L9_except_error)

#line 502 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_16);

#line 502 "cysystemd/reader.pyx"
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_16);

#line 502 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

#line 502 "cysystemd/reader.pyx"
          if (__pyx_t_15 < (0)) __PYX_ERR(0, 502, __pyx_L9_except_error)

#line 502 "cysystemd/reader.pyx"
          __pyx_t_17 = (!__pyx_t_15);

#line 502 "cysystemd/reader.pyx"
          if (unlikely(__pyx_t_17)) {

#line 502 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_1);

#line 502 "cysystemd/reader.pyx"
            __Pyx_GIVEREF(__pyx_t_2);

#line 502 "cysystemd/reader.pyx"
            __Pyx_XGIVEREF(__pyx_t_5);

#line 502 "cysystemd/reader.pyx"
            __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_2, __pyx_t_5);

#line 502 "cysystemd/reader.pyx"
            __pyx_t_1 = 0;  __pyx_t_2 = 0;  __pyx_t_5 = 0; 

#line 502 "cysystemd/reader.pyx"
            __PYX_ERR(0, 502, __pyx_L9_except_error)

#line 502 "cysystemd/reader.pyx"
          }

#line 502 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 502 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 502 "cysystemd/reader.pyx"
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 502 "cysystemd/reader.pyx"
          goto __pyx_L8_exception_handled;

#line 502 "cysystemd/reader.pyx"
        }

#line 502 "cysystemd/reader.pyx"
        __pyx_L9_except_error:;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 502 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 502 "cysystemd/reader.pyx"
        goto __pyx_L1_error;

#line 502 "cysystemd/reader.pyx"
        __pyx_L8_exception_handled:;

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_7);

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_8);

#line 502 "cysystemd/reader.pyx"
        __Pyx_XGIVEREF(__pyx_t_9);

#line 502 "cysystemd/reader.pyx"
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);

#line 502 "cysystemd/reader.pyx"
        __pyx_L12_try_end:;

#line 502 "cysystemd/reader.pyx"
      }

#line 502 "cysystemd/reader.pyx"
    }

#line 502 "cysystemd/reader.pyx"
    /*finally:*/ {

#line 502 "cysystemd/reader.pyx"
      /*normal exit:*/{

#line 502 "cysystemd/reader.pyx"
        if (__pyx_t_4) {

#line 502 "cysystemd/reader.pyx"
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);

#line 502 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 502 "cysystemd/reader.pyx"
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 502, __pyx_L1_error)

#line 502 "cysystemd/reader.pyx"
          __Pyx_GOTREF(__pyx_t_9);

#line 502 "cysystemd/reader.pyx"
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

#line 502 "cysystemd/reader.pyx"
        }

#line 502 "cysystemd/reader.pyx"
        goto __pyx_L6;

#line 502 "cysystemd/reader.pyx"
      }

#line 502 "cysystemd/reader.pyx"
      __pyx_L6:;

#line 502 "cysystemd/reader.pyx"
    }

#line 502 "cysystemd/reader.pyx"
    goto __pyx_L22;

#line 502 "cysystemd/reader.pyx"
    __pyx_L3_error:;

#line 502 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 502 "cysystemd/reader.pyx"
    goto __pyx_L1_error;

#line 502 "cysystemd/reader.pyx"
    __pyx_L22:;

#line 502 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":498
 *         return check_error_code(result)
 * 
 *     def add_filter(self, Rule rule) -> None:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* exp
*/

#line 498 "cysystemd/reader.pyx"


#line 498 "cysystemd/reader.pyx"
  /* function exit code */

#line 498 "cysystemd/reader.pyx"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 498 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 498 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 498 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 498 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 498 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 498 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 498 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_12);

#line 498 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.add_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 498 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 498 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 498 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_operand);

#line 498 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 498 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 498 "cysystemd/reader.pyx"
  return __pyx_r;

#line 498 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":518
 *                     raise ValueError('Invalid operation')
 * 
 *     def clear_filter(self) -> None:             # <<<<<<<<<<<<<<
 *         sd_journal_flush_matches(self.context)
 * 
*/

#line 518 "cysystemd/reader.pyx"


#line 518 "cysystemd/reader.pyx"
/* Python wrapper */

#line 518 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_36clear_filter(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_36clear_filter = 
#line 518 "cysystemd/reader.pyx"
{"clear_filter", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_36clear_filter, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 518 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_36clear_filter(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 518 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 518 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 518 "cysystemd/reader.pyx"
  #endif

#line 518 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 518 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 518 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 518 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("clear_filter (wrapper)", 0);

#line 518 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 518 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 518 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 518 "cysystemd/reader.pyx"
  #else

#line 518 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 518 "cysystemd/reader.pyx"
  #endif

#line 518 "cysystemd/reader.pyx"
  #endif

#line 518 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 518 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("clear_filter", 1, 0, 0, __pyx_nargs); return NULL; }

#line 518 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 518 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 518 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("clear_filter", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 518 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_35clear_filter(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 518 "cysystemd/reader.pyx"


#line 518 "cysystemd/reader.pyx"
  /* function exit code */

#line 518 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 518 "cysystemd/reader.pyx"
  return __pyx_r;

#line 518 "cysystemd/reader.pyx"
}

#line 518 "cysystemd/reader.pyx"


#line 518 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_35clear_filter(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 518 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 518 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 518 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("clear_filter", 0);

  /* "cysystemd/reader.pyx":519
 * 
 *     def clear_filter(self) -> None:
 *         sd_journal_flush_matches(self.context)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self) -> str:
*/

#line 519 "cysystemd/reader.pyx"
  sd_journal_flush_matches(__pyx_v_self->context);

  /* "cysystemd/reader.pyx":518
 *                     raise ValueError('Invalid operation')
 * 
 *     def clear_filter(self) -> None:             # <<<<<<<<<<<<<<
 *         sd_journal_flush_matches(self.context)
 * 
*/

#line 518 "cysystemd/reader.pyx"


#line 518 "cysystemd/reader.pyx"
  /* function exit code */

#line 518 "cysystemd/reader.pyx"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 518 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 518 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 518 "cysystemd/reader.pyx"
  return __pyx_r;

#line 518 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":521
 *         sd_journal_flush_matches(self.context)
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         return "<Reader[%s]: %s>" % (
 *             self.flags, 'closed' if self.closed else 'opened'
*/

#line 521 "cysystemd/reader.pyx"


#line 521 "cysystemd/reader.pyx"
/* Python wrapper */

#line 521 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_38__repr__(PyObject *__pyx_v_self); /*proto*/

#line 521 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_38__repr__(PyObject *__pyx_v_self) {

#line 521 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 521 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 521 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 521 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);

#line 521 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 521 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_37__repr__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 521 "cysystemd/reader.pyx"


#line 521 "cysystemd/reader.pyx"
  /* function exit code */

#line 521 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 521 "cysystemd/reader.pyx"
  return __pyx_r;

#line 521 "cysystemd/reader.pyx"
}

#line 521 "cysystemd/reader.pyx"


#line 521 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_37__repr__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 521 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 521 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 521 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 521 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 521 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 521 "cysystemd/reader.pyx"
  int __pyx_t_4;

#line 521 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5[5];

#line 521 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 521 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 521 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 521 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "cysystemd/reader.pyx":522
 * 
 *     def __repr__(self) -> str:
 *         return "<Reader[%s]: %s>" % (             # <<<<<<<<<<<<<<
 *             self.flags, 'closed' if self.closed else 'opened'
 *         )
*/

#line 522 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

  /* "cysystemd/reader.pyx":523
 *     def __repr__(self) -> str:
 *         return "<Reader[%s]: %s>" % (
 *             self.flags, 'closed' if self.closed else 'opened'             # <<<<<<<<<<<<<<
 *         )
 * 
*/

#line 523 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_self->flags), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)

#line 523 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 523 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_closed); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 523, __pyx_L1_error)

#line 523 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 523 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 523, __pyx_L1_error)

#line 523 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 523 "cysystemd/reader.pyx"
  if (__pyx_t_4) {

#line 523 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_closed);

#line 523 "cysystemd/reader.pyx"
    __pyx_t_2 = __pyx_mstate_global->__pyx_n_u_closed;

#line 523 "cysystemd/reader.pyx"
  } else {

#line 523 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_opened);

#line 523 "cysystemd/reader.pyx"
    __pyx_t_2 = __pyx_mstate_global->__pyx_n_u_opened;

#line 523 "cysystemd/reader.pyx"
  }

#line 523 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 523, __pyx_L1_error)

#line 523 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 523 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 523 "cysystemd/reader.pyx"
  __pyx_t_5[0] = __pyx_mstate_global->__pyx_kp_u_Reader;

#line 523 "cysystemd/reader.pyx"
  __pyx_t_5[1] = __pyx_t_1;

#line 523 "cysystemd/reader.pyx"
  __pyx_t_5[2] = __pyx_mstate_global->__pyx_kp_u__6;

#line 523 "cysystemd/reader.pyx"
  __pyx_t_5[3] = __pyx_t_3;

#line 523 "cysystemd/reader.pyx"
  __pyx_t_5[4] = __pyx_mstate_global->__pyx_kp_u__7;

  /* "cysystemd/reader.pyx":522
 * 
 *     def __repr__(self) -> str:
 *         return "<Reader[%s]: %s>" % (             # <<<<<<<<<<<<<<
 *             self.flags, 'closed' if self.closed else 'opened'
 *         )
*/

#line 522 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));

#line 522 "cysystemd/reader.pyx"
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)

#line 522 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 522 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 522 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 522 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_2;

#line 522 "cysystemd/reader.pyx"
  __pyx_t_2 = 0;

#line 522 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":521
 *         sd_journal_flush_matches(self.context)
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         return "<Reader[%s]: %s>" % (
 *             self.flags, 'closed' if self.closed else 'opened'
*/

#line 521 "cysystemd/reader.pyx"


#line 521 "cysystemd/reader.pyx"
  /* function exit code */

#line 521 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 521 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 521 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 521 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 521 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 521 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 521 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 521 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 521 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 521 "cysystemd/reader.pyx"
  return __pyx_r;

#line 521 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":526
 *         )
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         sd_journal_close(self.context)
 * 
*/

#line 526 "cysystemd/reader.pyx"


#line 526 "cysystemd/reader.pyx"
/* Python wrapper */

#line 526 "cysystemd/reader.pyx"
static void __pyx_pw_9cysystemd_6reader_13JournalReader_40__dealloc__(PyObject *__pyx_v_self); /*proto*/

#line 526 "cysystemd/reader.pyx"
static void __pyx_pw_9cysystemd_6reader_13JournalReader_40__dealloc__(PyObject *__pyx_v_self) {

#line 526 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 526 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 526 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);

#line 526 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);

#line 526 "cysystemd/reader.pyx"
  __pyx_pf_9cysystemd_6reader_13JournalReader_39__dealloc__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 526 "cysystemd/reader.pyx"


#line 526 "cysystemd/reader.pyx"
  /* function exit code */

#line 526 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 526 "cysystemd/reader.pyx"
}

#line 526 "cysystemd/reader.pyx"


#line 526 "cysystemd/reader.pyx"
static void __pyx_pf_9cysystemd_6reader_13JournalReader_39__dealloc__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

  /* "cysystemd/reader.pyx":527
 * 
 *     def __dealloc__(self):
 *         sd_journal_close(self.context)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 527 "cysystemd/reader.pyx"
  sd_journal_close(__pyx_v_self->context);

  /* "cysystemd/reader.pyx":526
 *         )
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         sd_journal_close(self.context)
 * 
*/

#line 526 "cysystemd/reader.pyx"


#line 526 "cysystemd/reader.pyx"
  /* function exit code */

#line 526 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":529
 *         sd_journal_close(self.context)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def fd(self) -> int:
 *         return check_error_code(sd_journal_get_fd(self.context))
*/

#line 529 "cysystemd/reader.pyx"


#line 529 "cysystemd/reader.pyx"
/* Python wrapper */

#line 529 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_2fd_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 529 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_2fd_1__get__(PyObject *__pyx_v_self) {

#line 529 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 529 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 529 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 529 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 529 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 529 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_2fd___get__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 529 "cysystemd/reader.pyx"


#line 529 "cysystemd/reader.pyx"
  /* function exit code */

#line 529 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 529 "cysystemd/reader.pyx"
  return __pyx_r;

#line 529 "cysystemd/reader.pyx"
}

#line 529 "cysystemd/reader.pyx"


#line 529 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_2fd___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 529 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 529 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 529 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 529 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 529 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 529 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 529 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 529 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 529 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 529 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 529 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":531
 *     @property
 *     def fd(self) -> int:
 *         return check_error_code(sd_journal_get_fd(self.context))             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 531 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 531 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 531 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 531, __pyx_L1_error)

#line 531 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 531 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_int(sd_journal_get_fd(__pyx_v_self->context)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 531, __pyx_L1_error)

#line 531 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 531 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 531 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 531 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 531 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 531 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 531 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 531 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 531 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 531 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 531 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 531 "cysystemd/reader.pyx"
  }

#line 531 "cysystemd/reader.pyx"
  #endif

#line 531 "cysystemd/reader.pyx"
  {

#line 531 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 531 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 531 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 531 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 531 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 531 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L1_error)

#line 531 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 531 "cysystemd/reader.pyx"
  }

#line 531 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 531 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 531 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":529
 *         sd_journal_close(self.context)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def fd(self) -> int:
 *         return check_error_code(sd_journal_get_fd(self.context))
*/

#line 529 "cysystemd/reader.pyx"


#line 529 "cysystemd/reader.pyx"
  /* function exit code */

#line 529 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 529 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 529 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 529 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 529 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 529 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.fd.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 529 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 529 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 529 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 529 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 529 "cysystemd/reader.pyx"
  return __pyx_r;

#line 529 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":533
 *         return check_error_code(sd_journal_get_fd(self.context))
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def events(self) -> Poll:
 *         return Poll(check_error_code(sd_journal_get_events(self.context)))
*/

#line 533 "cysystemd/reader.pyx"


#line 533 "cysystemd/reader.pyx"
/* Python wrapper */

#line 533 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_6events_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 533 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_6events_1__get__(PyObject *__pyx_v_self) {

#line 533 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 533 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 533 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 533 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 533 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_6events___get__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 533 "cysystemd/reader.pyx"


#line 533 "cysystemd/reader.pyx"
  /* function exit code */

#line 533 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 533 "cysystemd/reader.pyx"
  return __pyx_r;

#line 533 "cysystemd/reader.pyx"
}

#line 533 "cysystemd/reader.pyx"


#line 533 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_6events___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 533 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 533 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 533 "cysystemd/reader.pyx"
  size_t __pyx_t_8;

#line 533 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 533 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 533 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 533 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":535
 *     @property
 *     def events(self) -> Poll:
 *         return Poll(check_error_code(sd_journal_get_events(self.context)))             # <<<<<<<<<<<<<<
 * 
 *     @property
*/

#line 535 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 535 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 535 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Poll); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 535, __pyx_L1_error)

#line 535 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 535 "cysystemd/reader.pyx"
  __pyx_t_5 = NULL;

#line 535 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 535, __pyx_L1_error)

#line 535 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 535 "cysystemd/reader.pyx"
  __pyx_t_7 = __Pyx_PyLong_From_int(sd_journal_get_events(__pyx_v_self->context)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 535, __pyx_L1_error)

#line 535 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_7);

#line 535 "cysystemd/reader.pyx"
  __pyx_t_8 = 1;

#line 535 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 535 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 535 "cysystemd/reader.pyx"
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 535 "cysystemd/reader.pyx"
    assert(__pyx_t_5);

#line 535 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 535 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_5);

#line 535 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 535 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 535 "cysystemd/reader.pyx"
    __pyx_t_8 = 0;

#line 535 "cysystemd/reader.pyx"
  }

#line 535 "cysystemd/reader.pyx"
  #endif

#line 535 "cysystemd/reader.pyx"
  {

#line 535 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};

#line 535 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 535 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 535 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 535 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 535 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 535, __pyx_L1_error)

#line 535 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 535 "cysystemd/reader.pyx"
  }

#line 535 "cysystemd/reader.pyx"
  __pyx_t_8 = 1;

#line 535 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 535 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 535 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 535 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 535 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 535 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 535 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 535 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 535 "cysystemd/reader.pyx"
    __pyx_t_8 = 0;

#line 535 "cysystemd/reader.pyx"
  }

#line 535 "cysystemd/reader.pyx"
  #endif

#line 535 "cysystemd/reader.pyx"
  {

#line 535 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 535 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 535 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 535 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 535 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 535 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)

#line 535 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 535 "cysystemd/reader.pyx"
  }

#line 535 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 535 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 535 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":533
 *         return check_error_code(sd_journal_get_fd(self.context))
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def events(self) -> Poll:
 *         return Poll(check_error_code(sd_journal_get_events(self.context)))
*/

#line 533 "cysystemd/reader.pyx"


#line 533 "cysystemd/reader.pyx"
  /* function exit code */

#line 533 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 533 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 533 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 533 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 533 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 533 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 533 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 533 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_7);

#line 533 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.events.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 533 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 533 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 533 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 533 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 533 "cysystemd/reader.pyx"
  return __pyx_r;

#line 533 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":537
 *         return Poll(check_error_code(sd_journal_get_events(self.context)))
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def timeout(self) -> int:
 *         cdef uint64_t timeout
*/

#line 537 "cysystemd/reader.pyx"


#line 537 "cysystemd/reader.pyx"
/* Python wrapper */

#line 537 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_7timeout_1__get__(PyObject *__pyx_v_self); /*proto*/

#line 537 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_7timeout_1__get__(PyObject *__pyx_v_self) {

#line 537 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 537 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 537 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 537 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);

#line 537 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = 
#line 537 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_7timeout___get__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 537 "cysystemd/reader.pyx"


#line 537 "cysystemd/reader.pyx"
  /* function exit code */

#line 537 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 537 "cysystemd/reader.pyx"
  return __pyx_r;

#line 537 "cysystemd/reader.pyx"
}

#line 537 "cysystemd/reader.pyx"


#line 537 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_7timeout___get__(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {
  uint64_t __pyx_v_timeout
#line 537 "cysystemd/reader.pyx"
;

#line 537 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 537 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 537 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 537 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 537 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 537 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 537 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 537 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 537 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 537 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 537 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "cysystemd/reader.pyx":540
 *     def timeout(self) -> int:
 *         cdef uint64_t timeout
 *         check_error_code(sd_journal_get_timeout(self.context, &timeout))             # <<<<<<<<<<<<<<
 *         return timeout
 * 
*/

#line 540 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 540 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 540, __pyx_L1_error)

#line 540 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 540 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_int(sd_journal_get_timeout(__pyx_v_self->context, (&__pyx_v_timeout))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 540, __pyx_L1_error)

#line 540 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 540 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 540 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 540 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 540 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 540 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 540 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 540 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 540 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 540 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 540 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 540 "cysystemd/reader.pyx"
  }

#line 540 "cysystemd/reader.pyx"
  #endif

#line 540 "cysystemd/reader.pyx"
  {

#line 540 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 540 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 540 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 540 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 540 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 540 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)

#line 540 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 540 "cysystemd/reader.pyx"
  }

#line 540 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":541
 *         cdef uint64_t timeout
 *         check_error_code(sd_journal_get_timeout(self.context, &timeout))
 *         return timeout             # <<<<<<<<<<<<<<
 * 
 *     def process_events(self) -> JournalEvent:
*/

#line 541 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 541 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyLong_From_uint64_t(__pyx_v_timeout); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)

#line 541 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 541 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 541 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 541 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":537
 *         return Poll(check_error_code(sd_journal_get_events(self.context)))
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def timeout(self) -> int:
 *         cdef uint64_t timeout
*/

#line 537 "cysystemd/reader.pyx"


#line 537 "cysystemd/reader.pyx"
  /* function exit code */

#line 537 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 537 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 537 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 537 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 537 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 537 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.timeout.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 537 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 537 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 537 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 537 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 537 "cysystemd/reader.pyx"
  return __pyx_r;

#line 537 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":543
 *         return timeout
 * 
 *     def process_events(self) -> JournalEvent:             # <<<<<<<<<<<<<<
 *         return JournalEvent(check_error_code(sd_journal_process(self.context)))
 * 
*/

#line 543 "cysystemd/reader.pyx"


#line 543 "cysystemd/reader.pyx"
/* Python wrapper */

#line 543 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_42process_events(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_42process_events = 
#line 543 "cysystemd/reader.pyx"
{"process_events", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_42process_events, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 543 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_42process_events(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 543 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 543 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 543 "cysystemd/reader.pyx"
  #endif

#line 543 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 543 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 543 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("process_events (wrapper)", 0);

#line 543 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 543 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 543 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 543 "cysystemd/reader.pyx"
  #else

#line 543 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 543 "cysystemd/reader.pyx"
  #endif

#line 543 "cysystemd/reader.pyx"
  #endif

#line 543 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 543 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("process_events", 1, 0, 0, __pyx_nargs); return NULL; }

#line 543 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 543 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 543 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("process_events", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 543 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_41process_events(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 543 "cysystemd/reader.pyx"


#line 543 "cysystemd/reader.pyx"
  /* function exit code */

#line 543 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 543 "cysystemd/reader.pyx"
  return __pyx_r;

#line 543 "cysystemd/reader.pyx"
}

#line 543 "cysystemd/reader.pyx"


#line 543 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_41process_events(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 543 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_t_6 = NULL;

#line 543 "cysystemd/reader.pyx"
  PyObject *__pyx_t_7 = NULL;

#line 543 "cysystemd/reader.pyx"
  size_t __pyx_t_8;

#line 543 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 543 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 543 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 543 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("process_events", 0);

  /* "cysystemd/reader.pyx":544
 * 
 *     def process_events(self) -> JournalEvent:
 *         return JournalEvent(check_error_code(sd_journal_process(self.context)))             # <<<<<<<<<<<<<<
 * 
 *     def get_catalog(self) -> Path:
*/

#line 544 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 544 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 544 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_JournalEvent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 544, __pyx_L1_error)

#line 544 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 544 "cysystemd/reader.pyx"
  __pyx_t_5 = NULL;

#line 544 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 544, __pyx_L1_error)

#line 544 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 544 "cysystemd/reader.pyx"
  __pyx_t_7 = __Pyx_PyLong_From_int(sd_journal_process(__pyx_v_self->context)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 544, __pyx_L1_error)

#line 544 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_7);

#line 544 "cysystemd/reader.pyx"
  __pyx_t_8 = 1;

#line 544 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 544 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_6))) {

#line 544 "cysystemd/reader.pyx"
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);

#line 544 "cysystemd/reader.pyx"
    assert(__pyx_t_5);

#line 544 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);

#line 544 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_5);

#line 544 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 544 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);

#line 544 "cysystemd/reader.pyx"
    __pyx_t_8 = 0;

#line 544 "cysystemd/reader.pyx"
  }

#line 544 "cysystemd/reader.pyx"
  #endif

#line 544 "cysystemd/reader.pyx"
  {

#line 544 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};

#line 544 "cysystemd/reader.pyx"
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 544 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 544 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

#line 544 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 544 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 544, __pyx_L1_error)

#line 544 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_4);

#line 544 "cysystemd/reader.pyx"
  }

#line 544 "cysystemd/reader.pyx"
  __pyx_t_8 = 1;

#line 544 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 544 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 544 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 544 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 544 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 544 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 544 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 544 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 544 "cysystemd/reader.pyx"
    __pyx_t_8 = 0;

#line 544 "cysystemd/reader.pyx"
  }

#line 544 "cysystemd/reader.pyx"
  #endif

#line 544 "cysystemd/reader.pyx"
  {

#line 544 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 544 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 544 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 544 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 544 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 544 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 544, __pyx_L1_error)

#line 544 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 544 "cysystemd/reader.pyx"
  }

#line 544 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 544 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 544 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":543
 *         return timeout
 * 
 *     def process_events(self) -> JournalEvent:             # <<<<<<<<<<<<<<
 *         return JournalEvent(check_error_code(sd_journal_process(self.context)))
 * 
*/

#line 543 "cysystemd/reader.pyx"


#line 543 "cysystemd/reader.pyx"
  /* function exit code */

#line 543 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 543 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 543 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 543 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 543 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 543 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 543 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 543 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_7);

#line 543 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.process_events", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 543 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 543 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 543 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 543 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 543 "cysystemd/reader.pyx"
  return __pyx_r;

#line 543 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":546
 *         return JournalEvent(check_error_code(sd_journal_process(self.context)))
 * 
 *     def get_catalog(self) -> Path:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* catalog
*/

#line 546 "cysystemd/reader.pyx"


#line 546 "cysystemd/reader.pyx"
/* Python wrapper */

#line 546 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_44get_catalog(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_44get_catalog = 
#line 546 "cysystemd/reader.pyx"
{"get_catalog", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_44get_catalog, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 546 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_44get_catalog(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 546 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 546 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 546 "cysystemd/reader.pyx"
  #endif

#line 546 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 546 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 546 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 546 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_catalog (wrapper)", 0);

#line 546 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 546 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 546 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 546 "cysystemd/reader.pyx"
  #else

#line 546 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 546 "cysystemd/reader.pyx"
  #endif

#line 546 "cysystemd/reader.pyx"
  #endif

#line 546 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 546 "cysystemd/reader.pyx"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("get_catalog", 1, 0, 0, __pyx_nargs); return NULL; }

#line 546 "cysystemd/reader.pyx"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 546 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 546 "cysystemd/reader.pyx"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("get_catalog", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 546 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_43get_catalog(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 546 "cysystemd/reader.pyx"


#line 546 "cysystemd/reader.pyx"
  /* function exit code */

#line 546 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 546 "cysystemd/reader.pyx"
  return __pyx_r;

#line 546 "cysystemd/reader.pyx"
}

#line 546 "cysystemd/reader.pyx"


#line 546 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_43get_catalog(struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {
  int __pyx_v_result
#line 546 "cysystemd/reader.pyx"
;
  char *__pyx_v_catalog
#line 546 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_bcatalog = 0
#line 546 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_length = NULL
#line 546 "cysystemd/reader.pyx"
;

#line 546 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 546 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 546 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 546 "cysystemd/reader.pyx"
  PyObject *__pyx_t_2 = NULL;

#line 546 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 546 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 546 "cysystemd/reader.pyx"
  size_t __pyx_t_5;

#line 546 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_6;

#line 546 "cysystemd/reader.pyx"
  int __pyx_t_7;

#line 546 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_8;

#line 546 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 546 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 546 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 546 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_catalog", 0);

  /* "cysystemd/reader.pyx":551
 *         cdef bytes bcatalog
 * 
 *         result = sd_journal_get_catalog(self.context, &catalog)             # <<<<<<<<<<<<<<
 * 
 *         length = check_error_code(result)
*/

#line 551 "cysystemd/reader.pyx"
  __pyx_v_result = sd_journal_get_catalog(__pyx_v_self->context, (&__pyx_v_catalog));

  /* "cysystemd/reader.pyx":553
 *         result = sd_journal_get_catalog(self.context, &catalog)
 * 
 *         length = check_error_code(result)             # <<<<<<<<<<<<<<
 *         bcatalog = catalog[:length]
 *         PyMem_Free(catalog)
*/

#line 553 "cysystemd/reader.pyx"
  __pyx_t_2 = NULL;

#line 553 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 553, __pyx_L1_error)

#line 553 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 553 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 553, __pyx_L1_error)

#line 553 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 553 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 553 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 553 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_3))) {

#line 553 "cysystemd/reader.pyx"
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);

#line 553 "cysystemd/reader.pyx"
    assert(__pyx_t_2);

#line 553 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);

#line 553 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_2);

#line 553 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 553 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);

#line 553 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 553 "cysystemd/reader.pyx"
  }

#line 553 "cysystemd/reader.pyx"
  #endif

#line 553 "cysystemd/reader.pyx"
  {

#line 553 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};

#line 553 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 553 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 553 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 553 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 553 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 553, __pyx_L1_error)

#line 553 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 553 "cysystemd/reader.pyx"
  }

#line 553 "cysystemd/reader.pyx"
  __pyx_v_length = __pyx_t_1;

#line 553 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":554
 * 
 *         length = check_error_code(result)
 *         bcatalog = catalog[:length]             # <<<<<<<<<<<<<<
 *         PyMem_Free(catalog)
 * 
*/

#line 554 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_length);

#line 554 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_v_length;

#line 554 "cysystemd/reader.pyx"
  __pyx_t_7 = (__pyx_t_1 == Py_None);

#line 554 "cysystemd/reader.pyx"
  if (__pyx_t_7) {

#line 554 "cysystemd/reader.pyx"
    __pyx_t_6 = PY_SSIZE_T_MAX;

#line 554 "cysystemd/reader.pyx"
  } else {

#line 554 "cysystemd/reader.pyx"
    __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_t_1); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 554, __pyx_L1_error)

#line 554 "cysystemd/reader.pyx"
    __pyx_t_6 = __pyx_t_8;

#line 554 "cysystemd/reader.pyx"
  }

#line 554 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 554 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_catalog + 0, __pyx_t_6 - 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 554, __pyx_L1_error)

#line 554 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 554 "cysystemd/reader.pyx"
  __pyx_v_bcatalog = ((PyObject*)__pyx_t_1);

#line 554 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":555
 *         length = check_error_code(result)
 *         bcatalog = catalog[:length]
 *         PyMem_Free(catalog)             # <<<<<<<<<<<<<<
 * 
 *         return Path(bcatalog.decode())
*/

#line 555 "cysystemd/reader.pyx"
  PyMem_Free(__pyx_v_catalog);

  /* "cysystemd/reader.pyx":557
 *         PyMem_Free(catalog)
 * 
 *         return Path(bcatalog.decode())             # <<<<<<<<<<<<<<
 * 
 *     def get_catalog_for_message_id(self, message_id: UUID) -> Path:
*/

#line 557 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 557 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 557 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 557, __pyx_L1_error)

#line 557 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 557 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_decode_bytes(__pyx_v_bcatalog, 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 557, __pyx_L1_error)

#line 557 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 557 "cysystemd/reader.pyx"
  __pyx_t_5 = 1;

#line 557 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 557 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 557 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 557 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 557 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 557 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 557 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 557 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 557 "cysystemd/reader.pyx"
    __pyx_t_5 = 0;

#line 557 "cysystemd/reader.pyx"
  }

#line 557 "cysystemd/reader.pyx"
  #endif

#line 557 "cysystemd/reader.pyx"
  {

#line 557 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};

#line 557 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 557 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 557 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 557 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 557 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)

#line 557 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 557 "cysystemd/reader.pyx"
  }

#line 557 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 557 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 557 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":546
 *         return JournalEvent(check_error_code(sd_journal_process(self.context)))
 * 
 *     def get_catalog(self) -> Path:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* catalog
*/

#line 546 "cysystemd/reader.pyx"


#line 546 "cysystemd/reader.pyx"
  /* function exit code */

#line 546 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 546 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 546 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 546 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 546 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 546 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.get_catalog", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 546 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 546 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 546 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_bcatalog);

#line 546 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_length);

#line 546 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 546 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 546 "cysystemd/reader.pyx"
  return __pyx_r;

#line 546 "cysystemd/reader.pyx"
}

/* "cysystemd/reader.pyx":559
 *         return Path(bcatalog.decode())
 * 
 *     def get_catalog_for_message_id(self, message_id: UUID) -> Path:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* catalog
*/

#line 559 "cysystemd/reader.pyx"


#line 559 "cysystemd/reader.pyx"
/* Python wrapper */

#line 559 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_46get_catalog_for_message_id(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_46get_catalog_for_message_id = 
#line 559 "cysystemd/reader.pyx"
{"get_catalog_for_message_id", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_46get_catalog_for_message_id, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 559 "cysystemd/reader.pyx"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_46get_catalog_for_message_id(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_message_id = 0
#line 559 "cysystemd/reader.pyx"
;

#line 559 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 559 "cysystemd/reader.pyx"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 559 "cysystemd/reader.pyx"
  #endif

#line 559 "cysystemd/reader.pyx"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 559 "cysystemd/reader.pyx"
  PyObject* values[1] = {0};

#line 559 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 559 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 559 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 559 "cysystemd/reader.pyx"
  PyObject *__pyx_r = 0;

#line 559 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 559 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_catalog_for_message_id (wrapper)", 0);

#line 559 "cysystemd/reader.pyx"
  #if !CYTHON_METH_FASTCALL

#line 559 "cysystemd/reader.pyx"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 559 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 559 "cysystemd/reader.pyx"
  #else

#line 559 "cysystemd/reader.pyx"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 559 "cysystemd/reader.pyx"
  #endif

#line 559 "cysystemd/reader.pyx"
  #endif

#line 559 "cysystemd/reader.pyx"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 559 "cysystemd/reader.pyx"
  {

#line 559 "cysystemd/reader.pyx"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_message_id,0};

#line 559 "cysystemd/reader.pyx"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 559 "cysystemd/reader.pyx"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 559, __pyx_L3_error)

#line 559 "cysystemd/reader.pyx"
    if (__pyx_kwds_len > 0) {

#line 559 "cysystemd/reader.pyx"
      switch (__pyx_nargs) {

#line 559 "cysystemd/reader.pyx"
        case  1:

#line 559 "cysystemd/reader.pyx"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 559 "cysystemd/reader.pyx"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 559, __pyx_L3_error)

#line 559 "cysystemd/reader.pyx"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 559 "cysystemd/reader.pyx"
break;
        default: 
#line 559 "cysystemd/reader.pyx"
goto __pyx_L5_argtuple_error;

#line 559 "cysystemd/reader.pyx"
      }

#line 559 "cysystemd/reader.pyx"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 559 "cysystemd/reader.pyx"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_catalog_for_message_id", 0) < (0)) __PYX_ERR(0, 559, __pyx_L3_error)

#line 559 "cysystemd/reader.pyx"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 559 "cysystemd/reader.pyx"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_catalog_for_message_id", 1, 1, 1, i); __PYX_ERR(0, 559, __pyx_L3_error) }

#line 559 "cysystemd/reader.pyx"
      }

#line 559 "cysystemd/reader.pyx"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 559 "cysystemd/reader.pyx"
      goto __pyx_L5_argtuple_error;

#line 559 "cysystemd/reader.pyx"
    } else {

#line 559 "cysystemd/reader.pyx"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 559 "cysystemd/reader.pyx"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 559, __pyx_L3_error)

#line 559 "cysystemd/reader.pyx"
    }

#line 559 "cysystemd/reader.pyx"
    __pyx_v_message_id = values[0];

#line 559 "cysystemd/reader.pyx"
  }

#line 559 "cysystemd/reader.pyx"
  goto __pyx_L6_skip;

#line 559 "cysystemd/reader.pyx"
  __pyx_L5_argtuple_error:;

#line 559 "cysystemd/reader.pyx"
  __Pyx_RaiseArgtupleInvalid("get_catalog_for_message_id", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 559, __pyx_L3_error)

#line 559 "cysystemd/reader.pyx"
  __pyx_L6_skip:;

#line 559 "cysystemd/reader.pyx"
  goto __pyx_L4_argument_unpacking_done;

#line 559 "cysystemd/reader.pyx"
  __pyx_L3_error:;

#line 559 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 559 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 559 "cysystemd/reader.pyx"
  }

#line 559 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.get_catalog_for_message_id", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 559 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 559 "cysystemd/reader.pyx"
  return NULL;

#line 559 "cysystemd/reader.pyx"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 559 "cysystemd/reader.pyx"
__pyx_pf_9cysystemd_6reader_13JournalReader_45get_catalog_for_message_id(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v_message_id);

#line 559 "cysystemd/reader.pyx"


#line 559 "cysystemd/reader.pyx"
  /* function exit code */

#line 559 "cysystemd/reader.pyx"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 559 "cysystemd/reader.pyx"
    Py_XDECREF(values[__pyx_temp]);

#line 559 "cysystemd/reader.pyx"
  }

#line 559 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 559 "cysystemd/reader.pyx"
  return __pyx_r;

#line 559 "cysystemd/reader.pyx"
}

#line 559 "cysystemd/reader.pyx"


#line 559 "cysystemd/reader.pyx"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_45get_catalog_for_message_id(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, PyObject *__pyx_v_message_id) {
  int __pyx_v_result
#line 559 "cysystemd/reader.pyx"
;
  char *__pyx_v_catalog
#line 559 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_bcatalog = 0
#line 559 "cysystemd/reader.pyx"
;
  sd_id128_t __pyx_v_id128
#line 559 "cysystemd/reader.pyx"
;
  PyObject *__pyx_v_length = NULL
#line 559 "cysystemd/reader.pyx"
;

#line 559 "cysystemd/reader.pyx"
  PyObject *__pyx_r = NULL;

#line 559 "cysystemd/reader.pyx"
  __Pyx_RefNannyDeclarations

#line 559 "cysystemd/reader.pyx"
  PyObject *__pyx_t_1 = NULL;

#line 559 "cysystemd/reader.pyx"
  uint8_t __pyx_t_2[16];

#line 559 "cysystemd/reader.pyx"
  PyObject *__pyx_t_3 = NULL;

#line 559 "cysystemd/reader.pyx"
  PyObject *__pyx_t_4 = NULL;

#line 559 "cysystemd/reader.pyx"
  PyObject *__pyx_t_5 = NULL;

#line 559 "cysystemd/reader.pyx"
  size_t __pyx_t_6;

#line 559 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_7;

#line 559 "cysystemd/reader.pyx"
  int __pyx_t_8;

#line 559 "cysystemd/reader.pyx"
  Py_ssize_t __pyx_t_9;

#line 559 "cysystemd/reader.pyx"
  int __pyx_lineno = 0;

#line 559 "cysystemd/reader.pyx"
  const char *__pyx_filename = NULL;

#line 559 "cysystemd/reader.pyx"
  int __pyx_clineno = 0;

#line 559 "cysystemd/reader.pyx"
  __Pyx_RefNannySetupContext("get_catalog_for_message_id", 0);

  /* "cysystemd/reader.pyx":565
 *         cdef sd_id128_t id128
 * 
 *         id128.bytes = message_id.bytes             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
*/

#line 565 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_message_id, __pyx_mstate_global->__pyx_n_u_bytes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)

#line 565 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 565 "cysystemd/reader.pyx"
  if (unlikely((__Pyx_carray_from_py_uint8_t(__pyx_t_1, __pyx_t_2, 16) < 0))) __PYX_ERR(0, 565, __pyx_L1_error)

#line 565 "cysystemd/reader.pyx"
  memcpy(&(__pyx_v_id128.bytes[0]), __pyx_t_2, sizeof(__pyx_v_id128.bytes[0]) * (16));

#line 565 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":567
 *         id128.bytes = message_id.bytes
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = sd_journal_get_catalog_for_message_id(id128, &catalog)
 * 
*/

#line 567 "cysystemd/reader.pyx"
  {

#line 567 "cysystemd/reader.pyx"
      PyThreadState * _save;

#line 567 "cysystemd/reader.pyx"
      _save = PyEval_SaveThread();

#line 567 "cysystemd/reader.pyx"
      __Pyx_FastGIL_Remember();

#line 567 "cysystemd/reader.pyx"
      /*try:*/ {

        /* "cysystemd/reader.pyx":568
 * 
 *         with nogil:
 *             result = sd_journal_get_catalog_for_message_id(id128, &catalog)             # <<<<<<<<<<<<<<
 * 
 *         length = check_error_code(result)
*/

#line 568 "cysystemd/reader.pyx"
        __pyx_v_result = sd_journal_get_catalog_for_message_id(__pyx_v_id128, (&__pyx_v_catalog));

#line 568 "cysystemd/reader.pyx"
      }

      /* "cysystemd/reader.pyx":567
 *         id128.bytes = message_id.bytes
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             result = sd_journal_get_catalog_for_message_id(id128, &catalog)
 * 
*/

#line 567 "cysystemd/reader.pyx"
      /*finally:*/ {

#line 567 "cysystemd/reader.pyx"
        /*normal exit:*/{

#line 567 "cysystemd/reader.pyx"
          __Pyx_FastGIL_Forget();

#line 567 "cysystemd/reader.pyx"
          PyEval_RestoreThread(_save);

#line 567 "cysystemd/reader.pyx"
          goto __pyx_L5;

#line 567 "cysystemd/reader.pyx"
        }

#line 567 "cysystemd/reader.pyx"
        __pyx_L5:;

#line 567 "cysystemd/reader.pyx"
      }

#line 567 "cysystemd/reader.pyx"
  }

  /* "cysystemd/reader.pyx":570
 *             result = sd_journal_get_catalog_for_message_id(id128, &catalog)
 * 
 *         length = check_error_code(result)             # <<<<<<<<<<<<<<
 *         bcatalog = catalog[:length]
 *         PyMem_Free(catalog)
*/

#line 570 "cysystemd/reader.pyx"
  __pyx_t_3 = NULL;

#line 570 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_check_error_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 570, __pyx_L1_error)

#line 570 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 570 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 570, __pyx_L1_error)

#line 570 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 570 "cysystemd/reader.pyx"
  __pyx_t_6 = 1;

#line 570 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 570 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_4))) {

#line 570 "cysystemd/reader.pyx"
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);

#line 570 "cysystemd/reader.pyx"
    assert(__pyx_t_3);

#line 570 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);

#line 570 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_3);

#line 570 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 570 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);

#line 570 "cysystemd/reader.pyx"
    __pyx_t_6 = 0;

#line 570 "cysystemd/reader.pyx"
  }

#line 570 "cysystemd/reader.pyx"
  #endif

#line 570 "cysystemd/reader.pyx"
  {

#line 570 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};

#line 570 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 570 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 570 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 570 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 570 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)

#line 570 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 570 "cysystemd/reader.pyx"
  }

#line 570 "cysystemd/reader.pyx"
  __pyx_v_length = __pyx_t_1;

#line 570 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":571
 * 
 *         length = check_error_code(result)
 *         bcatalog = catalog[:length]             # <<<<<<<<<<<<<<
 *         PyMem_Free(catalog)
 * 
*/

#line 571 "cysystemd/reader.pyx"
  __Pyx_INCREF(__pyx_v_length);

#line 571 "cysystemd/reader.pyx"
  __pyx_t_1 = __pyx_v_length;

#line 571 "cysystemd/reader.pyx"
  __pyx_t_8 = (__pyx_t_1 == Py_None);

#line 571 "cysystemd/reader.pyx"
  if (__pyx_t_8) {

#line 571 "cysystemd/reader.pyx"
    __pyx_t_7 = PY_SSIZE_T_MAX;

#line 571 "cysystemd/reader.pyx"
  } else {

#line 571 "cysystemd/reader.pyx"
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_1); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 571, __pyx_L1_error)

#line 571 "cysystemd/reader.pyx"
    __pyx_t_7 = __pyx_t_9;

#line 571 "cysystemd/reader.pyx"
  }

#line 571 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

#line 571 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_catalog + 0, __pyx_t_7 - 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 571, __pyx_L1_error)

#line 571 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_1);

#line 571 "cysystemd/reader.pyx"
  __pyx_v_bcatalog = ((PyObject*)__pyx_t_1);

#line 571 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

  /* "cysystemd/reader.pyx":572
 *         length = check_error_code(result)
 *         bcatalog = catalog[:length]
 *         PyMem_Free(catalog)             # <<<<<<<<<<<<<<
 * 
 *         return Path(bcatalog.decode())
*/

#line 572 "cysystemd/reader.pyx"
  PyMem_Free(__pyx_v_catalog);

  /* "cysystemd/reader.pyx":574
 *         PyMem_Free(catalog)
 * 
 *         return Path(bcatalog.decode())             # <<<<<<<<<<<<<<
*/

#line 574 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_r);

#line 574 "cysystemd/reader.pyx"
  __pyx_t_4 = NULL;

#line 574 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Path); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 574, __pyx_L1_error)

#line 574 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 574 "cysystemd/reader.pyx"
  __pyx_t_3 = __Pyx_decode_bytes(__pyx_v_bcatalog, 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 574, __pyx_L1_error)

#line 574 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_3);

#line 574 "cysystemd/reader.pyx"
  __pyx_t_6 = 1;

#line 574 "cysystemd/reader.pyx"
  #if CYTHON_UNPACK_METHODS

#line 574 "cysystemd/reader.pyx"
  if (unlikely(PyMethod_Check(__pyx_t_5))) {

#line 574 "cysystemd/reader.pyx"
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);

#line 574 "cysystemd/reader.pyx"
    assert(__pyx_t_4);

#line 574 "cysystemd/reader.pyx"
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);

#line 574 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx_t_4);

#line 574 "cysystemd/reader.pyx"
    __Pyx_INCREF(__pyx__function);

#line 574 "cysystemd/reader.pyx"
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);

#line 574 "cysystemd/reader.pyx"
    __pyx_t_6 = 0;

#line 574 "cysystemd/reader.pyx"
  }

#line 574 "cysystemd/reader.pyx"
  #endif

#line 574 "cysystemd/reader.pyx"
  {

#line 574 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};

#line 574 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 574 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 574 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 574 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 574 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 574, __pyx_L1_error)

#line 574 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_1);

#line 574 "cysystemd/reader.pyx"
  }

#line 574 "cysystemd/reader.pyx"
  __pyx_r = __pyx_t_1;

#line 574 "cysystemd/reader.pyx"
  __pyx_t_1 = 0;

#line 574 "cysystemd/reader.pyx"
  goto __pyx_L0;

  /* "cysystemd/reader.pyx":559
 *         return Path(bcatalog.decode())
 * 
 *     def get_catalog_for_message_id(self, message_id: UUID) -> Path:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* catalog
*/

#line 559 "cysystemd/reader.pyx"


#line 559 "cysystemd/reader.pyx"
  /* function exit code */

#line 559 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 559 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_1);

#line 559 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_3);

#line 559 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 559 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 559 "cysystemd/reader.pyx"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.get_catalog_for_message_id", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 559 "cysystemd/reader.pyx"
  __pyx_r = NULL;

#line 559 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 559 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_bcatalog);

#line 559 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_v_length);

#line 559 "cysystemd/reader.pyx"
  __Pyx_XGIVEREF(__pyx_r);

#line 559 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 559 "cysystemd/reader.pyx"
  return __pyx_r;

#line 559 "cysystemd/reader.pyx"
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
*/

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
/* Python wrapper */

#line 1 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_48__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_48__reduce_cython__ = 
#line 1 "(tree fragment)"
{"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_48__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 1 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_48__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {

#line 1 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 1 "(tree fragment)"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 1 "(tree fragment)"
  PyObject *__pyx_r = 0;

#line 1 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 1 "(tree fragment)"
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);

#line 1 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 1 "(tree fragment)"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 1 "(tree fragment)"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 1 "(tree fragment)"
  #else

#line 1 "(tree fragment)"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 1 "(tree fragment)"
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }

#line 1 "(tree fragment)"
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 1 "(tree fragment)"
  if (unlikely(__pyx_kwds_len < 0)) return NULL;

#line 1 "(tree fragment)"
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = 
#line 1 "(tree fragment)"
__pyx_pf_9cysystemd_6reader_13JournalReader_47__reduce_cython__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self));

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
  /* function exit code */

#line 1 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 1 "(tree fragment)"
  return __pyx_r;

#line 1 "(tree fragment)"
}

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_47__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self) {

#line 1 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 1 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 1 "(tree fragment)"
  int __pyx_lineno = 0;

#line 1 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 1 "(tree fragment)"
  int __pyx_clineno = 0;

#line 1 "(tree fragment)"
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
*/

#line 2 "(tree fragment)"
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_self_context_cannot_be_converted, 0, 0);

#line 2 "(tree fragment)"
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
*/

#line 1 "(tree fragment)"


#line 1 "(tree fragment)"
  /* function exit code */

#line 1 "(tree fragment)"
  __pyx_L1_error:;

#line 1 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 1 "(tree fragment)"
  __pyx_r = NULL;

#line 1 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 1 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 1 "(tree fragment)"
  return __pyx_r;

#line 1 "(tree fragment)"
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
*/

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
/* Python wrapper */

#line 3 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_50__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_13JournalReader_50__setstate_cython__ = 
#line 3 "(tree fragment)"
{"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_50__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 3 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_13JournalReader_50__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0
#line 3 "(tree fragment)"
;

#line 3 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 3 "(tree fragment)"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 3 "(tree fragment)"
  PyObject* values[1] = {0};

#line 3 "(tree fragment)"
  int __pyx_lineno = 0;

#line 3 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 3 "(tree fragment)"
  int __pyx_clineno = 0;

#line 3 "(tree fragment)"
  PyObject *__pyx_r = 0;

#line 3 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 3 "(tree fragment)"
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);

#line 3 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 3 "(tree fragment)"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 3 "(tree fragment)"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 3 "(tree fragment)"
  #else

#line 3 "(tree fragment)"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 3 "(tree fragment)"
  {

#line 3 "(tree fragment)"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};

#line 3 "(tree fragment)"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 3 "(tree fragment)"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
    if (__pyx_kwds_len > 0) {

#line 3 "(tree fragment)"
      switch (__pyx_nargs) {

#line 3 "(tree fragment)"
        case  1:

#line 3 "(tree fragment)"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 3 "(tree fragment)"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 3 "(tree fragment)"
break;
        default: 
#line 3 "(tree fragment)"
goto __pyx_L5_argtuple_error;

#line 3 "(tree fragment)"
      }

#line 3 "(tree fragment)"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 3 "(tree fragment)"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {

#line 3 "(tree fragment)"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(1, 3, __pyx_L3_error) }

#line 3 "(tree fragment)"
      }

#line 3 "(tree fragment)"
    } else if (unlikely(__pyx_nargs != 1)) {

#line 3 "(tree fragment)"
      goto __pyx_L5_argtuple_error;

#line 3 "(tree fragment)"
    } else {

#line 3 "(tree fragment)"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 3 "(tree fragment)"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
    }

#line 3 "(tree fragment)"
    __pyx_v___pyx_state = values[0];

#line 3 "(tree fragment)"
  }

#line 3 "(tree fragment)"
  goto __pyx_L6_skip;

#line 3 "(tree fragment)"
  __pyx_L5_argtuple_error:;

#line 3 "(tree fragment)"
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)

#line 3 "(tree fragment)"
  __pyx_L6_skip:;

#line 3 "(tree fragment)"
  goto __pyx_L4_argument_unpacking_done;

#line 3 "(tree fragment)"
  __pyx_L3_error:;

#line 3 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 3 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 3 "(tree fragment)"
  }

#line 3 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 3 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 3 "(tree fragment)"
  return NULL;

#line 3 "(tree fragment)"
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = 
#line 3 "(tree fragment)"
__pyx_pf_9cysystemd_6reader_13JournalReader_49__setstate_cython__(((struct __pyx_obj_9cysystemd_6reader_JournalReader *)__pyx_v_self), __pyx_v___pyx_state);

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
  /* function exit code */

#line 3 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 3 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 3 "(tree fragment)"
  }

#line 3 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 3 "(tree fragment)"
  return __pyx_r;

#line 3 "(tree fragment)"
}

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
static PyObject *__pyx_pf_9cysystemd_6reader_13JournalReader_49__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9cysystemd_6reader_JournalReader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {

#line 3 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 3 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 3 "(tree fragment)"
  int __pyx_lineno = 0;

#line 3 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 3 "(tree fragment)"
  int __pyx_clineno = 0;

#line 3 "(tree fragment)"
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
*/

#line 4 "(tree fragment)"
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_self_context_cannot_be_converted, 0, 0);

#line 4 "(tree fragment)"
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
*/

#line 3 "(tree fragment)"


#line 3 "(tree fragment)"
  /* function exit code */

#line 3 "(tree fragment)"
  __pyx_L1_error:;

#line 3 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.JournalReader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 3 "(tree fragment)"
  __pyx_r = NULL;

#line 3 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 3 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 3 "(tree fragment)"
  return __pyx_r;

#line 3 "(tree fragment)"
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Rule(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, b'_child, _expression, _operand, _root')
*/

#line 4 "(tree fragment)"


#line 4 "(tree fragment)"
/* Python wrapper */

#line 4 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_3__pyx_unpickle_Rule(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysystemd_6reader_3__pyx_unpickle_Rule = 
#line 4 "(tree fragment)"
{"__pyx_unpickle_Rule", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_3__pyx_unpickle_Rule, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};

#line 4 "(tree fragment)"
static PyObject *__pyx_pw_9cysystemd_6reader_3__pyx_unpickle_Rule(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0
#line 4 "(tree fragment)"
;
  long __pyx_v___pyx_checksum
#line 4 "(tree fragment)"
;
  PyObject *__pyx_v___pyx_state = 0
#line 4 "(tree fragment)"
;

#line 4 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 4 "(tree fragment)"
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;

#line 4 "(tree fragment)"
  #endif

#line 4 "(tree fragment)"
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;

#line 4 "(tree fragment)"
  PyObject* values[3] = {0,0,0};

#line 4 "(tree fragment)"
  int __pyx_lineno = 0;

#line 4 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 4 "(tree fragment)"
  int __pyx_clineno = 0;

#line 4 "(tree fragment)"
  PyObject *__pyx_r = 0;

#line 4 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 4 "(tree fragment)"
  __Pyx_RefNannySetupContext("__pyx_unpickle_Rule (wrapper)", 0);

#line 4 "(tree fragment)"
  #if !CYTHON_METH_FASTCALL

#line 4 "(tree fragment)"
  #if CYTHON_ASSUME_SAFE_SIZE

#line 4 "(tree fragment)"
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);

#line 4 "(tree fragment)"
  #else

#line 4 "(tree fragment)"
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;

#line 4 "(tree fragment)"
  #endif

#line 4 "(tree fragment)"
  #endif

#line 4 "(tree fragment)"
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);

#line 4 "(tree fragment)"
  {

#line 4 "(tree fragment)"
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};

#line 4 "(tree fragment)"
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;

#line 4 "(tree fragment)"
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
    if (__pyx_kwds_len > 0) {

#line 4 "(tree fragment)"
      switch (__pyx_nargs) {

#line 4 "(tree fragment)"
        case  3:

#line 4 "(tree fragment)"
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);

#line 4 "(tree fragment)"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
        CYTHON_FALLTHROUGH;

#line 4 "(tree fragment)"
        case  2:

#line 4 "(tree fragment)"
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);

#line 4 "(tree fragment)"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
        CYTHON_FALLTHROUGH;

#line 4 "(tree fragment)"
        case  1:

#line 4 "(tree fragment)"
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 4 "(tree fragment)"
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
        CYTHON_FALLTHROUGH;
        case  0: 
#line 4 "(tree fragment)"
break;
        default: 
#line 4 "(tree fragment)"
goto __pyx_L5_argtuple_error;

#line 4 "(tree fragment)"
      }

#line 4 "(tree fragment)"
      const Py_ssize_t kwd_pos_args = __pyx_nargs;

#line 4 "(tree fragment)"
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_Rule", 0) < (0)) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {

#line 4 "(tree fragment)"
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Rule", 1, 3, 3, i); __PYX_ERR(1, 4, __pyx_L3_error) }

#line 4 "(tree fragment)"
      }

#line 4 "(tree fragment)"
    } else if (unlikely(__pyx_nargs != 3)) {

#line 4 "(tree fragment)"
      goto __pyx_L5_argtuple_error;

#line 4 "(tree fragment)"
    } else {

#line 4 "(tree fragment)"
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);

#line 4 "(tree fragment)"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);

#line 4 "(tree fragment)"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);

#line 4 "(tree fragment)"
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
    }

#line 4 "(tree fragment)"
    __pyx_v___pyx_type = values[0];

#line 4 "(tree fragment)"
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
    __pyx_v___pyx_state = ((PyObject*)values[2]);

#line 4 "(tree fragment)"
  }

#line 4 "(tree fragment)"
  goto __pyx_L6_skip;

#line 4 "(tree fragment)"
  __pyx_L5_argtuple_error:;

#line 4 "(tree fragment)"
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Rule", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 4, __pyx_L3_error)

#line 4 "(tree fragment)"
  __pyx_L6_skip:;

#line 4 "(tree fragment)"
  goto __pyx_L4_argument_unpacking_done;

#line 4 "(tree fragment)"
  __pyx_L3_error:;

#line 4 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 4 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 4 "(tree fragment)"
  }

#line 4 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.__pyx_unpickle_Rule", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 4 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 4 "(tree fragment)"
  return NULL;

#line 4 "(tree fragment)"
  __pyx_L4_argument_unpacking_done:;

#line 4 "(tree fragment)"
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(1, 4, __pyx_L1_error)
  __pyx_r = 
#line 4 "(tree fragment)"
__pyx_pf_9cysystemd_6reader_2__pyx_unpickle_Rule(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

#line 4 "(tree fragment)"


#line 4 "(tree fragment)"
  /* function exit code */

#line 4 "(tree fragment)"
  goto __pyx_L0;

#line 4 "(tree fragment)"
  __pyx_L1_error:;

#line 4 "(tree fragment)"
  __pyx_r = NULL;

#line 4 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 4 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 4 "(tree fragment)"
  }

#line 4 "(tree fragment)"
  goto __pyx_L7_cleaned_up;

#line 4 "(tree fragment)"
  __pyx_L0:;

#line 4 "(tree fragment)"
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {

#line 4 "(tree fragment)"
    Py_XDECREF(values[__pyx_temp]);

#line 4 "(tree fragment)"
  }

#line 4 "(tree fragment)"
  __pyx_L7_cleaned_up:;

#line 4 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 4 "(tree fragment)"
  return __pyx_r;

#line 4 "(tree fragment)"
}

#line 4 "(tree fragment)"


#line 4 "(tree fragment)"
static PyObject *__pyx_pf_9cysystemd_6reader_2__pyx_unpickle_Rule(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0
#line 4 "(tree fragment)"
;

#line 4 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 4 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 4 "(tree fragment)"
  int __pyx_t_1;

#line 4 "(tree fragment)"
  PyObject *__pyx_t_2 = NULL;

#line 4 "(tree fragment)"
  PyObject *__pyx_t_3 = NULL;

#line 4 "(tree fragment)"
  size_t __pyx_t_4;

#line 4 "(tree fragment)"
  int __pyx_t_5;

#line 4 "(tree fragment)"
  int __pyx_lineno = 0;

#line 4 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 4 "(tree fragment)"
  int __pyx_clineno = 0;

#line 4 "(tree fragment)"
  __Pyx_RefNannySetupContext("__pyx_unpickle_Rule", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_Rule(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, b'_child, _expression, _operand, _root')             # <<<<<<<<<<<<<<
 *     __pyx_result = Rule.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/

#line 6 "(tree fragment)"
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, __pyx_k_child__expression__operand__roo); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(1, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, b'_child, _expression, _operand, _root')
 *     __pyx_result = Rule.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Rule__set_state(<Rule> __pyx_result, __pyx_state)
*/

#line 7 "(tree fragment)"
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule);

#line 7 "(tree fragment)"
  __Pyx_INCREF(__pyx_t_3);

#line 7 "(tree fragment)"
  __pyx_t_4 = 0;

#line 7 "(tree fragment)"
  {

#line 7 "(tree fragment)"
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};

#line 7 "(tree fragment)"
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 7 "(tree fragment)"
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

#line 7 "(tree fragment)"
    if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)

#line 7 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_2);

#line 7 "(tree fragment)"
  }

#line 7 "(tree fragment)"
  __pyx_v___pyx_result = __pyx_t_2;

#line 7 "(tree fragment)"
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, b'_child, _expression, _operand, _root')
 *     __pyx_result = Rule.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Rule__set_state(<Rule> __pyx_result, __pyx_state)
 *     return __pyx_result
*/

#line 8 "(tree fragment)"
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));

#line 8 "(tree fragment)"
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = Rule.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Rule__set_state(<Rule> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Rule__set_state(Rule __pyx_result, __pyx_state: tuple):
*/

#line 9 "(tree fragment)"
    if (unlikely(__pyx_v___pyx_state == Py_None)) {

#line 9 "(tree fragment)"
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");

#line 9 "(tree fragment)"
      __PYX_ERR(1, 9, __pyx_L1_error)

#line 9 "(tree fragment)"
    }

#line 9 "(tree fragment)"
    __pyx_t_2 = __pyx_f_9cysystemd_6reader___pyx_unpickle_Rule__set_state(((struct __pyx_obj_9cysystemd_6reader_Rule *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 9, __pyx_L1_error)

#line 9 "(tree fragment)"
    __Pyx_GOTREF(__pyx_t_2);

#line 9 "(tree fragment)"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, b'_child, _expression, _operand, _root')
 *     __pyx_result = Rule.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Rule__set_state(<Rule> __pyx_result, __pyx_state)
 *     return __pyx_result
*/

#line 8 "(tree fragment)"
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Rule__set_state(<Rule> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Rule__set_state(Rule __pyx_result, __pyx_state: tuple):
 *     __pyx_result._child = __pyx_state[0]; __pyx_result._expression = __pyx_state[1]; __pyx_result._operand = __pyx_state[2]; __pyx_result._root = __pyx_state[3]
*/

#line 10 "(tree fragment)"
  __Pyx_XDECREF(__pyx_r);

#line 10 "(tree fragment)"
  __Pyx_INCREF(__pyx_v___pyx_result);

#line 10 "(tree fragment)"
  __pyx_r = __pyx_v___pyx_result;

#line 10 "(tree fragment)"
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Rule(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, b'_child, _expression, _operand, _root')
*/

#line 4 "(tree fragment)"


#line 4 "(tree fragment)"
  /* function exit code */

#line 4 "(tree fragment)"
  __pyx_L1_error:;

#line 4 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_2);

#line 4 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_3);

#line 4 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.__pyx_unpickle_Rule", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 4 "(tree fragment)"
  __pyx_r = NULL;

#line 4 "(tree fragment)"
  __pyx_L0:;

#line 4 "(tree fragment)"
  __Pyx_XDECREF(__pyx_v___pyx_result);

#line 4 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 4 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 4 "(tree fragment)"
  return __pyx_r;

#line 4 "(tree fragment)"
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Rule__set_state(<Rule> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Rule__set_state(Rule __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result._child = __pyx_state[0]; __pyx_result._expression = __pyx_state[1]; __pyx_result._operand = __pyx_state[2]; __pyx_result._root = __pyx_state[3]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 4)
*/

#line 11 "(tree fragment)"


#line 11 "(tree fragment)"
static PyObject *__pyx_f_9cysystemd_6reader___pyx_unpickle_Rule__set_state(struct __pyx_obj_9cysystemd_6reader_Rule *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {

#line 11 "(tree fragment)"
  PyObject *__pyx_r = NULL;

#line 11 "(tree fragment)"
  __Pyx_RefNannyDeclarations

#line 11 "(tree fragment)"
  PyObject *__pyx_t_1 = NULL;

#line 11 "(tree fragment)"
  int __pyx_t_2;

#line 11 "(tree fragment)"
  int __pyx_lineno = 0;

#line 11 "(tree fragment)"
  const char *__pyx_filename = NULL;

#line 11 "(tree fragment)"
  int __pyx_clineno = 0;

#line 11 "(tree fragment)"
  __Pyx_RefNannySetupContext("__pyx_unpickle_Rule__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Rule__set_state(Rule __pyx_result, __pyx_state: tuple):
 *     __pyx_result._child = __pyx_state[0]; __pyx_result._expression = __pyx_state[1]; __pyx_result._operand = __pyx_state[2]; __pyx_result._root = __pyx_state[3]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 4)
*/

#line 12 "(tree fragment)"
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_v___pyx_result->_child);

#line 12 "(tree fragment)"
  __Pyx_DECREF(__pyx_v___pyx_result->_child);

#line 12 "(tree fragment)"
  __pyx_v___pyx_result->_child = __pyx_t_1;

#line 12 "(tree fragment)"
  __pyx_t_1 = 0;

#line 12 "(tree fragment)"
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_v___pyx_result->_expression);

#line 12 "(tree fragment)"
  __Pyx_DECREF(__pyx_v___pyx_result->_expression);

#line 12 "(tree fragment)"
  __pyx_v___pyx_result->_expression = __pyx_t_1;

#line 12 "(tree fragment)"
  __pyx_t_1 = 0;

#line 12 "(tree fragment)"
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_v___pyx_result->_operand);

#line 12 "(tree fragment)"
  __Pyx_DECREF(__pyx_v___pyx_result->_operand);

#line 12 "(tree fragment)"
  __pyx_v___pyx_result->_operand = __pyx_t_1;

#line 12 "(tree fragment)"
  __pyx_t_1 = 0;

#line 12 "(tree fragment)"
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GIVEREF(__pyx_t_1);

#line 12 "(tree fragment)"
  __Pyx_GOTREF(__pyx_v___pyx_result->_root);

#line 12 "(tree fragment)"
  __Pyx_DECREF(__pyx_v___pyx_result->_root);

#line 12 "(tree fragment)"
  __pyx_v___pyx_result->_root = __pyx_t_1;

#line 12 "(tree fragment)"
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_Rule__set_state(Rule __pyx_result, __pyx_state: tuple):
 *     __pyx_result._child = __pyx_state[0]; __pyx_result._expression = __pyx_state[1]; __pyx_result._operand = __pyx_state[2]; __pyx_result._root = __pyx_state[3]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 4)             # <<<<<<<<<<<<<<
*/

#line 13 "(tree fragment)"
  __pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_Rule__set_state(<Rule> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Rule__set_state(Rule __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result._child = __pyx_state[0]; __pyx_result._expression = __pyx_state[1]; __pyx_result._operand = __pyx_state[2]; __pyx_result._root = __pyx_state[3]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 4)
*/

#line 11 "(tree fragment)"


#line 11 "(tree fragment)"
  /* function exit code */

#line 11 "(tree fragment)"
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);

#line 11 "(tree fragment)"
  goto __pyx_L0;

#line 11 "(tree fragment)"
  __pyx_L1_error:;

#line 11 "(tree fragment)"
  __Pyx_XDECREF(__pyx_t_1);

#line 11 "(tree fragment)"
  __Pyx_AddTraceback("cysystemd.reader.__pyx_unpickle_Rule__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 11 "(tree fragment)"
  __pyx_r = 0;

#line 11 "(tree fragment)"
  __pyx_L0:;

#line 11 "(tree fragment)"
  __Pyx_XGIVEREF(__pyx_r);

#line 11 "(tree fragment)"
  __Pyx_RefNannyFinishContext();

#line 11 "(tree fragment)"
  return __pyx_r;

#line 11 "(tree fragment)"
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_9cysystemd_6reader_Rule(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9cysystemd_6reader_Rule *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9cysystemd_6reader_Rule *)o);
  p->_expression = Py_None; Py_INCREF(Py_None);
  p->_child = Py_None; Py_INCREF(Py_None);
  p->_root = Py_None; Py_INCREF(Py_None);
  p->_operand = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9cysystemd_6reader_Rule(PyObject *o) {
  struct __pyx_obj_9cysystemd_6reader_Rule *p = (struct __pyx_obj_9cysystemd_6reader_Rule *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9cysystemd_6reader_Rule) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_expression);
  Py_CLEAR(p->_child);
  Py_CLEAR(p->_root);
  Py_CLEAR(p->_operand);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_9cysystemd_6reader_Rule(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9cysystemd_6reader_Rule *p = (struct __pyx_obj_9cysystemd_6reader_Rule *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->_expression) {
    e = (*v)(p->_expression, a); if (e) return e;
  }
  if (p->_child) {
    e = (*v)(p->_child, a); if (e) return e;
  }
  if (p->_root) {
    e = (*v)(p->_root, a); if (e) return e;
  }
  if (p->_operand) {
    e = (*v)(p->_operand, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9cysystemd_6reader_Rule(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9cysystemd_6reader_Rule *p = (struct __pyx_obj_9cysystemd_6reader_Rule *)o;
  tmp = ((PyObject*)p->_expression);
  p->_expression = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_child);
  p->_child = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_root);
  p->_root = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_operand);
  p->_operand = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static CYTHON_INLINE PyObject *__pyx_nb_and_9cysystemd_6reader_Rule_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS
    slot = type->tp_as_number ? type->tp_as_number->nb_and : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_and);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_and_9cysystemd_6reader_Rule(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_and == &__pyx_nb_and_9cysystemd_6reader_Rule)
#endif
            || __Pyx_TypeCheck(left, __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_9cysystemd_6reader_4Rule_3__and__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_and == &__pyx_nb_and_9cysystemd_6reader_Rule)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule);
    if (maybe_self_is_right) {
        return __pyx_nb_and_9cysystemd_6reader_Rule_maybe_call_slot(__Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, tp_base, PyTypeObject*), left, right );
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_or_9cysystemd_6reader_Rule_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS
    slot = type->tp_as_number ? type->tp_as_number->nb_or : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_or);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_or_9cysystemd_6reader_Rule(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_or == &__pyx_nb_or_9cysystemd_6reader_Rule)
#endif
            || __Pyx_TypeCheck(left, __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_9cysystemd_6reader_4Rule_5__or__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_or == &__pyx_nb_or_9cysystemd_6reader_Rule)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule);
    if (maybe_self_is_right) {
        return __pyx_nb_or_9cysystemd_6reader_Rule_maybe_call_slot(__Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, tp_base, PyTypeObject*), left, right );
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static PyObject *__pyx_getprop_9cysystemd_6reader_4Rule_expression(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_4Rule_10expression_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_4Rule_child(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_4Rule_5child_1__get__(o);
}

static int __pyx_setprop_9cysystemd_6reader_4Rule_child(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9cysystemd_6reader_4Rule_5child_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9cysystemd_6reader_4Rule_root(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_4Rule_4root_1__get__(o);
}

static int __pyx_setprop_9cysystemd_6reader_4Rule_root(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9cysystemd_6reader_4Rule_4root_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9cysystemd_6reader_4Rule_operand(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_4Rule_7operand_1__get__(o);
}

static int __pyx_setprop_9cysystemd_6reader_4Rule_operand(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9cysystemd_6reader_4Rule_7operand_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_9cysystemd_6reader_Rule[] = {
  {"__and__", (PyCFunction)__pyx_pw_9cysystemd_6reader_4Rule_3__and__, METH_O|METH_COEXIST, 0},
  {"__or__", (PyCFunction)__pyx_pw_9cysystemd_6reader_4Rule_5__or__, METH_O|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_4Rule_12__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_4Rule_14__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9cysystemd_6reader_Rule[] = {
  {"expression", __pyx_getprop_9cysystemd_6reader_4Rule_expression, 0, 0, 0},
  {"child", __pyx_getprop_9cysystemd_6reader_4Rule_child, __pyx_setprop_9cysystemd_6reader_4Rule_child, 0, 0},
  {"root", __pyx_getprop_9cysystemd_6reader_4Rule_root, __pyx_setprop_9cysystemd_6reader_4Rule_root, 0, 0},
  {"operand", __pyx_getprop_9cysystemd_6reader_4Rule_operand, __pyx_setprop_9cysystemd_6reader_4Rule_operand, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9cysystemd_6reader_Rule_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9cysystemd_6reader_Rule},
  {Py_tp_repr, (void *)__pyx_pw_9cysystemd_6reader_4Rule_7__repr__},
  {Py_nb_and, (void *)__pyx_nb_and_9cysystemd_6reader_Rule},
  {Py_nb_or, (void *)__pyx_nb_or_9cysystemd_6reader_Rule},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9cysystemd_6reader_Rule},
  {Py_tp_clear, (void *)__pyx_tp_clear_9cysystemd_6reader_Rule},
  {Py_tp_iter, (void *)__pyx_pw_9cysystemd_6reader_4Rule_9__iter__},
  {Py_tp_methods, (void *)__pyx_methods_9cysystemd_6reader_Rule},
  {Py_tp_getset, (void *)__pyx_getsets_9cysystemd_6reader_Rule},
  {Py_tp_init, (void *)__pyx_pw_9cysystemd_6reader_4Rule_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_9cysystemd_6reader_Rule},
  {0, 0},
};
static PyType_Spec __pyx_type_9cysystemd_6reader_Rule_spec = {
  "cysystemd.reader.Rule",
  sizeof(struct __pyx_obj_9cysystemd_6reader_Rule),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9cysystemd_6reader_Rule_slots,
};
#else

static PyNumberMethods __pyx_tp_as_number_Rule = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_bool*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  __pyx_nb_and_9cysystemd_6reader_Rule, /*nb_and*/
  0, /*nb_xor*/
  __pyx_nb_or_9cysystemd_6reader_Rule, /*nb_or*/
  0, /*nb_int*/
  0, /*nb_long (reserved)*/
  0, /*nb_float*/
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  0, /*nb_index*/
  0, /*nb_matrix_multiply*/
  0, /*nb_inplace_matrix_multiply*/
};

static PyTypeObject __pyx_type_9cysystemd_6reader_Rule = {
  PyVarObject_HEAD_INIT(0, 0)
  "cysystemd.reader.""Rule", /*tp_name*/
  sizeof(struct __pyx_obj_9cysystemd_6reader_Rule), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9cysystemd_6reader_Rule, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_9cysystemd_6reader_4Rule_7__repr__, /*tp_repr*/
  &__pyx_tp_as_number_Rule, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9cysystemd_6reader_Rule, /*tp_traverse*/
  __pyx_tp_clear_9cysystemd_6reader_Rule, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_9cysystemd_6reader_4Rule_9__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9cysystemd_6reader_Rule, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9cysystemd_6reader_Rule, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_9cysystemd_6reader_4Rule_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9cysystemd_6reader_Rule, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9cysystemd_6reader_JournalEntry __pyx_vtable_9cysystemd_6reader_JournalEntry;

static PyObject *__pyx_tp_new_9cysystemd_6reader_JournalEntry(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9cysystemd_6reader_JournalEntry *)o);
  p->__pyx_vtab = __pyx_vtabptr_9cysystemd_6reader_JournalEntry;
  p->_JournalEntry__boot_uuid = Py_None; Py_INCREF(Py_None);
  p->_JournalEntry__data = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_data = Py_None; Py_INCREF(Py_None);
  p->_JournalEntry__date = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9cysystemd_6reader_12JournalEntry_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9cysystemd_6reader_JournalEntry(PyObject *o) {
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *p = (struct __pyx_obj_9cysystemd_6reader_JournalEntry *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9cysystemd_6reader_JournalEntry) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9cysystemd_6reader_12JournalEntry_11__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->_JournalEntry__boot_uuid);
  Py_CLEAR(p->_JournalEntry__data);
  Py_CLEAR(p->_data);
  Py_CLEAR(p->_JournalEntry__date);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_9cysystemd_6reader_JournalEntry(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *p = (struct __pyx_obj_9cysystemd_6reader_JournalEntry *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->_JournalEntry__boot_uuid) {
    e = (*v)(p->_JournalEntry__boot_uuid, a); if (e) return e;
  }
  if (p->_JournalEntry__data) {
    e = (*v)(p->_JournalEntry__data, a); if (e) return e;
  }
  if (p->_data) {
    e = (*v)(p->_data, a); if (e) return e;
  }
  if (p->_JournalEntry__date) {
    e = (*v)(p->_JournalEntry__date, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9cysystemd_6reader_JournalEntry(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9cysystemd_6reader_JournalEntry *p = (struct __pyx_obj_9cysystemd_6reader_JournalEntry *)o;
  tmp = ((PyObject*)p->_JournalEntry__boot_uuid);
  p->_JournalEntry__boot_uuid = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_JournalEntry__data);
  p->_JournalEntry__data = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_data);
  p->_data = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_JournalEntry__date);
  p->_JournalEntry__date = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_sq_item_9cysystemd_6reader_JournalEntry(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyLong_FromSsize_t(i); if(!x) return 0;
  #if CYTHON_USE_TYPE_SLOTS || (!CYTHON_USE_TYPE_SPECS && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  #else
  r = ((binaryfunc)PyType_GetSlot(Py_TYPE(o), Py_mp_subscript))(o, x);
  #endif
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_getprop_9cysystemd_6reader_12JournalEntry_cursor(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_12JournalEntry_6cursor_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_12JournalEntry_boot_id(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_12JournalEntry_7boot_id_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_12JournalEntry_date(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_12JournalEntry_4date_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_12JournalEntry_data(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_12JournalEntry_4data_1__get__(o);
}

static PyMethodDef __pyx_methods_9cysystemd_6reader_JournalEntry[] = {
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_17__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_12JournalEntry_19__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9cysystemd_6reader_JournalEntry[] = {
  {"cursor", __pyx_getprop_9cysystemd_6reader_12JournalEntry_cursor, 0, 0, 0},
  {"boot_id", __pyx_getprop_9cysystemd_6reader_12JournalEntry_boot_id, 0, 0, 0},
  {"date", __pyx_getprop_9cysystemd_6reader_12JournalEntry_date, 0, 0, 0},
  {"data", __pyx_getprop_9cysystemd_6reader_12JournalEntry_data, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9cysystemd_6reader_JournalEntry_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9cysystemd_6reader_JournalEntry},
  {Py_tp_repr, (void *)__pyx_pw_9cysystemd_6reader_12JournalEntry_13__repr__},
  {Py_sq_item, (void *)__pyx_sq_item_9cysystemd_6reader_JournalEntry},
  {Py_mp_subscript, (void *)__pyx_pw_9cysystemd_6reader_12JournalEntry_15__getitem__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9cysystemd_6reader_JournalEntry},
  {Py_tp_clear, (void *)__pyx_tp_clear_9cysystemd_6reader_JournalEntry},
  {Py_tp_methods, (void *)__pyx_methods_9cysystemd_6reader_JournalEntry},
  {Py_tp_getset, (void *)__pyx_getsets_9cysystemd_6reader_JournalEntry},
  {Py_tp_new, (void *)__pyx_tp_new_9cysystemd_6reader_JournalEntry},
  {0, 0},
};
static PyType_Spec __pyx_type_9cysystemd_6reader_JournalEntry_spec = {
  "cysystemd.reader.JournalEntry",
  sizeof(struct __pyx_obj_9cysystemd_6reader_JournalEntry),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9cysystemd_6reader_JournalEntry_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_JournalEntry = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_9cysystemd_6reader_JournalEntry, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_JournalEntry = {
  0, /*mp_length*/
  __pyx_pw_9cysystemd_6reader_12JournalEntry_15__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_9cysystemd_6reader_JournalEntry = {
  PyVarObject_HEAD_INIT(0, 0)
  "cysystemd.reader.""JournalEntry", /*tp_name*/
  sizeof(struct __pyx_obj_9cysystemd_6reader_JournalEntry), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9cysystemd_6reader_JournalEntry, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_9cysystemd_6reader_12JournalEntry_13__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_JournalEntry, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_JournalEntry, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9cysystemd_6reader_JournalEntry, /*tp_traverse*/
  __pyx_tp_clear_9cysystemd_6reader_JournalEntry, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9cysystemd_6reader_JournalEntry, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9cysystemd_6reader_JournalEntry, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9cysystemd_6reader_JournalEntry, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9cysystemd_6reader_JournalReader __pyx_vtable_9cysystemd_6reader_JournalReader;

static PyObject *__pyx_tp_new_9cysystemd_6reader_JournalReader(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9cysystemd_6reader_JournalReader *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9cysystemd_6reader_JournalReader *)o);
  p->__pyx_vtab = __pyx_vtabptr_9cysystemd_6reader_JournalReader;
  p->flags = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9cysystemd_6reader_JournalReader(PyObject *o) {
  struct __pyx_obj_9cysystemd_6reader_JournalReader *p = (struct __pyx_obj_9cysystemd_6reader_JournalReader *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9cysystemd_6reader_JournalReader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9cysystemd_6reader_13JournalReader_40__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->flags);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_9cysystemd_6reader_JournalReader(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9cysystemd_6reader_JournalReader *p = (struct __pyx_obj_9cysystemd_6reader_JournalReader *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->flags) {
    e = (*v)(p->flags, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9cysystemd_6reader_JournalReader(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9cysystemd_6reader_JournalReader *p = (struct __pyx_obj_9cysystemd_6reader_JournalReader *)o;
  tmp = ((PyObject*)p->flags);
  p->flags = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9cysystemd_6reader_13JournalReader_data_threshold(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_13JournalReader_14data_threshold_1__get__(o);
}

static int __pyx_setprop_9cysystemd_6reader_13JournalReader_data_threshold(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9cysystemd_6reader_13JournalReader_14data_threshold_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9cysystemd_6reader_13JournalReader_closed(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_13JournalReader_6closed_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_13JournalReader_locked(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_13JournalReader_6locked_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_13JournalReader_idle(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_13JournalReader_4idle_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_13JournalReader_fd(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_13JournalReader_2fd_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_13JournalReader_events(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_13JournalReader_6events_1__get__(o);
}

static PyObject *__pyx_getprop_9cysystemd_6reader_13JournalReader_timeout(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9cysystemd_6reader_13JournalReader_7timeout_1__get__(o);
}

static PyMethodDef __pyx_methods_9cysystemd_6reader_JournalReader[] = {
  {"open", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_3open, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"open_directory", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_5open_directory, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"open_files", (PyCFunction)(void(*)(void))(PyCFunctionWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_7open_files, METH_VARARGS|METH_KEYWORDS, 0},
  {"_lock", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_9_lock, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"seek_head", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_12seek_head, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"seek_tail", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_14seek_tail, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"seek_monotonic_usec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_16seek_monotonic_usec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"seek_realtime_usec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_18seek_realtime_usec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"seek_cursor", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_20seek_cursor, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"next", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_26next, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"skip_next", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_28skip_next, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"previous", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_30previous, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"skip_previous", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_32skip_previous, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"add_filter", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_34add_filter, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"clear_filter", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_36clear_filter, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"process_events", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_42process_events, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_catalog", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_44get_catalog, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_catalog_for_message_id", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_46get_catalog_for_message_id, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_48__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysystemd_6reader_13JournalReader_50__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9cysystemd_6reader_JournalReader[] = {
  {"data_threshold", __pyx_getprop_9cysystemd_6reader_13JournalReader_data_threshold, __pyx_setprop_9cysystemd_6reader_13JournalReader_data_threshold, 0, 0},
  {"closed", __pyx_getprop_9cysystemd_6reader_13JournalReader_closed, 0, 0, 0},
  {"locked", __pyx_getprop_9cysystemd_6reader_13JournalReader_locked, 0, 0, 0},
  {"idle", __pyx_getprop_9cysystemd_6reader_13JournalReader_idle, 0, 0, 0},
  {"fd", __pyx_getprop_9cysystemd_6reader_13JournalReader_fd, 0, 0, 0},
  {"events", __pyx_getprop_9cysystemd_6reader_13JournalReader_events, 0, 0, 0},
  {"timeout", __pyx_getprop_9cysystemd_6reader_13JournalReader_timeout, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9cysystemd_6reader_JournalReader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9cysystemd_6reader_JournalReader},
  {Py_tp_repr, (void *)__pyx_pw_9cysystemd_6reader_13JournalReader_38__repr__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9cysystemd_6reader_JournalReader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9cysystemd_6reader_JournalReader},
  {Py_tp_iter, (void *)__pyx_pw_9cysystemd_6reader_13JournalReader_24__iter__},
  {Py_tp_methods, (void *)__pyx_methods_9cysystemd_6reader_JournalReader},
  {Py_tp_getset, (void *)__pyx_getsets_9cysystemd_6reader_JournalReader},
  {Py_tp_init, (void *)__pyx_pw_9cysystemd_6reader_13JournalReader_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_9cysystemd_6reader_JournalReader},
  {0, 0},
};
static PyType_Spec __pyx_type_9cysystemd_6reader_JournalReader_spec = {
  "cysystemd.reader.JournalReader",
  sizeof(struct __pyx_obj_9cysystemd_6reader_JournalReader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9cysystemd_6reader_JournalReader_slots,
};
#else

static PyTypeObject __pyx_type_9cysystemd_6reader_JournalReader = {
  PyVarObject_HEAD_INIT(0, 0)
  "cysystemd.reader.""JournalReader", /*tp_name*/
  sizeof(struct __pyx_obj_9cysystemd_6reader_JournalReader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9cysystemd_6reader_JournalReader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_9cysystemd_6reader_13JournalReader_38__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9cysystemd_6reader_JournalReader, /*tp_traverse*/
  __pyx_tp_clear_9cysystemd_6reader_JournalReader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_9cysystemd_6reader_13JournalReader_24__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9cysystemd_6reader_JournalReader, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9cysystemd_6reader_JournalReader, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_9cysystemd_6reader_13JournalReader_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9cysystemd_6reader_JournalReader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct____iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct____iter__ > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__, sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9cysystemd_6reader___pyx_scope_struct____iter__[--__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct____iter__];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct____iter__(PyObject *o) {
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *p = (struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct____iter__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_rule);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct____iter__ < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__, sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__))))
  {
    __pyx_mstate_global->__pyx_freelist_9cysystemd_6reader___pyx_scope_struct____iter__[__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct____iter__++] = ((struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9cysystemd_6reader___pyx_scope_struct____iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *p = (struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__ *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_rule) {
    e = (*v)(p->__pyx_v_rule, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9cysystemd_6reader___pyx_scope_struct____iter___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct____iter__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9cysystemd_6reader___pyx_scope_struct____iter__},
  {Py_tp_new, (void *)__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct____iter__},
  {0, 0},
};
static PyType_Spec __pyx_type_9cysystemd_6reader___pyx_scope_struct____iter___spec = {
  "cysystemd.reader.__pyx_scope_struct____iter__",
  sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9cysystemd_6reader___pyx_scope_struct____iter___slots,
};
#else

static PyTypeObject __pyx_type_9cysystemd_6reader___pyx_scope_struct____iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cysystemd.reader.""__pyx_scope_struct____iter__", /*tp_name*/
  sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct____iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct____iter__, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9cysystemd_6reader___pyx_scope_struct____iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9cysystemd_6reader___pyx_scope_struct____iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct_1__lock(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct_1__lock > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock, sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9cysystemd_6reader___pyx_scope_struct_1__lock[--__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct_1__lock];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct_1__lock(PyObject *o) {
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *p = (struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct_1__lock) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_opening);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct_1__lock < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock, sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock))))
  {
    __pyx_mstate_global->__pyx_freelist_9cysystemd_6reader___pyx_scope_struct_1__lock[__pyx_mstate_global->__pyx_freecount_9cysystemd_6reader___pyx_scope_struct_1__lock++] = ((struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9cysystemd_6reader___pyx_scope_struct_1__lock(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *p = (struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_opening) {
    e = (*v)(p->__pyx_v_opening, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct_1__lock},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9cysystemd_6reader___pyx_scope_struct_1__lock},
  {Py_tp_new, (void *)__pyx_tp_new_9cysystemd_6reader___pyx_scope_struct_1__lock},
  {0, 0},
};
static PyType_Spec __pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock_spec = {
  "cysystemd.reader.__pyx_scope_struct_1__lock",
  sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock_slots,
};
#else

static PyTypeObject __pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock = {
  PyVarObject_HEAD_INIT(0, 0)
  "cysystemd.reader.""__pyx_scope_struct_1__lock", /*tp_name*/
  sizeof(struct __pyx_obj_9cysystemd_6reader___pyx_scope_struct_1__lock), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9cysystemd_6reader___pyx_scope_struct_1__lock, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9cysystemd_6reader___pyx_scope_struct_1__lock, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9cysystemd_6reader___pyx_scope_struct_1__lock, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path[--__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path))))
  {
    __pyx_mstate_global->__pyx_freelist___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path[__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path++] = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path},
  {Py_tp_new, (void *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path},
  {0, 0},
};
static PyType_Spec __pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_spec = {
  "cysystemd.reader.__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path",
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER,
  __pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_slots,
};
#else

static PyTypeObject __pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path = {
  PyVarObject_HEAD_INIT(0, 0)
  "cysystemd.reader.""__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path", /*tp_name*/
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9cysystemd_6reader_Rule_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule)) __PYX_ERR(0, 54, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9cysystemd_6reader_Rule_spec, __pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule) < (0)) __PYX_ERR(0, 54, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule = &__pyx_type_9cysystemd_6reader_Rule;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule) < (0)) __PYX_ERR(0, 54, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule->tp_dictoffset && __pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Rule, (PyObject *) __pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule) < (0)) __PYX_ERR(0, 54, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9cysystemd_6reader_Rule) < (0)) __PYX_ERR(0, 54, __pyx_L1_error)
  __pyx_vtabptr_9cysystemd_6reader_JournalEntry = &__pyx_vtable_9cysystemd_6reader_JournalEntry;
  __pyx_vtable_9cysystemd_6reader_JournalEntry.get_realtime_sec = (double (*)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch))__pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_sec;
  __pyx_vtable_9cysystemd_6reader_JournalEntry.get_monotonic_sec = (double (*)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch))__pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_sec;
  __pyx_vtable_9cysystemd_6reader_JournalEntry.get_realtime_usec = (uint64_t (*)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch))__pyx_f_9cysystemd_6reader_12JournalEntry_get_realtime_usec;
  __pyx_vtable_9cysystemd_6reader_JournalEntry.get_monotonic_usec = (uint64_t (*)(struct __pyx_obj_9cysystemd_6reader_JournalEntry *, int __pyx_skip_dispatch))__pyx_f_9cysystemd_6reader_12JournalEntry_get_monotonic_usec;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9cysystemd_6reader_JournalEntry_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry)) __PYX_ERR(0, 211, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9cysystemd_6reader_JournalEntry_spec, __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry) < (0)) __PYX_ERR(0, 211, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry = &__pyx_type_9cysystemd_6reader_JournalEntry;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry) < (0)) __PYX_ERR(0, 211, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry->tp_dictoffset && __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_vtabptr_9cysystemd_6reader_JournalEntry) < (0)) __PYX_ERR(0, 211, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry) < (0)) __PYX_ERR(0, 211, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_JournalEntry, (PyObject *) __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry) < (0)) __PYX_ERR(0, 211, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalEntry) < (0)) __PYX_ERR(0, 211, __pyx_L1_error)
  __pyx_vtabptr_9cysystemd_6reader_JournalReader = &__pyx_vtable_9cysystemd_6reader_JournalReader;
  __pyx_vtable_9cysystemd_6reader_JournalReader.wait = (PyObject *(*)(struct __pyx_obj_9cysystemd_6reader_JournalReader *, int __pyx_skip_dispatch, struct __pyx_opt_args_9cysystemd_6reader_13JournalReader_wait *__pyx_optional_args))__pyx_f_9cysystemd_6reader_13JournalReader_wait;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9cysystemd_6reader_JournalReader_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader)) __PYX_ERR(0, 304, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9cysystemd_6reader_JournalReader_spec, __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader) < (0)) __PYX_ERR(0, 304, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader = &__pyx_type_9cysystemd_6reader_JournalReader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader) < (0)) __PYX_ERR(0, 304, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_vtabptr_9cysystemd_6reader_JournalReader) < (0)) __PYX_ERR(0, 304, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader) < (0)) __PYX_ERR(0, 304, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_JournalReader, (PyObject *) __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader) < (0)) __PYX_ERR(0, 304, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9cysystemd_6reader_JournalReader) < (0)) __PYX_ERR(0, 304, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9cysystemd_6reader___pyx_scope_struct____iter___spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__)) __PYX_ERR(0, 121, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9cysystemd_6reader___pyx_scope_struct____iter___spec, __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__) < (0)) __PYX_ERR(0, 121, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__ = &__pyx_type_9cysystemd_6reader___pyx_scope_struct____iter__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__) < (0)) __PYX_ERR(0, 121, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__->tp_dictoffset && __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct____iter__->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock)) __PYX_ERR(0, 376, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock_spec, __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock) < (0)) __PYX_ERR(0, 376, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock = &__pyx_type_9cysystemd_6reader___pyx_scope_struct_1__lock;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock) < (0)) __PYX_ERR(0, 376, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock->tp_dictoffset && __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9cysystemd_6reader___pyx_scope_struct_1__lock->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path)) __PYX_ERR(1, 65, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path_spec, __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path) < (0)) __PYX_ERR(1, 65, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path = &__pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path) < (0)) __PYX_ERR(1, 65, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path->tp_dictoffset && __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "bool",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyLongObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyLongObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyLongObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyLongObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4bool_bool) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "complex",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyComplexObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyComplexObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyComplexObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyComplexObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_7complex_complex) __PYX_ERR(5, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_reader(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_reader},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "reader",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_reader(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_reader(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_reader(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  uint32_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'reader' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "reader" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_reader", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_cysystemd__reader) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "cysystemd.reader")) {
      if (unlikely((PyDict_SetItemString(modules, "cysystemd.reader", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "cysystemd/reader.pyx":2
 * #cython: unraisable_tracebacks=True
 * from pathlib import Path             # <<<<<<<<<<<<<<
 * from typing import Iterator, Tuple, Union
 * 
*/

#line 2 "cysystemd/reader.pyx"
  {

#line 2 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Path};

#line 2 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pathlib, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)

#line 2 "cysystemd/reader.pyx"
  }

#line 2 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 2 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 2 "cysystemd/reader.pyx"
  {

#line 2 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Path};

#line 2 "cysystemd/reader.pyx"
    __pyx_t_3 = 0; {

#line 2 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2, __pyx_L1_error)

#line 2 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 2 "cysystemd/reader.pyx"
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 2, __pyx_L1_error)

#line 2 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 2 "cysystemd/reader.pyx"
    }

#line 2 "cysystemd/reader.pyx"
  }

#line 2 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":3
 * #cython: unraisable_tracebacks=True
 * from pathlib import Path
 * from typing import Iterator, Tuple, Union             # <<<<<<<<<<<<<<
 * 
 * from cpython.mem cimport PyMem_Malloc, PyMem_Free
*/

#line 3 "cysystemd/reader.pyx"
  {

#line 3 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Iterator,__pyx_mstate_global->__pyx_n_u_Tuple,__pyx_mstate_global->__pyx_n_u_Union};

#line 3 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_typing, __pyx_imported_names, 3, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3, __pyx_L1_error)

#line 3 "cysystemd/reader.pyx"
  }

#line 3 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 3 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 3 "cysystemd/reader.pyx"
  {

#line 3 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Iterator,__pyx_mstate_global->__pyx_n_u_Tuple,__pyx_mstate_global->__pyx_n_u_Union};

#line 3 "cysystemd/reader.pyx"
    for (__pyx_t_3=0; __pyx_t_3 < 3; __pyx_t_3++) {

#line 3 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3, __pyx_L1_error)

#line 3 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 3 "cysystemd/reader.pyx"
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 3, __pyx_L1_error)

#line 3 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 3 "cysystemd/reader.pyx"
    }

#line 3 "cysystemd/reader.pyx"
  }

#line 3 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":12
 * from .sd_id128 cimport sd_id128_t
 * 
 * import os             # <<<<<<<<<<<<<<
 * import logging
 * import warnings
*/

#line 12 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)

#line 12 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 12 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 12 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_os, __pyx_t_2) < (0)) __PYX_ERR(0, 12, __pyx_L1_error)

#line 12 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":13
 * 
 * import os
 * import logging             # <<<<<<<<<<<<<<
 * import warnings
 * from datetime import datetime, timezone
*/

#line 13 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_logging, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)

#line 13 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 13 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 13 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_logging, __pyx_t_2) < (0)) __PYX_ERR(0, 13, __pyx_L1_error)

#line 13 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":14
 * import os
 * import logging
 * import warnings             # <<<<<<<<<<<<<<
 * from datetime import datetime, timezone
 * from uuid import UUID
*/

#line 14 "cysystemd/reader.pyx"
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_warnings, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)

#line 14 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 14 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 14 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_warnings, __pyx_t_2) < (0)) __PYX_ERR(0, 14, __pyx_L1_error)

#line 14 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":15
 * import logging
 * import warnings
 * from datetime import datetime, timezone             # <<<<<<<<<<<<<<
 * from uuid import UUID
 * from contextlib import contextmanager
*/

#line 15 "cysystemd/reader.pyx"
  {

#line 15 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_datetime,__pyx_mstate_global->__pyx_n_u_timezone};

#line 15 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_datetime, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)

#line 15 "cysystemd/reader.pyx"
  }

#line 15 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 15 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 15 "cysystemd/reader.pyx"
  {

#line 15 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_datetime,__pyx_mstate_global->__pyx_n_u_timezone};

#line 15 "cysystemd/reader.pyx"
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {

#line 15 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 15, __pyx_L1_error)

#line 15 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 15 "cysystemd/reader.pyx"
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 15, __pyx_L1_error)

#line 15 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 15 "cysystemd/reader.pyx"
    }

#line 15 "cysystemd/reader.pyx"
  }

#line 15 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":16
 * import warnings
 * from datetime import datetime, timezone
 * from uuid import UUID             # <<<<<<<<<<<<<<
 * from contextlib import contextmanager
 * from errno import errorcode
*/

#line 16 "cysystemd/reader.pyx"
  {

#line 16 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_UUID};

#line 16 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_uuid, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)

#line 16 "cysystemd/reader.pyx"
  }

#line 16 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 16 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 16 "cysystemd/reader.pyx"
  {

#line 16 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_UUID};

#line 16 "cysystemd/reader.pyx"
    __pyx_t_3 = 0; {

#line 16 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 16, __pyx_L1_error)

#line 16 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 16 "cysystemd/reader.pyx"
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 16, __pyx_L1_error)

#line 16 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 16 "cysystemd/reader.pyx"
    }

#line 16 "cysystemd/reader.pyx"
  }

#line 16 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":17
 * from datetime import datetime, timezone
 * from uuid import UUID
 * from contextlib import contextmanager             # <<<<<<<<<<<<<<
 * from errno import errorcode
 * from enum import IntEnum, IntFlag
*/

#line 17 "cysystemd/reader.pyx"
  {

#line 17 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_contextmanager};

#line 17 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_contextlib, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)

#line 17 "cysystemd/reader.pyx"
  }

#line 17 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 17 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 17 "cysystemd/reader.pyx"
  {

#line 17 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_contextmanager};

#line 17 "cysystemd/reader.pyx"
    __pyx_t_3 = 0; {

#line 17 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 17, __pyx_L1_error)

#line 17 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 17 "cysystemd/reader.pyx"
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 17, __pyx_L1_error)

#line 17 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 17 "cysystemd/reader.pyx"
    }

#line 17 "cysystemd/reader.pyx"
  }

#line 17 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":18
 * from uuid import UUID
 * from contextlib import contextmanager
 * from errno import errorcode             # <<<<<<<<<<<<<<
 * from enum import IntEnum, IntFlag
 * 
*/

#line 18 "cysystemd/reader.pyx"
  {

#line 18 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errorcode};

#line 18 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_errno, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)

#line 18 "cysystemd/reader.pyx"
  }

#line 18 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 18 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 18 "cysystemd/reader.pyx"
  {

#line 18 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errorcode};

#line 18 "cysystemd/reader.pyx"
    __pyx_t_3 = 0; {

#line 18 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 18, __pyx_L1_error)

#line 18 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 18 "cysystemd/reader.pyx"
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 18, __pyx_L1_error)

#line 18 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 18 "cysystemd/reader.pyx"
    }

#line 18 "cysystemd/reader.pyx"
  }

#line 18 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":19
 * from contextlib import contextmanager
 * from errno import errorcode
 * from enum import IntEnum, IntFlag             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 19 "cysystemd/reader.pyx"
  {

#line 19 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_IntEnum,__pyx_mstate_global->__pyx_n_u_IntFlag};

#line 19 "cysystemd/reader.pyx"
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_enum, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)

#line 19 "cysystemd/reader.pyx"
  }

#line 19 "cysystemd/reader.pyx"
  __pyx_t_2 = __pyx_t_1;

#line 19 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 19 "cysystemd/reader.pyx"
  {

#line 19 "cysystemd/reader.pyx"
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_IntEnum,__pyx_mstate_global->__pyx_n_u_IntFlag};

#line 19 "cysystemd/reader.pyx"
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {

#line 19 "cysystemd/reader.pyx"
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 19, __pyx_L1_error)

#line 19 "cysystemd/reader.pyx"
      __Pyx_GOTREF(__pyx_t_4);

#line 19 "cysystemd/reader.pyx"
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 19, __pyx_L1_error)

#line 19 "cysystemd/reader.pyx"
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 19 "cysystemd/reader.pyx"
    }

#line 19 "cysystemd/reader.pyx"
  }

#line 19 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":22
 * 
 * 
 * log = logging.getLogger(__name__)             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 22 "cysystemd/reader.pyx"
  __pyx_t_4 = NULL;

#line 22 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_logging); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 22, __pyx_L1_error)

#line 22 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 22 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_getLogger); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 22, __pyx_L1_error)

#line 22 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 22 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 22 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 22, __pyx_L1_error)

#line 22 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 22 "cysystemd/reader.pyx"
  __pyx_t_7 = 1;

#line 22 "cysystemd/reader.pyx"
  {

#line 22 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};

#line 22 "cysystemd/reader.pyx"
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 22 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 22 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 22 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 22 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)

#line 22 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_2);

#line 22 "cysystemd/reader.pyx"
  }

#line 22 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_log, __pyx_t_2) < (0)) __PYX_ERR(0, 22, __pyx_L1_error)

#line 22 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":25
 * 
 * 
 * WAIT_MAX_TIME = 4294967295             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 25 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_WAIT_MAX_TIME, __pyx_mstate_global->__pyx_int_4294967295) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)

  /* "cysystemd/reader.pyx":28
 * 
 * 
 * class JournalEvent(IntEnum):             # <<<<<<<<<<<<<<
 *     NOP = SD_JOURNAL_NOP
 *     APPEND = SD_JOURNAL_APPEND
*/

#line 28 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_IntEnum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 28 "cysystemd/reader.pyx"
  __pyx_t_6 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 28 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 28 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 28 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 28 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_5, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_JournalEvent, __pyx_mstate_global->__pyx_n_u_JournalEvent, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 28 "cysystemd/reader.pyx"
  if (__pyx_t_2 != __pyx_t_6) {

#line 28 "cysystemd/reader.pyx"
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_t_6) < 0))) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  }

#line 28 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":29
 * 
 * class JournalEvent(IntEnum):
 *     NOP = SD_JOURNAL_NOP             # <<<<<<<<<<<<<<
 *     APPEND = SD_JOURNAL_APPEND
 *     INVALIDATE =  SD_JOURNAL_INVALIDATE
*/

#line 29 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_NOP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 29, __pyx_L1_error)

#line 29 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 29 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_NOP, __pyx_t_6) < (0)) __PYX_ERR(0, 29, __pyx_L1_error)

#line 29 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":30
 * class JournalEvent(IntEnum):
 *     NOP = SD_JOURNAL_NOP
 *     APPEND = SD_JOURNAL_APPEND             # <<<<<<<<<<<<<<
 *     INVALIDATE =  SD_JOURNAL_INVALIDATE
 * 
*/

#line 30 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_APPEND); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 30, __pyx_L1_error)

#line 30 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 30 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_APPEND, __pyx_t_6) < (0)) __PYX_ERR(0, 30, __pyx_L1_error)

#line 30 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":31
 *     NOP = SD_JOURNAL_NOP
 *     APPEND = SD_JOURNAL_APPEND
 *     INVALIDATE =  SD_JOURNAL_INVALIDATE             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 31 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_INVALIDATE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 31, __pyx_L1_error)

#line 31 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 31 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_INVALIDATE, __pyx_t_6) < (0)) __PYX_ERR(0, 31, __pyx_L1_error)

#line 31 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":28
 * 
 * 
 * class JournalEvent(IntEnum):             # <<<<<<<<<<<<<<
 *     NOP = SD_JOURNAL_NOP
 *     APPEND = SD_JOURNAL_APPEND
*/

#line 28 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_JournalEvent, __pyx_t_2, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 28 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 28 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 28 "cysystemd/reader.pyx"
  #endif

#line 28 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_JournalEvent, __pyx_t_6) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)

#line 28 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 28 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 28 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 28 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":39
 * 
 * 
 * class MatchOperation(IntEnum):             # <<<<<<<<<<<<<<
 *     AND = MATCHER_OPERATION_CONJUNCTION
 *     OR = MATCHER_OPERATION_DISJUNCTION
*/

#line 39 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_IntEnum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 39 "cysystemd/reader.pyx"
  __pyx_t_5 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 39 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 39 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 39 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 39 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_MatchOperation, __pyx_mstate_global->__pyx_n_u_MatchOperation, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 39 "cysystemd/reader.pyx"
  if (__pyx_t_2 != __pyx_t_5) {

#line 39 "cysystemd/reader.pyx"
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_5) < 0))) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  }

#line 39 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":40
 * 
 * class MatchOperation(IntEnum):
 *     AND = MATCHER_OPERATION_CONJUNCTION             # <<<<<<<<<<<<<<
 *     OR = MATCHER_OPERATION_DISJUNCTION
 * 
*/

#line 40 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_enum____pyx_t_9cysystemd_6reader_MATCHER_OPERATION(__pyx_e_9cysystemd_6reader_MATCHER_OPERATION_CONJUNCTION); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 40, __pyx_L1_error)

#line 40 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 40 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_AND, __pyx_t_5) < (0)) __PYX_ERR(0, 40, __pyx_L1_error)

#line 40 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":41
 * class MatchOperation(IntEnum):
 *     AND = MATCHER_OPERATION_CONJUNCTION
 *     OR = MATCHER_OPERATION_DISJUNCTION             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 41 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_enum____pyx_t_9cysystemd_6reader_MATCHER_OPERATION(__pyx_e_9cysystemd_6reader_MATCHER_OPERATION_DISJUNCTION); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 41, __pyx_L1_error)

#line 41 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 41 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_OR, __pyx_t_5) < (0)) __PYX_ERR(0, 41, __pyx_L1_error)

#line 41 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":39
 * 
 * 
 * class MatchOperation(IntEnum):             # <<<<<<<<<<<<<<
 *     AND = MATCHER_OPERATION_CONJUNCTION
 *     OR = MATCHER_OPERATION_DISJUNCTION
*/

#line 39 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_Py3ClassCreate(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_MatchOperation, __pyx_t_2, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 39 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 39 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 39 "cysystemd/reader.pyx"
  #endif

#line 39 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_MatchOperation, __pyx_t_5) < (0)) __PYX_ERR(0, 39, __pyx_L1_error)

#line 39 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 39 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 39 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 39 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":49
 * 
 * 
 * class Poll(IntEnum):             # <<<<<<<<<<<<<<
 *     IN = POLLIN
 *     OUT = POLLOUT
*/

#line 49 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_IntEnum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 49 "cysystemd/reader.pyx"
  __pyx_t_4 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 49 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 49 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 49 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 49 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare(__pyx_t_6, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_Poll, __pyx_mstate_global->__pyx_n_u_Poll, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 49 "cysystemd/reader.pyx"
  if (__pyx_t_2 != __pyx_t_4) {

#line 49 "cysystemd/reader.pyx"
    if (unlikely((PyDict_SetItemString(__pyx_t_5, "__orig_bases__", __pyx_t_4) < 0))) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  }

#line 49 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cysystemd/reader.pyx":50
 * 
 * class Poll(IntEnum):
 *     IN = POLLIN             # <<<<<<<<<<<<<<
 *     OUT = POLLOUT
 * 
*/

#line 50 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_int(POLLIN); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 50, __pyx_L1_error)

#line 50 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 50 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_IN, __pyx_t_4) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)

#line 50 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cysystemd/reader.pyx":51
 * class Poll(IntEnum):
 *     IN = POLLIN
 *     OUT = POLLOUT             # <<<<<<<<<<<<<<
 * 
 * 
*/

#line 51 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyLong_From_int(POLLOUT); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 51, __pyx_L1_error)

#line 51 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 51 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_OUT, __pyx_t_4) < (0)) __PYX_ERR(0, 51, __pyx_L1_error)

#line 51 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cysystemd/reader.pyx":49
 * 
 * 
 * class Poll(IntEnum):             # <<<<<<<<<<<<<<
 *     IN = POLLIN
 *     OUT = POLLOUT
*/

#line 49 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_Py3ClassCreate(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Poll, __pyx_t_2, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 49 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 49 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);

#line 49 "cysystemd/reader.pyx"
  #endif

#line 49 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_Poll, __pyx_t_4) < (0)) __PYX_ERR(0, 49, __pyx_L1_error)

#line 49 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 49 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 49 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 49 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

#line 1 "(tree fragment)"
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_4Rule_12__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Rule___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)

#line 1 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_2);

#line 1 "(tree fragment)"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 1 "(tree fragment)"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(1, 1, __pyx_L1_error)

#line 1 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Rule, (type(self), 0xfd11a85, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Rule__set_state(self, __pyx_state)
*/

#line 16 "(tree fragment)"
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_4Rule_14__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Rule___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 16, __pyx_L1_error)

#line 16 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_2);

#line 16 "(tree fragment)"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 16 "(tree fragment)"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);

#line 16 "(tree fragment)"
  #endif

#line 16 "(tree fragment)"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_Rule, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(1, 16, __pyx_L1_error)

#line 16 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":129
 * 
 * 
 * def check_error_code(int code) -> int:             # <<<<<<<<<<<<<<
 *     if code >= 0:
 *         return code
*/

#line 129 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 129, __pyx_L1_error)

#line 129 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 129 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 129, __pyx_L1_error)

#line 129 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_1check_error_code, 0, __pyx_mstate_global->__pyx_n_u_check_error_code, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 129, __pyx_L1_error)

#line 129 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 129 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 129 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 129 "cysystemd/reader.pyx"
  #endif

#line 129 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);

#line 129 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 129 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_check_error_code, __pyx_t_6) < (0)) __PYX_ERR(0, 129, __pyx_L1_error)

#line 129 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":141
 * 
 * 
 * class JournalOpenMode(IntFlag):             # <<<<<<<<<<<<<<
 *     LOCAL_ONLY = SD_JOURNAL_LOCAL_ONLY
 *     RUNTIME_ONLY = SD_JOURNAL_RUNTIME_ONLY
*/

#line 141 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_IntFlag); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 141 "cysystemd/reader.pyx"
  __pyx_t_2 = PyTuple_Pack(1, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 141 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 141 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 141 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CalculateMetaclass(NULL, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 141 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_5, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_JournalOpenMode, __pyx_mstate_global->__pyx_n_u_JournalOpenMode, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 141 "cysystemd/reader.pyx"
  if (__pyx_t_6 != __pyx_t_2) {

#line 141 "cysystemd/reader.pyx"
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  }

#line 141 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":142
 * 
 * class JournalOpenMode(IntFlag):
 *     LOCAL_ONLY = SD_JOURNAL_LOCAL_ONLY             # <<<<<<<<<<<<<<
 *     RUNTIME_ONLY = SD_JOURNAL_RUNTIME_ONLY
 *     SYSTEM = SD_JOURNAL_SYSTEM
*/

#line 142 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_LOCAL_ONLY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 142, __pyx_L1_error)

#line 142 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 142 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_LOCAL_ONLY, __pyx_t_2) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)

#line 142 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":143
 * class JournalOpenMode(IntFlag):
 *     LOCAL_ONLY = SD_JOURNAL_LOCAL_ONLY
 *     RUNTIME_ONLY = SD_JOURNAL_RUNTIME_ONLY             # <<<<<<<<<<<<<<
 *     SYSTEM = SD_JOURNAL_SYSTEM
 *     CURRENT_USER = SD_JOURNAL_CURRENT_USER
*/

#line 143 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_RUNTIME_ONLY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)

#line 143 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 143 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_RUNTIME_ONLY, __pyx_t_2) < (0)) __PYX_ERR(0, 143, __pyx_L1_error)

#line 143 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":144
 *     LOCAL_ONLY = SD_JOURNAL_LOCAL_ONLY
 *     RUNTIME_ONLY = SD_JOURNAL_RUNTIME_ONLY
 *     SYSTEM = SD_JOURNAL_SYSTEM             # <<<<<<<<<<<<<<
 *     CURRENT_USER = SD_JOURNAL_CURRENT_USER
 * 
*/

#line 144 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_SYSTEM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 144, __pyx_L1_error)

#line 144 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 144 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_SYSTEM, __pyx_t_2) < (0)) __PYX_ERR(0, 144, __pyx_L1_error)

#line 144 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":145
 *     RUNTIME_ONLY = SD_JOURNAL_RUNTIME_ONLY
 *     SYSTEM = SD_JOURNAL_SYSTEM
 *     CURRENT_USER = SD_JOURNAL_CURRENT_USER             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
*/

#line 145 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyLong_From___pyx_anon_enum(SD_JOURNAL_CURRENT_USER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 145, __pyx_L1_error)

#line 145 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 145 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CURRENT_USER, __pyx_t_2) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)

#line 145 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":147
 *     CURRENT_USER = SD_JOURNAL_CURRENT_USER
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _missing_(cls, value) -> 'JournalOpenMode':
 *         if value == SD_JOURNAL_SYSTEM_ONLY:
*/

#line 147 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)

#line 147 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 147 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_JournalOpenMode_2) < (0)) __PYX_ERR(0, 147, __pyx_L1_error)

#line 147 "cysystemd/reader.pyx"
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_15JournalOpenMode_1_missing_, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_mstate_global->__pyx_n_u_JournalOpenMode__missing, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 147, __pyx_L1_error)

#line 147 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_8);

#line 147 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 147 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);

#line 147 "cysystemd/reader.pyx"
  #endif

#line 147 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_2);

#line 147 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 147 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)

#line 147 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 147 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

#line 147 "cysystemd/reader.pyx"
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_missing, __pyx_t_2) < (0)) __PYX_ERR(0, 147, __pyx_L1_error)

#line 147 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysystemd/reader.pyx":141
 * 
 * 
 * class JournalOpenMode(IntFlag):             # <<<<<<<<<<<<<<
 *     LOCAL_ONLY = SD_JOURNAL_LOCAL_ONLY
 *     RUNTIME_ONLY = SD_JOURNAL_RUNTIME_ONLY
*/

#line 141 "cysystemd/reader.pyx"
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_JournalOpenMode, __pyx_t_6, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 141 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 141 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);

#line 141 "cysystemd/reader.pyx"
  #endif

#line 141 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_JournalOpenMode, __pyx_t_2) < (0)) __PYX_ERR(0, 141, __pyx_L1_error)

#line 141 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 141 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 141 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 141 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":221
 *     cdef object __date
 * 
 *     max_message_size = 2**20             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, JournalReader reader):
*/

#line 221 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_mstate_global->__pyx_n_u_max_message_size, __pyx_mstate_global->__pyx_int_1048576) < (0)) __PYX_ERR(0, 221, __pyx_L1_error)

  /* "cysystemd/reader.pyx":268
 *         return self.cursor
 * 
 *     cpdef double get_realtime_sec(self):             # <<<<<<<<<<<<<<
 *         cdef double result = self.realtime_usec / 1000000.
 *         return result
*/

#line 268 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_12JournalEntry_3get_realtime_sec, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalEntry_get_realtime_sec, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 268, __pyx_L1_error)

#line 268 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 268 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 268 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 268 "cysystemd/reader.pyx"
  #endif

#line 268 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_mstate_global->__pyx_n_u_get_realtime_sec, __pyx_t_6) < (0)) __PYX_ERR(0, 268, __pyx_L1_error)

#line 268 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":272
 *         return result
 * 
 *     cpdef double get_monotonic_sec(self):             # <<<<<<<<<<<<<<
 *         cdef double result = self.monotonic_usec / 1000000.
 *         return self.monotonic_usec / 1000000.
*/

#line 272 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_12JournalEntry_5get_monotonic_sec, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalEntry_get_monotonic_sec, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 272, __pyx_L1_error)

#line 272 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 272 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 272 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 272 "cysystemd/reader.pyx"
  #endif

#line 272 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_mstate_global->__pyx_n_u_get_monotonic_sec, __pyx_t_6) < (0)) __PYX_ERR(0, 272, __pyx_L1_error)

#line 272 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":276
 *         return self.monotonic_usec / 1000000.
 * 
 *     cpdef uint64_t get_realtime_usec(self):             # <<<<<<<<<<<<<<
 *         return self.realtime_usec
 * 
*/

#line 276 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_12JournalEntry_7get_realtime_usec, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalEntry_get_realtime_usec, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 276, __pyx_L1_error)

#line 276 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 276 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 276 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 276 "cysystemd/reader.pyx"
  #endif

#line 276 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_mstate_global->__pyx_n_u_get_realtime_usec, __pyx_t_6) < (0)) __PYX_ERR(0, 276, __pyx_L1_error)

#line 276 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":279
 *         return self.realtime_usec
 * 
 *     cpdef uint64_t get_monotonic_usec(self):             # <<<<<<<<<<<<<<
 *         return self.monotonic_usec
 * 
*/

#line 279 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_12JournalEntry_9get_monotonic_usec, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalEntry_get_monotonic_usec, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 279, __pyx_L1_error)

#line 279 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 279 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 279 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 279 "cysystemd/reader.pyx"
  #endif

#line 279 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalEntry, __pyx_mstate_global->__pyx_n_u_get_monotonic_usec, __pyx_t_6) < (0)) __PYX_ERR(0, 279, __pyx_L1_error)

#line 279 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

#line 1 "(tree fragment)"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_12JournalEntry_17__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalEntry___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1, __pyx_L1_error)

#line 1 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_6);

#line 1 "(tree fragment)"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 1 "(tree fragment)"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(1, 1, __pyx_L1_error)

#line 1 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

#line 3 "(tree fragment)"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_12JournalEntry_19__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalEntry___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 3, __pyx_L1_error)

#line 3 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_6);

#line 3 "(tree fragment)"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 3 "(tree fragment)"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(1, 3, __pyx_L1_error)

#line 3 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":313
 *         self.flags = None
 * 
 *     def open(self, flags=JournalOpenMode.CURRENT_USER) -> int:             # <<<<<<<<<<<<<<
 *         self.flags = JournalOpenMode(int(flags))
 * 
*/

#line 313 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_JournalOpenMode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 313 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_CURRENT_USER); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 313 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 313 "cysystemd/reader.pyx"
  __pyx_mstate_global->__pyx_k__4 = __pyx_t_5;

#line 313 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_t_5);

#line 313 "cysystemd/reader.pyx"
  __pyx_t_5 = 0;

#line 313 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_JournalOpenMode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 313 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_CURRENT_USER); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 313 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 313 "cysystemd/reader.pyx"
  __pyx_t_5 = PyTuple_Pack(1, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 313 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 313 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 313 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_3open, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_open, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 313 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 313 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);

#line 313 "cysystemd/reader.pyx"
  #endif

#line 313 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_5);

#line 313 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_6);

#line 313 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 313 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 313 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_open, __pyx_t_4) < (0)) __PYX_ERR(0, 313, __pyx_L1_error)

#line 313 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cysystemd/reader.pyx":319
 *             return check_error_code(sd_journal_open(&self.context, self.flags.value))
 * 
 *     def open_directory(self, path) -> None:             # <<<<<<<<<<<<<<
 *         path = _check_dir_path(path)
 * 
*/

#line 319 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)

#line 319 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 319 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 319, __pyx_L1_error)

#line 319 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_5open_directory, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_open_directory, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 319, __pyx_L1_error)

#line 319 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 319 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 319 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 319 "cysystemd/reader.pyx"
  #endif

#line 319 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_4);

#line 319 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 319 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_open_directory, __pyx_t_6) < (0)) __PYX_ERR(0, 319, __pyx_L1_error)

#line 319 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":326
 *             check_error_code(sd_journal_open_directory(&self.context, cstr, 0))
 * 
 *     def open_files(self, *file_names: Union[str, Path]) -> None:             # <<<<<<<<<<<<<<
 *         file_names = tuple(map(_check_file_path, file_names))
 * 
*/

#line 326 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 326, __pyx_L1_error)

#line 326 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 326 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_file_names, __pyx_mstate_global->__pyx_kp_u_Union_str_Path) < (0)) __PYX_ERR(0, 326, __pyx_L1_error)

#line 326 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 326, __pyx_L1_error)

#line 326 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_7open_files, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_open_files, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 326, __pyx_L1_error)

#line 326 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 326 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 326 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);

#line 326 "cysystemd/reader.pyx"
  #endif

#line 326 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_6);

#line 326 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 326 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_open_files, __pyx_t_4) < (0)) __PYX_ERR(0, 326, __pyx_L1_error)

#line 326 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cysystemd/reader.pyx":376
 *         return self.state == READER_OPENED
 * 
 *     @contextmanager             # <<<<<<<<<<<<<<
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:
*/

#line 376 "cysystemd/reader.pyx"
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_4);

#line 376 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_9_lock, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader__lock, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 376 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 376 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 376 "cysystemd/reader.pyx"
  #endif

#line 376 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[1]);

#line 376 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_4);

#line 376 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 376 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_lock, __pyx_t_6) < (0)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 376 "cysystemd/reader.pyx"
  __pyx_t_4 = NULL;

#line 376 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_contextmanager); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 376 "cysystemd/reader.pyx"
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_lock); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_2);

#line 376 "cysystemd/reader.pyx"
  __pyx_t_7 = 1;

#line 376 "cysystemd/reader.pyx"
  {

#line 376 "cysystemd/reader.pyx"
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};

#line 376 "cysystemd/reader.pyx"
    __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));

#line 376 "cysystemd/reader.pyx"
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

#line 376 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

#line 376 "cysystemd/reader.pyx"
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 376 "cysystemd/reader.pyx"
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
    __Pyx_GOTREF(__pyx_t_6);

#line 376 "cysystemd/reader.pyx"
  }

#line 376 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_lock, __pyx_t_6) < (0)) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":392
 *             self.state = READER_OPENED
 * 
 *     def seek_head(self) -> bool:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 392 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 392, __pyx_L1_error)

#line 392 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 392 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 392, __pyx_L1_error)

#line 392 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_12seek_head, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_seek_head, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 392, __pyx_L1_error)

#line 392 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 392 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 392 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 392 "cysystemd/reader.pyx"
  #endif

#line 392 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);

#line 392 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 392 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_seek_head, __pyx_t_5) < (0)) __PYX_ERR(0, 392, __pyx_L1_error)

#line 392 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":402
 *         return True
 * 
 *     def seek_tail(self) -> bool:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 402 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 402, __pyx_L1_error)

#line 402 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 402 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 402, __pyx_L1_error)

#line 402 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_14seek_tail, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_seek_tail, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 402, __pyx_L1_error)

#line 402 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 402 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 402 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 402 "cysystemd/reader.pyx"
  #endif

#line 402 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);

#line 402 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 402 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_seek_tail, __pyx_t_6) < (0)) __PYX_ERR(0, 402, __pyx_L1_error)

#line 402 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":413
 *         return True
 * 
 *     def seek_monotonic_usec(self, boot_id: UUID, uint64_t usec) -> bool:             # <<<<<<<<<<<<<<
 *         cdef sd_id128_t cboot_id
 *         cdef int result
*/

#line 413 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 413, __pyx_L1_error)

#line 413 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 413 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_boot_id, __pyx_mstate_global->__pyx_n_u_UUID) < (0)) __PYX_ERR(0, 413, __pyx_L1_error)

#line 413 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 413, __pyx_L1_error)

#line 413 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_16seek_monotonic_usec, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_seek_monotonic_use, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 413, __pyx_L1_error)

#line 413 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 413 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 413 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 413 "cysystemd/reader.pyx"
  #endif

#line 413 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);

#line 413 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 413 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_seek_monotonic_usec, __pyx_t_5) < (0)) __PYX_ERR(0, 413, __pyx_L1_error)

#line 413 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":425
 *         return True
 * 
 *     def seek_realtime_usec(self, uint64_t usec) -> bool:             # <<<<<<<<<<<<<<
 *         cdef uint64_t cusec = usec
 *         cdef int result
*/

#line 425 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 425, __pyx_L1_error)

#line 425 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 425 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 425, __pyx_L1_error)

#line 425 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_18seek_realtime_usec, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_seek_realtime_usec, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 425, __pyx_L1_error)

#line 425 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 425 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 425 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 425 "cysystemd/reader.pyx"
  #endif

#line 425 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);

#line 425 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 425 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_seek_realtime_usec, __pyx_t_6) < (0)) __PYX_ERR(0, 425, __pyx_L1_error)

#line 425 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":435
 *         return True
 * 
 *     def seek_cursor(self, bytes cursor) -> bool:             # <<<<<<<<<<<<<<
 *         cdef char* ccursor = cursor
 *         cdef int result
*/

#line 435 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 435, __pyx_L1_error)

#line 435 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 435 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 435, __pyx_L1_error)

#line 435 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_20seek_cursor, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_seek_cursor, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 435, __pyx_L1_error)

#line 435 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 435 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 435 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 435 "cysystemd/reader.pyx"
  #endif

#line 435 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);

#line 435 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 435 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_seek_cursor, __pyx_t_5) < (0)) __PYX_ERR(0, 435, __pyx_L1_error)

#line 435 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":445
 *         return True
 * 
 *     cpdef wait(self, uint32_t timeout = WAIT_MAX_TIME):             # <<<<<<<<<<<<<<
 *         cdef uint64_t timeout_usec = timeout * 1000000
 *         cdef int result
*/

#line 445 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WAIT_MAX_TIME); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 445 "cysystemd/reader.pyx"
  __pyx_t_9 = __Pyx_PyLong_As_uint32_t(__pyx_t_5); if (unlikely((__pyx_t_9 == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 445 "cysystemd/reader.pyx"
  __pyx_mstate_global->__pyx_k__5 = __pyx_t_9;

#line 445 "cysystemd/reader.pyx"
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WAIT_MAX_TIME); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 445 "cysystemd/reader.pyx"
  __pyx_t_9 = __Pyx_PyLong_As_uint32_t(__pyx_t_5); if (unlikely((__pyx_t_9 == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 445 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyLong_From_uint32_t(__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 445 "cysystemd/reader.pyx"
  __pyx_t_6 = PyTuple_Pack(1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 445 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 445 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_22wait, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_wait, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 445 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 445 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 445 "cysystemd/reader.pyx"
  #endif

#line 445 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_6);

#line 445 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 445 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_wait, __pyx_t_5) < (0)) __PYX_ERR(0, 445, __pyx_L1_error)

#line 445 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":458
 *         return iter(self.next, None)
 * 
 *     def next(self, uint64_t skip=0) -> JournalEntry:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 458 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 458, __pyx_L1_error)

#line 458 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 458 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_JournalEntry) < (0)) __PYX_ERR(0, 458, __pyx_L1_error)

#line 458 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_26next, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_next, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 458, __pyx_L1_error)

#line 458 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 458 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 458 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 458 "cysystemd/reader.pyx"
  #endif

#line 458 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[2]);

#line 458 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);

#line 458 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 458 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_next, __pyx_t_6) < (0)) __PYX_ERR(0, 458, __pyx_L1_error)

#line 458 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":470
 *                 return JournalEntry(self)
 * 
 *     def skip_next(self, uint64_t skip) -> int:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 470 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 470, __pyx_L1_error)

#line 470 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 470 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 470, __pyx_L1_error)

#line 470 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_28skip_next, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_skip_next, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 470, __pyx_L1_error)

#line 470 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 470 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 470 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 470 "cysystemd/reader.pyx"
  #endif

#line 470 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);

#line 470 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 470 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_skip_next, __pyx_t_5) < (0)) __PYX_ERR(0, 470, __pyx_L1_error)

#line 470 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":478
 *         return check_error_code(result)
 * 
 *     def previous(self, uint64_t skip=0) -> JournalEntry:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 478 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 478, __pyx_L1_error)

#line 478 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 478 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_JournalEntry) < (0)) __PYX_ERR(0, 478, __pyx_L1_error)

#line 478 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_30previous, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_previous, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 478, __pyx_L1_error)

#line 478 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 478 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 478 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 478 "cysystemd/reader.pyx"
  #endif

#line 478 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[2]);

#line 478 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);

#line 478 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 478 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_previous, __pyx_t_6) < (0)) __PYX_ERR(0, 478, __pyx_L1_error)

#line 478 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":490
 *                 return JournalEntry(self)
 * 
 *     def skip_previous(self, uint64_t skip) -> int:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 490 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 490, __pyx_L1_error)

#line 490 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 490 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 490, __pyx_L1_error)

#line 490 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_32skip_previous, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_skip_previous, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 490, __pyx_L1_error)

#line 490 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 490 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 490 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 490 "cysystemd/reader.pyx"
  #endif

#line 490 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);

#line 490 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 490 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_skip_previous, __pyx_t_5) < (0)) __PYX_ERR(0, 490, __pyx_L1_error)

#line 490 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":498
 *         return check_error_code(result)
 * 
 *     def add_filter(self, Rule rule) -> None:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* exp
*/

#line 498 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 498, __pyx_L1_error)

#line 498 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 498 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 498, __pyx_L1_error)

#line 498 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_34add_filter, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_add_filter, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 498, __pyx_L1_error)

#line 498 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 498 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 498 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 498 "cysystemd/reader.pyx"
  #endif

#line 498 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);

#line 498 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 498 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_add_filter, __pyx_t_6) < (0)) __PYX_ERR(0, 498, __pyx_L1_error)

#line 498 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":518
 *                     raise ValueError('Invalid operation')
 * 
 *     def clear_filter(self) -> None:             # <<<<<<<<<<<<<<
 *         sd_journal_flush_matches(self.context)
 * 
*/

#line 518 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 518, __pyx_L1_error)

#line 518 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 518 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 518, __pyx_L1_error)

#line 518 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_36clear_filter, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_clear_filter, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 518, __pyx_L1_error)

#line 518 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 518 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 518 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 518 "cysystemd/reader.pyx"
  #endif

#line 518 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);

#line 518 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 518 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_clear_filter, __pyx_t_5) < (0)) __PYX_ERR(0, 518, __pyx_L1_error)

#line 518 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":543
 *         return timeout
 * 
 *     def process_events(self) -> JournalEvent:             # <<<<<<<<<<<<<<
 *         return JournalEvent(check_error_code(sd_journal_process(self.context)))
 * 
*/

#line 543 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 543, __pyx_L1_error)

#line 543 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 543 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_JournalEvent) < (0)) __PYX_ERR(0, 543, __pyx_L1_error)

#line 543 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_42process_events, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_process_events, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 543, __pyx_L1_error)

#line 543 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 543 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 543 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 543 "cysystemd/reader.pyx"
  #endif

#line 543 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);

#line 543 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 543 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_process_events, __pyx_t_6) < (0)) __PYX_ERR(0, 543, __pyx_L1_error)

#line 543 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":546
 *         return JournalEvent(check_error_code(sd_journal_process(self.context)))
 * 
 *     def get_catalog(self) -> Path:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* catalog
*/

#line 546 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 546, __pyx_L1_error)

#line 546 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 546 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_Path) < (0)) __PYX_ERR(0, 546, __pyx_L1_error)

#line 546 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_44get_catalog, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_get_catalog, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 546, __pyx_L1_error)

#line 546 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 546 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 546 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);

#line 546 "cysystemd/reader.pyx"
  #endif

#line 546 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);

#line 546 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 546 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_get_catalog, __pyx_t_5) < (0)) __PYX_ERR(0, 546, __pyx_L1_error)

#line 546 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cysystemd/reader.pyx":559
 *         return Path(bcatalog.decode())
 * 
 *     def get_catalog_for_message_id(self, message_id: UUID) -> Path:             # <<<<<<<<<<<<<<
 *         cdef int result
 *         cdef char* catalog
*/

#line 559 "cysystemd/reader.pyx"
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 559, __pyx_L1_error)

#line 559 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_5);

#line 559 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_message_id, __pyx_mstate_global->__pyx_n_u_UUID) < (0)) __PYX_ERR(0, 559, __pyx_L1_error)

#line 559 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_Path) < (0)) __PYX_ERR(0, 559, __pyx_L1_error)

#line 559 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_46get_catalog_for_message_id, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader_get_catalog_for_me, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 559, __pyx_L1_error)

#line 559 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 559 "cysystemd/reader.pyx"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 559 "cysystemd/reader.pyx"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 559 "cysystemd/reader.pyx"
  #endif

#line 559 "cysystemd/reader.pyx"
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);

#line 559 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

#line 559 "cysystemd/reader.pyx"
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9cysystemd_6reader_JournalReader, __pyx_mstate_global->__pyx_n_u_get_catalog_for_message_id, __pyx_t_6) < (0)) __PYX_ERR(0, 559, __pyx_L1_error)

#line 559 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
*/

#line 1 "(tree fragment)"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_48__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1, __pyx_L1_error)

#line 1 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_6);

#line 1 "(tree fragment)"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 1 "(tree fragment)"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 1 "(tree fragment)"
  #endif

#line 1 "(tree fragment)"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(1, 1, __pyx_L1_error)

#line 1 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.context cannot be converted to a Python object for pickling"
*/

#line 3 "(tree fragment)"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_13JournalReader_50__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_JournalReader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 3, __pyx_L1_error)

#line 3 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_6);

#line 3 "(tree fragment)"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 3 "(tree fragment)"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 3 "(tree fragment)"
  #endif

#line 3 "(tree fragment)"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(1, 3, __pyx_L1_error)

#line 3 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Rule(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xfd11a85, 0x5cc57e4, 0xb9426fe, b'_child, _expression, _operand, _root')
*/

#line 4 "(tree fragment)"
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9cysystemd_6reader_3__pyx_unpickle_Rule, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Rule, NULL, __pyx_mstate_global->__pyx_n_u_cysystemd_reader, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 4, __pyx_L1_error)

#line 4 "(tree fragment)"
  __Pyx_GOTREF(__pyx_t_6);

#line 4 "(tree fragment)"
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000

#line 4 "(tree fragment)"
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);

#line 4 "(tree fragment)"
  #endif

#line 4 "(tree fragment)"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Rule, __pyx_t_6) < (0)) __PYX_ERR(1, 4, __pyx_L1_error)

#line 4 "(tree fragment)"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cysystemd/reader.pyx":1
 * #cython: unraisable_tracebacks=True             # <<<<<<<<<<<<<<
 * from pathlib import Path
 * from typing import Iterator, Tuple, Union
*/

#line 1 "cysystemd/reader.pyx"
  __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1, __pyx_L1_error)

#line 1 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_t_6);

#line 1 "cysystemd/reader.pyx"
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_6) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)

#line 1 "cysystemd/reader.pyx"
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

#line 1 "cysystemd/reader.pyx"


#line 1 "cysystemd/reader.pyx"
  /*--- Wrapped vars code ---*/

#line 1 "cysystemd/reader.pyx"


#line 1 "cysystemd/reader.pyx"
  goto __pyx_L0;

#line 1 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 1 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_2);

#line 1 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_4);

#line 1 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_5);

#line 1 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_6);

#line 1 "cysystemd/reader.pyx"
  __Pyx_XDECREF(__pyx_t_8);

#line 1 "cysystemd/reader.pyx"
  if (__pyx_m) {

#line 1 "cysystemd/reader.pyx"
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {

#line 1 "cysystemd/reader.pyx"
      __Pyx_AddTraceback("init cysystemd.reader", __pyx_clineno, __pyx_lineno, __pyx_filename);

#line 1 "cysystemd/reader.pyx"
    }

#line 1 "cysystemd/reader.pyx"
    #if !CYTHON_USE_MODULE_STATE

#line 1 "cysystemd/reader.pyx"
    Py_CLEAR(__pyx_m);

#line 1 "cysystemd/reader.pyx"
    #else

#line 1 "cysystemd/reader.pyx"
    Py_DECREF(__pyx_m);

#line 1 "cysystemd/reader.pyx"
    if (pystate_addmodule_run) {

#line 1 "cysystemd/reader.pyx"
      PyObject *tp, *value, *tb;

#line 1 "cysystemd/reader.pyx"
      PyErr_Fetch(&tp, &value, &tb);

#line 1 "cysystemd/reader.pyx"
      PyState_RemoveModule(&__pyx_moduledef);

#line 1 "cysystemd/reader.pyx"
      PyErr_Restore(tp, value, tb);

#line 1 "cysystemd/reader.pyx"
    }

#line 1 "cysystemd/reader.pyx"
    #endif

#line 1 "cysystemd/reader.pyx"
  } else if (!PyErr_Occurred()) {

#line 1 "cysystemd/reader.pyx"
    PyErr_SetString(PyExc_ImportError, "init cysystemd.reader");

#line 1 "cysystemd/reader.pyx"
  }

#line 1 "cysystemd/reader.pyx"
  __pyx_L0:;

#line 1 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 1 "cysystemd/reader.pyx"
  #if CYTHON_PEP489_MULTI_PHASE_INIT

#line 1 "cysystemd/reader.pyx"
  return (__pyx_m != NULL) ? 0 : -1;

#line 1 "cysystemd/reader.pyx"
  #else

#line 1 "cysystemd/reader.pyx"
  return __pyx_m;

#line 1 "cysystemd/reader.pyx"
  #endif

#line 1 "cysystemd/reader.pyx"
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_map = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_map); if (!__pyx_builtin_map) __PYX_ERR(0, 327, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 332, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__upper.type = (PyObject*)(&PyUnicode_Type);
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__upper.method_name = &__pyx_mstate->__pyx_n_u_upper;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "cysystemd/reader.pyx":316
 *         self.flags = JournalOpenMode(int(flags))
 * 
 *         with self._lock(opening=True):             # <<<<<<<<<<<<<<
 *             return check_error_code(sd_journal_open(&self.context, self.flags.value))
 * 
*/

#line 316 "cysystemd/reader.pyx"
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 316, __pyx_L1_error)

#line 316 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);

#line 316 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "cysystemd/reader.pyx":376
 *         return self.state == READER_OPENED
 * 
 *     @contextmanager             # <<<<<<<<<<<<<<
 *     def _lock(self, opening=False) -> None:
 *         if self.closed:
*/

#line 376 "cysystemd/reader.pyx"
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 376, __pyx_L1_error)

#line 376 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);

#line 376 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "cysystemd/reader.pyx":458
 *         return iter(self.next, None)
 * 
 *     def next(self, uint64_t skip=0) -> JournalEntry:             # <<<<<<<<<<<<<<
 *         cdef int result
 * 
*/

#line 458 "cysystemd/reader.pyx"
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 458, __pyx_L1_error)

#line 458 "cysystemd/reader.pyx"
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);

#line 458 "cysystemd/reader.pyx"
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

#line 458 "cysystemd/reader.pyx"
  #if CYTHON_IMMORTAL_CONSTANTS

#line 458 "cysystemd/reader.pyx"
  {

#line 458 "cysystemd/reader.pyx"
    PyObject **table = __pyx_mstate->__pyx_tuple;

#line 458 "cysystemd/reader.pyx"
    for (Py_ssize_t i=0; i<3; ++i) {

#line 458 "cysystemd/reader.pyx"
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING

#line 458 "cysystemd/reader.pyx"
      #if PY_VERSION_HEX < 0x030E0000

#line 458 "cysystemd/reader.pyx"
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)

#line 458 "cysystemd/reader.pyx"
      #else

#line 458 "cysystemd/reader.pyx"
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))

#line 458 "cysystemd/reader.pyx"
      #endif

#line 458 "cysystemd/reader.pyx"
      {

#line 458 "cysystemd/reader.pyx"
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);

#line 458 "cysystemd/reader.pyx"
      }

#line 458 "cysystemd/reader.pyx"
      #else

#line 458 "cysystemd/reader.pyx"
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);

#line 458 "cysystemd/reader.pyx"
      #endif

#line 458 "cysystemd/reader.pyx"
    }

#line 458 "cysystemd/reader.pyx"
  }

#line 458 "cysystemd/reader.pyx"
  #endif

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 458 "cysystemd/reader.pyx"
  return 0;

#line 458 "cysystemd/reader.pyx"
  __pyx_L1_error:;

#line 458 "cysystemd/reader.pyx"
  __Pyx_RefNannyFinishContext();

#line 458 "cysystemd/reader.pyx"
  return -1;

#line 458 "cysystemd/reader.pyx"
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 8; } index[] = {{1},{24},{26},{19},{41},{14},{17},{20},{23},{18},{17},{32},{4},{179},{8},{13},{8},{109},{16},{1},{1},{3},{1},{1},{1},{8},{11},{20},{7},{6},{2},{35},{48},{25},{9},{50},{2},{64},{15},{3},{6},{12},{2},{10},{7},{7},{8},{12},{30},{32},{30},{31},{29},{30},{12},{15},{25},{13},{31},{33},{19},{24},{26},{25},{40},{18},{18},{28},{24},{22},{28},{25},{23},{33},{32},{23},{23},{27},{18},{10},{14},{3},{4},{2},{3},{4},{4},{82},{20},{12},{4},{13},{22},{24},{6},{5},{4},{5},{13},{7},{10},{6},{18},{8},{4},{7},{5},{7},{8},{7},{11},{16},{5},{12},{18},{5},{6},{3},{4},{10},{14},{4},{6},{5},{16},{4},{8},{6},{8},{5},{7},{6},{9},{4},{9},{5},{5},{9},{6},{6},{8},{3},{10},{10},{5},{13},{8},{9},{11},{26},{17},{18},{16},{17},{12},{1},{5},{3},{13},{5},{6},{6},{5},{8},{3},{6},{5},{6},{3},{7},{8},{3},{16},{10},{13},{9},{10},{15},{1},{4},{8},{7},{4},{4},{14},{10},{6},{7},{7},{2},{4},{7},{5},{3},{11},{8},{14},{14},{12},{11},{10},{19},{14},{12},{6},{8},{10},{17},{13},{7},{6},{6},{4},{4},{1},{11},{9},{19},{18},{9},{4},{4},{12},{10},{12},{19},{4},{9},{13},{10},{5},{8},{8},{5},{7},{8},{6},{6},{5},{12},{4},{3},{4},{5},{6},{4},{4},{7},{8},{4},{26},{41},{132},{45},{38},{45},{74},{11},{52},{26},{18},{7},{11},{9},{54},{60},{9},{62},{156},{70},{53},{5},{14},{54},{38},{55},{38},{115},{69},{61}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (2445 bytes) */
const char* const cstring = "(\265/\375`a\021\035L\000\252k`\026H\340\260:\0070\314\3634\204\2010\014\201\265X\213\265\020\006\302@\030\010\203\265HA\254\370[J\354\226\264ldk9rI\203Y\033\301\266,\236\266.5\345,nA\335~\037\007c}\225\375\007\222\3048\366\3745@\313\0028\0017\001\\\001\266\333\257\306\302\374\265\246~\234\306\364\026y\017\336|\016?\221+?\246<\324\261\255\363\323W\2776\364]\226\363\217\271<W\376\307,\313\357wC\003G\032h\036\r\254\272\217\274\034\266\274\\\277\317\232\030\225\240!bP\216\030\257nQ\024\303\356\374E\236\031\321\266\335\364\213}\3474\236/\265\037\330\342\345\024SaJ+\231\0262\243U\205-\242\3608T}\377B5b\364\034[\027\024W\2765[\024\332\237s\013R\335\351\367\237i\250i\264e\242#\376 \255\323|;\276!\213\2664\345\317\271\305\036+\344\224\327dKU>\250d@\225P4\337\3359\245\341g]\374\037\345\367\325i,\264\333W\247\337\365\351\263>m\275\367\367\020k\314\177v\371\016),\337\027\224\3774L\014J\211-\242!h\273\347\022\266y\207Z\305\210\026\335\026\207\256\337\037\265\034\245\233\272\335\337\305v\226M\217\257\313\376\356\331m_\036\335\000\203\362|m\317\332\353<\214\321\254/\347\277\301\233\322\227C\335\242]gJ\333\272{\277o\013\315\017\352\375\237\375M\277\347\032{\024\346iL;J\266,$\002\026\267l\256\017\366Zy\347\367\346\271\316\371k\365\364\367\325\372\337w\373\215\\6\333\030\207y\226\365\236\335\275\346[?_\354}\370\276\274\377\264W+\314\373\227\347\361\3574V\307Z\263X\374\363\355\241\336\372z\231\306\355\307Y\266\262\350`\352\312\324\255h1\315\314<\006\303\325\367[\2021\255N3\252\326\253N\267\005\264\333fT\202c\353i<b\004\252\324\232\177[\024\256uw^\267\207\n\242z9ta\25174T\255\030k\324j&F\025\203\2129\305\274\274na^:\226\230\227~\255M\005/\014_\333_[W\330?\377\312\371{:\324w\306k\377n\255\325\245\261\335\366\261\327\361mq~c\265\347\237\325\217\205\236w\263\356:\353X\355\357\352\266\363\376\274Vo\264u7\271,v)\365l*\255\272\026\323KGs2\235L\252\222\314L]\235J*\325\014K\313\251\204Bu-\247\256B\317\037s\331\377\335)`\230wA\272Y\032Em\337?{\026\365h\277\371Q\013?\337\242Z\373\315\327\303""\366\316\356\356\031r\370\321Z\337\013\277\337\265\322\216C\333\322\371\343\367\322$1$\212\234\214+\342\310\347\014\221 2\0042A\270\020n\345\026\272\205\0001\220\353\2205b\213\032\210\007\307\307\r{ka\353\000\302\315\260\251\330B6\016v|`KI\211&[J(Ae\005\231\210@\024!\215\rD+\"\370\310\245r\\8\0257\317Mf\2636\017!3\344\354\310\0244b\t\350\364\370\344H\343\007\361k\251\232\201\317)\023E\"H\004}\234\244\021\205H\022G>N;\246F\223\030\326Xj\037\237\\'\207\205K\301\211\340\366Mus`\323@\236|\316n$\215\000@6\022\004\323\216)ch\234\021Kn\"<\246\0144vF\005\237\\\350F\300\326R\226\230%\037\347\001\020\016\0017R\243\311\347$\225\027<f\207\363\340d7\023\031\314\256\304\340\300$\2155j\007>g\207\244\036\223\347mm\370\207\330\316\276\033\206^\017\367\203`\010\206\237\365\014\033\275_\025\377\354\313\317\303\335\265\336y\207\375\367{\026\2037_\261\re,\333g\237C\220\326;\016\371\357X\310\353o\013VP\203\\\177Y\273\362\2556\237\377n\275\303Os\213=\333\353\317\270\374\306\306\300|m\254\322\036\306c\337/\214\337}?~+\277\265\347\373\201\003\351\273\267\272\364K\177W\2551\356\n\251\322E\246H\323x\002\013\215\240\\W\313\311B\216\224\214D@\206,\214\rJl\tB\312\214&%\271\224\204\025\023\323\204\344\354RFp\245\020\217\331\271\325\204J\013\265\002\236\263\273\345\322\206\254q\3439U)\023\206\023\261\201\232\236\\\007\247s\263`\373\312T\231\241\034\345\264L\314nt`#\252\210\262\321\2166H\022\362sz\314\320\310\240tQ\222\204\234\" Y\251*Y\220\242\222B\r1A\310\031*;\312\017)\033!|\254\312\\\007W\263\300\\\020r\2264\244\010\305\255\201\reE\212\016\230\262\016\226\216\023\035':488n\314\340&\327\246\306&v\231.\031\246\014\032\223Fe\362\034Q\316\n.f\223`\343\245\250\\!?\214='\023\023\244F\222\025\265\031\316\000\317iI\014\243\013\212\332\207\347\224\335Tn\005\362(a\\ \256j \001T\224\236RF\242\200L\021\017\016\002\0363%^\250\021H\345\314p*8\006\267\225\255\213!I\035\3623\202\312N)Cvd=)\230\020\306\005]\216\005\034\201[\213\r\224`\364\020A\036\034\237\033$\034\313\005S\354\210\035\216%'8\010\331:l\020\310""\024\311\201\2140b\212\330H!s\325\341\210\324\324@>\247\025Sr!9PHI$\3718;qD\364P+\3609OBg\207\003*=\220!\362\304svpH$\2121E\017\201\317\250Q!bJ\221\031\021\021\221$I!\035!\010\302a\214Y\253\371b\372\032d\306!2B#\"$I\222\024v\326\214_'A\345\021\277\362;i\272\0032\376g\333k\005\357\026@\365\000\311\333\273~1d\200\021\000\377[P\340\311\366\\:0\322\204\tS\304\206\231t\316C\202\t\254QbI5\375\231\206\360\004\316\006\316}\3113\033JzB\306N&qPg6*x\201\346i\230(Y+\024o\006\214?\327\273\347\035.\ru\227\177s\366\024)>4m\254\031\256\377fbr\003\005\215\003\244I\355p2W\347\274\020\322h\231X\360X\322I4\343\033\036\350\363\256\372\202:\251\017\335\344Z\2201\325\302\253}\304V\210HW\242Zt\340\036+o\303\020!$\320\017ng\311}iGK\251\237\307+~\001r\325\366~\227\240\352\020{\220\020\352\017\240\361\361q\375.\363\271J2\\T\356\227\216\024\302\314\2660r\2337\254>\250\361]Z\303\331D\210[f\316G\312g\255,\025\241\007%\340\220j\035\247F\207si\351\255\377Z^\351>\253-\017d^\236\2430\267\"\353\261>\362\215w\255/\213Zl\337\310\266a.MFt\003c\323]\245\3676\325[\253'\312\020f\010\030\204or\340:[`5Q\034/\245\244K[\260\367\263VY#\274}\342\030\t\037\305\362\342\245\233\204_\260\250\361TNt\365\303\265f\347\225\323\207\235\260?\017Dv\243N7\267\235P\364Q-7\302PL\013\365\003L\246%)3\341\357[_\206\273\235LX\327g\330\004C\235\0256\324s\024\361\301\253-X\305\031\002\361\"\346f=\027\207\215\020\252\3173\371w\363\352\345h\361\372\t\371\252\"G\006\212\264\212\215\331m\254U\334\032ee'\327\370\224?\373H\034u.\316\216n\321\032\n\365\002E%\366\323\232\217\010\223g,\204\315s\016s\010\361} H\021jU\351\027\353G\2775T\177\205\227/\246\010\353\300\316o\235\"\241\260>\317\274\265X\245\201\336\350\024\366X\006/\2546N\001\302;\322!N\3570+\213Z\264\355cE\264\231 \255%}\262\217\2254\226\251\n\031\327\307\356\356\257\271\335\224\257Aj0\356\261!Z\255\306\320\215n\334\332\245GB]0\013`\370\346\\\315\223\240yQxi\205\300L\033\244\345\316\260b\230_A\017\320b,4\213\305\013\362\274\240\030=p\213\241L\021l\310\026\257\227\333\037}Q\343mCuo""\t\314\233\tb\333P\256\321\377\220$\225\255L\215K\302\375\376\002\315\\\362{\"#\273T\264\032\306\205\346\325\021R\240\016D[\020E*\333\2179\317\004\024\t\374\346C\353}\206\373<a3#\356\315&\351o\306q\321[\341\341\312\337\322\253]%\204S\234\257\257(4\004\334/\034\227\312\254\023+\2322Q\"\224\237s\001e\357\366\341\365\217V/\233\017\272\026\331\007\037\275\366ZFP\004\373\343.Z\300\357^\274\347\r\037\213\222\320\2450\346\322\206o9\003\3217\006\tf\324\366\3678\316\326\314[\245x\376)\277\262G\322S\014\027pq\327\031\014~\000\347\002'27/ss)\353l6\214\217\323\373\312\215W\353 H! \006L\234\310\363\276\004\314H\370\017\240\363peru\"\"Ve\031~0\330\022\321\354\213\225Y\230\356*@\304=-\240\300\322\350[\255\220H\261\024\310B/+T\t\n\031\364\326\"\010\206\3251\271\255\240B\245\236#\220\220\002\275,\025Z\337\311O\305\274\330\371\261\260\315\261~4a\0357\ti\244\204z\301\001b\0242\255\234\212G\264/\020\177\000\267\244!\r";
    PyObject *data = __Pyx_DecompressString(cstring, 2445, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (2572 bytes) */
const char* const cstring = "BZh91AY&SY\233\253\245\342\000\001\216\177\377\377\377\377\377\377\377\377\377\277\367\377\376\377\377\377\374\300@@@@@@@@@@@@\000@\000`\tn5\267mR\251\270wY@\025@\000\024\337 \274\341\242i\032A\250\331\023\007\251\210\006\246MQ\352mOQ\372\220\321\240\323M\2126\325\001\352cS\324dh\032\033L\247\251\275)\351\212~\242{T\365\006\2050L\247\246\212i\243M54\331\023!\223F\200h\032\006\206\203@\000\320\000\000\r\000\000\000\212z4\321\024z\232=@\0324\r\032\000h\000\000h\000\000\000\000\000\000\000\000\004\246\210\020 i4\321\244\323j\217E6S\312=2\236\243\323I\246\200\320\000\000\000\000\0004\001\2402\004\030\002a0&\023\t\246\t\210\300\023\000F\206L\002`\000\000\004`&\000\000\006\232\2254\031\032\000\332\200\000\0324\310\003&\231\000\000\3104\r\014@\036\221\2404\320\310\000\016\2211\363\2374\224d[\271\331\274\010\377\274\337\346`J\036r2\314\rFJ\317\320\203:\373n\214\371\022\357\372\177\344\3116\241\235\016\231\212\340\027\351\3341\316\302kY\t\204\204\231\010HL\204&d\314\200\270\320Q\2657%m\247\007%\004\256/\023$\314%)\242\001Xc\207b\014;:\206\206nq\014!\035W`\220\222CB\220,\245x\365\316J\250@0\205/\n\002\355t\006\240\2652\202\001\244\3266\030\221\021-\2260\312ZAa\226\203f\274\000\277\0330^\ri\030\027\2165B\014h\340\252R\242\010\006\213\004\344QLq\212\022\204R\357\000\223\303\347\303\277\333\362<\256~N\317\362\357'\305\303\317c\221\3572w&\211\240z\037\024c^3\353eW\247\3539N\235\345z\234\3719\246\301\366\213\t_\2501A\310&\304\003\347\020\333=X\343\200M\211\254\324I\021I0\236\20320 \314\004\370L\302\005M\317B\2432E-\003\023\010p\324L\266\376\317\\9\2000\247\r\221\220\356?\250\037\236\366>\322/\227\301^u\201\020\252\330\006`N\246\341\353\212\302\257K\005\337\346,5\265g\237\235\324\271c\026Y7\2501\214\353\"\"\031\230\273\201A`\031\024\246E\314\r\220.\367\231\250\203J@)\222\023a\371o4<\363\301%yH\024-\204Q\204\321\206\003\026\022\226vtq\232!Y\215\\a\313\224\3454\301\316\331\365X$\373\\\032\262%:Ohp\307b\342\352q\361\366\267\277a\355\322\256\005\221\032\2406\353:\353\233H\014\033X\343""\201\301d\324\303\307\267\223\212\315\017\025z\363\313\357\342\3413\272\354\002\236P1\371O+F\320\003\254~\255\201Z\027\335\262\345\023\2141\002{\275\364\212liG\327\303\2476\316\366\221)+\010nKJ\3718\364\014\273+h\343 \214\227*\331d\305\326\rc\223l\264Sr\241*\004\250\313ACn\201\006\"\357\222\342Z\331\005\272r,\264\022:$;\036\224\351\360eL]qs\305\014_gk#v\342,\013\250\016i\226\251\214\352\252\233\354\350|\252\004C\026\335\3130\210\216\t1\276\341ct\341\242\334%\033\257YM}K\023f\215\034I1\270\247\266\226\2542P\260\255\t\267\350i.\371S%\303F\363\327.\235\020\006\030\360\364,\014X.G\006\233\030\003O\314\362\201#\332 K\347\205\001\203F\000\201:h\307\210\325\032\226,\233P*\002\214\033q\347\001\177kq(\207\026\226\204]\206\353Oa:I\261\321\014S(\302\342\314\022*&\370\213\\\350RE\014,\226\242MR\206\002\204\356Q\030\357r\306O$Q\254\223\275\265BW'KC8\023j$\343[e\222\201\220\242\371\220dI*Q!\t\372\270\371s0B\266\305\277-\277\346\204c\236\337\351\000\005ob\372\305\216U\274\377Ta\203G\260}*\r\311\375\262\032eX\234\262Eg\212\037\230\2121(\007[\314\025\023*SK\t\247\000X\222\"t\312A2\003k\301\200\260\207\325\017\341\213\250\254\004\245!\250\260\000~\275\026\264R\250w\207p\tj\323p-\332~\364Bx#y\243AL\314r\304\241\031\027\245\004U\204\342\375@2\3142^\263\241\302i\320P\206\223F\203\257F]\314k%~\032\253KR\350\244\244Mb\310X;4\366M\324i\226\237Z\200L\341p\346\201\020D\n\371J%\244\322\236\270\327\261St^\331\200\350\327\251\334\220DL\366<(\030\216C'\n8\314\204L\236|\022\272W\314\243\031RKV\257YR\004#3\220\355\275nOt\305-\317\272\222)$\222HW5\2472\3518c\341\031\257@!\010\035\rB\325f\205rl(;\210\365\314h\303\250\240\261}=\017,\243\032T\0051\210\245\371\")H\210\270b\244\265Y\217\370\2624!\213V\333\336Mx\246\271t\341Q\010y\244b`\200d\220\223*\274\215\260A\234\363w\313\013\257\\\262\306\375\002\321\313\263F\253\347\244\206\036\tBsu\332\230\022\t\274\324&'i\024\256\202a7\242u\205`\361\270\346\354<Z\317.;\033;e\220\312\034@\363\326K\215\016\213\335\220]\003gN#\346\374\252\364\222\235\232\213\317""\265\364\264C^\216\326>\307#Y0\221\342FD\016\220\315\303[\027\r\314y4\031\314\350\275\216\211>\276\237?\274\304 \246\201\216u*\337\006O\316sj$\266{z\027|\271]r*'\332\035Lm\344A\"\222Z\026\017\014c\312(\367\014\265\306\207\246(\203q2\265Z\333\331\031\264!\200\014\2339\005L\305\270\3441\331LU\014\306\365\317\323\323\323{u\334@%M\317\232\225\010g\347\357\2716^\n\327\351q\312\017e\273\024/5\265\315\250\240W\\\351\313\031hr\214\211\000\230\021\242\010\252\347\221~\225\262\201P\2635\252\350\215\025\242&\222!3tO\324\246\024\3418$\204X\202\010\031\014Bv\035\334\212\260\301n\034\316`\033\253R\007\036\305\320`\344cO:\346\224\331\252!\306|OH\220N\363\222\224\301\304\332\023*\\6\024\272\275\321<\3352\362\000\204\232Q?\021\307q\202.\233\2662\3139\211\217\033\033\330\355\224\2516;\251\262\361\275\306=IY\301\300^\324\360>\221\261\033&<\326\273\263\247\223\201\222\354K\217&=R\353\211\340\320;\245vDD\3036\273\314\2535\346\341\366\246g\313\023\327\006\017\026\336@\320f\264q\235\364\ng\362\263\346[\370\352\357\336\336\233\0108!\235\345-\270A\215\264\340\236:\354t;*j\206\010\257o\274w\316\323\036\333\272\036I\315\004\342#\341\247`BS\036t\356+\274\232\271S\366\234f\0354&F\227\tA1\021\021\306<)pq\250\222\243\275=nc\374ra\346!\273\033\330\2441\274\306\013\305I\313\031H\2263\200w,\251\301\206\013\027\273\361\261\254\351\240\325:\260\001\366\253\330\214\024a\014\316\221\321vE}\310\365\265\272\\\363Ud\244\372\244\365\220\223\020Sd\236\273\022L$\262vF\333-k\270\273\251E\256\333S\014\006\334\253L\273\225\tO\016U\252-b\201\317\253~\315\245\000EG X\253\313\320k]a\352Km3\275\016x\226yJ\346\357q\370;)\245\303\316Y#\241l|\243\302t\205Ms{B\025\316\256\230X\253\260_\350N3'1\2441G\335H\200\025\317\314\232\201\204\214\007\271>Kf6\n6\332\303:\3322\240\302\242\250\331u\365sK[Q\264f`\027\364\031\215*P6\024_%^\2574'@\003MG=$Q:\360\240\346\310-Y\303\371\001\250\000HB\355\235\331\005\236\r\207\031\336$\335\263\321Y\0336a\351\3476\0309\371Xv\312\254Bi\310\341'3O\3407c\246\331\357\037\312\211C\2066\364\243""\247\223;l\306s\323\303\301\304\275s!\2345&\t\356\344@z\006X\211\311\310\376\200\010\005B\213\337\230\200\003\023\010\252M\327{V\253E\000{?V\331\356\246\324\251[\201\007_jM[\005\300\215\032\360\263#\205\022\240\024BRw\224OP\0342#\200\tpQ_K\330&\370R~\221ZDXk\000\266\353\335\340{\376\"(Wg\250 \361\032@\211(5\rH\217\243T]S#A\342.\357$\177\351\032\371v-\362\370m\013\276\006\025\325^\265\301\316\025\234\032\255_\362\020\351\273\233[qI\350\342\033\206X.l\0033<\243OL\3267\352\211A\353\351\013\200\342\021\217@v>\212#r!\031\345\223\261d\313X\016\201\314v\273\376\261\307ZA\337\220E\356\177E\030\220\262\212\326KX\307Xj\322-\326\237\036\367\340M\261\225J\330\270>\350\311]O\r\270\270\2074\002\271\333\037\304\266+\367?\022\337\307\327?Rp\253\236\370\340\250.\214C\244\366\275\234@V\253\230wz{\320\237gSPj\222(|99hK\004\033y\177J\220\374\020\367\255d\361\303rAZ\206+>\252hn\256\355\026\275 \321.\246\005\352\255\3113\t\020%\310Z\024\r\300\006\310\014C\035p\336n\341\333+\265\350\327\304\362\224\343\346U\244\263\347B)\365:r\314\215\001*\374@\231\"\305\220\020\032\300\304R\002\244\031\033JQ\002\211\247\342\324E6\300\227S\004\201\210\324B\305\240J\234\023!H\022I \220\211Z\203\340\250\365\254\235\025yh\360=*\327\\D\2538\211\177\361w$S\205\t\t\272\272^ ";
    PyObject *data = __Pyx_DecompressString(cstring, 2572, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (2424 bytes) */
const char* const cstring = "x\332\215V\317w\323V\026N\030\317\214\2014\304\001\312P`\220\0312\241\264\2705d\200\241L{\334$Ps \211\203C\313tz^_\244\027GD\226\034=)\211\031\316\031\226^j\251\245\226Zz\351\245\227Yj\251e\376\004\376\204\371\256\3448vb:\263\220\364t\337\257{\277\373\335\357\275\177\314ss\326Q\014K\335RT\303\222BSl\3015a\247v[X\ra*\364\352\367,\350\266P\035\313n*\246\345(\033\226kj\213{\r[H\251[\246Rw\245\223t\250\226\351p\335\224\312\277\276V\324Mns\325\021\366\023\335\020G\323\312\346\0167t\215\226\267\271\203\331egV&\335\\\321\016w\031\260\331\242\346\032\334V6\260\312\343g\226k\233\334X4\035\273\371H\231\261\277\235\355Y\226\341\354\013K\023\263\317us\013sT\327\226\372\216@K\032\226\341\322>\212\260m\313^\262L\261d9Bq6\271\243\3147\235M\364\350R\321\204\241\257\223G\302h*\322\261u\362\234\006\231\312\312\342\312\235\271\207s\n7\t\2157\360P*\322]W\r.\245\220\212\265\241\254\273\272\341\350\246\3424\033B\026\224\362\206\322\264\\\305\024\200\317\261\224\006\306\rNp6\201\256\024\0165\224Yn\"\316\004\010\206\351\272Y\233\355\301@\356c\366\023nHQx\274\232\244\341\347\364\223\244Nh\253\256!n\315\330\237W\261\3161\034\n/_\277\254.\276`\313K\317_\247\341!Y*\242\323\2220hgd\201'\336\217\236\252P<\030&\233\322\021uM\001<6\267\233\2055\023\256\376\014\204\276TV\270\263\371\313\230\362\313#\345\333\302w\\\323\030\"\021\352\206k\252\005\307b\215\246\332\354M\376*%Q\241\321\334\323t\311\327\r!Lz\327\324\032r\\\007\213xM(\273\272\263\251\010\323\262\353\226+\025C\2305\374\317h4\3045\305^\003\230\300\375\031P\301\266\352\212\324\330\233\324q&L\267\236\244\216i\334\341\024nJ\235>\321\300P\004\246\313tW\315\264\200\307\006w\rGa\314\026\232\253\n\306\024\315M\3606-\363\016\322\277\243s\003\275\252n\352\016c3\266\024\306F\201\350-\366@\363$i\312\272 \302\357\010\333I\023\315\225\225\224O\326:\261\004|\267\225\206\256n\031\310\352-\307\026\002\236\363Z]\230\316\347\245\245\205\322\312\312\342\322\302\374\332\352\352\342R\225\255\275\\\\-/\225\227^\225\236\227\027J\325\305\262\351,\",|\236\030\274Vv""(>\313\036\344\377`\273\320\217CM<`\354X/\350&\035Bhd\177M8\254n!$\313\324U\214U\177\243\327\035\325\215\374\242\000\352\202\375f\347\340\324\035\240p\214x\307y\310\352:\344\305\254\035\372\232r\177\350\347\243q\367\273?\026\370\341\000\252\244a\023\021\031b\343\034\337J5\004\267G\366P\220\250-nX\265\217v0\220\201\365\230\316tmx\034\330\355\014[\210\264'-\254/\220#\372H \345\260\0355\277\243\243\230\216[-\025\2160A98\326'\205\330b$\236\226=\242c\023\355\021\346\221\344\030\0340\212\001\203\37583\214c\346-\275\301N\302\222\230GG\265\313u\347\371\362|\351y\242y/\270\243n.\037\0361K\313+\244\373\313\253\313kU\022\255\025\3130\030[i\356\261\371'P+\366\367\276R\261\373\251T1\010\034c\306\n\267!HI5\203i\311\037K\244\215\3155\260N\3411\350\003}\376\266\260k\363F\272\342Js\001g\007[\202\357\253bcum\251Z~\261\230\370DrM\017X\251\203C\214\365~\2161\270g=A\334T\226\253n\303\020kk\345\205D\207\177,\225\253\354E\351'F\233\360uIN\035\361\2277\300\013\215\313\246\251\352\026\304\313\266p\020\232B\256\3678\271nY\006\036\007|\\o:B\366\314j\317\246\246<\030\024\364M\241n\261\344\034e*JT\335\324\rm\260.TH\035\350\r\220p\364\213u\256n%\367\213\364\222\241\0322\231\224\212(\316\223^\253\316M\024\205\255\002\362\336\216D\223~J\niF4:\274\360\020\217h\021\r\232\255\021\322\207\037\315R\031\216\202\264\007\314&\204\223\223\341\360t\200\337\246\2258\237\274h`\322\220bO\227\216\304\350=\322z:i\372W\033**fr\024\356\006dX\322\311C\016 3u\344\233\220a\014U\376\334\252!\202\201r\377x\345\237\320\332\223\362z\\QO\210h\262g\312\016\246\353Z\361\356C\335D\306$\353\347X\227\220\n]\222\373\272DR\266\300\270\272<$\336\226h\246\307k\"\177\351e\002\236\222\337\244\267\254\216;\034\275\033u\276\327w]\352o\305Q\030\350\026\016O\2564\310\300\241R\243ei\340/\243\226mQ\032l]`\204I\0302\226\276\361\025\273,)oR\256ae;\322\262\364\002Jo,\235\\\027M\315J(N\017\370C\037\331\260\220\010\244\253\201\342d}m\030\3268\330Q\231\t{\245[O\377\220`\\\000\322v\017Jj\322\025.m\271frv\213\244 S\323\216C\367\007\n`\333\345F""\032L\312Nz\023\314G\367\211\023u\3357\210=j6\014TH\352\204-\034(\231\215\252\263\261\225\034\320\340\276\352\216\320\331\223\312\332\327R\272\254\340\262\243%*\322\003\035\255\336\245g@[\330\010\235!\215\355\313\357\220\340b\034\001\262#\214d\006\3525\225\002Fm\2747mk\227\234\001\005\351\363\026\222\233^i\335\006U\256\0139\262\341g\177K\362\331uT\327\3255\\\325\\\221\274$\t\371.\267Mz0\267\367\221\244\260QF\t\306\343\354\271\326;\277\030]\3752,Ew\276\353lw3\335R\224\371\",\306\331k~\345\303\037\306&\317\305\023\027\243\213\260\204\013\3553\235\374A\366O\376\270\237\243\211\333Q\346\233\016\006^\364\326\374\274\177\317\347\321\365b;G\003~\347\027\375R\234\275\021|\325\276\332Y\355\330\335\351\356\275\356\372\376\370Av\2425\337r\275\262_\361y<q\336+zO\375b<\221\363r\336\214\267\035g?iUZ\302{\350\027\017\262\247\343\334E\357\025\026\372!(\305S\3605\312\337o\363\366v'\323y\326\255\355W\016&>\365\270\007\037\256\370E\362s\332\373\024+\220\257\237\207\271\360f\310{\236\322\236e\257\322s\370\177\016NF\335k#\254?\373|x\350\335v\276=\327~\333\315\rc\360\267\366\353\016\37701vz\262\365\332{\023\214\037|2\231\014\177\324\311w\036t\363]\304\222\213r\371 \027\344\343\354y\357\201\177\203\260\231\366\362^\221\266s\000\302\017\376\323\240\370~<\316\334\010\362\301\3750\367\276\024\347o\304\331\263\255\373\336y\257\024O\\\360\026\261\335T\356`\no\204p\000\350\356y<\316N\266\336\300\223i\202\033s\220\262j\224/\266\247\311}\254\034\235\377Kp7\250\364z\202\353\355S\355|\3424,W\377\032\360\367\245$^o\334\243\035S_\220\374\350\213\371n\361Cv\354t\316;\355_\242\200r}\014\200L{\241s\246{{\2774\214\302e\377zt\013!\307\t\334,(\005/\303\3610\327\233\353g\301\265\211\363\344P1X\306\032\245v\265\363Yw\256\273\263_\241\270\317\264\276\360*Q\206(wf\354\364t\224\233\r\266\303L\370\214\022\376\177\303\007\227\177?\331\252z\227\375\233\276\t\266\236\355\314u\266\343\314D\353)\306<\361\277\014x\234\371\343\373\235\326\217@\363\202_I\026\211\263\227<\354p\311s\374\207\301\203p&\224\355\233\355z\367""\301\376\314\276\214V_E\257~\215~\255E5#2\254\310\222\221|\373al\354\337\343\337\237\302\347\373S\363\247hA\320\366\\tn&\250\202I\263\355+\235\247\224\361!\013*j&x\025\0162\017\230\305S\227\243\313(\030l\370\246;~@\177\250\302\260\212\022\232\300\364\353\376v\220\rO\205\371x\352\222\367\016\260a\225[!*v&\370)\\\r\267\217\026\313Mc)\377:\340\276\020\376\223\360:\252\351\020\240~\346\347\243\014\310\034gQD\301\205\000&\344\236\322\366\037\237\373\333\303\031\362\346\274]*\315\253~)\272vTo\033\373\330\275\020\036+\210;a%\324\332\267;\245$^rx\374\375\370A\006\215H\371\032\360\177\323\335\212*\253q\206V\335\243^\202\353\035R\010\330\341B\260\033\232\235R\2349\333\002\353n\207\371Q\205\371\2463~\264x\224\001-\220\345\303QS)?\023 \017}Y\354\346\022\265\010P,\347\241$\367@\205R|\341Zt\355A\022\013\3327A\316\312\301\305k\376\313`2\344#\372\340\310\305+\376mjF\231|\360i\260=\"sG\301\367\301\257|,qc\250k\212\335\205\372m'\005s@Q\267J\007GF\n&G\310L\266\266\320\270\341\227\203JP\013+\377\005]\246,\362";
    PyObject *data = __Pyx_DecompressString(cstring, 2424, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (4705 bytes) */
const char* const bytes = "=Can't lock closed readerCan't reopen opened readerDirectory not foundExpression must not contains \\0 characterFile not foundInvalid operationIt's not a directoryIt's not a regular file<JournalEntry: %r>'JournalOpenMode'Link recursive reslolution errorNoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.<Reader[Reader lockedRule(%r)The JournalOpenMode.SYSTEM_ONLY is deprecated and the alias of JournalOpenMode.SYSTEM in the systemd library.Union[str, Path]\000 ]: >.?add_notecfunc.to_pycysystemd/reader.pyxdisableenablegcgot message with enormous length %dgot unexpected %r from sd_journal_enumerate_data is not a valid open modeisenabledno default __reduce__ due to non-trivial __cinit__%rself.context cannot be converted to a Python object for pickling(tree fragment)ANDAPPENDCURRENT_USERININVALIDATEIntEnumIntFlagIteratorJournalEntryJournalEntry.__reduce_cython__JournalEntry.__setstate_cython__JournalEntry.get_monotonic_secJournalEntry.get_monotonic_usecJournalEntry.get_realtime_secJournalEntry.get_realtime_usecJournalEventJournalOpenModeJournalOpenMode._missing_JournalReaderJournalReader.__reduce_cython__JournalReader.__setstate_cython__JournalReader._lockJournalReader.add_filterJournalReader.clear_filterJournalReader.get_catalogJournalReader.get_catalog_for_message_idJournalReader.nextJournalReader.openJournalReader.open_directoryJournalReader.open_filesJournalReader.previousJournalReader.process_eventsJournalReader.seek_cursorJournalReader.seek_headJournalReader.seek_monotonic_usecJournalReader.seek_realtime_usecJournalReader.seek_tailJournalReader.skip_nextJournalReader.skip_previousJournalReader.waitLOCAL_ONLYMatchOperationNOPNoneOROUTPathPoll__Pyx_CFunc_9cysystemd_6reader_str__lParenobject__rParen_to_py_4path.<locals>.wrap__Pyx_PyDict_NextRefRUNTIME_ONLYRuleRule.__iter__Rule.__reduce_cython__Rule.__setstate_cython__SYSTEMTupleUUIDUnionWA""IT_MAX_TIMEabspathadd_filterappendasyncio.coroutinesbcatalogboolboot_idbytescatalogcboot_idccursorcfunc.to_pycheck_error_codechildclear_filtercline_in_tracebackcloseclosedclscodecontextlibcontextmanagercstrcursorcuseccysystemd.readerdatedatetimedecode__dict___dict__doc__encode__enter__enumenumerateerrnoerrorerrorcodeerrorsexists__exit__expexpressionfile_namesflagsfromtimestamp__func__getLoggerget_catalogget_catalog_for_message_idget_monotonic_secget_monotonic_usecget_realtime_secget_realtime_usec__getstate__iid128int_is_coroutineisdirisfileislinkitems__iter__keylength_locklockedloglogging__main__mapmax_message_sizemessage_id__metaclass___missing___module____mro_entries__nname__name____new__nextopenopen_directoryopen_filesopenedopeningoperandospathpathlibpathspop__prepare__previousprocess_events__pyx_checksum__pyx_result__pyx_state__pyx_type__pyx_unpickle_Rule__pyx_vtable____qualname__readerreadlink__reduce____reduce_cython____reduce_ex__replaceresultreturnrootrulesseek_cursorseek_headseek_monotonic_usecseek_realtime_usecseek_tailselfsend__set_name__setdefault__setstate____setstate_cython__skipskip_nextskip_previousstacklevelstatestrerror__test__throwtimeouttimezonetypingupdateupperuse_setstateusecutcuuidvaluevalueswaitwarnwarningwarningswrap\320\004 \240\001\330\010\017\210|\2301\320\034,\250A\320-?\270q\300\004\300A\320\004+\2501\330\010\035\230Q\360\006\000\016\017\330\014\025\320\025+\2501\250D\260\n\270!\340\010\030\230\001\230\021\330\010\017\210q\320\004;\2701\330\010\025\220U\230!\2303\230a\320\0371\260\021\340\010\030\230\003\2301\230A\330\010\"\240/\260\034\270R\270r\300\022\3003\300b\310\001\340\010\014\210C\210u\220I\230Q\230a\330\014\023\2201\220G\2301\330\014\021\220\021\220%\220q\330\010\r\210Q\210e\2208\2301\340\010\t\330\021\025\220V\2301\230H\240A\330\020 \240\001\320!6\260a\260q\270\004\270J\300g\310Q\340\014\026\220a\220q\320\004\033\2301\360\006\000\016\022\220\026\220q\330\014\025\320\025)\250\021\250$\250a\340\010\030\230\001\230\021\340\010""\014\210I\220Q\330\010\017\210q\320\004\033\2301\360\006\000\016\022\220\026\220q\330\014\025\320\025)\250\021\250$\250a\340\010\030\230\001\230\021\340\010\017\210q\320\0043\2601\330\010\036\230a\360\006\000\016\022\220\026\220q\330\014\025\320\0252\260!\2604\260z\300\021\340\010\030\230\001\230\021\330\010\017\210q\320\0045\260Y\270a\360\014\000\t\016\210Y\220j\240\001\340\r\016\330\014\025\320\025:\270!\2707\300!\3001\340\010\021\320\021!\240\021\240!\330\010\023\2207\230\"\230A\330\010\022\220!\2201\340\010\017\210t\2201\220H\230G\2401\200\001\330\004\"\240!\2406\250\021\200A\330!\"\330\010\013\2106\220\023\220A\330\014\024\220E\230\021\330\020\021\340\020\021\330\020\033\2301\340\014\023\2203\220a\330\010\016\210j\230\001\230\022\2301\230A\200A\330\010\035\230T\320!1\260\022\2601\330\010\017\210t\320\023#\2402\240Q\200A\330\010\035\230T\240\037\260\002\260!\330\010\017\210q\200A\330\034&\240a\200A\340\010\017\210q\220\001\220\021\200A\330\010\017\210t\2201\320\004+\320+C\3001\360\010\000\t\021\220\t\230\027\240\001\340\r\021\220\026\220q\330\014\025\320\0253\2601\260D\270\n\300*\310A\340\010\030\230\001\230\021\330\010\017\210q\320\004\031\230\037\320(:\270!\330\010\014\210I\220_\240A\240S\250\001\250\021\340\r\021\220\026\220q\230\010\240\001\330\014\023\320\023#\2401\240O\2601\260A\260T\270\032\3004\300v\310Q\200\001\330\004\n\210+\220Q\320\004\035\230Q\360\n\000\t\022\320\021'\240q\250\004\250J\260a\260q\340\010\021\320\021!\240\021\240!\330\010\023\2207\230\"\230A\330\010\022\220!\2201\340\010\017\210t\2201\220H\230G\2401\200\001\360\010\000\005\016\210T\220\031\230$\230n\250D\260\013\2704\270q\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2308\2407\250%\250s\260$\260m\3007\310%\310s\320RV\320V`\320`g\320gl\320lo\320os\320sz\360\000\000{\001B\002\360\000\000B\002C\002\330\004\007\200q\330\010\017\320\017%\240T\250\021\250'\260\033\270G\3001\340\010\017\320\017%\240T\250\021""\250'\260\033\270A\320\004%\240V\2501\360\006\000\016\022\220\026\220q\330\014\017\210q\330\020\031\320\0311\260\021\260$\260j\300\001\340\020\031\320\031,\250A\250T\260\021\340\014\017\320\017\037\230q\240\010\250\002\250!\330\020\027\220|\2401\240A\320\004(\250\001\330\010%\240X\250R\250q\360\006\000\016\022\220\026\220q\330\021\022\330\020\031\230\037\250\001\250\024\250Z\260q\340\010\017\210|\2301\320\034,\250A\250Q\320\004\032\230!\320\004\036\230a\330\010 \240\001\240\024\240Q\320\004&\240a\330\010\017\210\177\230a\230q\340\r\021\220\026\220q\230\010\240\001\330\014\023\2204\220w\230a\330\014\034\230A\320\0356\260a\260q\270\004\270J\300f\310A\320\004.\250a\360\006\000\016\022\220\026\220q\330\014\025\320\025-\250Q\250d\260*\270A\340\010\017\320\017\037\230q\240\001\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\2204\220x\230q\240\001\330\004\007\200|\2207\230!\330\010&\240a\240w\250n\270A\330\004\013\2101\320\004*\250!\360\006\000\016\022\220\026\220q\330\014\025\320\025)\250\021\250$\250j\270\001\340\010\017\320\017\037\230q\240\001\320\004'\240q\360\010\000\016\022\220\026\220q\330\014\020\220\t\230\027\240\001\330\020\031\320\031-\250Q\250d\260*\270E\300\021\330\020 \240\001\240\021\340\020\023\2208\2303\230n\250A\330\024\035\320\0357\260q\270\004\270A\330\024$\240A\240Q\340\025\035\230S\240\016\250a\330\024\035\320\0357\260q\270\004\270A\330\024$\240A\240Q\360\006\000\025\033\230*\240A\240Q\320\004!\240\026\240q\360\006\000\016\022\220\026\220q\330\014\017\210q\330\020\031\320\031-\250Q\250d\260*\270A\340\020\031\230\037\250\001\250\024\250Q\340\014\017\320\017\037\230q\240\010\250\002\250!\330\020\027\220|\2401\240A\320\000\"\240!\330\004\007\200u\210C\210q\330\010\017\210q\340\004\013\2101\210A\340\004\007\200u\210C\210q\330\010\020\220\t\230\021\230!\330\010\016\210k\230\021\230\"\230I\240Q\240g\250Q";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 250; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 39) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 250; i < 280; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 280; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 250;
      for (Py_ssize_t i=0; i<30; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,1,2};
    int16_t const cint_constants_2[] = {255};
    int32_t const cint_constants_4[] = {1048576L,265362053L};
    int64_t const cint_constants_8[] = {4294967295LL};
    for (int i = 0; i < 7; i++) {
      numbertab[i] = PyLong_FromLongLong((i < 3 ? cint_constants_1[i - 0] : (i < 4 ? cint_constants_2[i - 3] : (i < 6 ? cint_constants_4[i - 4] : cint_constants_8[i - 6]))));
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<7; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 2;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 3;
    unsigned int flags : 10;
    unsigned int first_line : 10;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 67};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_path};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cfunc_to_py, __pyx_mstate->__pyx_n_u_wrap, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 121};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_rule};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_iter, __pyx_mstate->__pyx_kp_b_iso88591__10, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 376};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_opening};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_lock, __pyx_mstate->__pyx_kp_b_iso88591_A_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_2, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_nD_4q_G1F_a_vWE_Q_q_t87_s_m7, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 129};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_error};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_check_error_code, __pyx_mstate->__pyx_kp_b_iso88591_uCq_q_1A_uCq_k_IQgQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 147};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_missing, __pyx_mstate->__pyx_kp_b_iso88591_A_6_A_E_1_3a_j_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 268};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_get_realtime_sec, __pyx_mstate->__pyx_kp_b_iso88591_A_T_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 272};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_get_monotonic_sec, __pyx_mstate->__pyx_kp_b_iso88591_A_T_1_1_t_2Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 276};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_get_realtime_usec, __pyx_mstate->__pyx_kp_b_iso88591_A_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 279};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_get_monotonic_usec, __pyx_mstate->__pyx_kp_b_iso88591_A_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 313};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_flags};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_open, __pyx_mstate->__pyx_kp_b_iso88591_I_AS_q_1O1AT_4vQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 319};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_cstr};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_open_directory, __pyx_mstate->__pyx_kp_b_iso88591_a_aq_q_4wa_A_6aq_JfA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS), 326};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_file_names, __pyx_mstate->__pyx_n_u_n, __pyx_mstate->__pyx_n_u_paths, __pyx_mstate->__pyx_n_u_i, __pyx_mstate->__pyx_n_u_s, __pyx_mstate->__pyx_n_u_cstr};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_open_files, __pyx_mstate->__pyx_kp_b_iso88591_1_U_3a_1_1A_Rr_3b_CuIQa_1G1_q_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 392};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_seek_head, __pyx_mstate->__pyx_kp_b_iso88591_1_q_a_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 402};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_seek_tail, __pyx_mstate->__pyx_kp_b_iso88591_1_q_a_IQ_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 413};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_boot_id, __pyx_mstate->__pyx_n_u_usec, __pyx_mstate->__pyx_n_u_cboot_id, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_seek_monotonic_usec, __pyx_mstate->__pyx_kp_b_iso88591_C1_q_31D_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 425};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_usec, __pyx_mstate->__pyx_n_u_cusec, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_seek_realtime_usec, __pyx_mstate->__pyx_kp_b_iso88591_31_a_q_2_4z_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 435};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_cursor, __pyx_mstate->__pyx_n_u_ccursor, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_seek_cursor, __pyx_mstate->__pyx_kp_b_iso88591_1_Q_1D_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 445};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_timeout};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_wait, __pyx_mstate->__pyx_kp_b_iso88591_XRq_q_Zq_1_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 458};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_skip, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_next, __pyx_mstate->__pyx_kp_b_iso88591_q_q_q_Qd_A_Q_q_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 470};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_skip, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_skip_next, __pyx_mstate->__pyx_kp_b_iso88591_q_j_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 478};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_skip, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_previous, __pyx_mstate->__pyx_kp_b_iso88591_V1_q_q_1_j_AT_q_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 490};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_skip, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_skip_previous, __pyx_mstate->__pyx_kp_b_iso88591_a_q_Qd_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 498};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_rule, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_exp, __pyx_mstate->__pyx_n_u_operand};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_add_filter, __pyx_mstate->__pyx_kp_b_iso88591_q_q_Qd_E_83nA_7q_A_AQ_S_a_7q_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 518};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_clear_filter, __pyx_mstate->__pyx_kp_b_iso88591_a_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 543};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_process_events, __pyx_mstate->__pyx_kp_b_iso88591_1_A_q_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 546};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_catalog, __pyx_mstate->__pyx_n_u_bcatalog, __pyx_mstate->__pyx_n_u_length};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_get_catalog, __pyx_mstate->__pyx_kp_b_iso88591_Q_q_Jaq_7_A_1_t1HG1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 559};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_message_id, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_catalog, __pyx_mstate->__pyx_n_u_bcatalog, __pyx_mstate->__pyx_n_u_id128, __pyx_mstate->__pyx_n_u_length};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cysystemd_reader_pyx, __pyx_mstate->__pyx_n_u_get_catalog_for_message_id, __pyx_mstate->__pyx_kp_b_iso88591_5Ya_Yj_7_1_7_A_1_t1HG1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_Rule, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_4xq_7_awnA_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* Generator.init */
  if (likely(__pyx_Generator_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

#line 1 "cython_utility"

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* CallTypeTraverse (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    return __Pyx_PyTuple_FromArray(((PyTupleObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice_locked(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (length <= 0) {
        return PyList_New(0);
    }
    return __Pyx_PyList_FromArray(((PyListObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(src);
    result = __Pyx_PyList_GetSlice_locked(src, start, stop);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
#endif // CYTHON_COMPILING_IN_CPYTHON

/* GetException (used by pep479) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc, *new_exc;
    __Pyx_PyThreadState_declare
    int is_async_stopiteration = 0;
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    __Pyx_PyThreadState_assign
    cur_exc = __Pyx_PyErr_CurrentExceptionType();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else {
            return;
        }
    }
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(tb);
    new_exc = PyObject_CallFunction(PyExc_RuntimeError, "s",
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        "generator raised StopIteration");
    if (!new_exc) {
        Py_XDECREF(val);
        return;
    }
    PyException_SetCause(new_exc, val); // steals ref to val
    PyErr_SetObject(PyExc_RuntimeError, new_exc);
}

/* RejectKeywords */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds) {
    PyObject *key = NULL;
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds))) {
        key = __Pyx_PySequence_ITEM(kwds, 0);
    } else {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *pos = NULL;
#else
        Py_ssize_t pos = 0;
#endif
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
        if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return;
#endif
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL);
#if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(pos);
#endif
    }
    if (likely(key)) {
        PyErr_Format(PyExc_TypeError,
            "%s() got an unexpected keyword argument '%U'",
            function_name, key);
        Py_DECREF(key);
    }
}

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* pybuiltin_invalid (used by pyint_simplify) */
static void __Pyx_PyBuiltin_Invalid(PyObject *obj, const char *type_name, const char *argname) {
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    if (argname) {
        PyErr_Format(PyExc_TypeError,
            "Argument '%.200s' has incorrect type (expected %.200s, got " __Pyx_FMT_TYPENAME ")",
            argname, type_name, obj_type_name
        );
    } else {
        PyErr_Format(PyExc_TypeError,
            "Expected %.200s, got " __Pyx_FMT_TYPENAME,
            type_name, obj_type_name
        );
    }
    __Pyx_DECREF_TypeName(obj_type_name);
}

/* pyint_simplify */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none) {
    PyObject *number = *number_var;
    if (likely((accept_none && number == Py_None) || PyLong_CheckExact(number))) {
        return 0;
    }
    PyObject *int_object;
    if (likely(PyNumber_Check(number))) {
        int_object = PyNumber_Long(number);
        if (unlikely(!int_object)) goto bad;
    } else {
        __Pyx_PyBuiltin_Invalid(number, "int", argname);
        goto bad;
    }
    *number_var = int_object;
    Py_DECREF(number);
    return 0;
bad:
    *number_var = NULL;
    Py_DECREF(number);
    return -1;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* PyObjectVectorCallKwBuilder */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON
static int
__Pyx_unicode_modifiable(PyObject *unicode, int unsafe_shared)
{
    if (!__Pyx_IS_UNIQUELY_REFERENCED(unicode, unsafe_shared))
        return 0;
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030F0000
    if (PyUnstable_Unicode_GET_CACHED_HASH(unicode) != -1)
        return 0;
#endif
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left, unsafe_shared)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a + b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla + llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_AddObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) + (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_AddObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_AddObjC(op1, op2, inplace);
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* PyObjectCall2Args (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod1) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod1 (used by append) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* decode_c_bytes (used by decode_bytes) */
static CYTHON_INLINE PyObject* __Pyx_decode_c_bytes(
         const char* cstring, Py_ssize_t length, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    if (unlikely((start < 0) | (stop < 0))) {
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    if (stop > length)
        stop = length;
    if (unlikely(stop <= start))
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_unicode);
    length = stop - start;
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod0 (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* DelItemOnTypeDict (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_DelItem(tp_dict, k);
    if (likely(!result)) PyType_Modified(tp);
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_mstate_global->__pyx_n_u_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_mstate_global->__pyx_n_u_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython);
            if (likely(reduce_cython)) {
                ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_mstate_global->__pyx_n_u_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetFullyQualifiedName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i=0;
    Py_ssize_t size;
    void** base_vtables;
    __Pyx_TypeName tp_base_name = NULL;
    __Pyx_TypeName base_name = NULL;
    void* unknown = (void*)-1;
    PyObject* bases = __Pyx_PyType_GetSlot(type, tp_bases, PyObject*);
    int base_depth = 0;
    {
        PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        while (base) {
            base_depth += 1;
            base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
        }
    }
    base_vtables = (void**) PyMem_Malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
#if CYTHON_COMPILING_IN_LIMITED_API
    size = PyTuple_Size(bases);
    if (size < 0) goto other_failure;
#else
    size = PyTuple_GET_SIZE(bases);
#endif
    for (i = 1; i < size; i++) {
        PyObject *basei;
        void* base_vtable;
#if CYTHON_AVOID_BORROWED_REFS
        basei = PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#else
        basei = PyTuple_GET_ITEM(bases, i);
#endif
        base_vtable = __Pyx_GetVtable((PyTypeObject*)basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
            }
        }
    }
    PyErr_Clear();
    PyMem_Free(base_vtables);
    return 0;
bad:
    {
        PyTypeObject* basei = NULL;
        PyTypeObject* tp_base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        tp_base_name = __Pyx_PyType_GetFullyQualifiedName(tp_base);
#if CYTHON_AVOID_BORROWED_REFS
        basei = (PyTypeObject*)PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = (PyTypeObject*)PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#else
        basei = (PyTypeObject*)PyTuple_GET_ITEM(bases, i);
#endif
        base_name = __Pyx_PyType_GetFullyQualifiedName(basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
    }
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
really_bad: // bad has failed!
#endif
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
other_failure:
#endif
    PyMem_Free(base_vtables);
    return -1;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_2_4
#define __PYX_HAVE_RT_ImportType_3_2_4
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size)
{
    PyObject *result = 0;
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API)
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !( defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API) )
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    if (size == 0) {
        return (PyTypeObject *)result;
    }
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_2_4 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_2_4 && (size_t)basicsize > size) {
        if (PyErr_WarnFormat(NULL, 0,
                "%.200s.%.200s size changed, may indicate binary incompatibility. "
                "Expected %zd from C header, got %zd from PyObject",
                module_name, class_name, size, basicsize) < 0) {
            goto bad;
        }
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__8);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base = NULL, *meth, *new_base, *result, *new_bases = NULL;
#if CYTHON_ASSUME_SAFE_SIZE
    size_bases = PyTuple_GET_SIZE(bases);
#else
    size_bases = PyTuple_Size(bases);
    if (size_bases < 0) return NULL;
#endif
    for (i = 0; i < size_bases; i++) {
#if CYTHON_AVOID_BORROWED_REFS
        Py_CLEAR(base);
#endif
#if CYTHON_ASSUME_SAFE_MACROS
        base = PyTuple_GET_ITEM(bases, i);
#else
        base = PyTuple_GetItem(bases, i);
        if (!base) goto error;
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(base);
#endif
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_mstate_global->__pyx_n_u_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                PyObject *base_from_list;
#if CYTHON_ASSUME_SAFE_MACROS
                base_from_list = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base_from_list);
                Py_INCREF(base_from_list);
#else
                base_from_list = PyTuple_GetItem(bases, j);
                if (!base_from_list) goto error;
                Py_INCREF(base_from_list);
                if (PyList_SetItem(new_bases, j, base_from_list) < 0) goto error;
#endif
            }
        }
#if CYTHON_ASSUME_SAFE_SIZE
        j = PyList_GET_SIZE(new_bases);
#else
        j = PyList_Size(new_bases);
        if (j < 0) goto error;
#endif
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return result;
error:
    Py_XDECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_SIZE
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
        metaclass = &PyType_Type;
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    if (__Pyx_TypeCheck(method, &PyMethodDescr_Type))
#endif
    {
#if CYTHON_COMPILING_IN_LIMITED_API
        return PyErr_Format(
            PyExc_SystemError,
            "Cython cannot yet handle classmethod on a MethodDescriptorType (%S) in limited API mode. "
            "This is most likely a classmethod in a cdef class method with binding=False. "
            "Try setting 'binding' to True.",
            method);
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
        PyTypeObject *d_type = GraalPyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, GraalPyMethodDescrObject_GetMethod(method));
#elif CYTHON_COMPILING_IN_GRAAL
        PyTypeObject *d_type = PyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, PyMethodDescrObject_GetMethod(method));
#else
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        PyTypeObject *d_type = descr->d_common.d_type;
        return PyDescr_NewClassMethod(d_type, descr->d_method);
#endif
    }
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
#else
    {
        PyObject *func=NULL;
        PyObject *builtins, *classmethod, *classmethod_str, *result=NULL;
        if (__Pyx_TypeCheck(method, __pyx_mstate_global->__Pyx_CachedMethodType)) {
            func = PyObject_GetAttrString(method, "__func__");
            if (!func) goto bad;
        } else {
            func = method;
            Py_INCREF(func);
        }
        builtins = PyEval_GetBuiltins(); // borrowed
        if (unlikely(!builtins)) goto bad;
        classmethod_str = PyUnicode_FromString("classmethod");
        if (unlikely(!classmethod_str)) goto bad;
        classmethod = PyObject_GetItem(builtins, classmethod_str);
        Py_DECREF(classmethod_str);
        if (unlikely(!classmethod)) goto bad;
        result = PyObject_CallFunctionObjArgs(classmethod, func, NULL);
        Py_DECREF(classmethod);
        bad:
        Py_XDECREF(func);
        return result;
    }
#endif
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_mstate_global->__pyx_n_u_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CheckUnpickleChecksum */
static void __Pyx_RaiseUnpickleChecksumError(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    PyObject *pickle_module = PyImport_ImportModule("pickle");
    if (unlikely(!pickle_module)) return;
    PyObject *pickle_error = PyObject_GetAttrString(pickle_module, "PickleError");
    Py_DECREF(pickle_module);
    if (unlikely(!pickle_error)) return;
    if (checksum2 == checksum1) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x) = (%s))",
            checksum, checksum1, members);
    } else if (checksum3 == checksum2) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, members);
    } else {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, checksum3, members);
    }
    Py_DECREF(pickle_error);
}
static int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    int found = 0;
    found |= checksum1 == checksum;
    found |= checksum2 == checksum;
    found |= checksum3 == checksum;
    if (likely(found))
        return 0;
    __Pyx_RaiseUnpickleChecksumError(checksum, checksum1, checksum2, checksum3, members);
    return -1;
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From___pyx_anon_enum(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_enum____pyx_t_9cysystemd_6reader_MATCHER_OPERATION(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION neg_one = (enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION) -1, const_zero = (enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(enum __pyx_t_9cysystemd_6reader_MATCHER_OPERATION));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE uint8_t __Pyx_PyLong_As_uint8_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint8_t neg_one = (uint8_t) -1, const_zero = (uint8_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        uint8_t val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (uint8_t) -1;
        val = __Pyx_PyLong_As_uint8_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint8_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(uint8_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) >= 2 * PyLong_SHIFT)) {
                            return (uint8_t) (((((uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint8_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) >= 3 * PyLong_SHIFT)) {
                            return (uint8_t) (((((((uint8_t)digits[2]) << PyLong_SHIFT) | (uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint8_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) >= 4 * PyLong_SHIFT)) {
                            return (uint8_t) (((((((((uint8_t)digits[3]) << PyLong_SHIFT) | (uint8_t)digits[2]) << PyLong_SHIFT) | (uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (uint8_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(uint8_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint8_t, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(uint8_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint8_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint8_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(uint8_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint8_t) (((uint8_t)-1)*(((((uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(uint8_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint8_t) ((((((uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(uint8_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint8_t) (((uint8_t)-1)*(((((((uint8_t)digits[2]) << PyLong_SHIFT) | (uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint8_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint8_t) ((((((((uint8_t)digits[2]) << PyLong_SHIFT) | (uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(uint8_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint8_t) (((uint8_t)-1)*(((((((((uint8_t)digits[3]) << PyLong_SHIFT) | (uint8_t)digits[2]) << PyLong_SHIFT) | (uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint8_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint8_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint8_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint8_t) ((((((((((uint8_t)digits[3]) << PyLong_SHIFT) | (uint8_t)digits[2]) << PyLong_SHIFT) | (uint8_t)digits[1]) << PyLong_SHIFT) | (uint8_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(uint8_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint8_t, long, PyLong_AsLong(x))
        } else if ((sizeof(uint8_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint8_t, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        uint8_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (uint8_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (uint8_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (uint8_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (uint8_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(uint8_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((uint8_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(uint8_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((uint8_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((uint8_t) 1) << (sizeof(uint8_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (uint8_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to uint8_t");
    return (uint8_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to uint8_t");
    return (uint8_t) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE uint64_t __Pyx_PyLong_As_uint64_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint64_t neg_one = (uint64_t) -1, const_zero = (uint64_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        uint64_t val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (uint64_t) -1;
        val = __Pyx_PyLong_As_uint64_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint64_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(uint64_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) >= 2 * PyLong_SHIFT)) {
                            return (uint64_t) (((((uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint64_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) >= 3 * PyLong_SHIFT)) {
                            return (uint64_t) (((((((uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint64_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) >= 4 * PyLong_SHIFT)) {
                            return (uint64_t) (((((((((uint64_t)digits[3]) << PyLong_SHIFT) | (uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (uint64_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(uint64_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint64_t, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(uint64_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint64_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint64_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(uint64_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint64_t) (((uint64_t)-1)*(((((uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(uint64_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint64_t) ((((((uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(uint64_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint64_t) (((uint64_t)-1)*(((((((uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint64_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint64_t) ((((((((uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(uint64_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint64_t) (((uint64_t)-1)*(((((((((uint64_t)digits[3]) << PyLong_SHIFT) | (uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint64_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint64_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint64_t) ((((((((((uint64_t)digits[3]) << PyLong_SHIFT) | (uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(uint64_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint64_t, long, PyLong_AsLong(x))
        } else if ((sizeof(uint64_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint64_t, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        uint64_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (uint64_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (uint64_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (uint64_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (uint64_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(uint64_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((uint64_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(uint64_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((uint64_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((uint64_t) 1) << (sizeof(uint64_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (uint64_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to uint64_t");
    return (uint64_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to uint64_t");
    return (uint64_t) -1;
}

/* CIntFromPy */
static CYTHON_INLINE uint32_t __Pyx_PyLong_As_uint32_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint32_t neg_one = (uint32_t) -1, const_zero = (uint32_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        uint32_t val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (uint32_t) -1;
        val = __Pyx_PyLong_As_uint32_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint32_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(uint32_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) >= 2 * PyLong_SHIFT)) {
                            return (uint32_t) (((((uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint32_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) >= 3 * PyLong_SHIFT)) {
                            return (uint32_t) (((((((uint32_t)digits[2]) << PyLong_SHIFT) | (uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint32_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) >= 4 * PyLong_SHIFT)) {
                            return (uint32_t) (((((((((uint32_t)digits[3]) << PyLong_SHIFT) | (uint32_t)digits[2]) << PyLong_SHIFT) | (uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (uint32_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(uint32_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint32_t, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(uint32_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint32_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint32_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(uint32_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint32_t) (((uint32_t)-1)*(((((uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(uint32_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint32_t) ((((((uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(uint32_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint32_t) (((uint32_t)-1)*(((((((uint32_t)digits[2]) << PyLong_SHIFT) | (uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint32_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint32_t) ((((((((uint32_t)digits[2]) << PyLong_SHIFT) | (uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(uint32_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint32_t) (((uint32_t)-1)*(((((((((uint32_t)digits[3]) << PyLong_SHIFT) | (uint32_t)digits[2]) << PyLong_SHIFT) | (uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint32_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint32_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint32_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint32_t) ((((((((((uint32_t)digits[3]) << PyLong_SHIFT) | (uint32_t)digits[2]) << PyLong_SHIFT) | (uint32_t)digits[1]) << PyLong_SHIFT) | (uint32_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(uint32_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint32_t, long, PyLong_AsLong(x))
        } else if ((sizeof(uint32_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint32_t, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        uint32_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (uint32_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (uint32_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (uint32_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (uint32_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(uint32_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((uint32_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(uint32_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((uint32_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((uint32_t) 1) << (sizeof(uint32_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (uint32_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to uint32_t");
    return (uint32_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to uint32_t");
    return (uint32_t) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint32_t(uint32_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint32_t neg_one = (uint32_t) -1, const_zero = (uint32_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint32_t) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint32_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(uint32_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint32_t) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint32_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(uint32_t),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(uint32_t));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint8_t(uint8_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint8_t neg_one = (uint8_t) -1, const_zero = (uint8_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint8_t) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint8_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(uint8_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint8_t) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint8_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(uint8_t),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(uint8_t));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint64_t(uint64_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint64_t neg_one = (uint64_t) -1, const_zero = (uint64_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint64_t) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint64_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(uint64_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint64_t) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint64_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(uint64_t),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(uint64_t));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyLong_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyLong_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 2 * PyLong_SHIFT)) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 3 * PyLong_SHIFT)) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 4 * PyLong_SHIFT)) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (size_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(size_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(size_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
        } else if ((sizeof(size_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        size_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (size_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (size_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (size_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (size_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(size_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((size_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(size_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((size_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((size_t) 1) << (sizeof(size_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (size_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* UpdateUnpickledDict */
static int __Pyx__UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    PyObject *state_dict = __Pyx_PySequence_ITEM(state, index);
    if (unlikely(!state_dict)) {
        return -1;
    }
    int non_empty = PyObject_IsTrue(state_dict);
    if (non_empty == 0) {
        Py_DECREF(state_dict);
        return 0;
    } else if (unlikely(non_empty == -1)) {
        return -1;
    }
    PyObject *dict;
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    dict = PyObject_GetAttrString(obj, "__dict__");
    #else
    dict = PyObject_GenericGetDict(obj, NULL);
    #endif
    if (unlikely(!dict)) {
        Py_DECREF(state_dict);
        return -1;
    }
    int result;
    if (likely(PyDict_CheckExact(dict))) {
        result = PyDict_Update(dict, state_dict);
    } else {
        PyObject *obj_result = __Pyx_PyObject_CallMethod1(dict, __pyx_mstate_global->__pyx_n_u_update, state_dict);
        if (likely(obj_result)) {
            Py_DECREF(obj_result);
            result = 0;
        } else {
            result = -1;
        }
    }
    Py_DECREF(state_dict);
    Py_DECREF(dict);
    return result;
}
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    Py_ssize_t state_size = __Pyx_PyTuple_GET_SIZE(state);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(state_size == -1)) return -1;
    #endif
    if (state_size <= index) {
        return 0;
    }
    return __Pyx__UpdateUnpickledDict(obj, state, index);
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__9);
    }
    goto done;
}
#endif

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* IterNextPlain (used by CoroutineBase) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void) {
    if (unlikely(!__pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache))
        __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache = __Pyx_GetBuiltinName(__pyx_mstate_global->__pyx_n_u_next);
    return __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator) {
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    PyObject *result;
    PyObject *next = __Pyx_GetBuiltinNext_LimitedAPI();
    if (unlikely(!next)) return NULL;
    result = PyObject_CallFunctionObjArgs(next, iterator, NULL);
    return result;
#else
    (void)__Pyx_GetBuiltinName; // only for early limited API
    iternextfunc iternext = __Pyx_PyObject_GetIterNextFunc(iterator);
    assert(iternext);
    return iternext(iterator);
#endif
}

/* ReturnWithStopIteration (used by CoroutineBase) */
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async);
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext) {
    if (value == Py_None) {
        if (async || !iternext)
            PyErr_SetNone(async ? PyExc_StopAsyncIteration : PyExc_StopIteration);
        return;
    }
    __Pyx__ReturnWithStopIteration(value, async);
}
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async) {
#if CYTHON_COMPILING_IN_CPYTHON
    __Pyx_PyThreadState_declare
#endif
    PyObject *exc;
    PyObject *exc_type = async ? PyExc_StopAsyncIteration : PyExc_StopIteration;
#if CYTHON_COMPILING_IN_CPYTHON
    if ((PY_VERSION_HEX >= (0x030C00A6)) || unlikely(PyTuple_Check(value) || PyExceptionInstance_Check(value))) {
        if (PY_VERSION_HEX >= (0x030e00A1)) {
            exc = __Pyx_PyObject_CallOneArg(exc_type, value);
        } else {
            PyObject *args_tuple = PyTuple_New(1);
            if (unlikely(!args_tuple)) return;
            Py_INCREF(value);
            PyTuple_SET_ITEM(args_tuple, 0, value);
            exc = PyObject_Call(exc_type, args_tuple, NULL);
            Py_DECREF(args_tuple);
        }
        if (unlikely(!exc)) return;
    } else {
        Py_INCREF(value);
        exc = value;
    }
    #if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    #if CYTHON_USE_EXC_INFO_STACK
    if (!__pyx_tstate->exc_info->exc_value)
    #else
    if (!__pyx_tstate->exc_type)
    #endif
    {
        Py_INCREF(exc_type);
        __Pyx_ErrRestore(exc_type, exc, NULL);
        return;
    }
    #endif
#else
    exc = __Pyx_PyObject_CallOneArg(exc_type, value);
    if (unlikely(!exc)) return;
#endif
    PyErr_SetObject(exc_type, exc);
    Py_DECREF(exc);
}

/* CoroutineBase (used by Generator) */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6 && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#endif // CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void
__Pyx_Coroutine_Undelegate(__pyx_CoroutineObject *gen) {
#if CYTHON_USE_AM_SEND
    gen->yieldfrom_am_send = NULL;
#endif
    Py_CLEAR(gen->yieldfrom);
}
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
            value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
            if (unlikely(!value)) goto limited_api_failure;
            #else
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            #endif
            Py_DECREF(ev);
        }
        else if (unlikely(PyTuple_Check(ev))) {
            Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(ev);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely(tuple_size < 0)) {
                Py_XDECREF(tb);
                Py_DECREF(ev);
                Py_DECREF(et);
                return -1;
            }
            #endif
            if (tuple_size >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#elif CYTHON_ASSUME_SAFE_MACROS
                value = PySequence_ITEM(ev, 0);
#else
                value = PySequence_GetItem(ev, 0);
                if (!value) goto limited_api_failure;
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
#else
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
#endif
    Py_DECREF(ev);
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!value)) return -1;
#endif
    *pvalue = value;
    return 0;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL || !CYTHON_ASSUME_SAFE_MACROS
  limited_api_failure:
    Py_XDECREF(et);
    Py_XDECREF(tb);
    Py_XDECREF(ev);
    return -1;
#endif
}
static CYTHON_INLINE
__Pyx_PySendResult __Pyx_Coroutine_status_from_result(PyObject **retval) {
    if (*retval) {
        return PYGEN_NEXT;
    } else if (likely(__Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, retval) == 0)) {
        return PYGEN_RETURN;
    } else {
        return PYGEN_ERROR;
    }
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
static void __Pyx_Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
__Pyx_PySendResult __Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, PyObject **result, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(__Pyx_Coroutine_get_is_running(self));  // Callers should ensure is_running
    if (unlikely(self->resume_label == -1)) {
        __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
        return PYGEN_ERROR;
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    retval = self->body(self, tstate, value);
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    *result = retval;
    if (self->resume_label == -1) {
        return likely(retval) ? PYGEN_RETURN : PYGEN_ERROR;
    }
    return PYGEN_NEXT;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
#define __Pyx_Coroutine_MethodReturnFromResult(gen, result, retval, iternext)\
    ((result) == PYGEN_NEXT ? (retval) : __Pyx__Coroutine_MethodReturnFromResult(gen, result, retval, iternext))
static PyObject *
__Pyx__Coroutine_MethodReturnFromResult(PyObject* gen, __Pyx_PySendResult result, PyObject *retval, int iternext) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (likely(result == PYGEN_RETURN)) {
        int is_async = 0;
        #ifdef __Pyx_AsyncGen_USED
        is_async = __Pyx_AsyncGen_CheckExact(gen);
        #endif
        __Pyx_ReturnWithStopIteration(retval, is_async, iternext);
        Py_XDECREF(retval);
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE __Pyx_PySendResult
__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen, PyObject** retval) {
    __Pyx_PySendResult result;
    PyObject *val = NULL;
    assert(__Pyx_Coroutine_get_is_running(gen));
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    result = __Pyx_Coroutine_SendEx(gen, val, retval, 0);
    Py_XDECREF(val);
    return result;
}
#if CYTHON_USE_AM_SEND
static __Pyx_PySendResult
__Pyx_Coroutine_SendToDelegate(__pyx_CoroutineObject *gen, __Pyx_pyiter_sendfunc gen_am_send, PyObject *value, PyObject **retval) {
    PyObject *ret = NULL;
    __Pyx_PySendResult delegate_result, result;
    assert(__Pyx_Coroutine_get_is_running(gen));
    delegate_result = gen_am_send(gen->yieldfrom, value, &ret);
    if (delegate_result == PYGEN_NEXT) {
        assert (ret != NULL);
        *retval = ret;
        return PYGEN_NEXT;
    }
    assert (delegate_result != PYGEN_ERROR || ret == NULL);
    __Pyx_Coroutine_Undelegate(gen);
    result = __Pyx_Coroutine_SendEx(gen, ret, retval, 0);
    Py_XDECREF(ret);
    return result;
}
#endif
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result = __Pyx_Coroutine_AmSend(self, value, &retval);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
}
static __Pyx_PySendResult
__Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval) {
    __Pyx_PySendResult result;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, value, retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
      #if !CYTHON_USE_AM_SEND
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
      #endif
        {
            #if !CYTHON_COMPILING_IN_LIMITED_API || __PYX_LIMITED_VERSION_HEX >= 0x03080000
            if (value == Py_None && PyIter_Check(yf))
                ret = __Pyx_PyIter_Next_Plain(yf);
            else
            #endif
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_mstate_global->__pyx_n_u_send, value);
        }
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            *retval = ret;
            return PYGEN_NEXT;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, value, retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return result;
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    CYTHON_UNUSED_VAR(gen);
    assert(__Pyx_Coroutine_get_is_running(gen));
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        result = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf);
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    #endif
    {
        PyObject *meth;
        result = PYGEN_RETURN;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval)) {
                result = PYGEN_ERROR;
            }
        }
    }
    Py_XDECREF(retval);
    return result == PYGEN_ERROR ? -1 : 0;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, Py_None, &retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && (PY_VERSION_HEX < 0x030A00A3 || !CYTHON_USE_AM_SEND)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
            ret = __Pyx_PyIter_Next_Plain(yf);
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 1);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result;
    CYTHON_UNUSED_VAR(arg);
    result = __Pyx_Coroutine_Close(self, &retval);
    if (unlikely(result == PYGEN_ERROR))
        return NULL;
    Py_XDECREF(retval);
    Py_RETURN_NONE;
}
static __Pyx_PySendResult
__Pyx_Coroutine_Close(PyObject *self, PyObject **retval) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PySendResult result;
    PyObject *yf;
    int err = 0;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    yf = gen->yieldfrom;
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    result = __Pyx_Coroutine_SendEx(gen, NULL, retval, 1);
    if (result == PYGEN_ERROR) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_Coroutine_unset_is_running(gen);
        if (!__Pyx_PyErr_Occurred()) {
            return PYGEN_RETURN;
        } else if (likely(__Pyx_PyErr_ExceptionMatches2(PyExc_GeneratorExit, PyExc_StopIteration))) {
            __Pyx_PyErr_Clear();
            return PYGEN_RETURN;
        }
        return PYGEN_ERROR;
    } else if (likely(result == PYGEN_RETURN && *retval == Py_None)) {
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_RETURN;
    } else {
        const char *msg;
        Py_DECREF(*retval);
        *retval = NULL;
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
            msg = "async generator ignored GeneratorExit";
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_ERROR;
    }
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen)))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    yf = gen->yieldfrom;
    if (yf) {
        __Pyx_PySendResult result;
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                goto propagate_exception;
            goto throw_here;
        }
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    __Pyx_Coroutine_unset_is_running(gen);
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        Py_DECREF(yf);
        if (ret) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &ret);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, ret, 0);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
propagate_exception:
    {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, NULL, &retval, 0);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
    }
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, "throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    {
        int e = __Pyx_call_type_traverse((PyObject*)gen, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    #if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    if (gen->gi_weakreflist != NULL)
    #endif
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        {
            destructor del = __Pyx_PyObject_GetSlot(gen, tp_del, destructor);
            if (del) del(self);
        }
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
#if CYTHON_USE_TP_FINALIZE
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_Close(self, &retval);
        if (result == PYGEN_ERROR) {
            PyErr_WriteUnraisable(self);
        } else {
            Py_XDECREF(retval);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
}
#endif
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx__Coroutine_get_frame(__pyx_CoroutineObject *self)
{
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyObject *frame;
    #if PY_VERSION_HEX >= 0x030d0000
    Py_BEGIN_CRITICAL_SECTION(self);
    #endif
    frame = self->gi_frame;
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        PyObject *globals = PyDict_New();
        if (unlikely(!globals)) return NULL;
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            globals,                        /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        Py_DECREF(globals);
        if (unlikely(!frame))
            return NULL;
        if (unlikely(self->gi_frame)) {
            Py_DECREF(frame);
            frame = self->gi_frame;
        } else {
            self->gi_frame = frame;
        }
    }
    Py_INCREF(frame);
    #if PY_VERSION_HEX >= 0x030d0000
    Py_END_CRITICAL_SECTION();
    #endif
    return frame;
#else
    CYTHON_UNUSED_VAR(self);
    Py_RETURN_NONE;
#endif
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context) {
    CYTHON_UNUSED_VAR(context);
    PyObject *frame = self->gi_frame;
    if (frame)
        return __Pyx_NewRef(frame);
    return __Pyx__Coroutine_get_frame(self);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->yieldfrom_am_send = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_weakreflist = NULL;
#endif
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    gen->is_running = 1;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen) {
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    assert(gen->is_running);
    gen->is_running = 0;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
}
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure) {
    CYTHON_UNUSED_VAR(closure);
    char result = __Pyx_Coroutine_get_is_running((__pyx_CoroutineObject*)gen);
    if (result) Py_RETURN_TRUE;
    else Py_RETURN_FALSE;
}
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send) {
    Py_ssize_t ptr_offset = (char*)(type->tp_as_async) - (char*)type;
    if (ptr_offset < 0 || ptr_offset > type->tp_basicsize) {
        return;
    }
    memcpy((void*)static_amsend_methods, (void*)(type->tp_as_async), sizeof(*type->tp_as_async));
    static_amsend_methods->am_send = am_send;
    type->tp_as_async = __Pyx_SlotTpAsAsync(static_amsend_methods);
}
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    __Pyx_TypeName self_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE((PyObject*)self));
    PyErr_Format(PyExc_TypeError, "cannot pickle '" __Pyx_FMT_TYPENAME "' object",
                         self_type_name);
    __Pyx_DECREF_TypeName(self_type_name);
    return NULL;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {"__reduce_ex__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_O, 0},
    {"__reduce__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_NOARGS, 0},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {"gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     PyDoc_STR("object being iterated by 'yield from', or None")},
    {"gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {"__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {"__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     PyDoc_STR("name of the generator"), 0},
    {"__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     PyDoc_STR("qualified name of the generator"), 0},
    {"gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     PyDoc_STR("Frame of the generator"), 0},
    {"gi_running", __Pyx_Coroutine_get_is_running_getter, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) PyObject_GenericGetAttr},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    {Py_am_send, (void *)__Pyx_Coroutine_AmSend},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_WEAKREF |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | __Pyx_TPFLAGS_HAVE_AM_SEND,
    __pyx_GeneratorType_slots
};
#if __PYX_HAS_PY_AM_SEND == 2
static __Pyx_PyAsyncMethodsStruct __pyx_Generator_as_async;
#endif
static int __pyx_Generator_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_GeneratorType_spec, NULL);
    if (unlikely(!mstate->__pyx_GeneratorType)) {
        return -1;
    }
#if __PYX_HAS_PY_AM_SEND == 2
    __Pyx_SetBackportTypeAmSend(mstate->__pyx_GeneratorType, &__pyx_Generator_as_async, &__Pyx_Coroutine_AmSend);
#endif
    return 0;
}
static PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *retval = NULL;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    __Pyx_Coroutine_unset_is_running(gen);
    (void) result;
    assert (result == PYGEN_RETURN || result == PYGEN_ERROR);
    assert ((result == PYGEN_RETURN && retval != NULL) || (result == PYGEN_ERROR && retval == NULL));
    return retval;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
